/* This file is generated with usbsnoop2libusb.pl from a usbsnoop log file. */
/* Latest version of the script should be in http://iki.fi/lindi/usb/usbsnoop2libusb.pl */
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <assert.h>
#include <signal.h>
#include <ctype.h>
#include <usb.h>
#if 0
 #include <linux/usbdevice_fs.h>
 #define LIBUSB_AUGMENT
 #include "libusb_augment.h"
#endif

struct usb_dev_handle *devh;

void release_usb_device(int dummy) {
    int ret;
    ret = usb_release_interface(devh, 0);
    if (!ret)
	printf("failed to release interface: %d\n", ret);
    usb_close(devh);
    if (!ret)
	printf("failed to close interface: %d\n", ret);
    exit(1);
}

void list_devices() {
    struct usb_bus *bus;
    for (bus = usb_get_busses(); bus; bus = bus->next) {
	struct usb_device *dev;
	
	for (dev = bus->devices; dev; dev = dev->next)
	    printf("0x%04x 0x%04x\n",
		   dev->descriptor.idVendor,
		   dev->descriptor.idProduct);
    }
}    

struct usb_device *find_device(int vendor, int product) {
    struct usb_bus *bus;
    
    for (bus = usb_get_busses(); bus; bus = bus->next) {
	struct usb_device *dev;
	
	for (dev = bus->devices; dev; dev = dev->next) {
	    if (dev->descriptor.idVendor == vendor
		&& dev->descriptor.idProduct == product)
		return dev;
	}
    }
    return NULL;
}

void print_bytes(char *bytes, int len) {
    int i;
    if (len > 0) {
	for (i=0; i<len; i++) {
	    printf("%02x ", (int)((unsigned char)bytes[i]));
	}
	printf("\"");
        for (i=0; i<len; i++) {
	    printf("%c", isprint(bytes[i]) ? bytes[i] : '.');
        }
        printf("\"");
    }
}


int main(int argc, char **argv) {
    int ret, vendor, product;
    struct usb_device *dev;
    char buf[65535], *endptr;
#if 0
    usb_urb *isourb;
    struct timeval isotv;
    char isobuf[32768];
#endif

    usb_init();
    usb_set_debug(255);
    usb_find_busses();
    usb_find_devices();

    if (argc!=3) {
	printf("usage: %s vendorID productID\n", argv[0]);
	printf("ID numbers of currently attached devices:\n");
	list_devices();
	exit(1);
    }
    vendor = strtol(argv[1], &endptr, 16);
    if (*endptr != '\0') {
	printf("invalid vendor id\n");
	exit(1);
    }
    product = strtol(argv[2], &endptr, 16);
    if (*endptr != '\0') {
	printf("invalid product id\n");
	exit(1);
    }
    dev = find_device(vendor, product);
    assert(dev);

    devh = usb_open(dev);
    assert(devh);
    
    signal(SIGTERM, release_usb_device);

/*    ret = usb_get_driver_np(devh, 0, buf, sizeof(buf));
    printf("usb_get_driver_np returned %d\n", ret);
    if (ret == 0) {
	printf("interface 0 already claimed by driver \"%s\", attempting to detach it\n", buf);
	ret = usb_detach_kernel_driver_np(devh, 0);
	printf("usb_detach_kernel_driver_np returned %d\n", ret);
    }
*/    ret = usb_claim_interface(devh, 0);
    if (ret != 0) {
	printf("claim failed with error %d\n", ret);
		exit(1);
    }
    
    ret = usb_set_altinterface(devh, 0);
    assert(ret >= 0);

    FILE *file;
    file = fopen( "tmpfile.raw", "wb" );

memcpy(buf, "\x04\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("7943 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x8b\x03\x8b\x03", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("7944 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("7945 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x04\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("7946 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(186*1000);
memcpy(buf, "\x04\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("7947 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x03\x8b\x03", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("7948 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("7949 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x04\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("7950 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(28*1000);
memcpy(buf, "\x04\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("7951 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x82\x00\x83\x38\x84\x8e\x85\xe3", 0x0000008);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000008, 1000);
printf("7952 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x01\x5f\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("7953 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x60\x08\x61\x0b\x62\x0e\x63\x11\x64\x14\x65\x17\x66\x02\x67\x05\x68\x08\xd4\x00\xd5\x8e\xd6\xe3\xd7\x38\xec\x00\xed\x00\xee\xc0\xef\x00\xf0\x00\xf1\x00\xf2\x00\xf3\x30", 0x000002a);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x000002a, 1000);
printf("7954 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("7955 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("7956 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("7957 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xf4\x00\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("7958 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(15*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("7959 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("7960 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xf3\x21\xf4\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("7961 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xf3\xf3\xf3\xf3", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000005, 0x0000000, buf, 0x0000004, 1000);
printf("7962 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xf3\xf3\xf3\xf3", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000c0, 0x0000000, buf, 0x0000004, 1000);
printf("7963 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(14*1000);
memcpy(buf, "\x02\xa0\x05\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("7964 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(5*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("7965 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x8b\x03\x8b\x03", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("7966 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("7967 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x02\xa0\x36\x02\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("7968 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(6*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("7969 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xa0\x46\x02\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("7970 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(6*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("7971 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(12*1000);
memcpy(buf, "\x8b\x00\x8b\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("7972 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("7973 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x00\x8b\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("7974 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("7975 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x96\x21\x96\x21", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("7976 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xf3\x32\xfd\x94\xfe\x11\xa6\x4d\xf6\x00\x96\x21\xe4\x01\xe2\x32\xe3\x00\xe4\x00\x95\xa7\xf4\x01", 0x0000018);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000018, 1000);
printf("7977 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("7978 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("7979 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(53*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("7980 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("7981 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x0b\x8b\x0b", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("7982 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("7983 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x0a\x8b\x0a", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("7984 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("7985 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(5*1000);
memcpy(buf, "\x8b\x09\x8b\x09", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("7986 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("7987 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x96\x21\x96\x21", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("7988 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(5*1000);
memcpy(buf, "\x9a\x02\x9a\x02", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("7989 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x00\x01\x02\x0f", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("7990 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x96\x21\x96\x21", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("7991 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(699*1000);
memcpy(buf, "\xf4\x00\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("7992 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(19*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("7993 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("7994 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x96\x23\x96\x23", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("7995 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa0\x00\xa1\xf4\xa2\x0f\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x10\x7e\x00\x7f\x00", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("7996 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(19*1000);
memcpy(buf, "\x00\x10\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000002, 0x0000000, buf, 0x0000004, 1000);
printf("7997 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x46\x22\x46\x22\x46\x22\x46\x22\x46\x22\x46\x22\x46\x22\x46\x22\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x46\x22\x46\x22\x46\x22\x46\x22\x46\x22\x46\x22\x46\x22\x46\x22\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x46\x22\x46\x22\x46\x22\x46\x22\x46\x22\x46\x22\x46\x22\x46\x22\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x46\x22\x46\x22\x46\x22\x46\x22\x46\x22\x46\x22\x46\x22\x46\x22\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0001000);
ret = usb_bulk_write(devh, 0x00000001, buf, 0x0001000, 1245);
printf("7998 bulk write returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000005, 0x0000000, buf, 0x0000004, 1000);
printf("7999 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000c0, 0x0000000, buf, 0x0000004, 1000);
printf("8000 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(17*1000);
memcpy(buf, "\xa0\x00\xa1\x00\xa2\x00\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x01\x7e\x00\x79\x40", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("8001 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x00\x02\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8002 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000200, 1030);
printf("8003 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x5f\x02\x5f\x02", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8004 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa0\x01\xa0\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8005 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8006 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x02\x5f\x02", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8007 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa1\x00\xa2\x24\xa1\x00\xa2\x22\xa1\x00\xa2\x1a\xa1\x00\xa2\x23\xa1\x00\xa2\x24\xa1\x00\xa2\x22\xa1\x00\xa2\x1a\xa1\x00\xa2\x23\xa1\x00\xa2\x24\xa1\x00\xa2\x22\xa1\x00\xa2\x1a\xa1\x00\xa2\x23\xa1\x00\xa2\x24\xa1\x00\xa2\x22\xa1\x00\xa2\x1a\xa1\x00\xa2\x23", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("8008 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(5*1000);
memcpy(buf, "\xa1\x00\xa2\x24\xa1\x00\xa2\x22\xa1\x00\xa2\x1a\xa1\x00\xa2\x23\xa1\x00\xa2\x24\xa1\x00\xa2\x22\xa1\x00\xa2\x1a\xa1\x00\xa2\x23\xa1\x00\xa2\x24\xa1\x00\xa2\x22\xa1\x00\xa2\x1a\xa1\x00\xa2\x23\xa1\x00\xa2\x24\xa1\x00\xa2\x22\xa1\x00\xa2\x1a\xa1\x00\xa2\x23", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("8009 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\xa1\x00\xa2\x24\xa1\x00\xa2\x22\xa1\x00\xa2\x1a\xa1\x00\xa2\x23\xa1\x00\xa2\x24\xa1\x00\xa2\x22\xa1\x00\xa2\x1a\xa1\x00\xa2\x23\xa1\x00\xa2\x24\xa1\x00\xa2\x22\xa1\x00\xa2\x1a\xa1\x00\xa2\x23\xa1\x00\xa2\x24\xa1\x00\xa2\x22\xa1\x00\xa2\x1a\xa1\x00\xa2\x23", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("8010 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8011 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x02\x5f\x02", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8012 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa0\x00\xa0\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8013 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8014 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x01\x5f\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8015 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x60\x08\x61\x0b\x62\x0e\x63\x11\x64\x14\x65\x17\x66\x02\x67\x05\x68\x08\x69\x50\x6a\x01\x6b\x0c\x6d\x48\x6e\x55\x6f\x0e\x70\x50\x71\x55\x72\x0e\x73\xe8\x74\x57\x75\x0e\x76\xf0\x77\x57\x78\x0e\x79\x48\x7a\x2b\x7b\x0e\x7c\x50\x7d\x2b\x7e\x0e\x7f\xe8\x80\x2d", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("8016 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(5*1000);
memcpy(buf, "\x81\x0e\x82\xf0\x83\x2d\x84\x0e\x85\x48\x86\x7f\x87\x0e\x88\x50\x89\x7f\x8a\x0e\x8b\xe8\x8c\x81\x8d\x0e\x8e\xf0\x8f\x81\x90\x0e\x9a\x00\x9b\x15\x9d\x01\x9e\x00\x9f\x00\xa0\x0e\xa1\x00\xa2\x2a\xa3\x0e\xa4\x00\xa5\x54\xa6\x0e\xa7\xff\xa8\x29\xa9\x0e\xaa\xff", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("8017 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\xab\x53\xac\x0e\xad\xff\xae\x7d\xaf\x0e\xb0\x50\xb1\x01\xb9\xff\xba\x14\xcd\x00\xce\x0f\xd4\x00\xd5\x8e\xd6\xe3\xd7\x38\xec\x00\xed\x00\xee\xc0\xef\x00\xf0\x00\xf1\x00\xf2\x00\xf3\x30\xf4\x00\xf5\x00\xf6\xfe\xf7\x14\xf8\xaa\xf9\x00\xfa\x55\xfb\x00\xfc\x2a", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("8018 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xfd\x00\xfd\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8019 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8020 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x02\x5f\x02", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8021 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x60\x00\x61\x00\x62\x00\x63\x00\x64\x00\x65\x00\x66\x00\x67\x00\x68\x00\x69\x00\x6a\x00\x6b\x00\x6c\x00\x6d\x00\x6e\x00\x6f\x00\x70\x40\x71\x05\x72\x00\x73\x40\x74\x05\x75\x00\x76\x40\x77\x05\x78\x00\x79\x40\x7a\x05\x7b\x00\x7c\x80\x7d\x0a\x7e\x00\x7f\x80", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("8022 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x80\x0a\x81\x00\x82\x80\x83\x0a\x84\x00\x85\x80\x86\x0a\x87\x00\x88\xc0\x89\x0f\x8a\x00\x8b\xc0\x8c\x0f\x8d\x00\x8e\xc0\x8f\x0f\x90\x00\x91\xc0\x92\x0f\x93\x00\xb0\x00\xb1\x00\xb2\x00\xb3\x00\xb4\x00\xb5\x00\xb6\x00\xb7\x00\xb8\x00\xb9\x00\xba\x00\xbb\x00", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("8023 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xbc\x00\xbd\x00\xbe\x00\xbf\x00\xc0\x00\xc1\x00\xc2\x00\xc3\x00\xc4\x00\xc5\x00\xc6\x00\xc7\x00\xc8\x00\xc9\x00\xca\x00\xcb\x00\xcc\x00\xcd\x00\xce\x00\xcf\x00", 0x0000028);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000028, 1000);
printf("8024 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8025 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x58\x01\x5e\x01\x82\x00\x83\x38\x84\x8e\x85\xe3\x8a\x00\x8e\x00\x90\x64\x91\x00\x94\x30\x95\xa7\x96\x23\x9b\x3d\x9d\x3f\x9e\x00\x9f\x80\xa0\x00\xa1\x00\xa2\x00\xa3\xff\xa4\xfe\xa5\x0d\xa6\x41\xab\x00\xae\x08\xaf\x00\xb0\x08\xb1\x07\xb2\x14\xb3\x01\xb4\x7b", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("8026 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xb5\x00\xb6\x70\xb7\x05\xc9\x00\xca\x00\xcb\x02\xcc\x00\xcd\x3c\xce\x3c\xcf\x3c\xd0\x07\xd8\x05\xd9\x3c\xda\x54\xdb\x00\xdc\x01\xde\x01\xdf\x17\xe0\x2c\xe1\x01\xe2\x00\xe3\x00\xe4\x00\xe5\xc8\xe6\x00\xe7\x00\xe8\x00\xe9\x00\xea\x2c\xeb\x01\xec\x08\xed\x00", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("8027 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xee\x18\xef\x08\xf0\x6a\xf1\x00\xf2\x00\xf3\x0c\xf5\x12\xf6\x00\xf7\x00\xf8\x02\xf9\x03\xfa\x36\xfb\xfb\xfc\x00\xfd\x46\xfe\x22\xff\xfc", 0x0000022);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000022, 1000);
printf("8028 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(149*1000);
memcpy(buf, "\xf8\x02\xf4\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8029 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8030 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8031 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8032 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8033 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(8*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8034 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8035 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8036 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8037 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(8*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8038 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8039 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8040 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(5*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8041 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(7*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8042 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8043 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8044 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8045 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(8*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8046 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8047 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8048 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8049 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(8*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8050 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8051 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8052 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8053 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(18*1000);
memcpy(buf, "\x7c\x00\x7d\x00\x7e\x04\x7f\x00", 0x0000008);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000008, 1000);
printf("8054 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x00\x00\x08\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8055 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(25*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8056 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8057 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8058 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8059 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8060 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(115*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8061 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(115*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8062 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(115*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8063 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(87*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0002000, 1491);
printf("8064 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(9*1000);
memcpy(buf, "\x7c\x01\x7d\x9d\x7e\x03\x7f\x00", 0x0000008);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000008, 1000);
printf("8065 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(6*1000);
memcpy(buf, "\x02\x3a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8066 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(25*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8067 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8068 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(120*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8069 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8070 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8071 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8072 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8073 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(89*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0005600, 2320);
printf("8074 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(24*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("8075 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(8*1000);
memcpy(buf, "\xf4\x00\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8076 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(19*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8077 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8078 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(43*1000);
memcpy(buf, "\x8b\x0b\x8b\x0b", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8079 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(5*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8080 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x8b\x0a\x8b\x0a", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8081 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8082 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x09\x8b\x09", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8083 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8084 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(6*1000);
memcpy(buf, "\x8b\x00\x8b\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8085 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8086 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x96\x21\x96\x21", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8087 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xf3\x21\xfd\xb8\xfe\x0b\xa6\x41\xf6\x00\xea\x00\xeb\xf0\xe2\x4d\xe3\x00\xe4\x00\xe0\x00\xe1\x00\xe5\x00\x96\x21\xf4\x01", 0x000001e);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x000001e, 1000);
printf("8088 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(13*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8089 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8090 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(55*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8091 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8092 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(53*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8093 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8094 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(30*1000);
memcpy(buf, "\x8b\x0b\x8b\x0b", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8095 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8096 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(5*1000);
memcpy(buf, "\x8b\x0a\x8b\x0a", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8097 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8098 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x09\x8b\x09", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8099 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8100 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(13*1000);
memcpy(buf, "\x96\x21\x96\x21", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8101 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x96\x21\x96\x21", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8102 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(21*1000);
memcpy(buf, "\xf4\x00\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8103 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8104 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8105 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x96\x23\x96\x23", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8106 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(5*1000);
memcpy(buf, "\xa0\x00\xa1\xf4\xa2\x0f\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x10\x7e\x00\x7f\x00", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("8107 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(17*1000);
memcpy(buf, "\x00\x10\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000002, 0x0000000, buf, 0x0000004, 1000);
printf("8108 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\xea\x41\xea\x41\xea\x41\xea\x41\xea\x41\xea\x41\xea\x41\xea\x41\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xea\x41\xea\x41\xea\x41\xea\x41\xea\x41\xea\x41\xea\x41\xea\x41\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xea\x41\xea\x41\xea\x41\xea\x41\xea\x41\xea\x41\xea\x41\xea\x41\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xea\x41\xea\x41\xea\x41\xea\x41\xea\x41\xea\x41\xea\x41\xea\x41\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0001000);
ret = usb_bulk_write(devh, 0x00000001, buf, 0x0001000, 1245);
printf("8109 bulk write returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000005, 0x0000000, buf, 0x0000004, 1000);
printf("8110 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000c0, 0x0000000, buf, 0x0000004, 1000);
printf("8111 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(17*1000);
memcpy(buf, "\xa0\x00\xa1\x00\xa2\x00\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x01\x7e\x00\x79\x40", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("8112 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x00\x02\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8113 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000200, 1030);
printf("8114 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x5f\x02\x5f\x02", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8115 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa0\x01\xa0\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8116 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8117 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x02\x5f\x02", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8118 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa1\x00\xa2\x24\xa1\x00\xa2\x22\xa1\x00\xa2\x1a\xa1\x00\xa2\x23\xa1\x00\xa2\x24\xa1\x00\xa2\x22\xa1\x00\xa2\x1a\xa1\x00\xa2\x23\xa1\x00\xa2\x24\xa1\x00\xa2\x22\xa1\x00\xa2\x1a\xa1\x00\xa2\x23\xa1\x00\xa2\x24\xa1\x00\xa2\x22\xa1\x00\xa2\x1a\xa1\x00\xa2\x23", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("8119 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa1\x00\xa2\x24\xa1\x00\xa2\x22\xa1\x00\xa2\x1a\xa1\x00\xa2\x23\xa1\x00\xa2\x24\xa1\x00\xa2\x22\xa1\x00\xa2\x1a\xa1\x00\xa2\x23\xa1\x00\xa2\x24\xa1\x00\xa2\x22\xa1\x00\xa2\x1a\xa1\x00\xa2\x23\xa1\x00\xa2\x24\xa1\x00\xa2\x22\xa1\x00\xa2\x1a\xa1\x00\xa2\x23", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("8120 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa1\x00\xa2\x24\xa1\x00\xa2\x22\xa1\x00\xa2\x1a\xa1\x00\xa2\x23\xa1\x00\xa2\x24\xa1\x00\xa2\x22\xa1\x00\xa2\x1a\xa1\x00\xa2\x23\xa1\x00\xa2\x24\xa1\x00\xa2\x22\xa1\x00\xa2\x1a\xa1\x00\xa2\x23\xa1\x00\xa2\x24\xa1\x00\xa2\x22\xa1\x00\xa2\x1a\xa1\x00\xa2\x23", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("8121 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8122 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x02\x5f\x02", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8123 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa0\x00\xa0\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8124 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8125 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x01\x5f\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8126 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x60\x08\x61\x0b\x62\x0e\x63\x11\x64\x14\x65\x17\x66\x02\x67\x05\x68\x08\x69\x50\x6a\x01\x6b\x0c\x6d\x48\x6e\x55\x6f\x0e\x70\x50\x71\x55\x72\x0e\x73\xe8\x74\x57\x75\x0e\x76\xf0\x77\x57\x78\x0e\x79\x48\x7a\x2b\x7b\x0e\x7c\x50\x7d\x2b\x7e\x0e\x7f\xe8\x80\x2d", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("8127 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x81\x0e\x82\xf0\x83\x2d\x84\x0e\x85\x48\x86\x7f\x87\x0e\x88\x50\x89\x7f\x8a\x0e\x8b\xe8\x8c\x81\x8d\x0e\x8e\xf0\x8f\x81\x90\x0e\x9a\x00\x9b\x15\x9d\x01\x9e\x00\x9f\x00\xa0\x0e\xa1\x00\xa2\x2a\xa3\x0e\xa4\x00\xa5\x54\xa6\x0e\xa7\xff\xa8\x29\xa9\x0e\xaa\xff", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("8128 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xab\x53\xac\x0e\xad\xff\xae\x7d\xaf\x0e\xb0\x50\xb1\x01\xb9\xff\xba\x14\xcd\x00\xce\x0f\xd4\x00\xd5\x8e\xd6\xe3\xd7\x38\xec\x00\xed\x00\xee\xc0\xef\x00\xf0\x00\xf1\x00\xf2\x00\xf3\x30\xf4\x00\xf5\x00\xf6\xfe\xf7\x14\xf8\xaa\xf9\x00\xfa\x55\xfb\x00\xfc\x2a", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("8129 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xfd\x00\xfd\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8130 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8131 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x02\x5f\x02", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8132 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x60\x00\x61\x00\x62\x00\x63\x00\x64\x00\x65\x00\x66\x00\x67\x00\x68\x00\x69\x00\x6a\x00\x6b\x00\x6c\x00\x6d\x00\x6e\x00\x6f\x00\x70\x40\x71\x05\x72\x00\x73\x40\x74\x05\x75\x00\x76\x40\x77\x05\x78\x00\x79\x40\x7a\x05\x7b\x00\x7c\x80\x7d\x0a\x7e\x00\x7f\x80", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("8133 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x80\x0a\x81\x00\x82\x80\x83\x0a\x84\x00\x85\x80\x86\x0a\x87\x00\x88\xc0\x89\x0f\x8a\x00\x8b\xc0\x8c\x0f\x8d\x00\x8e\xc0\x8f\x0f\x90\x00\x91\xc0\x92\x0f\x93\x00\xb0\x00\xb1\x00\xb2\x00\xb3\x00\xb4\x00\xb5\x00\xb6\x00\xb7\x00\xb8\x00\xb9\x00\xba\x00\xbb\x00", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("8134 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xbc\x00\xbd\x00\xbe\x00\xbf\x00\xc0\x00\xc1\x00\xc2\x00\xc3\x00\xc4\x00\xc5\x00\xc6\x00\xc7\x00\xc8\x00\xc9\x00\xca\x00\xcb\x00\xcc\x00\xcd\x00\xce\x00\xcf\x00", 0x0000028);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000028, 1000);
printf("8135 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8136 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x58\x01\x5e\x01\x82\x00\x83\x38\x84\x8e\x85\xe3\x8a\x00\x8e\x00\x90\x64\x91\x00\x94\x30\x95\xa7\x96\x23\x9b\x3d\x9d\x3f\x9e\x00\x9f\x80\xa0\x00\xa1\x00\xa2\x00\xa3\xff\xa4\xfe\xa5\x0d\xa6\x41\xab\x00\xae\x08\xaf\x00\xb0\x10\xb1\x0e\xb2\x14\xb3\x01\xb4\x7b", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("8137 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xb5\x00\xb6\x70\xb7\x05\xc9\x00\xca\x00\xcb\x02\xcc\x00\xcd\x3c\xce\x3c\xcf\x3c\xd0\x07\xd8\x05\xd9\x3c\xda\x54\xdb\x00\xdc\x01\xde\x01\xdf\x17\xe0\x2c\xe1\x01\xe2\x00\xe3\x00\xe4\x00\xe5\xc8\xe6\x00\xe7\x00\xe8\x00\xe9\x00\xea\x2c\xeb\x01\xec\x08\xed\x00", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("8138 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xee\x18\xef\x08\xf0\xa6\xf1\x00\xf2\x00\xf3\x0c\xf5\x12\xf6\x00\xf7\x00\xf8\x02\xf9\x03\xfa\x36\xfb\xfb\xfc\x00\xfd\xea\xfe\x41\xff\xfc", 0x0000022);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000022, 1000);
printf("8139 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(149*1000);
memcpy(buf, "\xf8\x02\xf4\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8140 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8141 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8142 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8143 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8144 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(8*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8145 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8146 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8147 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8148 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(8*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8149 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8150 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8151 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(5*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8152 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(7*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8153 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8154 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8155 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8156 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(9*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8157 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8158 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8159 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8160 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(9*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8161 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8162 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8163 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8164 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(7*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8165 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8166 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8167 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8168 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(9*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8169 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8170 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8171 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8172 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(9*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8173 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8174 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8175 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(5*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8176 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(8*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8177 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8178 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8179 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8180 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8181 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8182 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8183 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8184 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(8*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8185 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8186 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8187 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8188 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(19*1000);
memcpy(buf, "\x7c\x00\x7d\x00\x7e\x04\x7f\x00", 0x0000008);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000008, 1000);
printf("8189 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x00\x00\x08\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8190 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(24*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8191 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8192 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8193 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(115*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8194 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(116*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8195 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(107*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8196 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8197 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(114*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8198 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(84*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0002000, 1491);
printf("8199 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x00\x00\x08\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8200 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(26*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8201 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(114*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8202 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(116*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8203 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(115*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8204 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8205 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8206 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(114*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8207 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8208 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(85*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0002000, 1491);
printf("8209 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x00\x00\x08\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8210 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(33*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8211 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8212 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(118*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8213 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(117*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8214 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(163*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8215 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(106*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8216 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8217 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(118*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8218 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(89*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0002000, 1491);
printf("8219 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x7c\x23\x7d\xfb\x7e\x02\x7f\x00", 0x0000008);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000008, 1000);
printf("8220 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(7*1000);
memcpy(buf, "\x46\xf6\x05\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8221 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(25*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8222 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8223 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8224 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8225 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(107*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8226 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(115*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8227 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(89*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000e40, 1218);
printf("8228 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(5*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("8229 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\xf4\x00\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8230 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(19*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8231 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8232 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x96\x23\x96\x23", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8233 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(204*1000);
memcpy(buf, "\x8b\x00\x8b\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8234 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8235 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x96\x21\x96\x21", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8236 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xf3\x22\xfd\x94\xfe\x11\xa6\x41\xf6\x00\x96\x21\xe4\x01\xe2\x40\xe3\x1f\xe4\x00\x95\xa7\xf4\x01", 0x0000018);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000018, 1000);
printf("8237 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8238 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8239 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(49*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8240 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8241 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(47*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8242 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8243 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(47*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8244 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8245 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(47*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8246 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8247 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(47*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8248 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8249 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(46*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8250 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8251 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(46*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8252 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8253 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(46*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8254 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8255 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(47*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8256 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8257 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x0b\x8b\x0b", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8258 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8259 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x0a\x8b\x0a", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8260 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8261 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x09\x8b\x09", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8262 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8263 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x96\x21\x96\x21", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8264 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(49*1000);
memcpy(buf, "\x8b\x00\x8b\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8265 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8266 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x96\x21\x96\x21", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8267 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xf3\x32\xfd\x94\xfe\x11\xa6\x4d\xf6\x00\x96\x21\xe4\x01\xe2\x32\xe3\x00\xe4\x00\x95\xa7\xf4\x01", 0x0000018);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000018, 1000);
printf("8268 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8269 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(7*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8270 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(47*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8271 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8272 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x0b\x8b\x0b", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8273 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8274 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x0a\x8b\x0a", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8275 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8276 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x09\x8b\x09", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8277 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8278 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x96\x21\x96\x21", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8279 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(59*1000);
memcpy(buf, "\xa0\x00\xa1\x00\xa2\x80\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x06\x7e\x00\x7f\x00", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("8280 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x00\x06\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000002, 0x0000000, buf, 0x0000004, 1000);
printf("8281 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x00\x00\xff\x03\xff\x07\xff\x0b\xff\x0f\xff\x13\xff\x17\xff\x1b\xff\x1f\xff\x23\xff\x27\xff\x2b\xff\x2f\xff\x33\xff\x37\xff\x3b\xff\x3f\xff\x43\xff\x47\xfe\x4b\x47\x4f\x32\x51\x0f\x53\xe0\x54\xa6\x56\x60\x58\x10\x5a\xb7\x5b\x54\x5d\xe9\x5e\x76\x60\xfb\x61\x79\x63\xf0\x64\x61\x66\xcb\x67\x30\x69\x8e\x6a\xe7\x6b\x3b\x6d\x8a\x6e\xd4\x6f\x19\x71\x5a\x72\x96\x73\xce\x74\x03\x76\x33\x77\x60\x78\x89\x79\xae\x7a\xd0\x7b\xef\x7c\x0b\x7e\x23\x7f\x38\x80\x4b\x81\x5b\x82\x68\x83\x72\x84\x79\x85\x7f\x86\x81\x87\x81\x88\x7f\x89\x7a\x8a\x74\x8b\x6b\x8c\x60\x8d\x52\x8e\x43\x8f\x32\x90\x1f\x91\x0a\x92\xf3\x92\xda\x93\xbf\x94\xa3\x95\x85\x96\x65\x97\x44\x98\x21\x99\xfc\x99\xd6\x9a\xae\x9b\x85\x9c\x5b\x9d\x2f\x9e\x01\x9f\xd2\x9f\xa2\xa0\x70\xa1\x3d\xa2\x09\xa3\xd4\xa3\x9d\xa4\x65\xa5\x2c\xa6\xf1\xa6\xb6\xa7\x79\xa8\x3b\xa9\xfc\xa9\xbc\xaa\x7b\xab\x39\xac\xf6\xac\xb1\xad\x6c\xae\x26\xaf\xde\xaf\x96\xb0\x4d\xb1\x03\xb2\xb7\xb2\x6b\xb3\x1e\xb4\xd1\xb4\x82\xb5\x32\xb6\xe2\xb6\x90\xb7\x3e\xb8\xeb\xb8\x97\xb9\x43\xba\xed\xba\x97\xbb\x40\xbc\xe8\xbc\x90\xbd\x36\xbe\xdc\xbe\x82\xbf\x26\xc0\xca\xc0\x6d\xc1\x0f\xc2\xb1\xc2\x52\xc3\xf3\xc3\x92\xc4\x31\xc5\xd0\xc5\x6d\xc6\x0a\xc7\xa7\xc7\x43\xc8\xde\xc8\x79\xc9\x13\xca\xac\xca\x45\xcb\xdd\xcb\x75\xcc\x0c\xcd\xa2\xcd\x38\xce\xce\xce\x62\xcf\xf7\xcf\x8b\xd0\x1e\xd1\xb0\xd1\x43\xd2\xd4\xd2\x65\xd3\xf6\xd3\x86\xd4\x16\xd5\xa5\xd5\x34\xd6\xc2\xd6\x4f\xd7\xdd\xd7\x69\xd8\xf6\xd8\x81\xd9\x0d\xda\x98\xda\x22\xdb\xac\xdb\x36\xdc\xbf\xdc\x47\xdd\xcf\xdd\x57\xde\xdf\xde\x66\xdf\xec\xdf\x72\xe0\xf8\xe0\x7d\xe1\x02\xe2\x87\xe2\x0b\xe3\x8e\xe3\x12\xe4\x95\xe4\x17\xe5\x99\xe5\x1b\xe6\x9d\xe6\x1e\xe7\x9e\xe7\x1e\xe8\x9e\xe8\x1e\xe9\x9d\xe9\x1c\xea\x9a\xea\x19\xeb\x96\xeb\x14\xec\x91\xec\x0e\xed\x8a\xed\x06\xee\x82\xee\xfd\xee\x79\xef\xf3\xef\x6e\xf0\xe8\xf0\x62\xf1\xdb\xf1\x54\xf2\xcd\xf2\x46\xf3\xbe\xf3\x36\xf4\xae\xf4\x25\xf5\x9c\xf5\x13\xf6\x89\xf6\xff\xf6\x75\xf7\xeb\xf7\x60\xf8\xd5\xf8\x4a\xf9\xbe\xf9\x32\xfa\xa6\xfa\x1a\xfb\x8d\xfb\x00\xfc\x73\xfc\xe5\xfc\x58\xfd\xca\xfd\x3b\xfe\xad\xfe\x1e\xff\x8f\xff\x00\x00\xff\x03\xff\x07\xff\x0b\xff\x0f\xff\x13\xff\x17\xff\x1b\xff\x1f\xff\x23\xff\x27\xff\x2b\xff\x2f\xff\x33\xff\x37\xff\x3b\xff\x3f\xff\x43\xff\x47\xfe\x4b\x47\x4f\x32\x51\x0f\x53\xe0\x54\xa6\x56\x60\x58\x10\x5a\xb7\x5b\x54\x5d\xe9\x5e\x76\x60\xfb\x61\x79\x63\xf0\x64\x61\x66\xcb\x67\x30\x69\x8e\x6a\xe7\x6b\x3b\x6d\x8a\x6e\xd4\x6f\x19\x71\x5a\x72\x96\x73\xce\x74\x03\x76\x33\x77\x60\x78\x89\x79\xae\x7a\xd0\x7b\xef\x7c\x0b\x7e\x23\x7f\x38\x80\x4b\x81\x5b\x82\x68\x83\x72\x84\x79\x85\x7f\x86\x81\x87\x81\x88\x7f\x89\x7a\x8a\x74\x8b\x6b\x8c\x60\x8d\x52\x8e\x43\x8f\x32\x90\x1f\x91\x0a\x92\xf3\x92\xda\x93\xbf\x94\xa3\x95\x85\x96\x65\x97\x44\x98\x21\x99\xfc\x99\xd6\x9a\xae\x9b\x85\x9c\x5b\x9d\x2f\x9e\x01\x9f\xd2\x9f\xa2\xa0\x70\xa1\x3d\xa2\x09\xa3\xd4\xa3\x9d\xa4\x65\xa5\x2c\xa6\xf1\xa6\xb6\xa7\x79\xa8\x3b\xa9\xfc\xa9\xbc\xaa\x7b\xab\x39\xac\xf6\xac\xb1\xad\x6c\xae\x26\xaf\xde\xaf\x96\xb0\x4d\xb1\x03\xb2\xb7\xb2\x6b\xb3\x1e\xb4\xd1\xb4\x82\xb5\x32\xb6\xe2\xb6\x90\xb7\x3e\xb8\xeb\xb8\x97\xb9\x43\xba\xed\xba\x97\xbb\x40\xbc\xe8\xbc\x90\xbd\x36\xbe\xdc\xbe\x82\xbf\x26\xc0\xca\xc0\x6d\xc1\x0f\xc2\xb1\xc2\x52\xc3\xf3\xc3\x92\xc4\x31\xc5\xd0\xc5\x6d\xc6\x0a\xc7\xa7\xc7\x43\xc8\xde\xc8\x79\xc9\x13\xca\xac\xca\x45\xcb\xdd\xcb\x75\xcc\x0c\xcd\xa2\xcd\x38\xce\xce\xce\x62\xcf\xf7\xcf\x8b\xd0\x1e\xd1\xb0\xd1\x43\xd2\xd4\xd2\x65\xd3\xf6\xd3\x86\xd4\x16\xd5\xa5\xd5\x34\xd6\xc2\xd6\x4f\xd7\xdd\xd7\x69\xd8\xf6\xd8\x81\xd9\x0d\xda\x98\xda\x22\xdb\xac\xdb\x36\xdc\xbf\xdc\x47\xdd\xcf\xdd\x57\xde\xdf\xde\x66\xdf\xec\xdf\x72\xe0\xf8\xe0\x7d\xe1\x02\xe2\x87\xe2\x0b\xe3\x8e\xe3\x12\xe4\x95\xe4\x17\xe5\x99\xe5\x1b\xe6\x9d\xe6\x1e\xe7\x9e\xe7\x1e\xe8\x9e\xe8\x1e\xe9\x9d\xe9\x1c\xea\x9a\xea\x19\xeb\x96\xeb\x14\xec\x91\xec\x0e\xed\x8a\xed\x06\xee\x82\xee\xfd\xee\x79\xef\xf3\xef\x6e\xf0\xe8\xf0\x62\xf1\xdb\xf1\x54\xf2\xcd\xf2\x46\xf3\xbe\xf3\x36\xf4\xae\xf4\x25\xf5\x9c\xf5\x13\xf6\x89\xf6\xff\xf6\x75\xf7\xeb\xf7\x60\xf8\xd5\xf8\x4a\xf9\xbe\xf9\x32\xfa\xa6\xfa\x1a\xfb\x8d\xfb\x00\xfc\x73\xfc\xe5\xfc\x58\xfd\xca\xfd\x3b\xfe\xad\xfe\x1e\xff\x8f\xff\x00\x00\xff\x03\xff\x07\xff\x0b\xff\x0f\xff\x13\xff\x17\xff\x1b\xff\x1f\xff\x23\xff\x27\xff\x2b\xff\x2f\xff\x33\xff\x37\xff\x3b\xff\x3f\xff\x43\xff\x47\xfe\x4b\x47\x4f\x32\x51\x0f\x53\xe0\x54\xa6\x56\x60\x58\x10\x5a\xb7\x5b\x54\x5d\xe9\x5e\x76\x60\xfb\x61\x79\x63\xf0\x64\x61\x66\xcb\x67\x30\x69\x8e\x6a\xe7\x6b\x3b\x6d\x8a\x6e\xd4\x6f\x19\x71\x5a\x72\x96\x73\xce\x74\x03\x76\x33\x77\x60\x78\x89\x79\xae\x7a\xd0\x7b\xef\x7c\x0b\x7e\x23\x7f\x38\x80\x4b\x81\x5b\x82\x68\x83\x72\x84\x79\x85\x7f\x86\x81\x87\x81\x88\x7f\x89\x7a\x8a\x74\x8b\x6b\x8c\x60\x8d\x52\x8e\x43\x8f\x32\x90\x1f\x91\x0a\x92\xf3\x92\xda\x93\xbf\x94\xa3\x95\x85\x96\x65\x97\x44\x98\x21\x99\xfc\x99\xd6\x9a\xae\x9b\x85\x9c\x5b\x9d\x2f\x9e\x01\x9f\xd2\x9f\xa2\xa0\x70\xa1\x3d\xa2\x09\xa3\xd4\xa3\x9d\xa4\x65\xa5\x2c\xa6\xf1\xa6\xb6\xa7\x79\xa8\x3b\xa9\xfc\xa9\xbc\xaa\x7b\xab\x39\xac\xf6\xac\xb1\xad\x6c\xae\x26\xaf\xde\xaf\x96\xb0\x4d\xb1\x03\xb2\xb7\xb2\x6b\xb3\x1e\xb4\xd1\xb4\x82\xb5\x32\xb6\xe2\xb6\x90\xb7\x3e\xb8\xeb\xb8\x97\xb9\x43\xba\xed\xba\x97\xbb\x40\xbc\xe8\xbc\x90\xbd\x36\xbe\xdc\xbe\x82\xbf\x26\xc0\xca\xc0\x6d\xc1\x0f\xc2\xb1\xc2\x52\xc3\xf3\xc3\x92\xc4\x31\xc5\xd0\xc5\x6d\xc6\x0a\xc7\xa7\xc7\x43\xc8\xde\xc8\x79\xc9\x13\xca\xac\xca\x45\xcb\xdd\xcb\x75\xcc\x0c\xcd\xa2\xcd\x38\xce\xce\xce\x62\xcf\xf7\xcf\x8b\xd0\x1e\xd1\xb0\xd1\x43\xd2\xd4\xd2\x65\xd3\xf6\xd3\x86\xd4\x16\xd5\xa5\xd5\x34\xd6\xc2\xd6\x4f\xd7\xdd\xd7\x69\xd8\xf6\xd8\x81\xd9\x0d\xda\x98\xda\x22\xdb\xac\xdb\x36\xdc\xbf\xdc\x47\xdd\xcf\xdd\x57\xde\xdf\xde\x66\xdf\xec\xdf\x72\xe0\xf8\xe0\x7d\xe1\x02\xe2\x87\xe2\x0b\xe3\x8e\xe3\x12\xe4\x95\xe4\x17\xe5\x99\xe5\x1b\xe6\x9d\xe6\x1e\xe7\x9e\xe7\x1e\xe8\x9e\xe8\x1e\xe9\x9d\xe9\x1c\xea\x9a\xea\x19\xeb\x96\xeb\x14\xec\x91\xec\x0e\xed\x8a\xed\x06\xee\x82\xee\xfd\xee\x79\xef\xf3\xef\x6e\xf0\xe8\xf0\x62\xf1\xdb\xf1\x54\xf2\xcd\xf2\x46\xf3\xbe\xf3\x36\xf4\xae\xf4\x25\xf5\x9c\xf5\x13\xf6\x89\xf6\xff\xf6\x75\xf7\xeb\xf7\x60\xf8\xd5\xf8\x4a\xf9\xbe\xf9\x32\xfa\xa6\xfa\x1a\xfb\x8d\xfb\x00\xfc\x73\xfc\xe5\xfc\x58\xfd\xca\xfd\x3b\xfe\xad\xfe\x1e\xff\x8f\xff", 0x0000600);
ret = usb_bulk_write(devh, 0x00000001, buf, 0x0000600, 1092);
printf("8282 bulk write returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(11*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000005, 0x0000000, buf, 0x0000004, 1000);
printf("8283 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000c0, 0x0000000, buf, 0x0000004, 1000);
printf("8284 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(16*1000);
memcpy(buf, "\xa0\x00\xa1\x08\xa2\x80\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x06\x7e\x00\x7f\x00", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("8285 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x00\x06\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000002, 0x0000000, buf, 0x0000004, 1000);
printf("8286 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x00\x00\x47\x10\x8b\x21\x6b\x32\x18\x43\xda\x52\x9c\x62\x5d\x72\x10\x82\x4f\x91\x8f\xa0\xce\xaf\x0e\xbf\x4d\xce\x39\xde\x91\xf7\x00\x00\x3f\x10\x09\x22\xd8\x32\x78\x43\x5d\x53\x43\x63\x28\x73\xfa\x82\x6b\x92\xdc\xa1\x4d\xb1\xbe\xc0\x2f\xd0\xf0\xdf\xfb\xf7\x00\x00\x0a\x10\x03\x22\x02\x33\xc4\x43\xa5\x53\x87\x63\x68\x73\x32\x83\x96\x92\xfa\xa1\x5e\xb1\xc2\xc0\x26\xd0\xe4\xdf\xf8\xf7\x00\x00\xf0\x0f\xe9\x21\xe4\x32\x9d\x43\x5b\x53\x19\x63\xd7\x72\x8d\x82\x17\x92\xa2\xa1\x2c\xb1\xb6\xc0\x40\xd0\x08\xe0\x01\xf8\x00\x00\xd3\x0f\xe8\x21\xd8\x32\x8a\x43\x46\x53\x03\x63\xc0\x72\x74\x82\xed\x91\x66\xa1\xe0\xb0\x59\xc0\xd2\xcf\xa7\xdf\xea\xf7\x00\x00\xbb\x0f\xb8\x21\x94\x32\x34\x43\xd1\x52\x6f\x62\x0c\x72\xab\x81\x5a\x91\x08\xa1\xb7\xb0\x66\xc0\x14\xd0\xf2\xdf\xfc\xf7\x00\x00\xad\x0f\xc0\x21\x96\x32\x32\x43\xd3\x52\x73\x62\x14\x72\xb3\x81\x3d\x91\xc7\xa0\x51\xb0\xdb\xbf\x65\xcf\x53\xdf\xd5\xf7\x00\x00\x85\x0f\x49\x21\x2a\x32\xd8\x42\x83\x52\x2d\x62\xd7\x71\x84\x81\x47\x91\x0b\xa1\xce\xb0\x92\xc0\x55\xd0\x2d\xe0\x0a\xf8\x00\x00\x7d\x0f\x39\x21\x21\x32\xd5\x42\x77\x52\x19\x62\xbb\x71\x5b\x81\xdc\x90\x5d\xa0\xde\xaf\x5f\xbf\xe0\xce\xde\xde\xb9\xf7\x00\x00\x7d\x0f\x2c\x21\x42\x32\x13\x43\xac\x52\x45\x62\xde\x71\x79\x81\x26\x91\xd2\xa0\x7f\xb0\x2c\xc0\xd8\xcf\xc1\xdf\xf0\xf7\x00\x00\x7d\x0f\x1f\x21\x35\x32\x07\x43\x95\x52\x23\x62\xb1\x71\x3d\x81\xb2\x90\x28\xa0\x9d\xaf\x12\xbf\x88\xce\x8a\xde\xa5\xf7\x00\x00\x68\x0f\x07\x21\x24\x32\xfd\x42\x8a\x52\x17\x62\xa4\x71\x32\x81\xd6\x90\x79\xa0\x1d\xb0\xc1\xbf\x64\xcf\x5e\xdf\xd8\xf7\x00\x00\x67\x0f\x21\x21\x58\x32\x44\x43\xf3\x52\xa1\x62\x50\x72\xfa\x81\x80\x91\x06\xa1\x8c\xb0\x12\xc0\x98\xcf\x7c\xdf\xdf\xf7\x00\x00\x67\x0f\x8b\x21\x78\x32\x26\x43\xbd\x52\x55\x62\xec\x71\x84\x81\x24\x91\xc4\xa0\x64\xb0\x04\xc0\xa4\xcf\x91\xdf\xe4\xf7\x00\x00\xe3\x0f\xbb\x21\xbf\x32\x78\x43\x07\x53\x97\x62\x27\x72\xb7\x81\x4a\x91\xdd\xa0\x70\xb0\x03\xc0\x96\xcf\x80\xdf\xe0\xf7\x00\x00\xda\x0f\x67\x21\x41\x32\xda\x42\x30\x52\x87\x61\xdd\x70\x33\x80\xdf\x8f\x8b\x9f\x37\xaf\xe3\xbe\x8f\xce\xad\xde\xad\xf7\x00\x00\xed\x0f\x56\x21\x1f\x32\xba\x42\x57\x52\xf4\x61\x92\x71\x2c\x81\x94\x90\xfc\x9f\x65\xaf\xcd\xbe\x36\xce\x3a\xde\x91\xf7\x00\x00\xe7\x0f\x8e\x21\x7f\x32\x33\x43\xdd\x52\x87\x62\x30\x72\xda\x81\x81\x91\x29\xa1\xd1\xb0\x79\xc0\x21\xd0\xfa\xdf\xfe\xf7\x00\x00\xb0\x0f\x88\x21\x97\x32\x60\x43\x08\x53\xaf\x62\x57\x72\xfe\x81\x9e\x91\x3d\xa1\xdd\xb0\x7c\xc0\x1c\xd0\xf3\xdf\xfc\xf7\x00\x00\xa5\x0f\x6d\x21\x97\x32\x6d\x43\xfb\x52\x89\x62\x17\x72\xa9\x81\x60\x91\x18\xa1\xcf\xb0\x87\xc0\x3e\xd0\x17\xe0\x05\xf8\x00\x00\x58\x0f\x4b\x21\x5b\x32\x24\x43\xaf\x52\x3a\x62\xc5\x71\x4e\x81\xc6\x90\x3d\xa0\xb5\xaf\x2c\xbf\xa4\xce\xa4\xde\xab\xf7\x00\x00\x4a\x0f\x1a\x21\x19\x32\xda\x42\x5c\x52\xde\x61\x60\x71\xe3\x80\x7e\x90\x19\xa0\xb4\xaf\x4e\xbf\xe9\xce\xf2\xde\xbe\xf7\x00\x00\x36\x0f\x1f\x21\x17\x32\xd1\x42\x50\x52\xcf\x61\x4e\x71\xcd\x80\x44\x90\xbb\x9f\x33\xaf\xaa\xbe\x21\xce\x2f\xde\x8f\xf7\x00\x00\x1e\x0f\x0e\x21\xfc\x31\xb3\x42\x37\x52\xba\x61\x3d\x71\xc2\x80\x7e\x90\x3a\xa0\xf5\xaf\xb1\xbf\x6d\xcf\x6f\xdf\xdc\xf7\x00\x00\x1b\x0f\x03\x21\xc5\x31\x5e\x42\xf4\x51\x89\x61\x1f\x71\xb4\x80\x41\x90\xcd\x9f\x59\xaf\xe5\xbe\x72\xce\x83\xde\xa3\xf7\x00\x00\x23\x0f\x1b\x21\x01\x32\xb7\x42\x65\x52\x13\x62\xc0\x71\x70\x81\x33\x91\xf7\xa0\xba\xb0\x7d\xc0\x41\xd0\x1d\xe0\x06\xf8\x00\x00\x24\x0f\x10\x21\x03\x32\xc6\x42\x82\x52\x3d\x62\xf9\x71\xb0\x81\x36\x91\xbd\xa0\x43\xb0\xc9\xbf\x4f\xcf\x3f\xdf\xd0\xf7\x00\x00\x11\x0f\x0d\x21\x2d\x32\x0d\x43\xc2\x52\x77\x62\x2c\x72\xe1\x81\x9d\x91\x59\xa1\x15\xb1\xd1\xc0\x8d\xd0\x56\xe0\x14\xf8\x00\x00\x07\x0f\xff\x20\x23\x32\x09\x43\xc7\x52\x85\x62\x43\x72\xfd\x81\x92\x91\x27\xa1\xbd\xb0\x52\xc0\xe7\xcf\xc4\xdf\xf1\xf7\x00\x00\x0d\x0f\x3f\x21\x50\x32\x23\x43\xe1\x52\x9f\x62\x5d\x72\x1b\x82\xdf\x91\xa2\xa1\x66\xb1\x29\xc1\xed\xd0\xa3\xe0\x26\xf8\x00\x00\x32\x0f\x6c\x21\x78\x32\x4b\x43\x27\x53\x03\x63\xdf\x72\xae\x82\x34\x92\xba\xa1\x40\xb1\xc7\xc0\x4d\xd0\x10\xe0\x03\xf8\x00\x00\x3a\x0f\x4a\x21\x34\x32\xea\x42\x9a\x52\x4b\x62\xfb\x71\xa9\x81\x3c\x91\xd0\xa0\x64\xb0\xf7\xbf\x8b\xcf\x77\xdf\xde\xf7\x00\x00\x79\x0f\x8f\x20\x31\x31\xb5\x41\x0b\x51\x61\x60\xb6\x6f\x0c\x7f\xe6\x8e\xcc\x9e\xb2\xae\x98\xbe\x7e\xce\xb9\xde\xb0\xf7\x00\x00\x79\x0f\xab\x20\x5b\x31\xe6\x41\x37\x51\x88\x60\xd9\x6f\x2a\x7f\x44\x8f\x6d\x9f\x96\xaf\xc0\xbf\xe9\xcf\xfd\xdf\xfe\xf7\x00\x00\x68\x0f\xbc\x20\x87\x31\x27\x42\x8b\x51\xee\x60\x52\x70\xb6\x7f\xbc\x8f\xc9\x9f\xd5\xaf\xe2\xbf\xee\xcf\xf7\xdf\xfd\xf7\x00\x00\x51\x0f\x95\x20\x5e\x31\xfd\x41\x40\x51\x83\x60\xc7\x6f\x0a\x7f\x2a\x8f\x5f\x9f\x93\xaf\xc8\xbf\xfc\xcf\x10\xe0\x03\xf8\x00\x00\x4c\x0f\xb0\x20\x72\x31\x09\x42\x50\x51\x96\x60\xdd\x6f\x23\x7f\x22\x8f\x2f\x9f\x3c\xaf\x49\xbf\x57\xcf\x7e\xdf\xe0\xf7\x00\x00\x3a\x0f\x7f\x20\x34\x31\xc3\x41\xf4\x50\x24\x60\x54\x6f\x85\x7e\xb9\x8e\x10\x9f\x67\xaf\xbe\xbf\x15\xd0\x2f\xe0\x0a\xf8\x00\x00\x60\x0f\x09\x21\x74\x31\xbf\x41\xe3\x50\x07\x60\x2b\x6f\x4f\x7e\x57\x8e\x82\x9e\xac\xae\xd7\xbe\x01\xcf\x45\xdf\xd2\xf7\x00\x00\x3c\x0f\x8e\x20\x00\x31\x5b\x41\x91\x50\xc7\x5f\xfd\x6e\x32\x7e\x75\x8e\xe3\x9e\x52\xaf\xc0\xbf\x2e\xd0\x49\xe0\x11\xf8\x00\x00\x40\x0f\xad\x20\x0e\x31\x5b\x41\x89\x50\xb8\x5f\xe6\x6e\x15\x7e\x29\x8e\x63\x9e\x9e\xae\xd9\xbe\x14\xcf\x5b\xdf\xd7\xf7\x00\x00\x2b\x0f\x97\x20\x1e\x31\x89\x41\xb0\x50\xd8\x5f\xff\x6e\x27\x7e\x66\x8e\xd3\x9e\x40\xaf\xad\xbf\x1a\xd0\x3a\xe0\x0d\xf8\x00\x00\x2f\x0f\x7f\x20\xfe\x30\x61\x41\x63\x50\x66\x5f\x68\x6e\x6a\x7d\x3e\x8d\x43\x9d\x49\xad\x4e\xbd\x54\xcd\xc5\xdd\x75\xf7\x00\x00\xe0\x0e\x6c\x20\xea\x30\x4e\x41\x5b\x50\x67\x5f\x74\x6e\x81\x7d\x82\x8d\xbb\x9d\xf5\xad\x2e\xbe\x67\xce\xce\xde\xb5\xf7\x00\x00\xee\x0e\x90\x20\x34\x31\xb2\x41\xbc\x50\xc6\x5f\xd1\x6e\xdb\x7d\xe9\x8d\x2a\x9e\x6a\xae\xaa\xbe\xeb\xce\x3c\xdf\xd0\xf7\x00\x00\xc7\x0e\xdf\x20\x42\x31\x87\x41\x7e\x50\x76\x5f\x6d\x6e\x65\x7d\x9d\x8d\x23\x9e\xa9\xae\x2f\xbf\xb5\xcf\xf6\xdf\xfd\xf7\x00\x00\x1d\x0f\x10\x21\x68\x31\xa5\x41\xbb\x50\xd0\x5f\xe6\x6e\xfc\x7d\x0d\x8e\x4b\x9e\x8a\xae\xc8\xbe\x06\xcf\x52\xdf\xd5\xf7\x00\x00\x14\x0f\xbc\x20\x06\x31\x3b\x41\x32\x50\x2a\x5f\x21\x6e\x18\x7d\x22\x8d\x78\x9d\xcd\xad\x22\xbe\x78\xce\xe8\xde\xbb\xf7", 0x0000600);
ret = usb_bulk_write(devh, 0x00000001, buf, 0x0000600, 1092);
printf("8287 bulk write returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(11*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000005, 0x0000000, buf, 0x0000004, 1000);
printf("8288 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000c0, 0x0000000, buf, 0x0000004, 1000);
printf("8289 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(23*1000);
memcpy(buf, "\xa0\x00\xa1\x40\xa2\x0f\xa3\xff\xa4\xff\xa5\x0f\x7c\x6c\x7d\x0c\x7e\x01\x7f\x00", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("8290 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(23*1000);
memcpy(buf, "\x00\xf0\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000002, 0x0000000, buf, 0x0000004, 1000);
printf("8291 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(28*1000);
memcpy(buf, "\x78\x01\x15\x00\x40\xd1\x1a\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x07\x08\xff\xff\x05\x08\xff\xff\xff\x07\xff\xff\xff\x07\xff\xff\xfd\x07\xff\xff\x03\x08\xff\xff\x04\x08\xff\xff\xff\x07\xff\xff\xfb\x07\xff\xff\xff\x07\xff\xff\xfa\x07\xff\xff\x08\x08\xff\xff\x09\x08\xff\xff\x0d\x08\xff\xff\xfc\x07\xff\xff\xff\x07\xff\xff\xfd\x07\xff\xff\xff\x07\xff\xff\xf9\x07\xff\xff\xf7\x07\xff\xff\xf6\x07\xff\xff\xfb\x07\xff\xff\xf9\x07\xff\xff\x02\x08\xff\xff\xf6\x07\xff\xff\xf3\x07\xff\xff\xf8\x07\xff\xff\xf9\x07\xff\xff\xf7\x07\xff\xff\xf8\x07\xff\xff\xfe\x07\xff\xff\xfe\x07\xff\xff\xf9\x07\xff\xff\xf9\x07\xff\xff\xfa\x07\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xf4\x07\xff\xff\xfc\x07\xff\xff\xfa\x07\xff\xff\xf4\x07\xff\xff\xef\x07\xff\xff\xf1\x07\xff\xff\xe9\x07\xff\xff\xed\x07\xff\xff\xec\x07\xff\xff\xe4\x07\xff\xff\xe4\x07\xff\xff\xe8\x07\xff\xff\xee\x07\xff\xff\xec\x07\xff\xff\xec\x07\xff\xff\xe6\x07\xff\xff\xe1\x07\xff\xff\xe6\x07\xff\xff\xe0\x07\xff\xff\xe4\x07\xff\xff\xe8\x07\xff\xff\xe0\x07\xff\xff\xda\x07\xff\xff\xeb\x07\xff\xff\xe5\x07\xff\xff\xe2\x07\xff\xff\xdb\x07\xff\xff\xdd\x07\xff\xff\xd9\x07\xff\xff\xe2\x07\xff\xff\xe5\x07\xff\xff\xe5\x07\xff\xff\xe1\x07\xff\xff\xdb\x07\x11\xfc\xd9\x07\xa5\xf5\xe3\x07\xff\xff\xe2\x07\xbc\xf6\xde\x07\x49\xf1\xe1\x07\xf5\xfb\xdb\x07\xb7\xec\xd7\x07\x24\xe7\xdd\x07\xe0\xf0\xde\x07\xfb\xe5\xd9\x07\xdc\xde\xe0\x07\x2f\xea\xce\x07\x8b\xdd\xd0\x07\x0e\xd9\xe0\x07\xc1\xe3\xd9\x07\x41\xd5\xda\x07\x63\xd0\xd5\x07\x64\xda\xd4\x07\x42\xcf\xd5\x07\xa3\xc9\xde\x07\x49\xd0\xcd\x07\xb2\xc5\xd5\x07\xf0\xc2\xd5\x07\x41\xca\xd0\x07\x3c\xc0\xcc\x07\x89\xbc\xd2\x07\x4c\xc5\xd0\x07\xe8\xbd\xd2\x07\x6f\xb8\xcd\x07\x5d\xc0\xcf\x07\x96\xba\xc7\x07\x84\xb5\xc8\x07\xfc\xbe\xcc\x07\xb7\xb7\xce\x07\x70\xb4\xc9\x07\xaf\xba\xc6\x07\xa6\xb7\xc4\x07\xe1\xb4\xc5\x07\xa4\xb9\xc9\x07\x1f\xb8\xc5\x07\xd1\xb2\xc6\x07\x29\xb8\xca\x07\xfe\xb2\xc4\x07\x77\xae\xcb\x07\xa7\xb4\xc6\x07\x15\xae\xc0\x07\x45\xaa\xc3\x07\x0d\xb2\xc1\x07\x4a\xac\xc3\x07\x53\xa8\xc7\x07\x1e\xaf\xb5\x07\xa0\xae\xb6\x07\xfd\xa8\xbd\x07\x8d\xab\xbe\x07\x68\xa8\xb0\x07\xcf\xa2\xc0\x07\x11\xaa\xc6\x07\x43\xa9\xc2\x07\x26\xa2\xc7\x07\xda\xa9\xc2\x07\xa3\xa8\xbd\x07\x04\xa3\xc3\x07\x49\xa8\xc7\x07\xbe\xa0\xc1\x07\xaf\x9c\xbf\x07\xd3\xa3\xbf\x07\x6a\x9f\xbe\x07\xbc\x9c\xc5\x07\xe1\xa1\xbc\x07\x5d\x9b\xbf\x07\xf1\x97\xbe\x07\x42\x9f\xba\x07\x82\x99\xbe\x07\x43\x96\xbd\x07\x64\x9b\xb5\x07\xda\x98\xb8\x07\x51\x94\xc3\x07\x2a\x9b\xc1\x07\x3d\x97\xbe\x07\x7d\x94\xc0\x07\x94\x98\xbd\x07\xd4\x96\xc3\x07\xa2\x92\xbe\x07\xbf\x97\xb8\x07\x76\x94\xb8\x07\xfa\x8f\xbd\x07\xd2\x95\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xbe\x07\xf1\x90\xbc\x07\x6a\x8d\xbc\x07\xcc\x92\xb8\x07\xea\x8e\xb1\x07\xdd\x89\xb7\x07\xdc\x8f\xbf\x07\x11\x8e\xb6\x07\xae\x89\xbb\x07\x78\x8f\xb5\x07\xa6\x8a\xb3\x07\xbb\x87\xb2\x07\x10\x8c\xc1\x07\x78\x89\xbd\x07\x7f\x86\xbc\x07\xbe\x8d\xc3\x07\x15\x8c\xb2\x07\x72\x87\xb9\x07\x07\x8d\xb7\x07\x2b\x89\xb3\x07\xda\x83\xbd\x07\x09\x8b\xaf\x07\x7b\x86\xac\x07\xc9\x82\xb3\x07\xc4\x87\xb1\x07\x86\x84\xb4\x07\xaa\x80\xb9\x07\x8d\x85\xb5\x07\xc0\x80\xb9\x07\x7e\x7e\xc1\x07\x06\x84\xab\x07\xc0\x81\xa6\x07\x79\x7d\xb6\x07\x5a\x81\xb6\x07\x25\x81\xa7\x07\xe7\x7c\xb5\x07\x11\x81\xb1\x07\x37\x81\xad\x07\x2c\x7d\xb5\x07\xcc\x81\xbb\x07\x6e\x7d\xb8\x07\x3e\x7a\xb0\x07\x0a\x7e\xb6\x07\x10\x7b\xaa\x07\x6a\x77\xb4\x07\xcb\x7c\xa7\x07\x29\x7a\x97\x07\xce\x75\xb1\x07\x08\x7b\xb4\x07\xb6\x77\xb6\x07\xe8\x73\xb4\x07\x8b\x78\xb5\x07\xb1\x76\xac\x07\x43\x72\xb0\x07\x08\x77\xab\x07\xa9\x75\xa5\x07\x70\x71\xa7\x07\x87\x76\xa6\x07\x70\x75\xa7\x07\xd5\x71\xab\x07\xd1\x75\xb4\x07\x1c\x75\xab\x07\x76\x71\xb9\x07\x2b\x77\xa7\x07\x32\x71\xa5\x07\x80\x6e\xb0\x07\x6b\x72\xae\x07\xc5\x6e\xa9\x07\x8d\x6c\xae\x07\xa6\x6f\xaf\x07\x71\x6d\xac\x07\x77\x6a\xab\x07\x9a\x6e\xae\x07\xc7\x6c\xab\x07\x26\x68\xb8\x07\x25\x6d\xb1\x07\x1e\x6c\xaa\x07\x4c\x68\xa9\x07\xbf\x6c\xab\x07\xd4\x6a\xa9\x07\xd6\x67\xae\x07\xb0\x6b\x9d\x07\x34\x6d\x92\x07\x99\x69\xb0\x07\x84\x6b\xa9\x07\x0f\x69\xaa\x07\x89\x66\xb3\x07\xf8\x69\xab\x07\xd7\x66\xa9\x07\x76\x64\xaf\x07\x24\x68\xb6\x07\x47\x66\xaa\x07\x1d\x63\xab\x07\x88\x66\xa1\x07\xb6\x63\xa4\x07\x73\x61\xaa\x07\x26\x65\xa8\x07\x83\x63\xa5\x07\x61\x61\xa2\x07\xc1\x63\xa4\x07\x67\x62\xa2\x07\x09\x60\xa8\x07\x58\x64\x9f\x07\xf7\x63\x98\x07\x25\x60\xa2\x07\xaf\x63\x9a\x07\xc9\x60\x99\x07\x6a\x60\xae\x07\xcc\x62\xa2\x07\x9f\x5f\xa7\x07\x62\x5d\xac\x07\xa7\x60\x98\x07\x59\x5f\x9d\x07\xb0\x5d\xa4\x07\xad\x5f\x92\x07\xcf\x5e\x96\x07\x21\x5c\xb2\x07\x52\x5f\x9a\x07\x7b\x5c\xa1\x07\x98\x5b\xa5\x07\xd6\x5d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xa2\x07\x78\x5b\xa0\x07\x4c\x5a\xa8\x07\xe3\x5d\xab\x07\x8d\x5c\x9d\x07\xd3\x59\xa5\x07\x97\x5d\xa9\x07\x01\x5b\xa7\x07\x38\x59\xa4\x07\x66\x5b\x9e\x07\xf8\x58\x98\x07\x47\x57\xa2\x07\x24\x5a\x96\x07\x2b\x58\x95\x07\x9e\x56\xa7\x07\x24\x59\x97\x07\xd4\x56\x92\x07\x11\x56\xa5\x07\x54\x58\xa0\x07\x56\x56\x9b\x07\x50\x54\xa2\x07\x3a\x57\xa2\x07\xa8\x55\x9b\x07\xa5\x53\xa5\x07\x1c\x57\x9c\x07\x08\x55\x95\x07\x8c\x53\xa8\x07\xe1\x56\xa0\x07\x9a\x54\x9d\x07\x2c\x53\x9e\x07\xdb\x55\xa0\x07\x0c\x54\x9e\x07\x86\x52\xa3\x07\x13\x55\x9f\x07\x59\x52\x9a\x07\xe5\x50\xa0\x07\x0a\x53\x89\x07\x6e\x52\x86\x07\xa7\x50\x99\x07\x6f\x52\xa1\x07\x69\x51\x94\x07\xdb\x4e\xa9\x07\xc8\x51\x95\x07\x7c\x50\x93\x07\x12\x4f\x9c\x07\x13\x51\x9a\x07\x97\x50\x95\x07\x55\x4e\x9f\x07\xac\x51\x94\x07\x1d\x50\x8b\x07\x5e\x4d\xa2\x07\x9f\x51\x9a\x07\x6a\x4f\x90\x07\xc2\x4c\x99\x07\x5d\x4f\x88\x07\xdd\x4e\x8a\x07\x6d\x4c\x9b\x07\x18\x4e\x8c\x07\x0a\x4f\x86\x07\x48\x4b\x97\x07\x58\x4e\x87\x07\xe7\x4c\x8b\x07\xb1\x4a\x9b\x07\xdc\x4c\x89\x07\x15\x4d\x81\x07\x40\x4a\x8c\x07\xae\x4c\x93\x07\xc3\x4c\x88\x07\x93\x4a\x9e\x07\x68\x4c\x87\x07\x2e\x4c\x7d\x07\xa4\x4a\x97\x07\x73\x4c\x94\x07\xa8\x4a\x8d\x07\x2b\x49\x8d\x07\x1d\x4b\x8c\x07\x01\x4b\x88\x07\x73\x47\x9b\x07\x48\x4a\x7a\x07\x88\x49\x7c\x07\x70\x47\x8d\x07\x3d\x49\x8b\x07\xef\x48\x7b\x07\x68\x46\x8f\x07\x94\x48\x82\x07\x1d\x49\x79\x07\x15\x46\x8a\x07\x2c\x48\x8c\x07\x88\x48\x83\x07\x5a\x45\x8c\x07\x96\x47\x88\x07\x5d\x48\x77\x07\x14\x45\x8a\x07\xed\x47\x80\x07\xd3\x46\x78\x07\x83\x44\x84\x07\x03\x47\x83\x07\xcc\x45\x83\x07\x75\x44\x86\x07\x37\x46\x74\x07\x93\x45\x6d\x07\x9d\x43\x82\x07\xa7\x45\x87\x07\x2f\x46\x82\x07\x90\x43\x7e\x07\xae\x45\x6d\x07\xae\x46\x6a\x07\x10\x43\x7e\x07\x4a\x45\x74\x07\xb0\x46\x70\x07\x87\x42\x83\x07\x27\x45\x72\x07\xb8\x45\x6e\x07\x43\x42\x82\x07\xe4\x44\x7b\x07\x41\x44\x75\x07\xe4\x41\x81\x07\x3e\x44\x7b\x07\xfa\x42\x73\x07\x99\x41\x84\x07\x9c\x43\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x6b\x07\xf1\x42\x6f\x07\xbb\x41\x7a\x07\xc9\x42\x73\x07\xa1\x41\x6f\x07\xe7\x40\x7c\x07\x66\x42\x73\x07\xd8\x41\x76\x07\x30\x41\x80\x07\x52\x42\x7b\x07\x73\x42\x7b\x07\xa5\x40\x7e\x07\x00\x42\x71\x07\xd8\x42\x65\x07\xa5\x40\x84\x07\x34\x43\x70\x07\xd8\x42\x61\x07\x23\x40\x70\x07\x87\x41\x72\x07\x1c\x41\x66\x07\x5f\x3e\x72\x07\xa6\x40\x71\x07\x39\x40\x72\x07\xaf\x3e\x77\x07\x7e\x40\x65\x07\xc4\x3f\x5d\x07\x28\x3e\x78\x07\xe9\x3f\x4e\x07\x9a\x3f\x4b\x07\x46\x3e\x70\x07\x40\x3f\x60\x07\xf6\x3e\x51\x07\x8a\x3d\x74\x07\x40\x3f\x69\x07\xed\x3e\x64\x07\x9b\x3d\x6b\x07\x78\x3f\x76\x07\xc7\x3e\x6d\x07\xa8\x3d\x6e\x07\x51\x3f\x68\x07\x86\x3d\x6f\x07\x0b\x3d\x72\x07\x56\x3e\x7c\x07\xa0\x3d\x72\x07\xd8\x3b\x78\x07\x88\x3d\x62\x07\x3c\x3d\x5a\x07\xb1\x3b\x6e\x07\x31\x3d\x5e\x07\xd5\x3c\x59\x07\xbf\x3b\x71\x07\x1a\x3d\x6a\x07\x87\x3c\x67\x07\x31\x3b\x6d\x07\x21\x3d\x6e\x07\xd9\x3c\x65\x07\x35\x3c\x6d\x07\x4a\x3d\x54\x07\x4b\x3d\x51\x07\x26\x3c\x63\x07\xc9\x3c\x5e\x07\x02\x3c\x58\x07\xba\x3a\x6e\x07\x1f\x3c\x48\x07\xa7\x3b\x48\x07\x84\x3a\x69\x07\xbe\x3b\x5d\x07\x79\x3b\x57\x07\x65\x3a\x70\x07\x17\x3b\x5c\x07\xc7\x3a\x63\x07\xaa\x39\x6c\x07\xf6\x3a\x4f\x07\xd9\x3a\x50\x07\xcd\x39\x6e\x07\x9f\x3a\x60\x07\x12\x3b\x4c\x07\x89\x39\x60\x07\x37\x3a\x66\x07\x1e\x3b\x63\x07\xee\x39\x6b\x07\x9c\x3a\x61\x07\x60\x3a\x59\x07\x34\x39\x69\x07\xae\x39\x56\x07\xc2\x39\x51\x07\xa5\x38\x67\x07\x4c\x39\x4d\x07\xa2\x39\x3a\x07\x49\x38\x65\x07\x4c\x39\x4f\x07\x7e\x39\x4c\x07\x68\x38\x5f\x07\xb0\x38\x4e\x07\x11\x39\x4e\x07\xdb\x37\x62\x07\xf1\x38\x6b\x07\x39\x39\x60\x07\xb7\x37\x6b\x07\xc7\x38\x63\x07\x2c\x39\x5b\x07\x1f\x38\x6a\x07\x01\x39\x5f\x07\x98\x38\x5c\x07\xcd\x37\x60\x07\x61\x38\x4a\x07\x83\x38\x38\x07\x27\x37\x64\x07\xbe\x37\x63\x07\xe9\x37\x5b\x07\xaf\x36\x65\x07\x8e\x37\x48\x07\xc1\x37\x47\x07\x01\x37\x65\x07\x93\x37\x56\x07\xb1\x38\x3c\x07\x18\x36\x64\x07\xa7\x37\x5b\x07\x8f\x39\x4d\x07\x31\x36\x5a\x07\xba\x37\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x4e\x07\xfd\x39\x3a\x07\x23\x36\x5f\x07\x05\x38\x5b\x07\x98\x38\x5c\x07\x30\x36\x67\x07\x8c\x37\x55\x07\x3c\x37\x4b\x07\x09\x36\x62\x07\xa3\x36\x5b\x07\x34\x37\x5c\x07\x2b\x35\x63\x07\x75\x36\x4f\x07\x46\x37\x3b\x07\x2e\x35\x62\x07\x0d\x36\x53\x07\xa5\x36\x4f\x07\xb0\x35\x62\x07\x05\x36\x54\x07\x5e\x36\x58\x07\xa4\x34\x5e\x07\xd9\x35\x51\x07\x15\x37\x43\x07\xec\x34\x5c\x07\x34\x36\x4e\x07\x9a\x36\x4f\x07\xf8\x34\x59\x07\x41\x36\x56\x07\x2e\x36\x4b\x07\x48\x34\x67\x07\xd0\x35\x57\x07\x77\x35\x4f\x07\x77\x34\x59\x07\x11\x35\x4d\x07\x8e\x35\x36\x07\x1c\x34\x5d\x07\x15\x35\x4f\x07\x39\x35\x3e\x07\xe0\x33\x49\x07\xb9\x34\x52\x07\x0a\x35\x43\x07\xba\x33\x5e\x07\xc6\x34\x55\x07\x5d\x35\x4a\x07\xa2\x33\x57\x07\xd0\x34\x4f\x07\xcb\x35\x45\x07\x59\x34\x53\x07\xf7\x34\x49\x07\x4a\x35\x38\x07\x31\x33\x55\x07\x16\x34\x47\x07\x61\x34\x48\x07\x33\x33\x50\x07\xb3\x33\x54\x07\x66\x34\x49\x07\x15\x33\x53\x07\x4c\x33\x48\x07\x61\x34\x3a\x07\xc3\x32\x4d\x07\x3d\x33\x54\x07\xdc\x33\x44\x07\x8c\x32\x49\x07\xc3\x32\x4d\x07\xe3\x33\x48\x07\xbb\x32\x56\x07\x3c\x33\x3c\x07\x16\x35\x36\x07\x5b\x33\x58\x07\x76\x33\x4e\x07\x44\x34\x48\x07\xda\x32\x4b\x07\xf1\x32\x42\x07\xb9\x33\x41\x07\x19\x32\x49\x07\xa3\x32\x43\x07\x56\x33\x39\x07\xfc\x31\x4b\x07\x0f\x32\x47\x07\x74\x33\x43\x07\xdd\x31\x53\x07\x45\x32\x43\x07\x75\x33\x3a\x07\x98\x31\x51\x07\x3a\x32\x4a\x07\x94\x33\x32\x07\xd6\x31\x46\x07\xf8\x31\x57\x07\xd0\x33\x3f\x07\xe9\x31\x48\x07\xde\x31\x45\x07\xd5\x33\x33\x07\xad\x31\x4b\x07\xca\x31\x3d\x07\x9e\x32\x3d\x07\x4e\x31\x44\x07\x32\x31\x44\x07\xa8\x32\x47\x07\x49\x31\x49\x07\x2a\x31\x3a\x07\xcd\x32\x3a\x07\x5d\x31\x45\x07\x64\x31\x46\x07\xbe\x32\x35\x07\x3c\x31\x42\x07\x39\x31\x37\x07\xa9\x32\x2b\x07\xf7\x30\x49\x07\x7a\x31\x4d\x07\xce\x32\x3e\x07\xfb\x30\x4a\x07\x5c\x31\x3c\x07\xfe\x32\x35\x07\x59\x31\x4f\x07\x49\x31\x43\x07\x41\x32\x44\x07\xeb\x30\x4f\x07\x3f\x31\x4e\x07\x2f\x32\x3f\x07\x91\x30\x48\x07\xfd\x30\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x44\x07\x49\x32\x39\x07\x81\x30\x5a\x07\xdb\x30\x41\x07\x48\x32\x3b\x07\xbd\x30\x44\x07\xca\x30\x45\x07\x17\x32\x3c\x07\xc4\x30\x4d\x07\xf5\x30\x44\x07\x1e\x32\x3e\x07\x88\x30\x4f\x07\x45\x31\x35\x07\xfa\x32\x2b\x07\x10\x31\x4f\x07\x21\x31\x4c\x07\x37\x32\x3b\x07\x8e\x30\x45\x07\x03\x31\x42\x07\xd8\x31\x3d\x07\x97\x30\x4a\x07\x86\x30\x31\x07\xb3\x31\x2c\x07\x63\x30\x3a\x07\x18\x30\x45\x07\xf3\x31\x35\x07\x4c\x30\x3e\x07\x01\x30\x3d\x07\xcb\x31\x34\x07\x3f\x30\x40\x07\x4d\x30\x41\x07\x06\x32\x3f\x07\x30\x31\x45\x07\x6c\x30\x48\x07\xf8\x31\x44\x07\x78\x30\x53\x07\xcb\x30\x2e\x07\x7e\x31\x31\x07\x02\x30\x44\x07\x2c\x30\x31\x07\x7a\x31\x23\x07\xaf\x2f\x3a\x07\x96\x2f\x2d\x07\x67\x31\x21\x07\xaa\x2f\x33\x07\x57\x2f\x19\x07\x8d\x31\x0c\x07\x15\x30\x3a\x07\x33\x2f\x42\x07\x2a\x31\x44\x07\xac\x2f\x40\x07\x4b\x2f\x37\x07\x82\x31\x1c\x07\xb4\x2f\x49\x07\xa9\x2f\x3e\x07\xdb\x31\x3b\x07\xdf\x2f\x44\x07\xf4\x2f\x2c\x07\x09\x31\x28\x07\xcf\x2f\x40\x07\x7e\x2f\x36\x07\x2b\x31\x2b\x07\xa8\x2f\x3b\x07\x38\x2f\x46\x07\x0e\x31\x36\x07\x73\x2f\x34\x07\x5f\x2f\x3b\x07\xf0\x30\x44\x07\xd2\x2f\x45\x07\x57\x2f\x46\x07\xc6\x30\x3c\x07\x6c\x2f\x4a\x07\xa5\x2f\x48\x07\x17\x31\x32\x07\xe3\x2f\x3c\x07\x70\x2f\x40\x07\x47\x31\x3a\x07\x02\x30\x3f\x07\xcc\x2f\x46\x07\x4a\x31\x36\x07\xbe\x2f\x52\x07\xe0\x2f\x2f\x07\xe7\x30\x24\x07\x6d\x2f\x40\x07\x73\x2f\x2e\x07\x2d\x31\x2f\x07\xb8\x2f\x31\x07\x78\x2f\x28\x07\xb4\x30\x22\x07\x70\x2f\x3f\x07\x24\x2f\x40\x07\x88\x30\x3f\x07\x70\x2f\x41\x07\x02\x2f\x3d\x07\x1e\x31\x34\x07\xbe\x2f\x4b\x07\xb9\x2f\x32\x07\xb7\x31\x32\x07\xf9\x2f\x41\x07\xd2\x2f\x40\x07\x57\x31\x36\x07\xde\x2f\x3c\x07\xc6\x2f\x45\x07\x13\x31\x39\x07\x9a\x2f\x42\x07\x5c\x2f\x39\x07\xd0\x30\x31\x07\x37\x2f\x33\x07\x1d\x2f\x35\x07\x85\x30\x37\x07\x30\x2f\x39\x07\xce\x2e\x49\x07\x9b\x30\x36\x07\x01\x2f\x3b\x07\x91\x2e\x30\x07\x92\x30\x2b\x07\xe3\x2e\x37\x07\xf9\x2e\x35\x07\x08\x31\x39\x07\x2f\x2f\x39\x07\xd8\x2e\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x37\x07\xed\x30\x37\x07\x3d\x2f\x3c\x07\x24\x2f\x35\x07\x1b\x30\x3e\x07\x89\x2e\x3e\x07\x72\x2e\x27\x07\xed\x2f\x2a\x07\x73\x2e\x3c\x07\x56\x2e\x24\x07\x2d\x30\x0a\x07\x89\x2e\x37\x07\x76\x2e\x24\x07\xcb\x2f\x19\x07\x3d\x2e\x31\x07\x3f\x2e\x32\x07\xd1\x2f\x1c\x07\x5b\x2e\x38\x07\x2e\x2e\x37\x07\xe4\x2f\x33\x07\x82\x2e\x39\x07\xe9\x2d\x47\x07\x40\x30\x3e\x07\xbd\x2e\x40\x07\x2e\x2e\x3b\x07\xdf\x2f\x29\x07\x0d\x2e\x3a\x07\x36\x2e\x29\x07\x13\x30\x23\x07\x17\x2e\x3d\x07\xdf\x2d\x27\x07\x8e\x2f\x24\x07\x23\x2e\x3a\x07\xca\x2d\x2f\x07\x2e\x2f\x2f\x07\xf5\x2d\x31\x07\x76\x2d\x3f\x07\x89\x2f\x2d\x07\xed\x2d\x2d\x07\x9d\x2d\x28\x07\xa1\x2f\x21\x07\xa3\x2d\x3e\x07\xaa\x2d\x2c\x07\x0c\x30\x22\x07\xfd\x2d\x32\x07\x85\x2d\x30\x07\xaf\x2f\x25\x07\xf9\x2d\x31\x07\x6a\x2d\x37\x07\x67\x2f\x21\x07\x5b\x2d\x2b\x07\xfa\x2c\x2a\x07\x44\x2f\x26\x07\x82\x2d\x38\x07\xf7\x2c\x39\x07\x3a\x2f\x2f\x07\x9a\x2d\x2f\x07\x40\x2d\x20\x07\x31\x2f\x12\x07\x3e\x2d\x28\x07\x22\x2d\x2b\x07\x88\x2f\x20\x07\x69\x2d\x2b\x07\x20\x2d\x2d\x07\xdb\x2f\x25\x07\xdb\x2d\x2f\x07\xb5\x2d\x2a\x07\xc1\x2f\x1d\x07\xbe\x2d\x32\x07\x87\x2d\x2c\x07\x7b\x2f\x24\x07\xa7\x2d\x28\x07\x6b\x2d\x2c\x07\x55\x2f\x1d\x07\xc7\x2d\x35\x07\x35\x2d\x2d\x07\x18\x2f\x22\x07\x93\x2d\x31\x07\x97\x2d\x2b\x07\x0f\x2f\x25\x07\x94\x2d\x27\x07\x41\x2d\x2d\x07\xae\x2f\x2a\x07\x97\x2d\x33\x07\x68\x2d\x39\x07\x20\x30\x24\x07\xb6\x2d\x2c\x07\xc6\x2d\x1e\x07\x1d\x30\x1a\x07\x23\x2e\x29\x07\xa9\x2d\x2f\x07\xc4\x2f\x20\x07\xd0\x2d\x25\x07\x7a\x2d\x1f\x07\x0f\x2f\x1a\x07\xee\x2d\x2d\x07\x66\x2d\x3c\x07\x3d\x2f\x34\x07\x9d\x2d\x36\x07\x3c\x2d\x30\x07\x76\x2f\x22\x07\x97\x2d\x28\x07\x4d\x2d\x34\x07\x98\x2f\x21\x07\xeb\x2d\x24\x07\x51\x2d\x3c\x07\x6e\x30\x22\x07\xf5\x2d\x2e\x07\xa7\x2d\x2e\x07\x11\x30\x2b\x07\x1f\x2e\x27\x07\xe3\x2d\x33\x07\xdb\x2f\x2b\x07\xf2\x2d\x2d\x07\x7c\x2d\x1f\x07\xba\x2f\x14\x07\x23\x2e\x1e\x07\x7a\x2d\x06\x07\x70\x30\xfa\x06\x07\x2e\x28\x07\x77\x2d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x20\x07\xe2\x2f\x18\x07\xe4\x2d\x29\x07\x62\x2d\x32\x07\x76\x2f\x23\x07\xa9\x2d\x23\x07\xbe\x2d\x38\x07\x7b\x2f\x24\x07\x74\x2d\x2b\x07\x78\x2d\x1f\x07\xb4\x2f\x15\x07\x97\x2d\x2a\x07\x60\x2d\x19\x07\x72\x2f\x09\x07\x68\x2d\x22\x07\x6f\x2d\x35\x07\x31\x2f\x1d\x07\x3b\x2d\x29\x07\x34\x2d\x2a\x07\xf6\x2e\x2c\x07\x68\x2d\x26\x07\xd9\x2c\x32\x07\x4c\x2f\x1b\x07\x42\x2d\x23\x07\xeb\x2c\x0f\x07\x38\x2f\xfe\x06\x31\x2d\x2d\x07\x1e\x2d\x1d\x07\x3a\x2f\x11\x07\xf4\x2c\x24\x07\x26\x2d\x2f\x07\x0d\x2f\x1b\x07\x8e\x2c\x29\x07\xbc\x2c\x31\x07\x2a\x2f\x28\x07\xb2\x2c\x39\x07\xc7\x2c\x31\x07\xb4\x2e\x25\x07\xa0\x2c\x32\x07\xbb\x2c\x0c\x07\x44\x2e\x02\x07\x79\x2c\x1b\x07\x65\x2c\xe6\x06\xd6\x2d\xd5\x06\x2e\x2c\xe8\x06\x91\x2b\xc2\x06\xb0\x2e\xae\x06\xe0\x2b\xba\x06\x17\x2a\x9b\x06\x48\x29\x94\x06\x8d\x27\x83\x06\xca\x24\xd4\x06\xe7\x28\xc6\x06\xcb\x27\xcd\x06\x1b\x26\xe2\x06\x6e\x29\xdc\x06\xf2\x27\xe9\x06\x73\x26\x06\x07\x8e\x29\x0b\x07\xe4\x27\xfe\x06\x86\x26\x16\x07\xff\x29\x12\x07\x6e\x28\x05\x07\x0a\x27\x07\x07\x54\x2a\xf9\x06\xbb\x28\x08\x07\x51\x27\x0c\x07\x62\x2a\xfd\x06\x9d\x28\xfc\x06\x2d\x27\x06\x07\x4f\x2a\xf5\x06\x96\x28\xfd\x06\x2d\x27\x03\x07\x8c\x2a\x02\x07\xc7\x28\x02\x07\x41\x27\x03\x07\x27\x2a\x03\x07\xa3\x28\x00\x07\x33\x27\x03\x07\xd0\x29\x07\x07\x68\x28\xfa\x06\xa5\x26\x05\x07\x08\x2a\xfc\x06\x64\x28\xfd\x06\xe5\x26\xfc\x06\x51\x2a\xef\x06\x07\x29\xf5\x06\x60\x27\xfb\x06\x4f\x2a\xf6\x06\xe1\x28\xf1\x06\x4f\x27\xfb\x06\x82\x2a\xf0\x06\xd1\x28\x06\x07\x4b\x27\x08\x07\x39\x2a\x01\x07\xd1\x28\x04\x07\x84\x27\xf4\x06\x12\x2a\xf4\x06\x34\x29\xf3\x06\xb1\x27\xfa\x06\x97\x29\xf6\x06\x83\x28\xf8\x06\x15\x27\xfb\x06\xac\x29\x01\x07\xb7\x28\xfc\x06\x1e\x27\x04\x07\x01\x2a\xf8\x06\xcf\x28\xf6\x06\x60\x27\xf8\x06\xea\x29\xf4\x06\xf6\x28\xf9\x06\x46\x27\xf4\x06\x1b\x2a\xf1\x06\xfd\x28\xf1\x06\x6a\x27\x09\x07\xdc\x29\xfa\x06\x29\x29\xfa\x06\x5e\x27\x08\x07\xb7\x29\x03\x07\x02\x29\xfa\x06\x58\x27\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x07\xa2\x29\xff\x06\xea\x28\xf7\x06\xe0\x26\x02\x07\xd3\x29\xfc\x06\xb3\x28\xf1\x06\xcd\x26\xf5\x06\xd5\x29\xf4\x06\x5f\x29\xf7\x06\x62\x27\x12\x07\xd8\x29\x05\x07\xf3\x28\xf7\x06\x6a\x27\x08\x07\xb7\x29\xff\x06\xde\x28\xf8\x06\x2c\x27\x13\x07\xd0\x29\x02\x07\xea\x28\xf5\x06\x38\x27\xef\x06\xfc\x29\xf2\x06\xe2\x28\xfd\x06\x6c\x27\x09\x07\xfa\x29\x04\x07\x96\x28\xfa\x06\x34\x27\x07\x07\x6b\x29\x06\x07\x46\x28\xf4\x06\x9f\x26\xf4\x06\x52\x29\xfb\x06\x86\x28\xf5\x06\x0d\x27\x08\x07\xbf\x29\x04\x07\xd0\x28\xf6\x06\x1f\x27\x07\x07\xfd\x29\x00\x07\xbb\x28\x01\x07\x0c\x27\xfe\x06\x0d\x2a\xf9\x06\xcb\x28\x01\x07\x38\x27\x0b\x07\xf8\x29\x04\x07\x05\x29\xfb\x06\x43\x27\x06\x07\xe3\x29\xff\x06\xbe\x28\xff\x06\x55\x27\x0c\x07\xb3\x29\xf4\x06\x29\x28\xf8\x06\xb6\x26\x06\x07\xec\x29\xf7\x06\x3f\x28\x01\x07\xd7\x26\x08\x07\x21\x2a\xf4\x06\x91\x28\xfa\x06\xec\x26\x13\x07\x23\x2a\xf9\x06\xaf\x28\xfc\x06\x13\x27\x0d\x07\xee\x29\x02\x07\xbf\x28\xf0\x06\xc2\x26\xff\x06\xe6\x29\xf2\x06\xaf\x28\xfc\x06\x1d\x27\xfd\x06\x02\x2a\x00\x07\x08\x29\xfb\x06\x20\x27\x0a\x07\xfa\x29\xff\x06\xa4\x28\xf9\x06\xbb\x26\x08\x07\x0c\x2a\x06\x07\xcc\x28\xf0\x06\x0a\x27\x08\x07\x00\x2a\xf8\x06\xad\x28\xfb\x06\x3b\x27\xfc\x06\xf4\x29\xfc\x06\x2c\x29\xf2\x06\x5d\x27\xfd\x06\xbc\x29\x0f\x07\x29\x29\x05\x07\x46\x27\x02\x07\xca\x29\xf7\x06\x03\x29\xf5\x06\x26\x27\xff\x06\xff\x29\x00\x07\x1c\x29\xee\x06\x4a\x27\x0a\x07\x86\x29\x01\x07\xda\x28\xed\x06\xc2\x26\x07\x07\xaa\x29\x02\x07\xb7\x28\x06\x07\xd2\x26\x07\x07\xb4\x29\xfe\x06\xfd\x28\x06\x07\x3d\x27\x05\x07\xaf\x29\x01\x07\xf5\x28\xfe\x06\xed\x26\xef\x06\xcb\x29\xf6\x06\x23\x29\xf6\x06\x26\x27\xed\x06\x91\x29\xe7\x06\xce\x28\x01\x07\x19\x27\xfe\x06\xd3\x29\xfa\x06\xe7\x28\x02\x07\x0f\x27\x01\x07\xb1\x29\xf9\x06\x84\x28\xfb\x06\xdd\x26\xff\x06\x59\x29\x10\x07\x8d\x28\xfb\x06\xd4\x26\x08\x07\x65\x29\x00\x07\xa4\x28\x05\x07\x0a\x27\x00\x07\xc7\x29\xf7\x06\xd7\x28\xf8\x06\x28\x27\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x06\x07\xbd\x29\x08\x07\xb8\x28\x05\x07\x3b\x27\x0c\x07\xe7\x29\xf9\x06\xca\x28\xf9\x06\xf2\x26\x06\x07\x94\x29\x0c\x07\x06\x29\xf3\x06\x3c\x27\xf3\x06\x47\x2a\xf2\x06\xfa\x28\xfb\x06\x39\x27\x11\x07\xdc\x29\x04\x07\xa6\x28\x01\x07\x13\x27\x0b\x07\xfa\x29\x08\x07\xd6\x28\xfc\x06\x2d\x27\x05\x07\xcf\x29\x04\x07\x0a\x29\xfb\x06\x47\x27\xf4\x06\x00\x2a\xf4\x06\xf2\x28\xf9\x06\x1b\x27\x13\x07\xbb\x29\xff\x06\xd0\x28\xf7\x06\x2a\x27\x00\x07\x0c\x2a\xfe\x06\xb9\x28\xfc\x06\x40\x27\x05\x07\xc4\x29\x06\x07\xed\x28\xf5\x06\x17\x27\x0c\x07\x7b\x29\xff\x06\x7f\x28\xf6\x06\xdc\x26\xe6\x06\xd8\x29\xdc\x06\xd2\x28\xdf\x06\x22\x27\xfa\x06\x9b\x29\xec\x06\xcd\x28\xfe\x06\x0f\x27\x01\x07\xe6\x29\xfd\x06\xe8\x28\xfc\x06\x1c\x27\x14\x07\x1f\x2a\x0a\x07\xf4\x28\x06\x07\x04\x27\x01\x07\xdb\x29\xfe\x06\x2a\x29\xf8\x06\xfd\x26\xf6\x06\xe8\x29\xea\x06\x44\x29\xf3\x06\x35\x27\x07\x07\x50\x2a\x07\x07\xcf\x28\x03\x07\x1f\x27\x0b\x07\xdd\x29\x01\x07\xcc\x28\xfb\x06\x44\x27\x04\x07\xdd\x29\x0e\x07\xdd\x28\xfc\x06\xf3\x26\x01\x07\x93\x29\xff\x06\x0a\x29\xf0\x06\xe8\x26\x13\x07\xc2\x29\x0e\x07\xe4\x28\xff\x06\xd7\x26\xf9\x06\x0a\x2a\xf3\x06\x02\x29\xee\x06\xcf\x26\x02\x07\xa8\x29\xfe\x06\xd4\x28\xf6\x06\xa0\x26\x0a\x07\x3a\x29\x04\x07\x9e\x28\xe8\x06\x19\x26\xe5\x06\x92\x29\xe8\x06\xd2\x28\xef\x06\x36\x26\x07\x07\x65\x29\x02\x07\x6d\x28\xed\x06\x0b\x26\x08\x07\x66\x29\x07\x07\x61\x28\xea\x06\xce\x25\xef\x06\xe9\x29\xec\x06\xa8\x28\xeb\x06\xe5\x25\xfb\x06\x6f\x29\xff\x06\x87\x28\xf0\x06\x07\x26\xfd\x06\x58\x29\xfb\x06\xc4\x28\xf2\x06\x51\x26\x06\x07\xe1\x28\xf7\x06\x3a\x28\xea\x06\xe8\x25\xfd\x06\xab\x28\xf8\x06\xb9\x27\xf1\x06\xe8\x25\xfc\x06\x3c\x29\xf3\x06\x51\x28\xf2\x06\x51\x26\x09\x07\x73\x29\x06\x07\xbb\x28\xfe\x06\x9d\x26\xfa\x06\xbb\x29\xfb\x06\x9c\x28\xfd\x06\xc9\x26\xec\x06\xa6\x29\xe6\x06\xd6\x28\xf1\x06\x7f\x26\x10\x07\xce\x29\xfb\x06\x8e\x28\xf4\x06\x86\x26\x00\x07\x92\x29\xfe\x06\xab\x28\xf6\x06\xa7\x26\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xf9\x06\xf3\x29\xe7\x06\x14\x28\xf2\x06\x30\x26\x06\x07\xae\x29\x04\x07\x9f\x28\xef\x06\xa7\x26\xff\x06\x9f\x29\xf9\x06\xab\x28\xf0\x06\xed\x26\xfe\x06\xa5\x29\xf6\x06\xd4\x28\xec\x06\xd8\x26\x0a\x07\xa0\x29\xf6\x06\xf9\x28\xee\x06\x01\x27\xf7\x06\xbd\x29\xf0\x06\xb0\x28\xf6\x06\xac\x26\x00\x07\x8f\x29\xfa\x06\x73\x28\xee\x06\x92\x26\xf9\x06\x31\x29\xfb\x06\x25\x28\xe3\x06\x2c\x26\x0c\x07\xb7\x29\xfc\x06\xd5\x28\xec\x06\xb9\x26\xfb\x06\x8f\x29\xf0\x06\x86\x28\xed\x06\xbb\x26\xfc\x06\x9b\x29\xe6\x06\x5d\x28\xed\x06\x95\x26\x0a\x07\xab\x29\x04\x07\x72\x28\xee\x06\xaa\x26\x02\x07\x8a\x29\xfa\x06\x94\x28\xef\x06\xba\x26\xfd\x06\x38\x29\xf9\x06\xaf\x28\xf9\x06\xb2\x26\xff\x06\x21\x29\xfd\x06\x2c\x28\xe9\x06\x54\x26\x05\x07\x18\x29\xff\x06\x5a\x28\xed\x06\x3e\x26\xfc\x06\x47\x29\xf2\x06\x72\x28\xf1\x06\x7a\x26\x0e\x07\x82\x29\xf3\x06\x18\x28\xea\x06\x7f\x26\x0b\x07\x38\x29\xfc\x06\x5a\x28\xf0\x06\x7b\x26\x09\x07\x49\x29\xf9\x06\x79\x28\xe9\x06\x28\x26\x08\x07\x80\x29\x03\x07\x69\x28\xf5\x06\x60\x26\xfa\x06\xe6\x28\xfc\x06\x04\x28\xee\x06\x07\x26\xf5\x06\x15\x29\xe4\x06\x03\x28\xf3\x06\x16\x26\xf8\x06\x75\x29\xe8\x06\x52\x28\xeb\x06\x56\x26\xfd\x06\x52\x29\xf7\x06\x4d\x28\xf4\x06\x38\x26\xfd\x06\x8a\x29\xee\x06\x19\x28\xec\x06\x23\x26\x08\x07\xee\x29\xf6\x06\x73\x28\xf5\x06\x45\x26\x07\x07\xd8\x29\xfd\x06\x36\x28\xe6\x06\x2f\x26\xf9\x06\xe4\x29\xef\x06\x24\x28\xf5\x06\x6c\x26\xfa\x06\x85\x29\xf7\x06\x4d\x28\xec\x06\x4a\x26\xed\x06\x40\x2a\xe6\x06\xad\x28\xfb\x06\xb9\x26\x0d\x07\xde\x2a\xf9\x06\x29\x28\xfc\x06\xed\x26\x06\x07\x0c\x2b\xf6\x06\x80\x28\xfc\x06\x09\x27\x0a\x07\x4d\x2a\x04\x07\x9a\x28\xf0\x06\xe0\x26\xf5\x06\x7d\x29\xf2\x06\xd2\x28\xf5\x06\xf9\x26\xe8\x06\xdb\x29\xde\x06\xac\x28\xf7\x06\xc5\x26\x05\x07\x4c\x29\x07\x07\x1c\x28\xf8\x06\x64\x26\xfc\x06\x7d\x29\xfb\x06\xbc\x28\xf6\x06\xfa\x26\xe3\x06\xcd\x29\xd9\x06\x0e\x29\xdb\x06\x26\x27\x01\x07\x5e\x29\x06\x07\xac\x28\xee\x06\xc2\x26\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe0\x06\xec\x29\xde\x06\xfd\x28\xcc\x06\x52\x27\xfc\x06\xa0\x29\xe8\x06\xf0\x28\xe2\x06\xe6\x26\x00\x07\x22\x29\x00\x07\x87\x28\xf2\x06\xc9\x26\xf2\x06\xa2\x28\xf1\x06\x09\x28\xe3\x06\xec\x25\xf7\x06\xf4\x28\xf3\x06\x71\x28\xf2\x06\xbd\x26\xfb\x06\x66\x29\xfe\x06\x66\x28\xf7\x06\xcd\x26\x04\x07\x4e\x29\x00\x07\x32\x28\xf7\x06\xbe\x26\xf9\x06\x06\x29\x02\x07\x80\x28\xf5\x06\xa8\x26\xfc\x06\x4b\x29\xfa\x06\x72\x28\xee\x06\xfa\x26\x0c\x07\x52\x29\xf3\x06\x2e\x28\xe9\x06\x83\x26\xef\x06\xc3\x28\xe6\x06\xcd\x27\xec\x06\xf3\x25\xf8\x06\x2b\x29\xf4\x06\x19\x28\xee\x06\x61\x26\xfb\x06\x67\x29\xf9\x06\x5a\x28\xf6\x06\xb3\x26\x04\x07\x72\x29\xf5\x06\x19\x28\xf5\x06\x83\x26\x01\x07\x62\x29\xe6\x06\x34\x28\xf1\x06\x63\x26\x0f\x07\xe6\x29\xf0\x06\x7e\x28\xf5\x06\x50\x26\x0b\x07\xdb\x29\xf8\x06\x7c\x28\xfa\x06\x7a\x26\xff\x06\x82\x29\xee\x06\x55\x28\xea\x06\x61\x26\x05\x07\x3d\x29\xf7\x06\x31\x28\xf3\x06\x6a\x26\xe5\x06\xa2\x29\xe1\x06\xbb\x28\xe9\x06\x8e\x26\xeb\x06\x84\x29\xea\x06\xd9\x28\xf9\x06\xc2\x26\x05\x07\x7d\x29\x05\x07\x7e\x28\xf2\x06\xb2\x26\x02\x07\xfa\x29\xf7\x06\x83\x28\xf8\x06\xe2\x26\x0a\x07\x08\x2a\xf8\x06\x92\x28\xeb\x06\xc0\x26\xef\x06\x5b\x2a\xe5\x06\x6f\x28\xf3\x06\xd0\x26\x0c\x07\x70\x2a\xf6\x06\x3e\x28\xf7\x06\xb0\x26\x0c\x07\x90\x2a\x03\x07\x73\x28\xef\x06\xcf\x26\x08\x07\x78\x2a\xfa\x06\xec\x28\xe8\x06\xc7\x26\xfc\x06\xc4\x29\xf9\x06\xa4\x28\xf6\x06\xbd\x26\x06\x07\xb4\x29\xf8\x06\x53\x28\xfe\x06\xa2\x26\x05\x07\x13\x2a\xf2\x06\x89\x28\xef\x06\x22\x27\xf9\x06\xc1\x29\xf3\x06\x8c\x28\xf1\x06\xbb\x26\x0c\x07\xae\x29\xfc\x06\x2d\x28\xf4\x06\x54\x26\xfd\x06\x4b\x2a\xee\x06\x4e\x28\xf4\x06\x8a\x26\x07\x07\xcf\x2a\xef\x06\x50\x28\xf4\x06\xcb\x26\x0c\x07\xb8\x2a\xf9\x06\x49\x28\xee\x06\xfd\x26\x05\x07\xfd\x2a\x04\x07\x4d\x28\xff\x06\x15\x27\x0a\x07\x8a\x2a\xf7\x06\x1c\x28\xf0\x06\xd0\x26\x04\x07\x12\x2a\xff\x06\x62\x28\xeb\x06\xac\x26\x04\x07\x7b\x29\xfd\x06\x1c\x28\xf3\x06\x57\x26\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x03\x07\x06\x2a\xfe\x06\x18\x28\xf1\x06\x87\x26\xfe\x06\x15\x2a\xef\x06\x0b\x28\xe2\x06\xbd\x26\xfe\x06\x08\x2a\xef\x06\x95\x28\xec\x06\x64\x26\x00\x07\x69\x2a\xf2\x06\x9f\x28\xea\x06\xa9\x26\xfd\x06\x2d\x2a\xf7\x06\x48\x28\xe3\x06\xc7\x26\x0e\x07\x21\x2a\xfa\x06\x6b\x28\xf2\x06\xe6\x26\x09\x07\xfe\x29\x0b\x07\x6c\x28\xef\x06\x6e\x26\xff\x06\xdc\x29\xfc\x06\x7b\x28\xe5\x06\xe1\x26\x02\x07\xda\x29\xfd\x06\x6d\x28\xf6\x06\xdd\x26\xfc\x06\x13\x2a\xec\x06\x7b\x28\xf1\x06\xc7\x26\x02\x07\x20\x2a\x00\x07\x5d\x28\xec\x06\xbd\x26\x0a\x07\x1c\x2a\xf5\x06\x69\x28\xfb\x06\xb8\x26\x06\x07\x70\x2a\xfb\x06\x63\x28\xf3\x06\xcd\x26\x08\x07\x53\x2a\xf4\x06\x51\x28\xf2\x06\xba\x26\x03\x07\x31\x2a\xf3\x06\x16\x28\xf2\x06\x7d\x26\xec\x06\xfa\x29\xe2\x06\x51\x28\xed\x06\xf0\x26\xfe\x06\x6e\x29\xfb\x06\x65\x28\xf3\x06\xaa\x26\xff\x06\xac\x29\xf8\x06\x58\x28\xeb\x06\x91\x26\x0b\x07\xf6\x29\x03\x07\x1d\x28\xeb\x06\x6a\x26\x00\x07\xa8\x29\xfb\x06\x39\x28\xe8\x06\xbe\x26\xfb\x06\x60\x29\xf6\x06\x03\x28\xeb\x06\x50\x26\xd8\x06\x6d\x29\xca\x06\x3f\x28\xd1\x06\xff\x25\xfe\x06\x63\x29\xf7\x06\x41\x28\xea\x06\x42\x26\xf5\x06\xd0\x29\xec\x06\x49\x28\xe0\x06\x59\x26\xf6\x06\xbf\x29\xe5\x06\x45\x28\xdd\x06\x57\x26\xef\x06\xaa\x29\xe2\x06\x59\x28\xf0\x06\x82\x26\xf8\x06\xa6\x29\xf0\x06\x9c\x28\xf1\x06\xc6\x26\x06\x07\xd3\x29\xfd\x06\x5d\x28\xef\x06\xbd\x26\x00\x07\xca\x29\xeb\x06\x15\x28\xe1\x06\x6c\x26\xf7\x06\xeb\x29\xfb\x06\x3a\x28\xde\x06\x63\x26\xfc\x06\xdf\x29\xea\x06\x6e\x28\xea\x06\x8e\x26\x0b\x07\xa2\x29\xfe\x06\xfc\x27\xf2\x06\xa2\x26\xfd\x06\x72\x29\xf7\x06\x4d\x28\xed\x06\xa0\x26\xea\x06\x0b\x2a\xe0\x06\x7a\x28\xe9\x06\x8a\x26\x0a\x07\x2a\x2a\xf5\x06\x2c\x28\xfb\x06\xc4\x26\x00\x07\xb8\x29\x04\x07\x54\x28\xdd\x06\x16\x26\x08\x07\xfa\x29\xf3\x06\x3c\x28\xef\x06\x32\x26\xf2\x06\x2d\x2a\xeb\x06\x0e\x28\xf2\x06\x1a\x26\xfc\x06\xdb\x29\xf3\x06\xee\x27\xed\x06\xe3\x25\x02\x07\xd4\x29\xf5\x06\xde\x27\xe7\x06\x92\x25\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe7\x06\x8a\x29\xd7\x06\xf1\x27\xf1\x06\xff\x25\x08\x07\x59\x29\xef\x06\x32\x28\xea\x06\xf0\x25\x00\x07\x55\x29\xf7\x06\xae\x27\xea\x06\xb0\x25\x06\x07\xa1\x29\xf0\x06\x76\x27\xe7\x06\x9e\x25\xf9\x06\xae\x29\xec\x06\xbd\x27\xeb\x06\xb8\x25\xfd\x06\xce\x29\xf2\x06\xa9\x27\xe6\x06\x96\x25\x06\x07\xe3\x29\x05\x07\xe1\x27\xf2\x06\xd8\x25\xf7\x06\x1f\x2a\xd4\x06\xd7\x27\xf1\x06\xe6\x25\x05\x07\x63\x29\xf8\x06\xdc\x27\xec\x06\xfb\x25\xee\x06\x33\x29\xeb\x06\xd6\x27\xe6\x06\xcc\x25\x02\x07\x64\x29\xed\x06\x68\x27\xe3\x06\x9c\x25\x03\x07\xa7\x29\xf3\x06\x96\x27\xfb\x06\xdd\x25\xff\x06\x6a\x29\xf4\x06\xaf\x27\xed\x06\xbe\x25\x03\x07\xd3\x29\xf4\x06\xb7\x27\xef\x06\x9d\x25\x01\x07\xc9\x29\xf0\x06\x88\x27\xf0\x06\x9e\x25\xf9\x06\xab\x29\xef\x06\xce\x27\xed\x06\xcf\x25\x02\x07\x79\x29\xff\x06\xcb\x27\xf4\x06\x90\x25\xde\x06\xe9\x28\xd5\x06\xb0\x27\xe2\x06\x5f\x25\x05\x07\xed\x28\xfc\x06\xe0\x27\xf3\x06\xe2\x25\xfe\x06\x29\x29\xf5\x06\xd0\x27\xec\x06\xf4\x25\xf2\x06\x97\x29\xe7\x06\xd4\x27\xf1\x06\x1f\x26\xf9\x06\x8b\x29\xf4\x06\xb3\x27\xea\x06\x0c\x26\x06\x07\x95\x29\xee\x06\xe6\x27\xe5\x06\x18\x26\x07\x07\x30\x29\xf5\x06\xc3\x27\xeb\x06\x97\x25\xfe\x06\xc5\x28\xf3\x06\xf1\x26\xe9\x06\x70\x25\xfd\x06\xea\x28\xfb\x06\x0c\x27\xf9\x06\xad\x25\x07\x07\xf9\x28\xed\x06\xb4\x27\xea\x06\xf4\x25\x01\x07\x1d\x29\xfb\x06\x96\x27\xee\x06\xcf\x25\xef\x06\xb3\x29\xe3\x06\xdd\x27\xdd\x06\x53\x26\x00\x07\xb3\x29\xf0\x06\xb1\x27\xea\x06\xfe\x25\xfb\x06\x68\x29\xe4\x06\xc0\x27\xe5\x06\xdb\x25\xf5\x06\xb1\x28\xf4\x06\x5e\x27\xec\x06\x77\x25\xe6\x06\x06\x29\xe1\x06\x58\x27\xe7\x06\xc2\x25\xe5\x06\x9d\x29\xcf\x06\x92\x27\xef\x06\x30\x26\xfc\x06\x4c\x29\xf6\x06\xb5\x27\xef\x06\x1d\x26\xf9\x06\x1f\x29\xfa\x06\xc7\x27\xf3\x06\xf9\x25\x06\x07\x46\x29\xfc\x06\xf2\x27\xf5\x06\x73\x26\x05\x07\x3a\x29\xf0\x06\x73\x27\xfa\x06\x39\x26\xfb\x06\xbd\x28\xf2\x06\x16\x27\xe8\x06\x80\x25\xfc\x06\xdf\x28\xf1\x06\x49\x27\xea\x06\xe3\x25\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfb\x06\x10\x29\xf5\x06\xae\x27\xe3\x06\x24\x26\xf3\x06\x65\x29\xdf\x06\xd1\x27\xd5\x06\x1c\x26\x05\x07\xf9\x28\xf3\x06\xac\x27\xf0\x06\x00\x26\xfc\x06\xd9\x28\xfc\x06\xf1\x27\xf2\x06\xf9\x25\xf2\x06\xd3\x28\xe2\x06\x9b\x27\xed\x06\xf1\x25\xf3\x06\x18\x28\xec\x06\xfe\x26\xec\x06\x88\x25\xf6\x06\x28\x28\xee\x06\x4a\x27\xee\x06\xa7\x25\xf1\x06\xcd\x28\xe1\x06\x79\x27\xf1\x06\x0c\x26\xfd\x06\x26\x29\xf4\x06\x91\x27\xe5\x06\xcb\x25\xee\x06\xc8\x28\xe6\x06\x9c\x27\xe7\x06\xda\x25\xfa\x06\xd7\x28\xf2\x06\x7c\x27\xf1\x06\xff\x25\x03\x07\xed\x28\xf8\x06\x10\x27\xec\x06\x91\x25\xf0\x06\x35\x28\xf0\x06\x0a\x27\xe1\x06\x71\x25\xfc\x06\xe9\x27\xec\x06\xad\x26\xe5\x06\x37\x25\xe1\x06\xbd\x28\xd3\x06\x65\x27\xe3\x06\xa3\x25\xea\x06\xe7\x28\xdf\x06\x4b\x27\xe6\x06\x96\x25\x01\x07\xd8\x28\xfc\x06\x5b\x27\xf4\x06\xc3\x25\xe3\x06\xa3\x28\xd8\x06\x64\x27\xea\x06\x7b\x25\xf2\x06\xb7\x28\xdf\x06\x2a\x27\xe2\x06\x54\x25\xea\x06\x85\x28\xe2\x06\xea\x26\xdc\x06\xce\x24\xf8\x06\x58\x28\xe4\x06\x5e\x26\xe6\x06\x9b\x24\x0d\x07\x32\x28\x07\x07\xf7\x26\xfb\x06\xc5\x24\xfa\x06\x64\x28\xf6\x06\x45\x27\xe6\x06\x99\x24\xeb\x06\xd8\x28\xe5\x06\x0c\x27\xe8\x06\xc9\x24\x03\x07\x86\x28\xf0\x06\xf3\x26\xea\x06\xde\x24\xe0\x06\x9e\x28\xd2\x06\x7d\x27\xe4\x06\x42\x25\xfe\x06\x4c\x28\xec\x06\x2f\x27\xfc\x06\x8c\x25\xe3\x06\xdb\x27\xe5\x06\xe2\x26\xed\x06\x10\x25\xfd\x06\x73\x28\xe7\x06\x38\x27\xf0\x06\x99\x25\xfb\x06\xcf\x28\xef\x06\x91\x27\xed\x06\xcf\x25\xf2\x06\x98\x28\xea\x06\x94\x27\xf2\x06\x95\x25\xf6\x06\xb4\x28\xea\x06\xa1\x27\xe0\x06\x69\x25\xee\x06\x90\x28\xeb\x06\xa6\x27\xdf\x06\x22\x25\x06\x07\xae\x28\xf3\x06\xb9\x27\xdd\x06\x1c\x25\xe5\x06\xea\x28\xd2\x06\x37\x27\xe4\x06\xda\x24\x01\x07\x08\x29\xed\x06\x99\x27\xeb\x06\x7d\x25\x06\x07\xde\x28\xfa\x06\xde\x27\xe7\x06\x64\x25\xf8\x06\x24\x29\xea\x06\xa9\x27\xe3\x06\x8d\x25\xc2\x06\xd9\x29\xb5\x06\x20\x28\xc1\x06\x05\x26\xff\x06\x8c\x29\xfe\x06\xad\x27\xee\x06\xfa\x25\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe6\x06\xa3\x29\xd7\x06\x52\x28\xcf\x06\x52\x26\xee\x06\xad\x28\xe9\x06\x45\x27\xdd\x06\x6d\x25\xeb\x06\x28\x29\xe6\x06\x6e\x27\xec\x06\x8e\x25\xf6\x06\x32\x29\xeb\x06\xa0\x27\xde\x06\x03\x26\xe9\x06\x33\x29\xe2\x06\xc2\x27\xe2\x06\x0c\x26\xf0\x06\xaf\x29\xe2\x06\xf1\x27\xef\x06\x1a\x26\xfa\x06\x95\x29\xf5\x06\xa9\x27\xf3\x06\x44\x26\x01\x07\x89\x29\xf4\x06\xab\x27\xf0\x06\x69\x26\x00\x07\x34\x29\xe7\x06\x96\x27\xee\x06\xb0\x25\xe2\x06\x41\x29\xde\x06\x8e\x27\xe7\x06\xa6\x25\xf3\x06\x7e\x29\xe2\x06\xca\x27\xe7\x06\xed\x25\xfe\x06\x7c\x29\xf5\x06\xc1\x27\xf6\x06\x14\x26\xe6\x06\x0b\x2a\xd9\x06\xad\x27\xf5\x06\x34\x26\x09\x07\xf1\x29\xf9\x06\xd9\x27\xf7\x06\x48\x26\xfa\x06\x57\x2a\xf2\x06\x39\x28\xe1\x06\x5a\x26\xfa\x06\xf6\x29\xd7\x06\x9b\x27\xf2\x06\x2f\x26\xfa\x06\x62\x29\xf0\x06\x6a\x27\xf1\x06\xeb\x25\xe7\x06\xd1\x29\xd4\x06\xcf\x27\xea\x06\x34\x26\xf5\x06\xcb\x29\xe6\x06\xbe\x27\xee\x06\x56\x26\x05\x07\xbf\x29\xf0\x06\xb5\x27\xf9\x06\x11\x26\xe0\x06\xca\x29\xd8\x06\xdb\x27\xee\x06\x2c\x26\xf4\x06\xaf\x29\xeb\x06\xfd\x27\xf1\x06\x5e\x26\xfe\x06\xbc\x29\xdf\x06\x18\x28\xec\x06\x06\x26\xf6\x06\x9b\x29\xed\x06\x67\x27\xe0\x06\xe4\x25\xf1\x06\xcb\x29\xe7\x06\xbf\x27\xf1\x06\x38\x26\xfd\x06\xd9\x29\xdf\x06\x5a\x28\xe4\x06\x98\x26\x0e\x07\xa7\x29\xf0\x06\x03\x28\xee\x06\x86\x26\xfa\x06\x6e\x29\xf6\x06\x26\x28\xef\x06\x14\x26\xfc\x06\x1a\x2a\xe5\x06\x0e\x28\xde\x06\x90\x25\x00\x00\x68\x14\x00\x00\xf9\x14\x00\x00\xa2\x15\x00\x00\x69\x14\x00\x00\xf9\x14\x00\x00\xa2\x15\x00\x00\x6a\x14\x00\x00\xf9\x14\x00\x00\xa2\x15\x00\x00\x5a\x14\x00\x00\x1a\x15\x00\x00\xa2\x15\x00\x00\x5a\x14\x00\x00\x18\x15\x00\x00\xa2\x15\x00\x00\x5a\x14\x00\x00\x16\x15\x00\x00\xa2\x15\x29\x07\xa4\x2e\x1d\x07\x0b\x2c\x12\x07\x12\x2a\x15\x07\xee\x2d\x0f\x07\x76\x2c\x0a\x07\xf9\x2a\x1d\x07\x3b\x2e\x14\x07\x92\x2c\x1e\x07\x69\x2b\x24\x07\x9e\x2e\x16\x07\x13\x2d\x15\x07\x7e\x2b\x35\x07\x41\x2f\x26\x07\xdd\x2c\x20\x07\x07\x2c\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x2e\x07\x17\x2f\x1b\x07\x51\x2c\x20\x07\x41\x2b\x1f\x07\xbb\x2e\x18\x07\x6e\x2c\x16\x07\x52\x2b\x26\x07\x57\x2e\x16\x07\x6b\x2c\x14\x07\x00\x2b\x23\x07\x41\x2e\x10\x07\xfc\x2b\x13\x07\x18\x2b\x22\x07\x3d\x2e\x14\x07\x54\x2c\x0f\x07\x5c\x2b\x2b\x07\x99\x2e\x1b\x07\x04\x2c\x12\x07\xa1\x2a\x2c\x07\xd1\x2e\x04\x07\x00\x2c\x13\x07\xce\x2a\x18\x07\x3d\x2f\x0e\x07\x56\x2c\x15\x07\x46\x2b\x23\x07\xca\x2e\x17\x07\x4b\x2c\x0d\x07\x70\x2b\x22\x07\xc7\x2e\x1b\x07\x12\x2c\x20\x07\x41\x2b\x29\x07\x88\x2e\x23\x07\x57\x2c\x14\x07\x55\x2b\x18\x07\x74\x2e\x07\x07\x54\x2c\x16\x07\x56\x2b\x20\x07\xd6\x2e\x13\x07\x63\x2c\x0c\x07\x35\x2b\x18\x07\xca\x2e\x15\x07\xb6\x2c\x15\x07\x97\x2b\x2e\x07\xa9\x2e\x1a\x07\x4e\x2c\x1c\x07\x35\x2b\x1f\x07\x92\x2e\x1a\x07\x59\x2c\x15\x07\x37\x2b\x1e\x07\x5a\x2e\x17\x07\x0d\x2c\x11\x07\x2f\x2b\x1d\x07\x46\x2e\x0f\x07\xf7\x2b\x11\x07\x51\x2b\x30\x07\x2f\x2e\x1a\x07\x43\x2c\x1c\x07\x37\x2b\x1c\x07\xeb\x2d\x0a\x07\x04\x2c\x0a\x07\xdd\x2a\x22\x07\x40\x2e\x1b\x07\x54\x2c\x16\x07\x24\x2b\x20\x07\x28\x2e\x0d\x07\x6f\x2c\x0a\x07\x36\x2b\x11\x07\x82\x2e\x00\x07\x25\x2c\x16\x07\x1c\x2b\x08\x07\x95\x2e\xea\x06\x5c\x2c\x10\x07\x1e\x2b\x02\x07\xae\x2e\xfd\x06\xb6\x2c\xf2\x06\x5a\x2b\x10\x07\x65\x2e\x03\x07\x27\x2c\x11\x07\x93\x2b\x1f\x07\x33\x2e\x1b\x07\x19\x2c\x0d\x07\x26\x2b\x13\x07\x39\x2e\x1f\x07\x9f\x2c\x09\x07\x30\x2b\x22\x07\x0e\x2e\x13\x07\x6c\x2c\x19\x07\x46\x2b\x1f\x07\xc4\x2d\x15\x07\x57\x2c\x1b\x07\x35\x2b\x1c\x07\x6b\x2d\x0d\x07\x2a\x2c\x17\x07\x49\x2b\x17\x07\xc6\x2d\x07\x07\x1c\x2c\x10\x07\x23\x2b\x24\x07\x40\x2d\x19\x07\x48\x2c\x12\x07\x05\x2b\x12\x07\x11\x2d\x10\x07\xe1\x2b\x0f\x07\x08\x2b\x13\x07\xf1\x2c\x10\x07\x91\x2b\x0e\x07\xe5\x2a\x11\x07\x33\x2d\x09\x07\x3f\x2c\x09\x07\x01\x2b\x21\x07\x67\x2d\x0b\x07\xac\x2b\x10\x07\xfd\x2a\x1b\x07\x70\x2d\x15\x07\xfd\x2b\x0f\x07\xf5\x2a\x16\x07\x6f\x2d\x14\x07\x28\x2c\x0b\x07\xdf\x2a\x08\x07\xad\x2d\xfc\x06\xdc\x2b\x12\x07\xe3\x2a\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0b\x07\xfb\x2d\x02\x07\x69\x2c\x02\x07\x46\x2b\x24\x07\xc2\x2d\x19\x07\x32\x2c\x19\x07\x08\x2b\x27\x07\xfa\x2d\x0d\x07\xe5\x2b\x17\x07\x5c\x2b\x2b\x07\xf6\x2d\x1f\x07\x3f\x2c\x15\x07\x92\x2b\x24\x07\xa2\x2d\x15\x07\xfe\x2b\x12\x07\x1c\x2b\x21\x07\xdd\x2d\x10\x07\xf1\x2b\x1a\x07\xfa\x2a\x24\x07\xcd\x2d\x12\x07\xdc\x2b\x18\x07\xe6\x2a\x1f\x07\x0c\x2e\x0e\x07\x50\x2c\x0a\x07\x46\x2b\x1d\x07\x26\x2e\x0c\x07\x09\x2c\x10\x07\x27\x2b\x10\x07\x3c\x2e\x01\x07\xd9\x2b\x0c\x07\x32\x2b\x23\x07\x91\x2d\x1a\x07\x29\x2c\x20\x07\x61\x2b\x13\x07\xc2\x2d\x0e\x07\xa2\x2c\x07\x07\xf4\x2a\x08\x07\x4a\x2e\xfe\x06\x1f\x2c\x0c\x07\x2a\x2b\x2c\x07\x12\x2e\x0f\x07\xf4\x2b\x13\x07\xe1\x2a\x19\x07\x32\x2e\x06\x07\xc4\x2b\x17\x07\x02\x2b\x1d\x07\xe7\x2d\x0c\x07\x97\x2b\x0c\x07\xcf\x2a\x1c\x07\xbd\x2d\x10\x07\xab\x2b\x0b\x07\xab\x2a\x16\x07\xd4\x2d\x0f\x07\xf7\x2b\x0b\x07\x13\x2b\x1c\x07\xa8\x2d\x05\x07\xed\x2b\x0b\x07\xc0\x2a\x21\x07\x7e\x2d\x1f\x07\x78\x2d\x0e\x07\xb4\x2a\x21\x07\x83\x2d\x15\x07\xd6\x2b\x13\x07\xa9\x2a\x1f\x07\x46\x2e\x09\x07\xe5\x2b\x12\x07\xf6\x2a\x19\x07\xff\x2d\x07\x07\x04\x2c\x0a\x07\xab\x2a\x13\x07\x5d\x2d\x0a\x07\xf3\x2b\x0f\x07\x57\x2a\x27\x07\xf0\x2d\x19\x07\x0a\x2c\x12\x07\xc4\x2a\x18\x07\xdb\x2d\x08\x07\x0d\x2c\x16\x07\x99\x2a\x1b\x07\x7c\x2d\x14\x07\xe2\x2b\x0e\x07\x87\x2a\x27\x07\x5a\x2d\x17\x07\xa9\x2b\x1b\x07\x8b\x2a\x1f\x07\x56\x2d\x18\x07\xe5\x2b\x0a\x07\x6f\x2a\xef\x06\x0c\x2e\xd2\x06\xfd\x2b\x08\x07\x50\x2a\x22\x07\x57\x2d\x0f\x07\x75\x2b\x1a\x07\x60\x2a\xf7\x06\xfb\x2d\xf4\x06\xdd\x2b\x10\x07\xb3\x2a\x1b\x07\x16\x2e\x16\x07\x14\x2c\x0b\x07\x99\x2a\x26\x07\xf9\x2d\x17\x07\x0b\x2c\x0b\x07\xc3\x2a\x2d\x07\xe2\x2d\x1c\x07\xe3\x2b\x15\x07\xcf\x2a\x1f\x07\xd7\x2d\x17\x07\x31\x2c\x10\x07\xc3\x2a\x1c\x07\xbf\x2d\x0f\x07\x1f\x2c\x0e\x07\xd7\x2a\x23\x07\xcf\x2d\x0d\x07\xfb\x2b\x0c\x07\xc3\x2a\x1b\x07\xf2\x2d\x06\x07\x19\x2c\x0b\x07\x8d\x2a\x25\x07\x2e\x2e\x11\x07\x28\x2c\x1b\x07\xed\x2a\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x2b\x07\xf7\x2d\x15\x07\xec\x2b\x14\x07\xda\x2a\x1b\x07\xb9\x2d\x17\x07\x1f\x2c\x0c\x07\xd7\x2a\x22\x07\xeb\x2d\x18\x07\x11\x2c\x0e\x07\xe2\x2a\x14\x07\xa6\x2d\x0e\x07\xfb\x2b\x11\x07\xcc\x2a\x13\x07\x82\x2d\x0c\x07\xf9\x2b\x0c\x07\xc6\x2a\x18\x07\x94\x2d\xfd\x06\xd4\x2b\x11\x07\x66\x2a\x0e\x07\xbd\x2d\x09\x07\x1f\x2c\x1c\x07\xea\x2a\x18\x07\x2b\x2e\x06\x07\x06\x2c\x11\x07\xdb\x2a\x1d\x07\xe4\x2d\x12\x07\x39\x2c\x10\x07\xca\x2a\xe5\x06\x2a\x2e\xdb\x06\x8a\x2c\x09\x07\x85\x2a\x17\x07\x1f\x2e\x02\x07\xf5\x2b\x0e\x07\x9c\x2a\x19\x07\xa4\x2e\x0b\x07\x89\x2b\x09\x07\xc7\x2a\x10\x07\x73\x2d\x00\x07\x8c\x2b\x14\x07\xcb\x2a\x26\x07\xfc\x2d\x18\x07\x07\x2c\x0e\x07\xad\x2a\x2a\x07\xbe\x2d\x13\x07\x19\x2c\x09\x07\xfa\x2a\x1f\x07\x09\x2e\x20\x07\x48\x2c\x0a\x07\xc6\x2a\x1d\x07\x37\x2e\x1a\x07\xd7\x2b\x13\x07\xbc\x2a\x24\x07\x25\x2e\x0e\x07\xf9\x2b\x0e\x07\xd6\x2a\x26\x07\xff\x2d\x15\x07\x2a\x2c\x10\x07\xb4\x2a\x16\x07\xa2\x2d\x11\x07\xc8\x2b\x13\x07\x66\x2a\x15\x07\x1c\x2e\x0f\x07\x11\x2c\x08\x07\x92\x2a\x24\x07\x3b\x2e\x18\x07\xf0\x2b\x0e\x07\xb0\x2a\x12\x07\xb0\x2d\x14\x07\x80\x2c\x0d\x07\xb1\x2a\x01\x07\x82\x2d\x07\x07\x76\x2c\x0c\x07\xb9\x2a\x18\x07\xc1\x2d\x19\x07\x02\x2c\x16\x07\xe9\x2a\x21\x07\x2a\x2e\x10\x07\x0d\x2c\x0e\x07\xb4\x2a\x21\x07\xeb\x2d\x16\x07\xf6\x2b\x03\x07\x4f\x2a\x18\x07\x16\x2e\xf8\x06\xfb\x2b\x17\x07\xe5\x2a\x23\x07\x37\x2e\x1c\x07\x49\x2c\x18\x07\x01\x2b\x27\x07\x15\x2e\x1e\x07\x52\x2c\x1c\x07\x42\x2b\x35\x07\x23\x2e\x1d\x07\x56\x2c\x1d\x07\x22\x2b\x1f\x07\x87\x2d\x20\x07\x8e\x2c\x17\x07\x07\x2b\x0d\x07\x13\x2e\x0f\x07\x73\x2c\x11\x07\x15\x2b\x28\x07\x35\x2e\x1d\x07\x68\x2c\x2a\x07\x86\x2b\x23\x07\xc3\x2e\x1b\x07\x68\x2c\x1b\x07\x3c\x2b\x24\x07\x84\x2e\x15\x07\xa1\x2c\x23\x07\x5d\x2b\x30\x07\x39\x2e\x27\x07\xcb\x2c\x28\x07\x61\x2b\x1c\x07\x6c\x2e\x17\x07\xda\x2c\x2a\x07\x51\x2b\x22\x07\x50\x2e\x19\x07\xe1\x2c\x18\x07\x25\x2b\x28\x07\x28\x2e\x1c\x07\xec\x2c\x17\x07\x65\x2b\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x17\x07\x60\x2e\x13\x07\xc3\x2c\x14\x07\x15\x2b\x30\x07\x2a\x2e\x17\x07\x9e\x2c\x13\x07\x22\x2b\x17\x07\x6e\x2e\x16\x07\xe5\x2c\x18\x07\x79\x2b\x18\x07\x6f\x2e\xff\x06\x9c\x2c\x0c\x07\x5d\x2b\x10\x07\x92\x2e\xf9\x06\x81\x2c\x13\x07\x3b\x2b\x15\x07\xa9\x2e\x01\x07\x78\x2c\x1c\x07\x22\x2b\x21\x07\x4d\x2e\x16\x07\x89\x2c\x13\x07\x1d\x2b\x1d\x07\x05\x2e\x12\x07\x64\x2c\x13\x07\x60\x2b\x20\x07\x14\x2e\x17\x07\x27\x2c\x15\x07\xc4\x2a\x2d\x07\xbf\x2e\x1e\x07\x4e\x2c\x19\x07\x1e\x2b\x17\x07\x0b\x2f\x00\x07\x69\x2c\x15\x07\x68\x2b\x2b\x07\xaf\x2e\x1b\x07\x4c\x2c\x1b\x07\x01\x2b\x17\x07\xbf\x2e\x0e\x07\x8d\x2c\x12\x07\x06\x2b\x26\x07\x58\x2e\x1e\x07\x8e\x2c\x1f\x07\x57\x2b\x28\x07\x6b\x2e\x19\x07\x98\x2c\x18\x07\x49\x2b\x23\x07\x33\x2e\x16\x07\x6b\x2c\x22\x07\x26\x2b\x18\x07\x27\x2e\x0d\x07\xc7\x2c\x11\x07\x0d\x2b\x1b\x07\x8e\x2e\x0b\x07\xc2\x2c\x17\x07\x3f\x2b\x19\x07\xd9\x2e\x06\x07\x69\x2c\x12\x07\x08\x2b\x27\x07\xd9\x2e\x19\x07\x84\x2c\x25\x07\x3f\x2b\x1d\x07\xb3\x2e\x0d\x07\x9c\x2c\x28\x07\x37\x2b\x20\x07\x87\x2e\x07\x07\x7c\x2c\x14\x07\x1d\x2b\x20\x07\x85\x2e\x0b\x07\x5e\x2c\x0e\x07\xd3\x2a\x0a\x07\x76\x2e\xfa\x06\x68\x2c\x10\x07\x0d\x2b\x25\x07\x90\x2e\x12\x07\x92\x2c\x12\x07\x3e\x2b\x22\x07\x55\x2e\x07\x07\x26\x2c\x0e\x07\x16\x2b\x23\x07\xf5\x2e\x13\x07\x11\x2c\x0d\x07\x43\x2b\x25\x07\x72\x2f\x0d\x07\xd6\x2b\x13\x07\x6a\x2b\x26\x07\x51\x2f\x0c\x07\x4c\x2c\x15\x07\x48\x2b\x28\x07\x82\x2e\x1f\x07\x60\x2c\x19\x07\xda\x2a\x24\x07\x31\x2e\x1b\x07\xe6\x2b\x13\x07\x7c\x2a\x1c\x07\x45\x2e\x0b\x07\xe7\x2b\x0b\x07\xeb\x2a\x25\x07\xc0\x2d\x09\x07\x2e\x2c\x19\x07\x10\x2b\x1f\x07\x98\x2d\x13\x07\x41\x2c\x11\x07\xf6\x2a\x26\x07\xc2\x2d\x18\x07\x52\x2c\x10\x07\xfc\x2a\x17\x07\x04\x2e\x0a\x07\x5b\x2c\x05\x07\x0b\x2b\x1e\x07\x53\x2e\x12\x07\x4c\x2c\x12\x07\x03\x2b\x1f\x07\x91\x2e\x03\x07\xbf\x2b\x06\x07\x9b\x2a\x17\x07\xb3\x2e\x03\x07\x25\x2c\x0e\x07\x46\x2b\x20\x07\x3f\x2e\x13\x07\x05\x2c\x0e\x07\x0e\x2b\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x23\x07\x30\x2e\x13\x07\x47\x2c\x10\x07\xfe\x2a\x0d\x07\x9c\x2d\xfd\x06\x37\x2c\x0d\x07\xf0\x2a\x26\x07\xec\x2d\x05\x07\x4a\x2c\x12\x07\xdb\x2a\x15\x07\x9a\x2d\x14\x07\x03\x2c\x12\x07\xc8\x2a\x1d\x07\x4f\x2d\x18\x07\xf9\x2b\x0d\x07\x9b\x2a\x20\x07\x72\x2d\x1c\x07\x40\x2c\x11\x07\xaa\x2a\x1c\x07\xfe\x2d\x06\x07\x2a\x2c\x14\x07\xbb\x2a\x29\x07\xf4\x2d\x12\x07\xd1\x2b\x0d\x07\xa6\x2a\x12\x07\x58\x2d\x02\x07\xe3\x2b\x13\x07\xaa\x2a\x08\x07\x69\x2d\xff\x06\x10\x2c\x04\x07\x87\x2a\x17\x07\x39\x2d\x10\x07\xed\x2b\x0a\x07\x9b\x2a\x1d\x07\x68\x2d\x0b\x07\xb2\x2b\x0f\x07\x58\x2a\x1f\x07\xae\x2d\x13\x07\x12\x2c\x21\x07\x90\x2a\x2a\x07\x6d\x2d\x18\x07\x03\x2c\x17\x07\xc1\x2a\x1e\x07\x7b\x2d\x1b\x07\x24\x2c\x12\x07\x82\x2a\x1a\x07\x2e\x2d\x10\x07\xe8\x2b\x0d\x07\xb1\x2a\x1a\x07\x3e\x2d\x15\x07\x1f\x2c\x14\x07\xaf\x2a\x11\x07\xda\x2c\x09\x07\x00\x2c\x0a\x07\x80\x2a\x17\x07\xd5\x2c\x10\x07\x89\x2b\x0b\x07\x5a\x2a\x1f\x07\xe5\x2c\x0e\x07\x0a\x2b\x0c\x07\xf2\x29\x21\x07\x1a\x2d\x1f\x07\xd5\x2b\x12\x07\x7b\x2a\x23\x07\x20\x2d\x10\x07\x12\x2c\x0d\x07\x84\x2a\x1f\x07\x5f\x2d\x0f\x07\xf9\x2b\x0c\x07\x71\x2a\x1e\x07\xe2\x2c\x0d\x07\xd8\x2b\x0b\x07\x90\x2a\x1b\x07\xdb\x2c\x0d\x07\xbc\x2b\x0a\x07\x30\x2a\x17\x07\x87\x2c\x11\x07\x02\x2b\x06\x07\xcd\x29\x25\x07\x74\x2c\x15\x07\xf2\x2a\x0f\x07\xc6\x29\x12\x07\x1c\x2d\x0c\x07\xda\x2b\x09\x07\x79\x2a\x08\x07\xf2\x2c\x01\x07\x65\x2b\x07\x07\x21\x2a\x05\x07\xe2\x2c\x03\x07\x4b\x2b\x04\x07\x01\x2a\x09\x07\x52\x2d\xf8\x06\x24\x2b\x11\x07\x62\x2a\x1d\x07\x22\x2e\x11\x07\x4a\x2b\x0d\x07\x71\x2a\x1f\x07\x99\x2d\x12\x07\x90\x2a\x0e\x07\x15\x2a\x1c\x07\x8d\x2c\x16\x07\x84\x2a\x03\x07\x54\x29\x02\x07\xd8\x2c\xfd\x06\x99\x2b\x0b\x07\x10\x2a\x11\x07\x08\x2d\x05\x07\x3d\x2b\x09\x07\x4b\x2a\x14\x07\x5f\x2d\x0d\x07\x8f\x2b\x05\x07\xf0\x29\x14\x07\x1f\x2d\x14\x07\x97\x2b\x0a\x07\x33\x2a\x0a\x07\x26\x2d\xfe\x06\x7e\x2b\x09\x07\x3c\x2a\x20\x07\xd5\x2c\x18\x07\x9b\x2b\x19\x07\x38\x2a\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x14\x07\x70\x2c\x15\x07\xee\x2a\x14\x07\xc3\x29\x1e\x07\xb0\x2c\x0d\x07\x63\x2b\x03\x07\x4b\x2a\x11\x07\x1a\x2d\x00\x07\xc6\x2b\x03\x07\x72\x2a\x1c\x07\x1d\x2d\x11\x07\xa1\x2b\x19\x07\x93\x2a\x18\x07\xd0\x2c\x19\x07\xb2\x2b\xff\x06\x2a\x2a\x1b\x07\x4b\x2d\x12\x07\xbb\x2b\x07\x07\x3c\x2a\x18\x07\x0b\x2d\x10\x07\x56\x2b\x0c\x07\x3d\x2a\x18\x07\x66\x2c\x0e\x07\x4a\x2b\x07\x07\xd7\x29\x11\x07\xd4\x2c\x03\x07\x61\x2b\x09\x07\x29\x2a\x0b\x07\xfb\x2c\x0d\x07\x41\x2c\x0c\x07\x3f\x2a\x15\x07\x52\x2d\xfb\x06\x73\x2b\x0c\x07\x3d\x2a\x0d\x07\xff\x2c\x0b\x07\x4a\x2b\x0b\x07\x02\x2a\x11\x07\xcc\x2c\x0a\x07\x64\x2b\x0b\x07\x16\x2a\x1e\x07\x0e\x2d\x10\x07\x1d\x2b\x09\x07\xf1\x29\x12\x07\x99\x2c\x01\x07\xc3\x2a\xfe\x06\x88\x29\x18\x07\x97\x2c\x09\x07\xcf\x2a\x11\x07\xb2\x29\x17\x07\xb4\x2c\x10\x07\x3a\x2b\x05\x07\xc7\x29\x13\x07\xa7\x2c\x09\x07\x25\x2b\x06\x07\x22\x2a\x23\x07\x85\x2d\x10\x07\xdf\x2b\x07\x07\x79\x2a\x12\x07\xb4\x2d\x0c\x07\xe4\x2b\x09\x07\x83\x2a\x23\x07\x61\x2d\x15\x07\xf1\x2b\x10\x07\x83\x2a\x1c\x07\x5f\x2d\x12\x07\xa9\x2b\x10\x07\x1d\x2a\x0d\x07\xa8\x2d\xf6\x06\xac\x2b\x07\x07\x25\x2a\x11\x07\xab\x2d\x0e\x07\xec\x2b\x12\x07\x95\x2a\x1d\x07\x98\x2d\x15\x07\x0a\x2c\x0b\x07\xa4\x2a\x17\x07\x37\x2d\x12\x07\x2b\x2c\x17\x07\x6f\x2a\x21\x07\x46\x2d\x0c\x07\xc9\x2b\x06\x07\x6c\x2a\x12\x07\x75\x2d\x09\x07\xbb\x2b\x09\x07\x7b\x2a\x19\x07\x3f\x2d\x13\x07\xa4\x2b\x0b\x07\x30\x2a\x16\x07\x02\x2d\x0f\x07\xa8\x2b\x10\x07\x41\x2a\x11\x07\x82\x2d\x0d\x07\xcc\x2b\x01\x07\xbc\x2a\xfa\x06\xb4\x2d\xed\x06\x30\x2c\x09\x07\x6e\x2a\x1e\x07\x51\x2d\x10\x07\x09\x2c\x1d\x07\x74\x2a\x17\x07\x27\x2d\x08\x07\xda\x2b\x0b\x07\x60\x2a\xfa\x06\x75\x2d\xef\x06\xfb\x2b\x03\x07\x95\x2a\x1f\x07\x00\x2d\x14\x07\x8b\x2b\x0c\x07\x67\x2a\x15\x07\x17\x2d\x0c\x07\x5b\x2b\x0b\x07\x06\x2a\x0f\x07\x5f\x2d\x0b\x07\xdd\x2b\x09\x07\x82\x2a\x10\x07\x82\x2d\x05\x07\xeb\x2b\x0d\x07\x6c\x2a\x24\x07\xa7\x2d\x16\x07\xa6\x2b\x11\x07\x4d\x2a\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x1c\x07\x19\x2d\x13\x07\x8d\x2b\x12\x07\x4d\x2a\x1b\x07\x1b\x2d\x0f\x07\x7f\x2b\x14\x07\x38\x2a\x07\x07\x3e\x2d\xfa\x06\x7f\x2b\x19\x07\x4b\x2a\x17\x07\xc8\x2c\x0c\x07\xf4\x2a\x11\x07\xc9\x29\x10\x07\x6a\x2d\xfb\x06\x9a\x2b\x11\x07\x3a\x2a\x1e\x07\xeb\x2d\x01\x07\xba\x2b\x14\x07\x81\x2a\x21\x07\x75\x2d\x0f\x07\xb2\x2b\x12\x07\x5c\x2a\x15\x07\x23\x2d\x1b\x07\xa7\x2b\x0b\x07\x23\x2a\x11\x07\x03\x2d\x13\x07\xc2\x2b\x08\x07\x0e\x2a\x16\x07\x16\x2d\x0f\x07\x2f\x2b\x13\x07\x5e\x2a\x1c\x07\xfa\x2c\x0d\x07\x22\x2b\xff\x06\xa0\x29\x02\x07\x70\x2d\xec\x06\x90\x2b\x0d\x07\x19\x2a\x0f\x07\x6e\x2d\x07\x07\xc5\x2b\x09\x07\x57\x2a\xfd\x06\x2e\x2d\xf5\x06\xb3\x2b\x0d\x07\x26\x2a\x17\x07\x02\x2d\x17\x07\xa9\x2b\x09\x07\x1a\x2a\x0d\x07\xe2\x2c\x00\x07\x95\x2b\x03\x07\x30\x2a\x18\x07\x29\x2d\x11\x07\x87\x2b\x0d\x07\x5f\x2a\x1b\x07\x19\x2d\x1b\x07\x2a\x2b\x0b\x07\xa2\x29\x18\x07\x30\x2d\x0f\x07\x2a\x2b\x0d\x07\xe8\x29\x14\x07\x1f\x2d\x0d\x07\x8b\x2b\x11\x07\x38\x2a\x1a\x07\x94\x2d\x0c\x07\x4a\x2b\x0d\x07\x31\x2a\x20\x07\x24\x2d\x14\x07\x3a\x2b\x09\x07\x17\x2a\x0e\x07\x5a\x2d\xfa\x06\x5c\x2b\x13\x07\x3a\x2a\x1d\x07\x2d\x2d\x2b\x07\xd6\x2b\x18\x07\x4c\x2a\x12\x07\x99\x2c\x04\x07\x61\x2b\x0c\x07\xe0\x29\x10\x07\x3f\x2c\x07\x07\x92\x2a\x10\x07\xb2\x29\x28\x07\xf8\x2c\x15\x07\x58\x2b\x0e\x07\x31\x2a\x14\x07\x12\x2d\x0c\x07\x7c\x2b\x05\x07\x32\x2a\x0a\x07\xf1\x2c\xfb\x06\x98\x2b\x0e\x07\x58\x2a\x1d\x07\xbe\x2c\x12\x07\x46\x2b\x10\x07\x3c\x2a\x0f\x07\xa5\x2c\x10\x07\x3f\x2b\x0b\x07\x36\x2a\xff\x06\x33\x2d\xf2\x06\x96\x2b\x0d\x07\x0c\x2a\x10\x07\x7d\x2c\x03\x07\xd2\x2a\x0c\x07\xa4\x29\x0e\x07\xe2\x2c\x07\x07\x7d\x2b\x06\x07\x16\x2a\x14\x07\xaa\x2c\x0a\x07\x4b\x2b\x15\x07\x1b\x2a\x1b\x07\xf8\x2c\x08\x07\x66\x2b\x08\x07\xe9\x29\x08\x07\xdf\x2c\xfa\x06\x3c\x2b\x0c\x07\xf4\x29\x10\x07\x85\x2c\x12\x07\x39\x2b\x0a\x07\x03\x2a\x11\x07\xcb\x2c\x00\x07\xeb\x2a\x0e\x07\xd5\x29\x0a\x07\x29\x2c\x06\x07\x83\x2a\x08\x07\x1a\x29\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x16\x07\x77\x2c\x0f\x07\x89\x2a\x12\x07\x63\x29\x07\x07\xaf\x2c\x0b\x07\x33\x2b\x07\x07\xd9\x29\x20\x07\xe3\x2c\x14\x07\x31\x2b\x04\x07\x9c\x29\x04\x07\x36\x2d\xeb\x06\x09\x2b\x0e\x07\x27\x2a\x14\x07\x36\x2d\x14\x07\x54\x2b\x0f\x07\x25\x2a\x00\x07\xa2\x2d\xf2\x06\x85\x2b\x06\x07\xfb\x29\x14\x07\x98\x2c\x0c\x07\xc1\x2a\x03\x07\x79\x29\x0a\x07\x12\x2d\x01\x07\xd7\x2a\x00\x07\xe4\x29\x1d\x07\xfd\x2c\x16\x07\x84\x2b\x0a\x07\x13\x2a\x1e\x07\x04\x2d\x15\x07\x52\x2b\x10\x07\xef\x29\x1c\x07\x03\x2d\x13\x07\x05\x2b\x09\x07\xd8\x29\x13\x07\xc3\x2c\x0f\x07\xa4\x2b\x0b\x07\xf5\x29\x16\x07\xf4\x2c\x07\x07\x8a\x2b\x08\x07\xf5\x29\x0b\x07\xda\x2c\x09\x07\x1a\x2b\x06\x07\x82\x29\x0b\x07\xfd\x2c\xfe\x06\xff\x2a\x07\x07\x66\x29\x12\x07\x24\x2d\x09\x07\x6b\x2b\x09\x07\x1d\x2a\x18\x07\x46\x2d\x09\x07\x60\x2b\x10\x07\x02\x2a\x1d\x07\xdc\x2c\x18\x07\x82\x2b\x0e\x07\xe4\x29\x18\x07\x31\x2d\x04\x07\x0f\x2b\x0a\x07\x1d\x2a\x1a\x07\x41\x2d\x0d\x07\x97\x2b\x13\x07\xfe\x29\x27\x07\xed\x2c\x12\x07\x5f\x2b\x15\x07\xbe\x29\x17\x07\xc5\x2c\x0c\x07\x22\x2b\xfd\x06\x81\x29\x00\x07\x4e\x2d\xe9\x06\x98\x2b\x0c\x07\x49\x2a\x22\x07\x49\x2d\x0d\x07\x90\x2b\x0c\x07\x23\x2a\x1e\x07\x54\x2d\x10\x07\xce\x2b\x07\x07\x16\x2a\x1f\x07\x66\x2d\x18\x07\xca\x2b\x14\x07\x38\x2a\x21\x07\x70\x2d\x14\x07\xa6\x2b\x02\x07\x48\x2a\xfe\x06\x29\x2d\xf7\x06\xb0\x2b\x09\x07\x2d\x2a\x20\x07\xfa\x2c\x0a\x07\x62\x2b\x08\x07\xbd\x29\x23\x07\x53\x2d\x1d\x07\xdd\x2b\x15\x07\x60\x2a\x1d\x07\x8f\x2d\x12\x07\xb3\x2b\x12\x07\x60\x2a\x1b\x07\x9c\x2d\x00\x07\xba\x2b\x0b\x07\x7f\x2a\x26\x07\xfa\x2d\x10\x07\xae\x2b\x09\x07\x62\x2a\x11\x07\xc6\x2d\x06\x07\xe9\x2b\x03\x07\x98\x2a\x08\x07\xc4\x2d\xf6\x06\xd8\x2b\x0b\x07\x8d\x2a\x19\x07\xb8\x2d\x10\x07\x6a\x2b\x12\x07\x4f\x2a\x25\x07\xfc\x2d\x12\x07\xa4\x2b\x19\x07\x7d\x2a\x1d\x07\x26\x2e\x17\x07\x5d\x2b\x00\x07\x6a\x2a\x04\x07\xc7\x2d\xf8\x06\xc2\x2b\x0b\x07\x76\x2a\x1a\x07\xa3\x2d\x13\x07\x72\x2b\x0d\x07\x45\x2a\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x1d\x07\x32\x2e\x0e\x07\x5d\x2b\x0a\x07\x7e\x2a\x17\x07\xa8\x2d\xff\x06\x46\x2b\x0d\x07\x25\x2a\x28\x07\xa4\x2c\x1d\x07\xd9\x2a\x0e\x07\x94\x29\x1f\x07\xa1\x2d\x12\x07\xb6\x2b\x12\x07\x64\x2a\x1d\x07\x41\x2d\x0e\x07\xfb\x2a\x12\x07\x0a\x2a\x05\x07\x94\x2c\xfb\x06\xba\x2a\xf8\x06\x56\x29\xee\x06\x40\x2c\xe3\x06\x70\x2a\xd7\x06\x8a\x28\xb0\x06\x80\x2c\x9c\x06\xfb\x29\xa0\x06\xc6\x27\x7b\x06\x0f\x29\x69\x06\xf7\x26\x76\x06\xdf\x23\xcc\x06\xc1\x28\xc7\x06\x71\x27\xc8\x06\x4d\x25\xeb\x06\x17\x29\xe7\x06\xe5\x27\xdf\x06\xda\x25\x13\x07\x65\x29\x04\x07\x9f\x27\x03\x07\x1b\x26\x18\x07\xc9\x29\x0d\x07\xfe\x27\x01\x07\x7d\x26\x1a\x07\x19\x2a\x0b\x07\x1f\x28\x03\x07\x7d\x26\x09\x07\x35\x2a\x00\x07\x18\x28\xf4\x06\x8e\x26\x08\x07\x59\x2a\xf6\x06\x68\x28\xeb\x06\xb6\x26\x0e\x07\x6e\x2a\x03\x07\x41\x28\xf9\x06\xc7\x26\x08\x07\x6b\x2a\xf8\x06\x57\x28\xea\x06\xc5\x26\xf5\x06\x24\x2a\xe2\x06\x6b\x28\xfa\x06\x96\x26\x09\x07\xb4\x29\xfb\x06\x16\x28\xf8\x06\x48\x26\x07\x07\x4f\x2a\xf7\x06\x35\x28\xfa\x06\x5a\x26\x14\x07\xf4\x29\x09\x07\x6f\x28\xfc\x06\xa5\x26\x15\x07\x38\x2a\x09\x07\x6e\x28\xfa\x06\x91\x26\x0e\x07\x29\x2a\x01\x07\x5a\x28\x01\x07\x91\x26\xfe\x06\xbc\x2a\xf0\x06\x17\x29\xed\x06\x31\x27\x13\x07\xde\x29\x02\x07\x44\x28\xfb\x06\x82\x26\x10\x07\xd7\x29\xfe\x06\x07\x28\xf8\x06\x46\x26\x17\x07\xd2\x29\x05\x07\x5d\x28\xf6\x06\x88\x26\x07\x07\xe7\x29\xf9\x06\x5d\x28\xf0\x06\x58\x26\x09\x07\x92\x29\xfe\x06\x51\x28\xed\x06\x41\x26\x00\x07\x99\x29\xff\x06\x4a\x28\xf2\x06\x1d\x26\x18\x07\x97\x29\x02\x07\x1d\x28\x00\x07\x31\x26\x14\x07\x7a\x29\x0a\x07\xc4\x27\xf5\x06\xfa\x25\x02\x07\x42\x29\xfe\x06\x77\x27\xfb\x06\x9a\x25\x0d\x07\x4e\x29\x02\x07\xcd\x27\xf5\x06\x0f\x26\x04\x07\x4e\x29\xf2\x06\xbe\x27\xf6\x06\xe1\x25\x0a\x07\x5e\x29\x0b\x07\xf7\x27\xf8\x06\xf3\x25\x09\x07\x42\x29\xfc\x06\xde\x27\xef\x06\xd1\x25\x0d\x07\x49\x29\xfe\x06\x11\x28\xf4\x06\x2c\x26\x15\x07\xb9\x29\x03\x07\xe3\x27\xfa\x06\x0a\x26\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x04\x07\xdc\x28\xf3\x06\x60\x27\xeb\x06\x52\x25\x05\x07\xf3\x28\xfc\x06\x6e\x27\xf5\x06\xb1\x25\x0b\x07\x68\x29\x01\x07\xde\x27\x01\x07\xd7\x25\x05\x07\x88\x29\xf7\x06\xbb\x27\xef\x06\x93\x25\x01\x07\x66\x29\xf7\x06\xb0\x27\xfe\x06\xd3\x25\x01\x07\x72\x29\xf2\x06\xcf\x27\xfb\x06\xe8\x25\xf2\x06\xf3\x29\xe1\x06\x11\x28\xdd\x06\xea\x25\x06\x07\x45\x29\xfb\x06\x91\x27\xf3\x06\x5e\x25\x0e\x07\x7c\x29\x03\x07\xd2\x27\x00\x07\xbd\x25\x09\x07\x7d\x29\xfa\x06\xe6\x27\xf0\x06\x1e\x26\x00\x07\xaf\x29\xff\x06\xe7\x27\xe3\x06\xc0\x25\x12\x07\x0d\x29\x09\x07\x12\x28\xf4\x06\x3f\x26\x06\x07\x2e\x29\xf1\x06\x8e\x27\xf9\x06\xe7\x25\x14\x07\x8e\x29\x03\x07\xb8\x27\xf6\x06\xef\x25\x0b\x07\xd1\x28\xf4\x06\x3b\x27\xea\x06\x6a\x25\xf1\x06\xe8\x28\xdf\x06\x18\x27\xfb\x06\x59\x25\x09\x07\x6b\x29\xfb\x06\xba\x27\xfc\x06\xf8\x25\x0d\x07\x1e\x29\x01\x07\xf7\x27\xea\x06\xaf\x25\x08\x07\xf2\x28\xff\x06\x7a\x27\xfd\x06\xdd\x25\x04\x07\xf0\x28\x0a\x07\xcd\x27\xfe\x06\xfe\x25\xfb\x06\xe5\x28\xf0\x06\xf9\x27\xff\x06\x3c\x26\x11\x07\x00\x29\xff\x06\x81\x27\xf8\x06\xcf\x25\x05\x07\x87\x28\xff\x06\x37\x27\xf4\x06\x92\x25\x04\x07\xcd\x28\x06\x07\xd0\x27\xfd\x06\xd1\x25\x06\x07\x33\x29\x06\x07\x09\x28\x02\x07\x25\x26\x0e\x07\x32\x29\x06\x07\xc8\x27\xf5\x06\x0e\x26\x0d\x07\x46\x29\xfb\x06\xf2\x27\xf4\x06\xfe\x25\x0f\x07\x24\x29\x00\x07\x03\x28\xfe\x06\x37\x26\x10\x07\x15\x29\x0c\x07\x02\x28\xfa\x06\x03\x26\x12\x07\xa6\x28\xff\x06\x72\x27\xff\x06\x83\x25\x10\x07\x03\x29\x09\x07\xf9\x27\xfd\x06\xc2\x25\x0a\x07\xdb\x28\x01\x07\x1d\x28\xff\x06\x15\x26\x07\x07\x2a\x29\xfe\x06\xf2\x27\xfc\x06\x30\x26\x02\x07\x51\x29\xfe\x06\x1c\x28\xfb\x06\x0e\x26\x07\x07\x3e\x29\x02\x07\xf6\x27\xf3\x06\x54\x26\x10\x07\x83\x29\xfe\x06\x2c\x28\xff\x06\x30\x26\x07\x07\x32\x29\xf6\x06\x94\x27\xf3\x06\xc7\x25\xf5\x06\x68\x29\xee\x06\xa3\x27\xf6\x06\xec\x25\xfa\x06\x3a\x29\xef\x06\x27\x28\xf4\x06\xf7\x25\x0a\x07\x2b\x29\x11\x07\x20\x28\xf9\x06\x10\x26\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x09\x07\x64\x29\xf4\x06\xdd\x27\xf9\x06\x10\x26\x09\x07\x1d\x29\x0d\x07\x02\x28\xfc\x06\x4d\x26\x0c\x07\xe4\x28\xfb\x06\xdf\x27\x01\x07\x15\x26\xfa\x06\xfe\x28\xfc\x06\xad\x27\xf1\x06\x82\x25\xf4\x06\x19\x29\xe9\x06\xcc\x27\xfa\x06\xbc\x25\x0c\x07\x01\x29\x02\x07\x07\x28\xf0\x06\xe2\x25\x06\x07\xab\x28\x01\x07\x15\x28\xf3\x06\xbc\x25\x06\x07\x50\x29\xfe\x06\xbb\x27\xf1\x06\xd5\x25\x00\x07\xde\x28\xff\x06\x29\x28\xf1\x06\x99\x25\x09\x07\xaf\x28\xff\x06\xc9\x27\xef\x06\x75\x25\xf8\x06\x80\x28\xe9\x06\x39\x27\xf6\x06\x21\x25\x05\x07\x05\x28\x00\x07\x30\x27\xf3\x06\xa8\x24\x05\x07\x84\x28\xfe\x06\x4a\x27\xfa\x06\xe9\x24\xf6\x06\xc5\x28\xe4\x06\x13\x27\xfc\x06\xd3\x24\x02\x07\xa6\x28\x05\x07\x3a\x27\xf4\x06\xb9\x24\xfb\x06\x04\x29\x00\x07\x66\x27\xed\x06\x24\x25\xfd\x06\xea\x28\xf7\x06\xd5\x27\xfb\x06\x95\x25\xed\x06\xbb\x28\xfd\x06\x03\x28\xec\x06\x77\x25\xfa\x06\x98\x28\xf8\x06\x8a\x27\xf5\x06\x63\x25\xff\x06\xb2\x28\xf8\x06\x8c\x27\xee\x06\xb4\x25\xe9\x06\xc3\x28\xe3\x06\xdd\x27\xeb\x06\xbf\x25\x01\x07\xc5\x28\xf4\x06\x90\x27\xf0\x06\x90\x25\x0e\x07\xf5\x28\x02\x07\x96\x27\xf4\x06\xae\x25\xf4\x06\xce\x28\xf7\x06\x8e\x27\xf3\x06\x96\x25\x00\x07\xe2\x28\xf3\x06\x9e\x27\xf4\x06\x4c\x25\xf1\x06\x65\x28\xed\x06\x0b\x27\xe8\x06\x14\x25\x00\x07\xab\x28\xf2\x06\x55\x27\xe9\x06\x6d\x25\x01\x07\xa2\x28\xfc\x06\xac\x27\xf4\x06\x82\x25\x00\x07\xc7\x28\xf3\x06\xb2\x27\xf8\x06\x92\x25\xf3\x06\xa1\x28\xf1\x06\x8c\x27\xec\x06\x9c\x25\xed\x06\x26\x29\xe6\x06\xb1\x27\xef\x06\xbd\x25\x00\x07\xe3\x28\xeb\x06\xbc\x27\xf4\x06\xc2\x25\x09\x07\x85\x28\xfe\x06\x69\x27\x03\x07\x8d\x25\x04\x07\x6c\x28\xf6\x06\x57\x27\xf3\x06\x79\x25\xf5\x06\xd9\x28\xf5\x06\xc1\x27\xe4\x06\xa9\x25\xff\x06\xc7\x28\xee\x06\xcb\x27\xf6\x06\xeb\x25\x0d\x07\x0a\x29\xfd\x06\xa3\x27\xf4\x06\xe5\x25\x02\x07\x1b\x29\xf7\x06\xd5\x27\xff\x06\xe2\x25\x0d\x07\x25\x29\xfa\x06\xdd\x27\xee\x06\xca\x25\x09\x07\xe0\x28\xf6\x06\xe0\x27\xf2\x06\xcb\x25\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xf9\x06\x3e\x29\xf2\x06\xd7\x27\xeb\x06\xb7\x25\xff\x06\x13\x29\xf3\x06\x18\x28\xf3\x06\xfa\x25\x08\x07\xf3\x28\x00\x07\xbf\x27\xf2\x06\xd4\x25\x03\x07\x15\x29\xfc\x06\xf8\x27\xf3\x06\xbb\x25\x07\x07\x2c\x29\xf1\x06\xd0\x27\xf2\x06\x2d\x26\x06\x07\x37\x29\xfa\x06\xcf\x27\xf6\x06\xdf\x25\x09\x07\x20\x29\xfa\x06\xf0\x27\xf4\x06\xc2\x25\x01\x07\x9c\x28\xf5\x06\x99\x27\xee\x06\x85\x25\xf9\x06\xc3\x28\xfc\x06\xdd\x27\xfe\x06\x23\x26\x10\x07\xef\x28\x08\x07\xeb\x27\xf5\x06\xd7\x25\x02\x07\x09\x29\x03\x07\x05\x28\x00\x07\xd5\x25\x0c\x07\xed\x28\x04\x07\xd4\x27\xfb\x06\xc0\x25\xfe\x06\x53\x29\xf2\x06\xed\x27\xf5\x06\xdd\x25\xf7\x06\xba\x28\xf7\x06\xd3\x27\xf1\x06\xb8\x25\xf1\x06\xda\x28\xeb\x06\xb5\x27\xea\x06\x66\x25\xe6\x06\x87\x29\xdb\x06\xdd\x27\xed\x06\xd7\x25\x04\x07\xff\x28\xf6\x06\xad\x27\xf6\x06\xc8\x25\x0d\x07\x87\x28\x01\x07\xb3\x27\xfe\x06\xba\x25\xfb\x06\x82\x29\xe7\x06\x88\x27\xf0\x06\xdf\x25\x0e\x07\xab\x29\xff\x06\x80\x27\xf7\x06\xa8\x25\xfb\x06\x3c\x29\xed\x06\xa9\x27\xf7\x06\xc8\x25\xfc\x06\xa7\x28\xec\x06\x62\x27\xfc\x06\x4f\x25\xf9\x06\x7e\x29\xfe\x06\xa2\x27\xf1\x06\xa5\x25\x0d\x07\x3d\x2a\xfc\x06\x62\x27\x01\x07\x2b\x26\x0e\x07\x0e\x2a\xfa\x06\xf2\x27\xfc\x06\x70\x26\xf6\x06\x9c\x29\xe6\x06\xdd\x27\xda\x06\xf6\x25\x0e\x07\x11\x29\xfe\x06\xe0\x27\xf8\x06\xa5\x25\x0f\x07\x05\x29\x03\x07\xf0\x27\xfd\x06\xde\x25\x0a\x07\xac\x28\xf7\x06\x66\x27\xf2\x06\x47\x25\x01\x07\xb3\x28\xf4\x06\x60\x27\xe6\x06\x8a\x25\xfd\x06\xf9\x28\xf3\x06\xe4\x27\xf7\x06\xe2\x25\x0a\x07\xf1\x28\xfe\x06\xd0\x27\xea\x06\x74\x25\x02\x07\xa1\x28\x04\x07\x24\x28\xf2\x06\xdb\x25\xf4\x06\xfe\x28\xe7\x06\xf4\x27\xf0\x06\xa5\x25\xf9\x06\x0e\x29\x07\x07\xf0\x27\xf0\x06\xa8\x25\xfe\x06\x25\x29\xe5\x06\xe5\x27\xeb\x06\xe3\x25\xf3\x06\xb0\x28\xe6\x06\xb9\x27\xf7\x06\x84\x25\xff\x06\xae\x28\x00\x07\x4d\x28\xf9\x06\xe7\x25\x05\x07\xe1\x28\xfd\x06\xec\x27\xfd\x06\xc3\x25\x0c\x07\x46\x29\xf4\x06\xc7\x27\xfb\x06\x0c\x26\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xf8\x06\xb7\x28\xf0\x06\xb7\x27\xfc\x06\xc8\x25\xf3\x06\xd4\x28\xef\x06\xf5\x27\xf0\x06\xf9\x25\xfa\x06\xec\x28\xe3\x06\x82\x27\xfa\x06\xb7\x25\x0e\x07\xa3\x28\x01\x07\x6e\x27\xf4\x06\x7e\x25\x0d\x07\x16\x29\xfd\x06\x99\x27\xf2\x06\xdb\x25\xe5\x06\xfe\x28\xec\x06\xfa\x27\xf2\x06\xcd\x25\x01\x07\xf0\x28\xfe\x06\xcf\x27\xef\x06\x95\x25\xfb\x06\x05\x29\xec\x06\xd8\x27\xfa\x06\xac\x25\x02\x07\x0e\x29\xee\x06\xce\x27\xf7\x06\xc2\x25\xf4\x06\x3a\x29\xe9\x06\xdf\x27\xf8\x06\xe2\x25\xfb\x06\x7d\x28\xf2\x06\xa1\x27\xf3\x06\x78\x25\x04\x07\xcd\x28\x01\x07\xfc\x27\xeb\x06\xc0\x25\x05\x07\xe1\x28\x04\x07\xec\x27\xfb\x06\x2a\x26\x09\x07\xf5\x28\xfc\x06\xc5\x27\xf1\x06\xbc\x25\x0b\x07\x3b\x29\xfb\x06\x9f\x27\xf0\x06\xde\x25\x04\x07\x93\x29\xf9\x06\xe0\x27\xf2\x06\xe7\x25\xff\x06\xb6\x29\xfc\x06\xd0\x27\xf4\x06\x70\x25\x08\x07\x5e\x29\xff\x06\x60\x27\xf8\x06\x51\x25\x05\x07\x87\x29\xf2\x06\x4f\x27\xef\x06\x7b\x25\x02\x07\x87\x29\xf3\x06\x8d\x27\xee\x06\xd2\x25\x03\x07\x45\x29\xf1\x06\xae\x27\xee\x06\x9c\x25\x08\x07\x79\x28\xfe\x06\xd4\x27\xec\x06\x96\x25\x01\x07\xff\x28\xf0\x06\x7c\x27\xf7\x06\x9d\x25\x0f\x07\xe3\x28\xfd\x06\x88\x27\xf6\x06\xf7\x25\x06\x07\xfd\x28\xf3\x06\x60\x27\xf4\x06\x35\x25\xfb\x06\x27\x29\xfd\x06\x10\x27\xf2\x06\x63\x25\x06\x07\x7e\x29\xfd\x06\xb5\x27\xec\x06\x19\x26\x07\x07\xce\x29\xfb\x06\x9d\x27\xf4\x06\xe2\x25\x13\x07\x3d\x2a\xf1\x06\x4b\x27\xf2\x06\xe0\x25\xe4\x06\xf7\x29\xcb\x06\x7c\x27\xf5\x06\xe7\x25\xef\x06\x07\x29\xf5\x06\xc5\x27\xff\x06\x0e\x26\xe8\x06\xf7\x28\xe2\x06\x8c\x27\xd9\x06\xb7\x25\x05\x07\xcb\x28\xed\x06\xaa\x27\xf3\x06\xbb\x25\x04\x07\xd0\x28\xf5\x06\x86\x27\xed\x06\x89\x25\xfa\x06\x12\x29\xf9\x06\x75\x27\xf3\x06\xd6\x25\x0a\x07\x0e\x29\xf2\x06\x2c\x27\xe0\x06\x42\x25\x12\x07\xab\x29\xfb\x06\x5d\x27\xef\x06\x6a\x25\xfd\x06\xed\x28\xff\x06\x76\x27\xf5\x06\x69\x25\xf0\x06\x76\x28\xea\x06\xd5\x26\xf4\x06\x0e\x25\xfd\x06\xbb\x27\xf9\x06\xb5\x26\xef\x06\xab\x24\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe9\x06\x40\x28\xe8\x06\x1f\x27\xee\x06\xef\x24\x10\x07\xe8\x28\xfa\x06\xff\x26\xfa\x06\x57\x25\x07\x07\x98\x28\xf2\x06\x21\x27\xf7\x06\x53\x25\x09\x07\xd8\x28\x00\x07\x67\x27\xfb\x06\x48\x25\xf5\x06\x0e\x29\xf1\x06\x1e\x27\xf4\x06\x8d\x25\x01\x07\xbe\x28\xe9\x06\xa7\x26\xea\x06\x06\x25\xe4\x06\x6e\x28\xce\x06\x92\x26\xdd\x06\xe0\x24\xf9\x06\xfe\x27\xed\x06\x0c\x27\xea\x06\xf3\x24\xfe\x06\xa6\x28\xeb\x06\x66\x27\xf6\x06\x66\x25\xef\x06\xd3\x28\xea\x06\x2c\x27\xec\x06\x63\x25\xee\x06\xbc\x28\xee\x06\x1a\x27\xec\x06\x6c\x25\x06\x07\xca\x28\xfb\x06\x56\x27\xf2\x06\x5f\x25\xfc\x06\xf6\x27\xef\x06\xfb\x26\xf5\x06\x21\x25\xff\x06\xaa\x27\xf7\x06\x9a\x26\xef\x06\xea\x24\x04\x07\xfd\x27\xfe\x06\x33\x27\xef\x06\xfa\x24\x02\x07\x5f\x28\xfe\x06\x4f\x27\xf4\x06\x47\x25\xe3\x06\x7d\x28\xe3\x06\x21\x27\xe3\x06\x47\x25\x08\x07\x5f\x28\xfa\x06\x1d\x27\xf1\x06\x68\x25\x07\x07\xba\x28\xf3\x06\x1a\x27\xee\x06\x9c\x25\x00\x07\x76\x28\xef\x06\x1f\x27\xf3\x06\x4b\x25\xf4\x06\xec\x27\xe4\x06\x8b\x26\xe2\x06\xf7\x24\xf4\x06\x1e\x28\xe9\x06\x57\x26\xe9\x06\x1e\x25\xfe\x06\x97\x28\xf7\x06\x3b\x27\xeb\x06\x5c\x25\xfb\x06\x45\x28\xf0\x06\x4d\x27\xee\x06\x76\x25\xfe\x06\x52\x28\xf0\x06\x32\x27\xf5\x06\x69\x25\x07\x07\xa5\x28\xf8\x06\x5d\x27\xf5\x06\x76\x25\xfb\x06\xda\x28\xec\x06\x12\x27\xf6\x06\x94\x25\x04\x07\x5b\x28\xf1\x06\x91\x26\xea\x06\x0f\x25\xfe\x06\x23\x28\xf9\x06\xb0\x26\xf0\x06\xb3\x24\x05\x07\xc2\x28\x00\x07\x35\x27\xef\x06\x5c\x25\xfa\x06\xae\x28\xea\x06\x06\x27\xe6\x06\x75\x25\x07\x07\xcf\x28\x01\x07\x22\x27\xf4\x06\x32\x25\xff\x06\xd5\x28\xeb\x06\x77\x27\xf5\x06\x6f\x25\x05\x07\x58\x28\xf0\x06\x5f\x27\xfa\x06\xa7\x25\x02\x07\x92\x28\xf6\x06\x16\x27\xf1\x06\x3a\x25\xff\x06\xa6\x28\xf8\x06\xeb\x26\xed\x06\x11\x25\x00\x07\x12\x29\xfd\x06\xbf\x27\xf8\x06\xa6\x25\xfb\x06\x34\x29\xef\x06\x51\x27\xf1\x06\x8a\x25\x05\x07\x31\x29\xfd\x06\x56\x27\xf1\x06\x7f\x25\xfe\x06\x15\x29\xec\x06\x76\x27\xf3\x06\xa5\x25\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x12\x07\xca\x28\xf7\x06\x43\x27\xfa\x06\x87\x25\xef\x06\xcb\x28\xe9\x06\xd8\x26\xeb\x06\x1c\x25\xfa\x06\x7f\x28\xe7\x06\xba\x26\xe9\x06\xea\x24\x0a\x07\xe6\x28\xfb\x06\x2b\x27\xed\x06\x59\x25\x00\x07\xc1\x28\xf8\x06\x5b\x27\xf2\x06\x9b\x25\x07\x07\x1a\x29\x01\x07\x24\x27\xec\x06\x56\x25\xf8\x06\x5b\x29\xe3\x06\x0f\x27\xed\x06\x71\x25\xfb\x06\xf4\x28\xf1\x06\x44\x27\xef\x06\x73\x25\x01\x07\x92\x28\xf6\x06\x21\x27\xf3\x06\x51\x25\xfc\x06\x1e\x28\xeb\x06\x95\x26\xe9\x06\xb8\x24\x01\x07\x43\x28\xf1\x06\xf3\x26\xf5\x06\x0d\x25\xf4\x06\xf6\x28\xed\x06\x88\x27\xf0\x06\x36\x25\xfa\x06\xe3\x28\xf4\x06\x5f\x27\xeb\x06\x2e\x25\x04\x07\xdf\x28\xf4\x06\x4e\x27\xea\x06\x56\x25\xf9\x06\xff\x28\xed\x06\xa8\x27\xf4\x06\x5e\x25\xf0\x06\x13\x29\xe2\x06\x60\x27\xfc\x06\x78\x25\xf7\x06\x7c\x28\xf9\x06\x40\x27\xef\x06\x36\x25\x0f\x07\xe4\x28\xf7\x06\x1f\x27\xdd\x06\x71\x25\x06\x07\xa5\x28\xfa\x06\xa4\x27\xf2\x06\x7f\x25\xfa\x06\xba\x28\xf4\x06\xc7\x27\xf6\x06\x81\x25\x05\x07\xcd\x28\xfa\x06\x88\x27\xe9\x06\x69\x25\xfc\x06\x21\x29\xe8\x06\x84\x27\xf4\x06\x9a\x25\xf0\x06\x13\x29\xe3\x06\x6e\x27\xf1\x06\x8e\x25\xf1\x06\x86\x28\xea\x06\x26\x27\xed\x06\x3f\x25\xf5\x06\x82\x28\xf0\x06\xe4\x26\xf4\x06\x28\x25\xe8\x06\x07\x29\xd5\x06\x64\x27\xf0\x06\x9e\x25\x0b\x07\xd9\x28\xf1\x06\xba\x27\xfd\x06\xff\x25\xfc\x06\x03\x29\xf0\x06\xa2\x27\xf4\x06\xb8\x25\xec\x06\x9c\x29\xd6\x06\xf1\x27\xcd\x06\x03\x26\xf6\x06\x7e\x29\xe0\x06\xda\x27\xf0\x06\xbd\x25\x08\x07\xe4\x28\xf9\x06\x7b\x27\xf6\x06\x8c\x25\xf0\x06\x85\x28\xed\x06\x19\x27\xf4\x06\x6a\x25\xfb\x06\xb7\x28\xf5\x06\x57\x27\xf0\x06\x74\x25\xe3\x06\x02\x29\xdf\x06\xcd\x27\xf2\x06\xc4\x25\xf4\x06\x70\x29\xd6\x06\xdb\x27\xd8\x06\xaa\x25\xef\x06\xe2\x28\xe3\x06\xae\x27\xec\x06\x70\x25\xed\x06\xd0\x28\xe1\x06\xd3\x27\xee\x06\x74\x25\xf6\x06\x6e\x28\xf7\x06\xb8\x27\xf6\x06\x74\x25\xfa\x06\x3e\x28\x00\x07\x36\x27\xe8\x06\x08\x25\x04\x07\x2c\x29\xf3\x06\x93\x27\xf4\x06\x96\x25\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xf3\x06\x02\x29\xe1\x06\x9b\x27\xf6\x06\xb8\x25\x10\x07\xf0\x28\x05\x07\x9e\x27\xf2\x06\x79\x25\x0b\x07\xff\x28\x02\x07\x91\x27\xf7\x06\xa1\x25\x01\x07\xf7\x28\x01\x07\xfe\x27\xf1\x06\xb1\x25\xf2\x06\x72\x28\xe7\x06\x91\x27\xeb\x06\x77\x25\xfb\x06\x32\x28\xf3\x06\x4b\x27\xec\x06\x4e\x25\xfd\x06\xa1\x28\xf2\x06\x76\x27\xe2\x06\x3b\x25\xe4\x06\xb1\x28\xda\x06\xb5\x27\xe4\x06\x8e\x25\xfb\x06\x84\x28\xfd\x06\xac\x27\xef\x06\x86\x25\xfb\x06\xe6\x28\xfd\x06\xac\x27\xef\x06\x41\x25\xf3\x06\xcb\x28\xe7\x06\xa5\x27\xf8\x06\x65\x25\xf3\x06\x95\x28\xec\x06\x6c\x27\xed\x06\x5d\x25\x00\x07\x47\x28\xf6\x06\xdc\x26\xe9\x06\xbb\x24\xf8\x06\xdc\x27\xf5\x06\xa6\x26\xe2\x06\xac\x24\xfb\x06\x1b\x28\xfd\x06\xef\x26\xec\x06\x8e\x24\x04\x07\xdf\x28\x03\x07\x5f\x27\xf0\x06\xc4\x24\x03\x07\xab\x28\x00\x07\xa7\x27\xfc\x06\xdd\x24\x0b\x07\xef\x28\x00\x07\xa3\x27\xfc\x06\x83\x25\xe8\x06\x10\x29\xe1\x06\xf8\x27\x00\x07\xc2\x25\x0a\x07\xcc\x28\x02\x07\x8e\x27\xf8\x06\xc9\x25\x03\x07\xf7\x28\xfb\x06\xba\x27\xed\x06\x60\x25\xe2\x06\xe9\x28\xe3\x06\x05\x28\xec\x06\xd3\x25\xfa\x06\xeb\x28\xf7\x06\xf7\x27\xea\x06\xec\x25\xff\x06\xe1\x28\x09\x07\x02\x28\x00\x07\xe8\x25\x06\x07\xc6\x28\xf9\x06\xfc\x27\xed\x06\xc0\x25\xe9\x06\xf6\x28\xe2\x06\x1e\x28\xef\x06\xc2\x25\xfd\x06\xda\x28\xf6\x06\x81\x27\xef\x06\x60\x25\xff\x06\x5d\x28\xec\x06\xb3\x27\xf0\x06\x61\x25\xee\x06\xd5\x28\xeb\x06\xff\x27\xec\x06\xba\x25\xf3\x06\x25\x29\xf3\x06\x0b\x28\xf3\x06\x11\x26\x03\x07\x5e\x29\xfe\x06\xfc\x27\xdd\x06\xc6\x25\xfc\x06\x91\x29\xf9\x06\xe3\x27\xea\x06\xe3\x25\x0c\x07\x94\x29\xf9\x06\x10\x28\xf3\x06\xef\x25\xf0\x06\x74\x29\xeb\x06\x4b\x28\xf2\x06\xf3\x25\xe2\x06\x2c\x29\xe5\x06\xef\x27\xd3\x06\x9b\x25\x04\x07\x27\x29\xfa\x06\xd8\x27\xf3\x06\xe1\x25\xf9\x06\x5c\x29\xfa\x06\x03\x28\xf1\x06\x29\x26\x0b\x07\x79\x29\x03\x07\x4d\x28\xf5\x06\x01\x26\x0e\x07\x98\x29\x05\x07\x34\x28\xf9\x06\x3d\x26\xef\x06\xdc\x29\xf2\x06\x4f\x28\xe6\x06\x05\x26\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x00\x07\xf3\x29\xfc\x06\x06\x28\xf3\x06\x16\x26\xf7\x06\x34\x29\xf3\x06\x71\x27\xe4\x06\x9e\x25\x02\x07\x99\x29\x06\x07\xe1\x27\xf7\x06\xba\x25\x00\x07\xb4\x29\xf5\x06\xca\x27\xfb\x06\x0f\x26\xef\x06\x0f\x2a\xe5\x06\x38\x28\xf3\x06\x33\x26\x09\x07\x54\x2a\xf5\x06\x26\x28\xf3\x06\xf6\x25\x0f\x07\x61\x2a\x03\x07\x15\x28\xfa\x06\x2d\x26\x05\x07\x62\x2a\xfa\x06\x11\x28\xf5\x06\x31\x26\x01\x07\x2d\x2a\xf6\x06\xd2\x27\xf5\x06\x2c\x26\x01\x07\xe4\x29\xf4\x06\xbb\x27\xee\x06\x1d\x26\x05\x07\xf2\x29\xfa\x06\x5e\x28\xf8\x06\x3f\x26\x12\x07\x1a\x2a\x01\x07\x1a\x28\xfa\x06\x6e\x26\x00\x07\xf0\x29\xf2\x06\x23\x28\xfa\x06\x3d\x26\xfc\x06\xeb\x29\xe6\x06\x22\x28\xfb\x06\xf4\x25\xee\x06\x53\x2a\xdd\x06\xaf\x28\xdb\x06\x8d\x26\x01\x07\x3e\x2a\xe4\x06\xfa\x27\xf8\x06\x30\x26\xd6\x06\x9f\x2a\xc6\x06\xc4\x28\xc4\x06\x98\x26\x0c\x07\x66\x29\x00\x07\x3d\x28\xf7\x06\x22\x26\x03\x07\x51\x29\xfa\x06\x24\x28\x01\x07\x19\x26\x07\x07\xe5\x28\xfa\x06\xbb\x27\xfa\x06\xbc\x25\xff\x06\x6f\x29\xf8\x06\xa2\x27\xe8\x06\xd8\x24\x88\x07\xbb\xa2\x86\x07\x60\x9b\xaf\x07\xa8\x8b\x00\x00\x4c\x14\x00\x00\xf9\x14\x00\x00\xa2\x15\x00\x00\x4b\x14\x00\x00\xf9\x14\x00\x00\xa2\x15\x00\x00\x5a\x14\x00\x00\xf9\x14\x00\x00\xa2\x15\x00\x00\x5a\x14\x00\x00\xfb\x14\x00\x00\xa2\x15\x00\x00\x5a\x14\x00\x00\xfd\x14\x00\x00\xa2\x15\xf2\x06\x80\x2c\xe2\x06\x51\x2a\xd2\x06\x94\x27\xe2\x06\x9e\x2b\xe9\x06\xaa\x2a\xda\x06\xd0\x28\xf4\x06\xdc\x2b\xe9\x06\x5c\x2a\xe0\x06\xd4\x28\xe0\x06\x88\x2b\xd7\x06\x53\x2a\xd5\x06\x78\x28\xdf\x06\x10\x2c\xd9\x06\x08\x2a\xce\x06\x4b\x28\xe8\x06\xbc\x2c\xd5\x06\x97\x2a\xdd\x06\xa5\x28\xdf\x06\x8e\x2c\xcd\x06\x73\x2a\xd7\x06\x83\x28\xe5\x06\x3d\x2c\xd9\x06\x4e\x2a\xd7\x06\x3f\x28\xee\x06\x47\x2c\xd8\x06\x01\x2a\xd4\x06\xbd\x27\xee\x06\x65\x2c\xe8\x06\x48\x2a\xc9\x06\xd3\x27\xe9\x06\xe6\x2b\xe7\x06\x0d\x2a\xdc\x06\xf4\x27\xe0\x06\xf3\x2b\xdd\x06\x9a\x2a\xca\x06\xca\x27\xfb\x06\x48\x2c\xda\x06\x15\x2a\xe5\x06\x6c\x28\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xef\x06\xdf\x2c\xe1\x06\xa6\x2a\xe3\x06\xcb\x28\xfa\x06\x0d\x2d\xf0\x06\xd2\x2a\xe5\x06\x2e\x29\xee\x06\x40\x2d\xeb\x06\xb0\x2a\xda\x06\xe7\x28\xf3\x06\xb8\x2d\xe0\x06\xf7\x2a\xe0\x06\x77\x29\xe9\x06\x32\x2c\xeb\x06\x1c\x2b\xde\x06\xff\x28\xe8\x06\xcf\x2b\xe6\x06\xca\x2a\xd8\x06\x40\x28\xfa\x06\x3e\x2c\xe8\x06\xad\x2a\xe0\x06\xd1\x28\xf2\x06\xa4\x2c\xea\x06\x66\x2b\xdb\x06\x1a\x29\xf0\x06\xc2\x2c\xe6\x06\x20\x2b\xe4\x06\x15\x29\xf6\x06\xca\x2c\xe9\x06\x85\x2b\xe8\x06\xf4\x28\xf2\x06\x45\x2c\xea\x06\x57\x2b\xde\x06\xca\x28\xee\x06\x92\x2c\xe1\x06\x05\x2b\xda\x06\xe9\x28\xf2\x06\x13\x2c\xdf\x06\x19\x2b\xe4\x06\x1c\x29\xd3\x06\xae\x2c\xcd\x06\x75\x2b\xdb\x06\x07\x29\xf7\x06\xaa\x2c\xeb\x06\x4a\x2b\xe2\x06\x21\x29\xff\x06\xe8\x2c\xef\x06\x32\x2b\xe5\x06\x37\x29\xf6\x06\x9b\x2c\xf1\x06\x08\x2b\xe4\x06\x26\x29\xe2\x06\x63\x2c\xe9\x06\x41\x2b\xd7\x06\x14\x29\xf9\x06\xe8\x2c\xf0\x06\xeb\x2b\xdf\x06\x1e\x29\xea\x06\xc4\x2b\xe0\x06\x03\x2b\xd5\x06\xb2\x28\xf2\x06\xcd\x2b\xdf\x06\xda\x2a\xcd\x06\x8c\x28\xed\x06\x49\x2c\xe9\x06\x1d\x2b\xe4\x06\x15\x29\xea\x06\xf1\x2b\xe4\x06\x53\x2b\xe1\x06\x4f\x29\xe8\x06\xf8\x2b\xe0\x06\x4b\x2b\xd7\x06\xf1\x28\xe9\x06\x06\x2c\xd8\x06\x30\x2b\xdf\x06\x03\x29\xee\x06\x01\x2c\xe6\x06\x63\x2b\xd6\x06\x06\x29\xe5\x06\x93\x2b\xe9\x06\x5f\x2b\xd8\x06\xb4\x28\xe2\x06\xf5\x2b\xda\x06\xc2\x2a\xdd\x06\xf6\x28\xe3\x06\xdb\x2b\xdc\x06\x04\x2b\xdb\x06\x13\x29\xf3\x06\xf3\x2b\xe4\x06\xe0\x2a\xe2\x06\xdb\x28\xef\x06\x0d\x2c\xdf\x06\x0c\x2b\xdf\x06\xf8\x28\xf0\x06\xe1\x2b\xd3\x06\xa0\x2a\xdc\x06\xd7\x28\xe9\x06\x05\x2c\xd9\x06\x97\x2a\xce\x06\xa1\x28\xe7\x06\x74\x2b\xdf\x06\x7b\x2a\xd5\x06\x1a\x28\xe4\x06\xb1\x2b\xd5\x06\x08\x2a\xd4\x06\xfd\x27\xdd\x06\xc9\x2b\xd5\x06\xff\x29\xcc\x06\xc8\x27\xe4\x06\xc5\x2b\xd9\x06\x3e\x2a\xd3\x06\x49\x27\xef\x06\x03\x2c\xdf\x06\x5e\x2a\xd3\x06\x8d\x27\xe6\x06\xc0\x2b\xda\x06\x46\x2a\xd4\x06\xa4\x27\xe3\x06\xf0\x2b\xda\x06\x39\x2a\xce\x06\xef\x27\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe0\x06\x90\x2b\xe2\x06\x79\x2a\xe3\x06\x23\x28\xe6\x06\x63\x2b\xe4\x06\xd5\x29\xd8\x06\xca\x27\xd5\x06\x93\x2b\xcc\x06\x8d\x2a\xdb\x06\x2c\x28\xea\x06\xa8\x2b\xdd\x06\xb6\x2a\xd7\x06\x5d\x28\xed\x06\xf4\x2b\xe6\x06\x0c\x2b\xd6\x06\x5c\x28\xf0\x06\xb1\x2b\xe1\x06\x73\x2a\xd2\x06\x48\x28\xda\x06\xfa\x2b\xe2\x06\xa2\x2a\xd7\x06\x74\x28\xeb\x06\xb8\x2b\xe6\x06\x13\x2a\xd2\x06\x5f\x28\xe3\x06\x43\x2b\xd7\x06\xec\x29\xd4\x06\x2e\x28\xe3\x06\x7a\x2b\xd3\x06\x2a\x2a\xcf\x06\x6e\x28\xe0\x06\xa4\x2b\xd5\x06\xba\x2a\xcf\x06\x9e\x28\xe5\x06\xbb\x2b\xd9\x06\xbd\x2a\xdc\x06\xf9\x28\xe4\x06\xd5\x2b\xdf\x06\x03\x2b\xca\x06\x17\x29\xe5\x06\xd4\x2b\xda\x06\x97\x2a\xce\x06\xb9\x28\xe9\x06\xfe\x2b\xe7\x06\xc2\x2a\xe1\x06\x37\x29\xe6\x06\x8e\x2b\xdc\x06\x8b\x2a\xd8\x06\x65\x28\xf5\x06\xac\x2b\xde\x06\x31\x2a\xd2\x06\x80\x28\xea\x06\x7a\x2c\xe2\x06\x81\x2a\xda\x06\xf5\x28\xec\x06\xde\x2b\xe1\x06\x7d\x2a\xd6\x06\xe6\x28\xed\x06\xde\x2b\xe0\x06\xbf\x2a\xdf\x06\xf0\x28\xd9\x06\xbc\x2b\xda\x06\xd2\x2a\xd6\x06\xdb\x28\xe0\x06\xb9\x2b\xdd\x06\x93\x2a\xd1\x06\xda\x28\xed\x06\x38\x2b\xdd\x06\x4e\x2a\xd4\x06\x64\x28\xe0\x06\x12\x2b\xd9\x06\xd1\x29\xce\x06\x14\x28\xe7\x06\xb2\x2b\xd7\x06\x0f\x2a\xcd\x06\x7e\x28\xe3\x06\xfd\x2b\xd4\x06\x79\x2a\xda\x06\xfc\x28\xe6\x06\x1e\x2c\xd8\x06\xc1\x2a\xd3\x06\xf2\x28\xef\x06\xef\x2b\xe1\x06\xf9\x2a\xdc\x06\xeb\x28\xe0\x06\xde\x2b\xdc\x06\xd8\x2a\xdc\x06\x04\x29\xe9\x06\x72\x2b\xe8\x06\x56\x2a\xde\x06\xd7\x28\xef\x06\x5d\x2b\xd5\x06\xe7\x29\xd4\x06\x2f\x28\xed\x06\x52\x2c\xe0\x06\xc1\x2a\xcf\x06\xf6\x28\xed\x06\x6e\x2c\xdc\x06\xaa\x2a\xd8\x06\x82\x29\xe2\x06\xff\x2b\xdf\x06\xb4\x2a\xda\x06\xed\x28\xe5\x06\x77\x2c\xd8\x06\xb9\x2a\xd5\x06\x37\x29\xe5\x06\xdf\x2c\xd3\x06\xa8\x2a\xd3\x06\x0f\x29\xea\x06\x27\x2c\xe4\x06\x03\x2b\xd7\x06\xf6\x28\xe8\x06\x42\x2b\xdb\x06\x1c\x2a\xd2\x06\x77\x28\xec\x06\xbc\x2b\xe5\x06\xad\x2a\xe6\x06\xe5\x28\xf2\x06\x48\x2c\xe7\x06\xb0\x2a\xe0\x06\x03\x29\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xec\x06\x44\x2c\xd6\x06\xad\x2a\xcd\x06\xfd\x28\xe7\x06\x80\x2c\xdc\x06\x9a\x2a\xdc\x06\x1f\x29\xed\x06\xaa\x2c\xe3\x06\xc9\x2a\xd0\x06\xc0\x28\xd5\x06\x67\x2c\xc2\x06\xb9\x2a\xde\x06\xdd\x28\x06\x07\xa3\x2b\x01\x07\x10\x2b\x02\x07\x67\x28\xe8\x06\x90\x2b\xdb\x06\x91\x2a\xda\x06\x93\x28\xe1\x06\x3d\x2c\xd8\x06\xef\x2a\xdc\x06\x55\x29\xe6\x06\x44\x2c\xcc\x06\xc1\x2a\xd1\x06\xa4\x28\xdc\x06\x5b\x2c\xda\x06\x9a\x2a\xd4\x06\xd2\x28\xf4\x06\xa4\x2c\xe1\x06\xb9\x2a\xd3\x06\x9d\x29\xe9\x06\x59\x2c\xe7\x06\xff\x2a\xd0\x06\xc3\x28\xea\x06\xcb\x2b\xe1\x06\x89\x2a\xd8\x06\x8f\x28\xef\x06\xf7\x2b\xdb\x06\x64\x2a\xd8\x06\x67\x28\xec\x06\x47\x2c\xe6\x06\x0b\x2b\xd7\x06\xf4\x28\xeb\x06\x1f\x2c\xe2\x06\x3b\x2b\xd6\x06\x32\x29\xeb\x06\x4b\x2c\xd7\x06\xb7\x2a\xd4\x06\xca\x28\xf2\x06\x22\x2c\xe6\x06\xcf\x2a\xd7\x06\xcb\x28\xe7\x06\x2c\x2c\xd9\x06\x09\x2b\xd3\x06\xd4\x28\xe8\x06\x63\x2c\xe0\x06\xc2\x2a\xd4\x06\x75\x28\xe7\x06\xc9\x2b\xdb\x06\x51\x2a\xd2\x06\x88\x28\xd3\x06\x13\x2c\xbf\x06\xe0\x2a\xd0\x06\xc4\x28\xe5\x06\xaf\x2c\xd1\x06\xe6\x2a\xdd\x06\x35\x29\xf0\x06\x1d\x2c\xdc\x06\x95\x2a\xd2\x06\xd7\x28\xec\x06\x80\x2b\xe3\x06\xce\x2a\xd4\x06\xc4\x28\xd6\x06\xb2\x2b\xd0\x06\x87\x2a\xce\x06\xb3\x28\xe6\x06\x90\x2b\xd5\x06\x43\x2a\xd1\x06\xfb\x27\xe6\x06\x30\x2b\xdd\x06\xd6\x29\xdb\x06\x3b\x28\xe4\x06\x62\x2b\xe0\x06\x60\x2a\xd2\x06\x30\x28\xe1\x06\xc2\x2b\xd9\x06\x03\x2b\xd8\x06\xa6\x28\xe4\x06\x8e\x2b\xd7\x06\x6b\x2a\xcf\x06\x3b\x28\xdf\x06\x68\x2b\xe4\x06\xc1\x2a\xd6\x06\x2b\x28\xe1\x06\x9a\x2b\xd5\x06\xb6\x2a\xc7\x06\xee\x27\xe1\x06\x54\x2b\xde\x06\x14\x2a\xd6\x06\x9b\x27\xde\x06\xf6\x2a\xcd\x06\xd2\x29\xc9\x06\xe7\x27\xe0\x06\x1c\x2b\xe2\x06\xe3\x29\xcc\x06\xc0\x27\xda\x06\xb7\x2b\xce\x06\x7d\x2a\xc7\x06\x23\x28\xd8\x06\xbb\x2b\xcc\x06\xbe\x2a\xc5\x06\x04\x28\xd9\x06\xc5\x2b\xc6\x06\x68\x2a\xd3\x06\xfd\x27\xdc\x06\xb3\x2b\xd6\x06\x89\x2a\xcf\x06\x19\x28\xe4\x06\xd6\x2a\xdc\x06\x1c\x2a\xd0\x06\xd5\x27\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe6\x06\xd5\x2a\xd8\x06\x8c\x29\xcc\x06\xd7\x27\xf2\x06\xc0\x2b\xd9\x06\xa0\x29\xcf\x06\xdb\x27\xbd\x06\x4c\x2c\xbf\x06\x9a\x2a\xcd\x06\x9e\x28\xe6\x06\x13\x2c\xd6\x06\x60\x2a\xd8\x06\x93\x28\xe1\x06\xe2\x2b\xe7\x06\xa5\x2a\xcf\x06\x55\x28\xeb\x06\x57\x2c\xe4\x06\x81\x2a\xcb\x06\x9a\x28\xe3\x06\xe3\x2b\xd8\x06\x19\x2a\xcc\x06\xd2\x28\xdc\x06\xf0\x2a\xd4\x06\xeb\x29\xcc\x06\x25\x28\xe2\x06\xc9\x2a\xd3\x06\xb2\x29\xd9\x06\x05\x28\xdd\x06\xb4\x2b\xcc\x06\x35\x2a\xd2\x06\x7f\x28\xf2\x06\xe7\x2b\xe9\x06\x7c\x2a\xdb\x06\xf5\x28\xec\x06\x3b\x2c\xd9\x06\x9a\x2a\xd9\x06\x9d\x28\xe1\x06\xe6\x2b\xd9\x06\xbb\x2a\xd6\x06\xa1\x28\xe3\x06\x56\x2c\xd6\x06\xeb\x2a\xd2\x06\xde\x28\xf8\x06\xf8\x2b\xe6\x06\x63\x2a\xd9\x06\x4a\x28\xdc\x06\x8a\x2b\xd9\x06\x11\x2a\xd4\x06\x7c\x28\xcd\x06\x9c\x2b\xc4\x06\x67\x2a\xdd\x06\x74\x28\xe4\x06\x13\x2c\xe0\x06\xa2\x2a\xe0\x06\xed\x28\xed\x06\xa9\x2c\xd2\x06\x5b\x2a\xdd\x06\xce\x28\xec\x06\xe2\x2c\xd8\x06\xa0\x2a\xe5\x06\xed\x28\xda\x06\xe1\x2c\xcd\x06\x79\x2a\xe0\x06\xdb\x28\xeb\x06\x96\x2c\xe3\x06\x28\x2a\xd8\x06\x7f\x28\xdb\x06\x39\x2b\xd2\x06\xdf\x29\xcd\x06\xdb\x27\xdb\x06\xfc\x2a\xcf\x06\x79\x2a\xd7\x06\x3f\x28\xd9\x06\xc1\x2b\xcb\x06\xc3\x2a\xe2\x06\xbb\x28\xd6\x06\xa1\x2b\xcb\x06\x90\x2a\xd6\x06\xe1\x28\xf4\x06\xa8\x2b\xe4\x06\x77\x2a\xd8\x06\xb1\x28\xdf\x06\x01\x2c\xd9\x06\xb2\x2a\xd4\x06\xb9\x28\xe1\x06\x93\x2c\xd4\x06\x83\x2a\xd9\x06\xf0\x28\xed\x06\xf4\x2b\xd9\x06\xa8\x29\xcf\x06\x0e\x28\xea\x06\x1f\x2c\xe7\x06\x57\x2a\xd5\x06\x8f\x28\xf3\x06\x2f\x2c\xe5\x06\x1a\x2b\xd5\x06\xc7\x28\xe1\x06\xd2\x2b\xd4\x06\xa1\x2a\xda\x06\xc7\x28\xe7\x06\x88\x2b\xdf\x06\xe6\x2a\xd2\x06\x81\x28\xe0\x06\x7a\x2b\xdb\x06\x9c\x2a\xc9\x06\x7e\x28\xe3\x06\x2b\x2b\xd5\x06\x83\x2a\xd2\x06\x72\x28\xce\x06\x17\x2b\xb8\x06\x13\x2a\xcd\x06\x24\x28\xe4\x06\xdb\x2a\xdd\x06\x03\x2a\xce\x06\xf8\x27\xe8\x06\xb0\x2b\xd9\x06\x52\x2a\xcf\x06\x73\x28\xf0\x06\xf2\x2b\xde\x06\x3f\x2a\xdf\x06\x3e\x28\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe3\x06\x73\x2b\xe1\x06\x62\x2a\xd5\x06\x6a\x28\xe8\x06\x16\x2b\xe2\x06\x65\x2a\xd1\x06\x2d\x28\xe8\x06\x65\x2b\xd8\x06\x7e\x2a\xd1\x06\x0e\x28\xd1\x06\x14\x2b\xc7\x06\x17\x2a\xcb\x06\xcf\x27\xe1\x06\xcd\x2a\xd8\x06\xd2\x29\xcf\x06\xc1\x27\xec\x06\x53\x2b\xe3\x06\x27\x2a\xd1\x06\xcb\x27\xde\x06\x5d\x2b\xd8\x06\x9b\x2a\xd2\x06\xa4\x27\xd3\x06\x6a\x2b\xcc\x06\x6c\x2a\xd4\x06\xa1\x27\xd9\x06\x78\x2b\xd1\x06\xa5\x2a\xc8\x06\xfc\x27\xd5\x06\x1c\x2b\xd2\x06\x85\x2a\xc6\x06\x00\x28\xe6\x06\xda\x2a\xda\x06\x01\x2a\xd2\x06\x17\x28\xda\x06\x82\x2a\xd6\x06\xbc\x29\xd4\x06\xde\x27\xd7\x06\xf2\x2a\xd6\x06\x22\x2a\xd6\x06\x10\x28\xe0\x06\x25\x2b\xe6\x06\xbf\x2a\xd6\x06\x8e\x28\xea\x06\x7c\x2b\xe1\x06\xf7\x2a\xdd\x06\xc8\x28\xdc\x06\xc0\x2b\xdc\x06\xf0\x2a\xd9\x06\xa6\x28\xf7\x06\x86\x2b\xf4\x06\x18\x2b\xe0\x06\xbc\x28\xd8\x06\x89\x2b\xd3\x06\xcf\x2a\xda\x06\xfd\x28\xe6\x06\x1f\x2b\xe2\x06\x2e\x2a\xd3\x06\x58\x28\xd5\x06\x2f\x2b\xdb\x06\x58\x2a\xca\x06\x92\x28\xde\x06\x1f\x2c\xcd\x06\xed\x2a\xd2\x06\x1f\x29\xeb\x06\x24\x2c\xdd\x06\xeb\x2a\xd6\x06\x38\x29\xea\x06\xaf\x2c\xe4\x06\x30\x2b\xc6\x06\x38\x29\xe6\x06\x7b\x2d\xe3\x06\x18\x2b\xcd\x06\xd0\x29\xf4\x06\xc4\x2d\xd7\x06\x0c\x2b\xda\x06\xbf\x29\xdb\x06\x5b\x2c\xd8\x06\xc3\x2a\xd6\x06\x1d\x29\xe4\x06\x25\x2c\xe3\x06\x93\x2b\xd7\x06\x6b\x29\xef\x06\x9d\x2c\xe6\x06\x3a\x2b\xdd\x06\x91\x29\xe9\x06\xdf\x2c\xd2\x06\xee\x2a\xc9\x06\x41\x29\xec\x06\x67\x2c\xe5\x06\xaa\x2b\xd9\x06\x30\x29\xe3\x06\x30\x2c\xdb\x06\xe6\x2a\xd4\x06\x42\x29\xdc\x06\x28\x2c\xcb\x06\xd0\x2a\xe2\x06\x3c\x29\xd7\x06\x58\x2b\xd6\x06\xd4\x2a\xcc\x06\x8c\x28\xdd\x06\x75\x2b\xcc\x06\xa5\x2a\xd6\x06\xa1\x28\xe7\x06\xa3\x2b\xe6\x06\xfd\x2a\xd3\x06\x28\x29\xf1\x06\x21\x2c\xe6\x06\x00\x2b\xdd\x06\x5e\x29\xe1\x06\xd3\x2b\xe1\x06\x32\x2b\xd3\x06\xe7\x28\xe1\x06\x01\x2c\xdb\x06\x72\x2b\xd9\x06\x1b\x29\xe5\x06\xf2\x2b\xdc\x06\xfd\x2a\xdc\x06\x62\x29\xed\x06\xce\x2b\xdd\x06\xdb\x2a\xca\x06\xc8\x28\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xdb\x06\x62\x2b\xde\x06\xa7\x2a\xdc\x06\xd5\x28\xef\x06\x0a\x2c\xea\x06\xcc\x2b\xd9\x06\x22\x29\xe7\x06\xe6\x2b\xe4\x06\x3f\x2b\xd1\x06\x1a\x29\xe4\x06\x1b\x2c\xd6\x06\xfd\x2a\xd0\x06\xd6\x28\xe1\x06\x14\x2c\xda\x06\xcf\x2a\xd6\x06\x0a\x29\xde\x06\xe6\x2b\xd9\x06\x0d\x2b\xcf\x06\xdd\x28\xdb\x06\x7f\x2b\xdc\x06\x94\x2a\xd6\x06\xa9\x28\xda\x06\x56\x2b\xd9\x06\x8b\x2a\xd0\x06\x67\x28\xe6\x06\xb6\x2b\xdb\x06\xb9\x2a\xd3\x06\xa9\x28\xe1\x06\xaa\x2b\xd7\x06\xc3\x2a\xcb\x06\xd6\x28\xe6\x06\xb1\x2b\xe6\x06\x0f\x2b\xd4\x06\xf8\x28\xe2\x06\xd1\x2b\xe7\x06\x4b\x2b\xdd\x06\xfc\x28\xd9\x06\xd1\x2b\xcf\x06\x6d\x2b\xd6\x06\x47\x29\xce\x06\xb4\x2b\xc5\x06\xcb\x2a\xcf\x06\xe4\x28\xdf\x06\xf7\x2a\xe7\x06\x20\x2a\xd5\x06\x72\x28\xe9\x06\x8c\x2b\xe1\x06\x72\x2a\xcf\x06\x94\x28\xdf\x06\xc3\x2b\xd6\x06\x27\x2b\xc5\x06\xfa\x28\xea\x06\xda\x2b\xe3\x06\x2e\x2b\xd1\x06\xc9\x28\xd9\x06\x32\x2c\xd5\x06\x22\x2b\xd3\x06\xde\x28\xd1\x06\x38\x2c\xc7\x06\x0d\x2b\xcf\x06\x0a\x29\xdb\x06\xb6\x2b\xd8\x06\xf4\x2a\xce\x06\x30\x29\xef\x06\x71\x2c\xe2\x06\xb0\x2a\xd4\x06\xd6\x28\xdd\x06\x8c\x2b\xd3\x06\x83\x2a\xe1\x06\xe9\x28\xef\x06\x08\x2c\xea\x06\x36\x2b\xdc\x06\x35\x29\xeb\x06\x5f\x2c\xdf\x06\x56\x2b\xdd\x06\x59\x29\xda\x06\x0a\x2c\xda\x06\x11\x2b\xdf\x06\x42\x29\xe7\x06\x41\x2c\xd8\x06\x03\x2b\xd3\x06\x25\x29\xdf\x06\xfb\x2b\xe2\x06\x2a\x2b\xd0\x06\x20\x29\xdf\x06\xb2\x2b\xe2\x06\xfe\x2a\xd3\x06\x16\x29\xd9\x06\xc3\x2b\xcb\x06\xcc\x2a\xd0\x06\xfb\x28\xd9\x06\x25\x2c\xd5\x06\x57\x2b\xd0\x06\x29\x29\xdd\x06\x7f\x2c\xd4\x06\xad\x2b\xde\x06\x87\x29\xdd\x06\x61\x2c\xe2\x06\x54\x2b\xd9\x06\x65\x29\xe2\x06\x7a\x2c\xd5\x06\x6f\x2b\xd8\x06\x57\x29\xef\x06\x45\x2c\xdc\x06\x54\x2b\xd1\x06\x6b\x29\xdc\x06\xd6\x2b\xda\x06\x3c\x2b\xe3\x06\x12\x29\xec\x06\x9b\x2b\xe5\x06\xa8\x2a\xd9\x06\xd8\x28\xe3\x06\x44\x2c\xdb\x06\x2a\x2b\xd6\x06\x42\x29\xdc\x06\x29\x2c\xd9\x06\x42\x2b\xc9\x06\x16\x29\xed\x06\x4f\x2c\xdf\x06\x38\x2b\xdd\x06\x09\x29\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xf2\x06\x46\x2c\xe3\x06\x67\x2b\xdd\x06\x43\x29\xdc\x06\x2e\x2c\xd0\x06\x8c\x2b\xe1\x06\x3a\x29\xd3\x06\xe3\x2b\xdc\x06\x0f\x2b\xce\x06\x03\x29\xe8\x06\xb4\x2b\xee\x06\xa0\x2a\xd7\x06\xaf\x28\xf1\x06\xe8\x2b\xe7\x06\xfd\x2a\xd7\x06\xcd\x28\xe7\x06\x7b\x2c\xe3\x06\x73\x2b\xd2\x06\x4d\x29\xe1\x06\x3b\x2c\xdf\x06\x64\x2b\xd9\x06\x5c\x29\xd8\x06\x57\x2c\xd8\x06\x2f\x2b\xd2\x06\xfc\x28\xe1\x06\x1d\x2c\xdd\x06\x57\x2b\xd4\x06\x20\x29\xe3\x06\xb2\x2b\xe6\x06\xf2\x2a\xdd\x06\x31\x29\xe5\x06\xa8\x2b\xdd\x06\xa0\x2a\xcb\x06\x8a\x28\xe2\x06\xce\x2b\xe8\x06\x05\x2b\xd9\x06\xe9\x28\xea\x06\x00\x2c\xe6\x06\x6d\x2b\xd4\x06\x3c\x29\xf0\x06\xfe\x2b\xd8\x06\xea\x2a\xdf\x06\x41\x29\xea\x06\xcd\x2b\xe6\x06\xf2\x2a\xe1\x06\x2b\x29\xcd\x06\xe4\x2b\xc7\x06\x36\x2b\xdb\x06\x88\x29\xee\x06\xc0\x2b\xdb\x06\xe0\x2a\xe0\x06\x56\x29\xdc\x06\x7e\x2b\xc9\x06\x86\x2a\xd5\x06\xc0\x28\xe0\x06\xb9\x2b\xdb\x06\xd9\x2a\xdd\x06\xfb\x28\xdf\x06\xf2\x2b\xe2\x06\x21\x2b\xd3\x06\x39\x29\xe1\x06\xe9\x2b\xe4\x06\x61\x2b\xe1\x06\x4b\x29\xe1\x06\x0e\x2c\xe3\x06\x2a\x2b\xcf\x06\x50\x29\xec\x06\x09\x2c\xe3\x06\x7e\x2b\xd6\x06\x4e\x29\xe9\x06\x10\x2c\xdb\x06\x43\x2b\xe1\x06\x6b\x29\xe4\x06\x65\x2b\xe0\x06\xa3\x2a\xda\x06\xdc\x28\xe3\x06\x4e\x2b\xdb\x06\xab\x2a\xe4\x06\xc3\x28\xe2\x06\xb8\x2b\xd8\x06\x12\x2b\xda\x06\x3c\x29\xd8\x06\x44\x2c\xcc\x06\x20\x2b\xe4\x06\x9b\x29\xdd\x06\x0c\x2c\xd2\x06\x2b\x2b\xd9\x06\x34\x29\xc4\x06\x09\x2c\xbe\x06\x39\x2b\xe3\x06\x58\x29\xde\x06\x2f\x2c\xe2\x06\x87\x2b\xda\x06\x59\x29\xe1\x06\xdf\x2b\xd7\x06\x0e\x2b\xd8\x06\x00\x29\xe0\x06\x6a\x2b\xd9\x06\xa3\x2a\xd2\x06\xa7\x28\xcc\x06\x2e\x2c\xc6\x06\x1c\x2b\xcf\x06\x0c\x29\xd1\x06\xe2\x2b\xcb\x06\x39\x2b\xd7\x06\x49\x29\xde\x06\x06\x2c\xdb\x06\x50\x2b\xde\x06\x52\x29\xed\x06\x3d\x2c\xda\x06\xfa\x2a\xdb\x06\x3f\x29\xda\x06\x98\x2b\xdc\x06\xd9\x2a\xd2\x06\xce\x28\xe4\x06\xba\x2b\xda\x06\xc0\x2a\xd1\x06\xfb\x28\xcd\x06\x56\x2b\xca\x06\x6e\x2a\xce\x06\x6d\x28\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xd1\x06\x8b\x2b\xd0\x06\xac\x2a\xd3\x06\x28\x29\xe2\x06\x43\x2c\xd4\x06\x12\x2b\xe0\x06\xc8\x29\xe5\x06\x37\x2c\xe0\x06\xfe\x2a\xd8\x06\x0c\x29\xd7\x06\x2f\x2c\xc8\x06\x54\x2b\xc7\x06\xcd\x29\xf1\x06\x15\x2c\xe1\x06\xce\x2a\xdd\x06\xfb\x28\xee\x06\xc1\x2b\xe6\x06\x8f\x2a\xdb\x06\xde\x28\xcc\x06\x80\x2b\xcd\x06\x42\x2a\xcf\x06\x5e\x28\xdc\x06\xb9\x2b\xd8\x06\x62\x2a\xcd\x06\x7f\x28\xd7\x06\xec\x2b\xd7\x06\xb1\x2a\xd6\x06\x17\x29\xec\x06\xfc\x2b\xd5\x06\xc4\x2a\xd6\x06\x11\x29\xeb\x06\x32\x2c\xe0\x06\x0b\x2b\xd0\x06\x24\x29\xec\x06\x0d\x2c\xe3\x06\xfe\x2a\xcc\x06\x0e\x29\xdf\x06\x0f\x2c\xd6\x06\x47\x2b\xd5\x06\x32\x29\xdc\x06\xe5\x2b\xcc\x06\x93\x2a\xdb\x06\xde\x28\xe7\x06\xc3\x2b\xdd\x06\x94\x2a\xd5\x06\xa3\x28\xe5\x06\x59\x2c\xe1\x06\x2b\x2b\xdf\x06\x3c\x29\xeb\x06\x60\x2c\xe3\x06\xf7\x2a\xd7\x06\x3a\x29\xeb\x06\x3b\x2c\xe2\x06\xf6\x2a\xd7\x06\x0d\x29\xe5\x06\xf3\x2b\xdb\x06\xe2\x2a\xda\x06\x24\x29\xe6\x06\x32\x2c\xdf\x06\xf9\x2a\xdb\x06\x6a\x29\xf4\x06\xeb\x2b\xe7\x06\xb6\x2a\xe4\x06\xf1\x28\xee\x06\x93\x2b\xe0\x06\x57\x2a\xd8\x06\xa0\x28\xdf\x06\x15\x2c\xd7\x06\xf8\x2a\xd2\x06\x2e\x29\xef\x06\xcc\x2c\xe6\x06\x6b\x2b\xd9\x06\x46\x29\xe1\x06\x8d\x2c\xe1\x06\x98\x2b\xd6\x06\xc5\x29\xf1\x06\x5b\x2c\xe4\x06\xe0\x2a\xe2\x06\x57\x29\xe4\x06\xa4\x2c\xd7\x06\x19\x2b\xdc\x06\x3a\x29\xcd\x06\x4c\x2c\xd0\x06\x14\x2b\xdf\x06\x2f\x29\xea\x06\x32\x2c\xe0\x06\x89\x2a\xd5\x06\xd0\x28\xdb\x06\xa7\x2c\xd4\x06\x33\x2b\xe5\x06\x36\x29\xe8\x06\xb3\x2c\xd6\x06\xcd\x2a\xd5\x06\x81\x29\xe2\x06\x74\x2c\xde\x06\xb9\x2a\xd1\x06\x3a\x29\xf5\x06\xcb\x2c\xe0\x06\xc6\x2a\xdf\x06\x3e\x29\xeb\x06\xa5\x2c\xd5\x06\x01\x2b\xdd\x06\xfd\x28\xe6\x06\x0a\x2c\xd2\x06\xa6\x2a\xe4\x06\xf1\x28\x07\x07\x70\x2b\x0c\x07\x38\x2a\xfa\x06\x8a\x28\x06\x07\x7a\x2b\xfa\x06\x0d\x2a\xef\x06\x56\x28\xf7\x06\x66\x2b\xf3\x06\x0f\x2a\xec\x06\x47\x28\xbc\x06\x12\x2b\xb0\x06\xd6\x29\xb0\x06\x6d\x27\x54\x06\x8c\x2b\x43\x06\x4a\x29\x42\x06\x69\x26\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x54\x06\x2e\x2a\x4a\x06\x2c\x28\x45\x06\x23\x25\x83\x06\x39\x2a\x6c\x06\xc7\x28\x6f\x06\x9b\x26\x01\x07\x67\x2a\xf3\x06\xbc\x28\xe6\x06\xf4\x26\x03\x07\x6d\x2a\xfc\x06\x1b\x29\xf1\x06\xbc\x27\xed\x06\x68\x2a\xdc\x06\x06\x29\xe6\x06\x32\x27\xea\x06\xaf\x2a\xe3\x06\x9e\x29\xda\x06\xb4\x27\xe5\x06\x2d\x2b\xd8\x06\x8f\x29\xd8\x06\xf6\x27\xe2\x06\x1f\x2b\xd6\x06\x75\x29\xd2\x06\xd1\x27\xeb\x06\x35\x2b\xd6\x06\x83\x29\xcb\x06\x6c\x27\xe4\x06\x5a\x2b\xe2\x06\xb7\x29\xd2\x06\xc8\x27\xe6\x06\x58\x2b\xdb\x06\x9d\x29\xd2\x06\xb7\x27\xe3\x06\x90\x2a\xd5\x06\x18\x29\xd1\x06\x4e\x27\xdc\x06\xe1\x2a\xdc\x06\x68\x29\xcf\x06\xa0\x27\xf5\x06\x07\x2b\xe5\x06\xd1\x29\xd8\x06\xc5\x27\xcc\x06\xf4\x2a\xba\x06\xb0\x29\xe0\x06\xb8\x27\xe8\x06\xae\x2a\xe2\x06\x6b\x29\xde\x06\xd9\x27\xe8\x06\xa9\x2a\xdc\x06\x9c\x29\xd3\x06\x94\x27\xe2\x06\x9c\x2a\xdc\x06\x5a\x29\xd9\x06\xa3\x27\xd0\x06\x7a\x2a\xca\x06\x21\x29\xc8\x06\x10\x27\xdf\x06\x02\x2a\xdf\x06\xf3\x28\xcd\x06\x0e\x27\xe3\x06\x62\x2a\xd6\x06\x4f\x29\xcc\x06\x74\x27\xe1\x06\xa2\x2a\xd9\x06\x4b\x29\xd7\x06\x18\x27\xe6\x06\x93\x2a\xd2\x06\x3f\x29\xd9\x06\x7b\x27\xdb\x06\x45\x2a\xdd\x06\x8b\x29\xc6\x06\x4d\x27\xef\x06\x8b\x2a\xdf\x06\x22\x29\xd6\x06\x64\x27\xe5\x06\x4d\x2a\xdb\x06\xe1\x28\xd8\x06\x40\x27\xe4\x06\x15\x2a\xdb\x06\x94\x28\xd2\x06\xcc\x26\xd9\x06\x30\x2a\xc8\x06\x0a\x29\xca\x06\x1b\x27\xd1\x06\xe9\x29\xd8\x06\x3b\x29\xd1\x06\x56\x27\xe6\x06\x65\x2a\xd0\x06\x04\x29\xcd\x06\x4c\x27\xe3\x06\x28\x2a\xe9\x06\x45\x29\xdd\x06\x4a\x27\xcb\x06\x35\x2a\xc0\x06\x18\x29\xd2\x06\x54\x27\xe2\x06\x16\x2a\xd8\x06\xc5\x28\xde\x06\x45\x27\xd1\x06\xc9\x29\xd9\x06\xb3\x28\xd0\x06\xcb\x26\xe1\x06\xd4\x29\xd9\x06\xc8\x28\xd7\x06\x41\x27\xca\x06\xf6\x29\xc1\x06\x25\x29\xd9\x06\x4e\x27\xe3\x06\x09\x2a\xd9\x06\xfd\x28\xe4\x06\x41\x27\xe4\x06\x27\x2a\xe2\x06\x12\x29\xd8\x06\x2a\x27\xd4\x06\x0d\x2a\xcd\x06\x10\x29\xdd\x06\x3d\x27\xd9\x06\xfe\x29\xe0\x06\xef\x28\xd1\x06\x0f\x27\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xdf\x06\xd8\x29\xd4\x06\x83\x28\xd3\x06\xc5\x26\xd0\x06\xd8\x29\xcf\x06\xfd\x28\xca\x06\x03\x27\xca\x06\x21\x2a\xbb\x06\x13\x29\xcf\x06\x27\x27\xde\x06\x32\x2a\xd2\x06\xf7\x28\xd0\x06\x28\x27\xde\x06\xf5\x29\xcd\x06\xef\x28\xd1\x06\x45\x27\xe5\x06\xcc\x29\xe2\x06\xe7\x28\xd2\x06\x15\x27\xd4\x06\xfa\x29\xdf\x06\xcc\x28\xd2\x06\x0c\x27\xd8\x06\x99\x29\xd6\x06\x4c\x28\xc5\x06\x73\x26\xdb\x06\xb2\x29\xdb\x06\x90\x28\xcd\x06\xc9\x26\xd6\x06\xad\x29\xd1\x06\xf2\x28\xd0\x06\xec\x26\xd9\x06\x99\x29\xdc\x06\xd6\x28\xd3\x06\xb9\x26\xc9\x06\x21\x2a\xc0\x06\x13\x29\xd3\x06\x15\x27\xd6\x06\x94\x29\xdb\x06\x9d\x28\xd3\x06\x0e\x27\xc0\x06\xe1\x29\xb1\x06\xaa\x28\xc8\x06\xf2\x26\xda\x06\x6f\x29\xd5\x06\x58\x28\xc4\x06\x5d\x26\xdc\x06\x7a\x29\xc8\x06\x03\x28\xcf\x06\x81\x26\xd2\x06\x39\x29\xcd\x06\x5c\x28\xd1\x06\x99\x26\xc7\x06\x89\x29\xbb\x06\x52\x28\xdc\x06\x94\x26\xd1\x06\x4b\x29\xd4\x06\x5b\x28\xcc\x06\x74\x26\xce\x06\x57\x29\xcb\x06\x45\x28\xcb\x06\x85\x26\xe1\x06\x7d\x29\xdc\x06\x9d\x28\xd3\x06\xd1\x26\xcb\x06\x4a\x29\xc8\x06\x77\x28\xcd\x06\xcd\x26\xdc\x06\x30\x29\xcc\x06\xe8\x27\xd1\x06\x52\x26\xd4\x06\x95\x29\xd6\x06\x97\x28\xcb\x06\x8c\x26\xd7\x06\x8e\x29\xd2\x06\xbd\x28\xd8\x06\xf2\x26\xea\x06\xab\x29\xd7\x06\x6b\x28\xd3\x06\xb4\x26\xd8\x06\xc2\x29\xd6\x06\x83\x28\xce\x06\xc4\x26\xce\x06\xec\x29\xc5\x06\x87\x28\xd0\x06\xdc\x26\xd6\x06\xb2\x29\xd8\x06\xb0\x28\xd3\x06\xc5\x26\xc9\x06\x40\x29\xc4\x06\x69\x28\xce\x06\x82\x26\xe0\x06\xcb\x29\xd7\x06\x98\x28\xd0\x06\xf9\x26\xe3\x06\x85\x29\xdf\x06\xa2\x28\xd3\x06\xdc\x26\xe3\x06\xe4\x29\xda\x06\xd6\x28\xd2\x06\xd5\x26\xca\x06\x8f\x29\xcc\x06\x9f\x28\xce\x06\xd4\x26\xe3\x06\xb9\x29\xd8\x06\x96\x28\xc9\x06\xc6\x26\xdf\x06\x9b\x29\xdc\x06\x93\x28\xd0\x06\xdb\x26\xd9\x06\x35\x29\xd1\x06\x4c\x28\xcd\x06\x6b\x26\xca\x06\x7c\x29\xbe\x06\x69\x28\xcb\x06\xc6\x26\xc3\x06\xa8\x29\xc0\x06\x01\x29\xd2\x06\xd1\x26\xdb\x06\xa9\x29\xd9\x06\x76\x28\xc8\x06\xba\x26\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe4\x06\x92\x29\xd5\x06\x6a\x28\xcb\x06\x95\x26\xe0\x06\x81\x29\xd4\x06\xa4\x28\xc6\x06\xd2\x26\xd9\x06\x65\x29\xde\x06\x93\x28\xd8\x06\xca\x26\xd2\x06\x3a\x29\xd6\x06\x19\x28\xc6\x06\x45\x26\xe7\x06\x16\x29\xdd\x06\x4d\x28\xde\x06\x46\x26\xe4\x06\x53\x29\xd9\x06\x6e\x28\xdc\x06\xe4\x26\xda\x06\x5c\x29\xd5\x06\x71\x28\xc5\x06\x72\x26\xda\x06\x6c\x29\xd6\x06\x6e\x28\xd6\x06\xa3\x26\xd9\x06\x74\x29\xd0\x06\x4d\x28\xdc\x06\xc4\x26\xd0\x06\x78\x29\xc4\x06\x9c\x28\xd4\x06\xdc\x26\xd2\x06\x4f\x29\xd3\x06\x6f\x28\xc3\x06\x9f\x26\xe9\x06\x87\x29\xd3\x06\xf3\x27\xd1\x06\x4e\x26\xec\x06\xab\x29\xe0\x06\x6e\x28\xd0\x06\xb2\x26\xd3\x06\xa9\x29\xd3\x06\x61\x28\xd4\x06\x90\x26\xe9\x06\x89\x29\xd9\x06\x83\x28\xd3\x06\x95\x26\xd3\x06\x55\x29\xc1\x06\x83\x28\xcb\x06\xa4\x26\xd3\x06\x4f\x29\xc3\x06\x40\x28\xdf\x06\xa8\x26\xdb\x06\x49\x29\xd3\x06\x8b\x28\xc6\x06\x67\x26\xd7\x06\x2c\x29\xc4\x06\xfc\x27\xce\x06\x0f\x26\xdf\x06\x77\x29\xc9\x06\x25\x28\xca\x06\x60\x26\xc6\x06\x5d\x29\xc1\x06\x57\x28\xc8\x06\x40\x26\xe1\x06\x73\x29\xd1\x06\x2a\x28\xd5\x06\x66\x26\xcc\x06\x53\x29\xcc\x06\x51\x28\xbe\x06\x49\x26\xde\x06\x7d\x29\xca\x06\x19\x28\xca\x06\x02\x26\xde\x06\x0d\x29\xda\x06\x1f\x28\xdf\x06\xfe\x25\xc5\x06\xe3\x28\xbd\x06\x9d\x27\xc3\x06\x5f\x25\xc1\x06\x0b\x29\xc4\x06\xb3\x27\xcc\x06\x63\x25\xc8\x06\x14\x29\xbc\x06\xc9\x27\xbd\x06\x44\x25\xcf\x06\x0f\x29\xcd\x06\xe3\x27\xce\x06\x3e\x25\xbf\x06\x23\x29\xb6\x06\x29\x28\xd5\x06\x86\x25\xde\x06\x13\x29\xdc\x06\xde\x27\xd2\x06\xd9\x25\xd1\x06\xb2\x28\xc9\x06\xa7\x27\xc3\x06\xe7\x25\xde\x06\xc6\x28\xd9\x06\x80\x27\xcf\x06\xa2\x25\xcb\x06\x34\x29\xc2\x06\xcd\x27\xd1\x06\x1c\x26\xdb\x06\x33\x29\xcd\x06\x00\x28\xd4\x06\x82\x26\xd0\x06\x55\x29\xcc\x06\x00\x28\xd1\x06\x41\x26\xda\x06\x4e\x29\xd6\x06\x30\x28\xcf\x06\x68\x26\xdc\x06\x2e\x29\xdd\x06\x66\x28\xd8\x06\x95\x26\xd5\x06\x5d\x29\xd3\x06\x51\x28\xdd\x06\xa7\x26\xcb\x06\x2c\x29\xcd\x06\xe0\x27\xcc\x06\x01\x26\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xd6\x06\x35\x29\xc5\x06\xfe\x27\xc1\x06\x2f\x26\xda\x06\x4b\x29\xd1\x06\x43\x28\xcc\x06\x36\x26\xd9\x06\x04\x29\xd4\x06\x4d\x28\xcf\x06\x5f\x26\xd7\x06\x08\x29\xc5\x06\x0b\x28\xc3\x06\x58\x26\xe0\x06\x94\x29\xd4\x06\x5f\x28\xcc\x06\x5c\x26\xd8\x06\x18\x29\xd8\x06\x63\x28\xc7\x06\x66\x26\xde\x06\x04\x29\xd9\x06\x22\x28\xd4\x06\x1f\x26\xc0\x06\x1e\x29\xb6\x06\x63\x28\xbf\x06\x6b\x26\xd7\x06\x55\x29\xd0\x06\x80\x28\xc3\x06\xa4\x26\xcf\x06\x57\x29\xd5\x06\x6a\x28\xd0\x06\x88\x26\xde\x06\xbf\x29\xd6\x06\x6e\x28\xd4\x06\x9f\x26\xe5\x06\x06\x2a\xda\x06\x58\x28\xdd\x06\xb2\x26\xdd\x06\xe3\x29\xd9\x06\xe1\x27\xdb\x06\xa8\x26\xdb\x06\x67\x29\xca\x06\xf8\x27\xcd\x06\x7e\x26\xdd\x06\xa6\x29\xd4\x06\xb9\x27\xcf\x06\x97\x26\xe6\x06\x91\x2a\xd0\x06\x13\x28\xd8\x06\xab\x26\xdd\x06\xfe\x2a\xd2\x06\x34\x28\xd6\x06\xb5\x26\xe4\x06\xf2\x29\xd8\x06\x62\x28\xcf\x06\xbb\x26\xc6\x06\x75\x29\xc6\x06\x98\x28\xd4\x06\xa2\x26\xde\x06\xbc\x29\xd7\x06\x98\x28\xcc\x06\xb6\x26\xd5\x06\x62\x29\xe5\x06\xe3\x28\xce\x06\xa0\x26\xe0\x06\x5a\x29\xd2\x06\x52\x28\xd4\x06\x66\x26\xd9\x06\xa9\x29\xc8\x06\xdf\x28\xde\x06\xbb\x26\xda\x06\x6e\x29\xd7\x06\x86\x28\xc8\x06\xd8\x26\xda\x06\x47\x29\xd3\x06\xd3\x28\xda\x06\x1b\x27\xd5\x06\x74\x29\xd1\x06\xae\x28\xd1\x06\xe0\x26\xd7\x06\x55\x29\xe5\x06\xf5\x28\xd3\x06\xf5\x26\xd8\x06\x96\x29\xdc\x06\x9d\x28\xd2\x06\xef\x26\xe0\x06\x58\x29\xd7\x06\x76\x28\xc9\x06\xb0\x26\xd8\x06\x55\x29\xd3\x06\x57\x28\xd4\x06\xc1\x26\xdc\x06\x8a\x29\xd7\x06\xd0\x28\xd2\x06\xcd\x26\xe0\x06\x93\x29\xe4\x06\xbf\x28\xcd\x06\xc4\x26\xce\x06\x6b\x29\xcf\x06\x01\x29\xc6\x06\xeb\x26\xe4\x06\x72\x29\xda\x06\xa2\x28\xd3\x06\x0d\x27\xe0\x06\x9c\x29\xd9\x06\xa0\x28\xc9\x06\xd1\x26\xd6\x06\x1c\x29\xcf\x06\x69\x28\xcb\x06\x5b\x26\xe2\x06\x2f\x29\xd6\x06\x4e\x28\xcf\x06\x9d\x26\xd1\x06\x7d\x29\xcd\x06\x46\x28\xca\x06\x81\x26\xde\x06\x75\x29\xd0\x06\x5f\x28\xd4\x06\x9b\x26\xe3\x06\x5a\x29\xd7\x06\xef\x28\xc5\x06\x57\x26\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xda\x06\xa6\x29\xd7\x06\x99\x28\xd4\x06\x93\x26\xd9\x06\xb3\x29\xd5\x06\x8d\x28\xc4\x06\xb3\x26\xce\x06\xd7\x29\xc3\x06\xa1\x28\xbf\x06\xc1\x26\xd6\x06\x01\x29\xd2\x06\xb4\x28\xcf\x06\x59\x26\xdf\x06\xfa\x28\xe8\x06\x21\x29\xd9\x06\x95\x26\xd3\x06\x85\x29\xd1\x06\xca\x28\xd1\x06\x98\x26\xc7\x06\xb7\x29\xc4\x06\x84\x28\xce\x06\xd2\x26\xd3\x06\xdf\x29\xd7\x06\xf9\x28\xd6\x06\x94\x26\xe0\x06\xe0\x29\xd7\x06\xc2\x28\xd0\x06\xe8\x26\xe1\x06\xd5\x29\xdb\x06\x75\x28\xd4\x06\xa3\x26\xd8\x06\xd1\x29\xce\x06\x05\x28\xd3\x06\x24\x26\xe0\x06\xa0\x29\xd9\x06\x36\x28\xd4\x06\x6d\x26\xcb\x06\x78\x29\xb8\x06\x72\x28\xcb\x06\x46\x26\xcb\x06\x1a\x29\xc6\x06\x45\x28\xc5\x06\x74\x26\xe1\x06\x16\x29\xcb\x06\x3e\x28\xd1\x06\x4d\x26\xdc\x06\x64\x29\xd2\x06\x21\x28\xd1\x06\x54\x26\xd2\x06\x60\x29\xd1\x06\x2c\x28\xc9\x06\x42\x26\xe3\x06\xc9\x29\xcc\x06\xc3\x27\xd2\x06\x0f\x26\xed\x06\x71\x2a\xd5\x06\x28\x28\xd8\x06\x64\x26\xdd\x06\x7b\x2a\xd6\x06\x81\x28\xcb\x06\x8f\x26\xdb\x06\x0e\x2b\xcc\x06\x86\x28\xd2\x06\xc7\x26\xe5\x06\x62\x2a\xd5\x06\x30\x28\xcf\x06\x8e\x26\xdf\x06\x78\x29\xde\x06\x96\x28\xd4\x06\x83\x26\xd3\x06\xde\x29\xc9\x06\x98\x28\xd3\x06\xab\x26\xdd\x06\xda\x29\xde\x06\x35\x28\xd6\x06\x8b\x26\xda\x06\xcc\x29\xc7\x06\x35\x28\xd0\x06\xa4\x26\xe5\x06\xdc\x29\xe1\x06\xa3\x28\xd4\x06\x98\x26\xab\x06\x60\x2a\x9f\x06\xec\x28\xcc\x06\xba\x26\xe2\x06\x17\x2a\xd8\x06\x61\x28\xcb\x06\x63\x26\xdb\x06\x1e\x2a\xe0\x06\x85\x28\xe8\x06\xd9\x26\xec\x06\xe5\x29\xda\x06\xcb\x28\xd8\x06\xa7\x26\xc6\x06\xcd\x29\xc4\x06\xbf\x28\xd7\x06\xe8\x26\xf4\x06\xe4\x29\xe1\x06\x85\x28\xcf\x06\x8e\x26\xe0\x06\xda\x29\xe3\x06\xab\x28\xd8\x06\xe9\x26\xea\x06\xf6\x29\xda\x06\x8e\x28\xd8\x06\xba\x26\xd1\x06\x0c\x2a\xc9\x06\xaf\x28\xd2\x06\xb8\x26\xd6\x06\x4b\x2a\xc9\x06\xca\x28\xd4\x06\xc6\x26\xec\x06\x62\x2a\xe4\x06\x7d\x28\xe2\x06\xea\x26\xeb\x06\x76\x2a\xde\x06\xa2\x28\xde\x06\xeb\x26\xd6\x06\xac\x29\xcf\x06\x49\x28\xd9\x06\x8d\x26\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xeb\x06\xc7\x29\xdb\x06\xb0\x28\xcd\x06\xd8\x26\xdf\x06\xed\x29\xda\x06\xc3\x28\xd3\x06\xcd\x26\xdc\x06\x42\x2a\xd6\x06\xca\x28\xd3\x06\x25\x27\xeb\x06\x3d\x2a\xea\x06\xec\x28\xd1\x06\xe7\x26\xe5\x06\x27\x2a\xe7\x06\x0c\x29\xd4\x06\xe6\x26\xe6\x06\xa3\x2a\xd2\x06\x07\x29\xdc\x06\x42\x27\xe2\x06\x3f\x2a\xe0\x06\xef\x28\xdc\x06\xcf\x26\xd8\x06\x0e\x2a\xd7\x06\xe5\x28\xd0\x06\x22\x27\xf9\x06\x3a\x2a\xf5\x06\x04\x29\xdf\x06\xd0\x26\xdf\x06\x5c\x2a\xdb\x06\xf3\x28\xcf\x06\xce\x26\xe6\x06\xdf\x29\xdc\x06\xa3\x28\xcf\x06\xb5\x26\xe1\x06\x30\x2a\xdb\x06\x19\x29\xd5\x06\xf4\x26\xeb\x06\x63\x2a\xdc\x06\xb3\x28\xd3\x06\xd8\x26\xc6\x06\x06\x2a\xca\x06\x8a\x28\xd7\x06\xde\x26\xd4\x06\x36\x2a\xbf\x06\xa3\x28\xd4\x06\xab\x26\xeb\x06\xa9\x29\xdc\x06\xd7\x28\xda\x06\xb7\x26\xdc\x06\xaf\x29\xd9\x06\xb3\x28\xc8\x06\x94\x26\xde\x06\xea\x29\xce\x06\xa7\x28\xcf\x06\x9b\x26\xd1\x06\xf1\x29\xc4\x06\x5f\x28\xd5\x06\x99\x26\xd5\x06\xe3\x29\xd2\x06\xc1\x28\xd1\x06\xb5\x26\xea\x06\xe4\x29\xc8\x06\x45\x28\xd2\x06\x21\x26\xd6\x06\xd0\x29\xcf\x06\x3b\x28\xcc\x06\x5f\x26\xe4\x06\x05\x2a\xda\x06\x4f\x28\xdb\x06\xa9\x26\xdc\x06\xcb\x29\xd4\x06\x6d\x28\xcd\x06\x80\x26\xdf\x06\xd3\x29\xd7\x06\x62\x28\xdc\x06\x8e\x26\xdd\x06\x8a\x29\xde\x06\x8d\x28\xcc\x06\x66\x26\xe3\x06\xf1\x29\xdc\x06\xb7\x28\xd4\x06\xad\x26\xd0\x06\x2a\x2a\xca\x06\x9d\x28\xd1\x06\x98\x26\xe8\x06\x0d\x2a\xd5\x06\x3d\x28\xd9\x06\x62\x26\xc7\x06\x2f\x2a\xcb\x06\x7d\x28\xce\x06\xb9\x26\xe0\x06\x3e\x2a\xd0\x06\x70\x28\xcf\x06\x9a\x26\xd4\x06\x11\x2a\xcf\x06\x76\x28\xcf\x06\x95\x26\xdb\x06\x08\x2a\xda\x06\x2f\x28\xd8\x06\x9e\x26\xd8\x06\x79\x29\xce\x06\x6e\x28\xcf\x06\xa7\x26\xc3\x06\x71\x29\xbc\x06\x35\x28\xcb\x06\x7a\x26\xde\x06\x89\x29\xd8\x06\x01\x28\xca\x06\x37\x26\xdc\x06\x00\x2a\xcb\x06\x48\x28\xd8\x06\xa2\x26\xe8\x06\xf1\x29\xe3\x06\x7a\x28\xdc\x06\x7e\x26\xe7\x06\x11\x2a\xd3\x06\x38\x28\xd8\x06\x8c\x26\xdd\x06\xd4\x29\xc4\x06\x3c\x28\xd7\x06\xa7\x26\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xdf\x06\x34\x2a\xc4\x06\x42\x28\xcc\x06\x94\x26\xe2\x06\xae\x29\xe6\x06\x97\x28\xd5\x06\x99\x26\xe1\x06\x9d\x29\xd8\x06\x6d\x28\xdc\x06\x3a\x26\xd3\x06\xb7\x29\xc2\x06\x48\x28\xd1\x06\xb7\x26\xed\x06\xf2\x29\xe5\x06\x50\x28\xdb\x06\xb0\x26\xdd\x06\x15\x2a\xd4\x06\x75\x28\xdd\x06\xb2\x26\xd7\x06\x27\x2a\xd0\x06\x9c\x29\xdb\x06\x87\x26\xef\x06\x7e\x2a\xe4\x06\x9d\x28\xd4\x06\xc6\x26\xf5\x06\x3d\x2a\xe9\x06\xc1\x28\xda\x06\xd5\x26\xe8\x06\x5e\x2a\xda\x06\x6f\x28\xd1\x06\x9a\x26\xe7\x06\x07\x2a\xe0\x06\x74\x28\xd3\x06\xaf\x26\xe6\x06\x13\x2a\xe8\x06\x8a\x28\xd3\x06\x9c\x26\xba\x06\x34\x2a\xb6\x06\xc8\x28\xce\x06\x83\x26\xe5\x06\xe3\x29\xd0\x06\x6c\x28\xd7\x06\x41\x26\xea\x06\x07\x2a\xe2\x06\x0a\x29\xd6\x06\x35\x26\xdc\x06\xf1\x29\xdd\x06\x6c\x28\xd2\x06\x58\x26\xe3\x06\x01\x2a\xdf\x06\x4e\x28\xdb\x06\x4f\x26\xd1\x06\x14\x2a\xc8\x06\x3f\x28\xc5\x06\x2e\x26\xe5\x06\xb8\x29\xcb\x06\x7c\x28\xcd\x06\x92\x26\xd8\x06\xd7\x29\xc7\x06\x64\x28\xc6\x06\x64\x26\xe7\x06\x8d\x29\xd9\x06\x3a\x28\xda\x06\x3f\x26\xcc\x06\xb8\x29\xb9\x06\x58\x28\xbf\x06\x1c\x26\xd1\x06\xed\x29\xc8\x06\x7d\x28\xda\x06\x5b\x26\xcb\x06\x9f\x29\xb4\x06\x1e\x28\xc4\x06\xec\x25\xd5\x06\x65\x29\xd2\x06\xc4\x27\xc3\x06\xb8\x25\xd4\x06\x0f\x2a\xc2\x06\x2f\x28\xbf\x06\x10\x26\xe9\x06\xf4\x29\xce\x06\xf6\x27\xd2\x06\x17\x26\xe7\x06\xa2\x29\xdb\x06\x47\x28\xdd\x06\x1d\x26\xaf\x06\x1e\x2a\x9a\x06\xb1\x28\xb4\x06\x97\x26\xc6\x06\xa5\x29\xc2\x06\x6f\x28\xc9\x06\x33\x26\xe4\x06\xb5\x29\xd5\x06\x57\x28\xcc\x06\x64\x26\xc8\x06\x73\x29\xc7\x06\x54\x28\xbf\x06\x27\x26\xdd\x06\x84\x29\xd1\x06\x83\x28\xd8\x06\x40\x26\xc2\x06\xf3\x29\xb4\x06\xbd\x28\xc2\x06\xb1\x26\xcd\x06\xb3\x29\xcc\x06\x27\x28\xcc\x06\x8d\x26\xb9\x06\xe4\x29\xb9\x06\x67\x28\xce\x06\xa6\x26\xe0\x06\x9d\x29\xcf\x06\x4e\x28\xcd\x06\x88\x26\xdf\x06\xcc\x29\xd5\x06\x6d\x28\xce\x06\xb9\x26\xd5\x06\x7b\x29\xcf\x06\x1f\x28\xcc\x06\x5c\x26\xcf\x06\x97\x29\xc7\x06\x0d\x28\xcb\x06\x7e\x26\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xd7\x06\xa2\x29\xc1\x06\x6f\x28\xcc\x06\xb1\x26\xd2\x06\x93\x29\xd7\x06\x76\x28\xda\x06\xa0\x26\xe3\x06\xff\x29\xdb\x06\x88\x28\xd5\x06\xa1\x26\xce\x06\xf6\x29\xd2\x06\x60\x28\xc9\x06\xdc\x26\xd4\x06\xaf\x29\xd1\x06\x3e\x28\xc7\x06\xa3\x26\xd8\x06\x26\x29\xd6\x06\x19\x28\xcf\x06\x36\x26\xcf\x06\xb5\x29\xc3\x06\x44\x28\xd6\x06\x9b\x26\xdc\x06\xca\x29\xd2\x06\x3c\x28\xca\x06\xa0\x26\xdb\x06\x81\x29\xcf\x06\x4c\x28\xd0\x06\x86\x26\xce\x06\x6b\x29\xcc\x06\x51\x28\xce\x06\x71\x26\xc0\x06\x61\x29\xb8\x06\x5e\x28\xce\x06\x74\x26\xe0\x06\x95\x29\xdd\x06\x6c\x28\xd0\x06\x80\x26\xc9\x06\x1a\x29\xbc\x06\x00\x28\xc4\x06\x29\x26\xca\x06\x06\x29\xc9\x06\xd0\x27\xcc\x06\x3e\x26\xd1\x06\x53\x29\xbd\x06\x24\x28\xd0\x06\x9c\x26\xd3\x06\x7c\x29\xd5\x06\x96\x28\xc8\x06\x90\x26\xd4\x06\x58\x29\xd5\x06\x61\x28\xc6\x06\x98\x26\xdb\x06\x7b\x29\xd3\x06\x3f\x28\xd0\x06\x81\x26\xd8\x06\x85\x29\xd2\x06\x6d\x28\xce\x06\x7e\x26\xc2\x06\x3b\x29\xb1\x06\x8e\x28\xca\x06\xdb\x25\xe6\x06\x0a\x29\xd0\x06\x37\x28\xdc\x06\xf4\x25\xe3\x06\x8a\x29\xe1\x06\x7f\x28\xdb\x06\x84\x26\xda\x06\xe5\x29\xdc\x06\x75\x28\xcc\x06\x44\x26\xcd\x06\x25\x2a\xc7\x06\x49\x28\xd1\x06\x43\x26\xdc\x06\xdc\x29\xc9\x06\x79\x28\xcb\x06\x72\x26\xdc\x06\xc9\x29\xd0\x06\x7e\x28\xcf\x06\x86\x26\xd1\x06\xcf\x29\xca\x06\x06\x28\xc4\x06\x49\x26\xd6\x06\x3c\x29\xcd\x06\xb6\x27\xc7\x06\xe3\x25\xc6\x06\xbb\x29\xbf\x06\x56\x28\xcc\x06\x73\x26\xc2\x06\x84\x29\xb2\x06\x36\x28\xc1\x06\x57\x26\xdc\x06\xa2\x29\xd9\x06\x34\x28\xcc\x06\x72\x26\xdc\x06\x26\x2a\xd0\x06\x53\x28\xd3\x06\x5a\x26\xca\x06\x1f\x2a\xbe\x06\x69\x28\xca\x06\x7e\x26\xcd\x06\x2f\x2a\xc0\x06\x83\x28\xd4\x06\x8b\x26\xd0\x06\x92\x29\xbc\x06\xdf\x27\xc8\x06\x1a\x26\xdb\x06\x0b\x2a\xc1\x06\x16\x28\xc0\x06\x69\x26\xdf\x06\x34\x2a\xcd\x06\x55\x28\xc7\x06\x72\x26\xe5\x06\x89\x2a\xd2\x06\x94\x28\xce\x06\x8e\x26\xc8\x06\xaa\x2a\xc4\x06\x5e\x28\xc8\x06\xc5\x26\xbf\x06\xe0\x2a\xbf\x06\x85\x28\xd0\x06\xe8\x26\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xbd\x06\x19\x2b\xa6\x06\x9d\x28\xca\x06\x82\x27\xcf\x06\x4a\x2a\xb8\x06\xe2\x27\xbb\x06\x63\x26\xc8\x06\x3c\x2b\xb1\x06\x55\x28\xa5\x06\x93\x26\xc9\x06\x6d\x2a\xb5\x06\x5e\x28\xca\x06\xc1\x26\xe6\x06\x53\x2a\xd1\x06\x49\x28\xc9\x06\xb0\x26\xbd\x06\x88\x2a\xb2\x06\x69\x28\xcd\x06\x76\x26\xd8\x06\x6a\x2a\xbf\x06\x45\x28\xcb\x06\xaa\x26\xcd\x06\x57\x2a\xcb\x06\x9a\x28\xcf\x06\x8b\x26\xde\x06\xf6\x29\xd4\x06\xfd\x27\xc6\x06\x90\x26\xc1\x06\x11\x2a\xbb\x06\x21\x28\xcd\x06\x93\x26\xca\x06\x8f\x29\xc2\x06\x96\x28\xd1\x06\xc5\x26\xc3\x06\x58\x29\xc3\x06\x5e\x28\xc6\x06\x82\x26\xe0\x06\x00\x2a\xd3\x06\x6e\x28\xca\x06\xb3\x25\x00\x00\xb9\x14\x00\x00\x5d\x15\x00\x00\x0a\x16\x00\x00\xb9\x14\x00\x00\x5d\x15\x00\x00\x0b\x16\x00\x00\xb9\x14\x00\x00\x5d\x15\x00\x00\x0d\x16\x00\x00\x99\x14\x00\x00\x4c\x15\x00\x00\xe9\x15\x00\x00\x99\x14\x00\x00\x4c\x15\x00\x00\xe9\x15\x00\x00\x99\x14\x00\x00\x4c\x15\x00\x00\xe9\x15\xf1\x06\x55\x2c\xe9\x06\x84\x2a\xdc\x06\x94\x27\xf9\x06\xd5\x2b\xf6\x06\xab\x2a\xec\x06\x35\x28\xf2\x06\xda\x2b\xf5\x06\xb7\x2a\xef\x06\xd2\x28\x00\x07\x19\x2c\xf6\x06\xf8\x2a\xf1\x06\x07\x29\xf5\x06\x09\x2c\xeb\x06\x35\x2a\xdf\x06\x63\x28\xf7\x06\x5d\x2c\xec\x06\x69\x2a\xe2\x06\x20\x28\xf6\x06\x0c\x2c\xf3\x06\x99\x2a\xe6\x06\x88\x28\xf5\x06\x66\x2c\xe7\x06\xc8\x2a\xdf\x06\x91\x28\x07\x07\xff\x2c\xf2\x06\xb1\x2a\xee\x06\x7f\x28\x01\x07\xd5\x2c\xf6\x06\x9b\x2a\xfc\x06\xf5\x28\x02\x07\xba\x2c\xf2\x06\x99\x2a\xf5\x06\xd6\x28\x03\x07\xe8\x2c\xf1\x06\x2f\x2a\xf3\x06\xa9\x28\x01\x07\xac\x2c\xf4\x06\x31\x2a\xea\x06\xea\x28\xfc\x06\x19\x2d\xf2\x06\xa4\x2a\xf3\x06\x86\x29\x05\x07\x23\x2d\xf5\x06\x89\x2a\xf6\x06\xe2\x28\x01\x07\x10\x2d\xf0\x06\x81\x2a\xf1\x06\x88\x29\x03\x07\xd1\x2c\x00\x07\x49\x2b\xef\x06\xc5\x28\xfd\x06\x7f\x2c\xf4\x06\xd9\x2a\xe2\x06\xb8\x28\xfa\x06\x3a\x2c\xf1\x06\x39\x2a\xe3\x06\x63\x28\xfe\x06\xbc\x2b\xe8\x06\x03\x2a\xe3\x06\xf9\x27\xed\x06\x14\x2d\xd7\x06\xf4\x2a\xe3\x06\x8d\x28\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\x06\x1e\x2c\x00\x07\xc4\x2a\xeb\x06\x97\x28\x05\x07\xf4\x2b\xf7\x06\x79\x2a\xf4\x06\x50\x28\x02\x07\x86\x2b\xf3\x06\x4f\x2a\xf2\x06\xb1\x28\xea\x06\xa8\x2b\xe4\x06\x6f\x2a\xe8\x06\xab\x28\xf5\x06\x5c\x2b\xf1\x06\xec\x29\xe0\x06\x43\x28\xf8\x06\xbc\x2a\xe9\x06\xfb\x29\xe5\x06\xf6\x27\xeb\x06\x92\x2b\xe4\x06\x30\x2a\xe1\x06\xf6\x27\xf8\x06\x4c\x2b\xec\x06\x89\x2a\xe7\x06\x95\x28\x01\x07\x81\x2b\xf8\x06\x3c\x2a\xe8\x06\x5c\x28\xf7\x06\x92\x2b\xed\x06\x57\x2a\xe4\x06\xa0\x28\xfe\x06\xed\x2b\xf1\x06\xc5\x2a\xe5\x06\x5c\x28\xec\x06\x39\x2b\xea\x06\x69\x2a\xf0\x06\x33\x28\xf1\x06\x08\x2b\xde\x06\xfb\x29\xdf\x06\xdc\x27\xfc\x06\x55\x2b\xe0\x06\xf8\x29\xe0\x06\xd6\x27\xeb\x06\x29\x2b\xe1\x06\x7d\x2a\xe7\x06\x64\x28\xfc\x06\x04\x2b\xfa\x06\x49\x2a\xf2\x06\x63\x28\xf8\x06\x09\x2b\xef\x06\x6f\x2a\xef\x06\xa2\x28\x02\x07\x28\x2b\xfd\x06\x5c\x2a\xef\x06\x30\x28\xf9\x06\x34\x2b\xee\x06\x47\x2a\xdd\x06\x9b\x28\xf2\x06\xfc\x2a\xf6\x06\xfa\x29\xe7\x06\xde\x27\xf9\x06\x8a\x2b\xf2\x06\xf8\x29\xea\x06\x2b\x28\x01\x07\x62\x2b\xf8\x06\x70\x2a\xf0\x06\x2c\x28\xfb\x06\x62\x2b\xe6\x06\x89\x2a\xe4\x06\x1d\x28\xe2\x06\x5c\x2b\xd6\x06\x44\x2a\xe4\x06\x5c\x28\xfb\x06\xc7\x2b\xed\x06\x2b\x2a\xea\x06\x67\x28\xf1\x06\x3e\x2b\xe5\x06\xf8\x29\xe3\x06\x3c\x28\x03\x07\xec\x2a\xfd\x06\xc3\x29\xe4\x06\xcc\x27\xec\x06\xe7\x2a\xec\x06\x5a\x29\xe2\x06\x6c\x27\xfe\x06\xbe\x2b\xe2\x06\x39\x2a\xd9\x06\xcd\x27\xf5\x06\x7c\x2b\xec\x06\x00\x2a\xe1\x06\xf5\x27\xfd\x06\x31\x2b\xf5\x06\xfc\x29\xed\x06\xf0\x27\xfb\x06\x82\x2b\xf7\x06\x10\x2a\xf2\x06\xec\x27\xf4\x06\xd0\x2b\xf9\x06\x0b\x2a\xe4\x06\x1d\x28\xf3\x06\x85\x2b\xed\x06\x3b\x2a\xe1\x06\x0c\x28\xf8\x06\x1d\x2b\xf2\x06\xfc\x29\xe9\x06\x7e\x27\xef\x06\x53\x2b\xe6\x06\x20\x2a\xea\x06\x21\x28\xfa\x06\x72\x2b\xeb\x06\x1d\x2a\xe6\x06\xfc\x27\xf7\x06\x6a\x2b\xed\x06\xfa\x29\xf5\x06\xc8\x28\x01\x07\xac\x2b\xef\x06\x19\x2a\xf6\x06\x3e\x28\x04\x07\x34\x2b\xea\x06\xca\x29\xe9\x06\x1d\x28\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xee\x06\x1f\x2b\xe4\x06\xea\x29\xdd\x06\x26\x28\xeb\x06\x98\x2a\xe6\x06\x72\x29\xe3\x06\xb5\x27\xf5\x06\x70\x2a\xea\x06\x9c\x29\xeb\x06\xb3\x27\xe8\x06\xe1\x2a\xec\x06\x60\x2a\xf0\x06\x1a\x28\xf0\x06\xaa\x2b\xe5\x06\x28\x2a\xe5\x06\x0e\x28\xf0\x06\x27\x2b\xf8\x06\xd8\x29\xe6\x06\xc7\x27\xf9\x06\x62\x2b\xea\x06\xb4\x29\xe4\x06\x30\x28\xfb\x06\x1d\x2b\xf1\x06\xef\x29\xef\x06\x0f\x28\xf1\x06\xbc\x2a\xe7\x06\x0d\x2a\xdb\x06\x82\x27\xff\x06\x05\x2b\xed\x06\xac\x29\xe3\x06\xa7\x27\xff\x06\x4b\x2b\xf9\x06\xda\x29\xf3\x06\x21\x28\xfd\x06\x3e\x2b\xf2\x06\x21\x2a\xe7\x06\x1a\x28\xf6\x06\x99\x2b\xf5\x06\x50\x2a\xe7\x06\x7f\x28\x00\x07\x87\x2b\xee\x06\x03\x2a\xed\x06\x15\x28\xef\x06\xbb\x2b\xe5\x06\x2b\x2a\xce\x06\x67\x28\xf6\x06\x0c\x2b\xf2\x06\xae\x29\xe5\x06\xae\x27\xf7\x06\xdb\x2a\xeb\x06\xc2\x29\xed\x06\xa8\x27\xfc\x06\x5d\x2b\xf9\x06\x67\x2a\xeb\x06\x2b\x28\xf3\x06\xa2\x2b\xec\x06\x4c\x2a\xe1\x06\x86\x28\xfd\x06\xa6\x2b\xfc\x06\x11\x2a\xf7\x06\x7d\x28\x0a\x07\x62\x2b\xfb\x06\x7c\x2a\xf4\x06\x84\x28\xfe\x06\x7e\x2b\xef\x06\x35\x2a\xe9\x06\x5d\x28\xf0\x06\xb3\x2b\xdc\x06\x10\x2a\xe8\x06\x47\x28\x08\x07\xb6\x2b\xfe\x06\xf6\x29\xed\x06\x38\x28\xf7\x06\xd2\x2b\xee\x06\x1d\x2a\xf0\x06\xc9\x28\x02\x07\xbb\x2b\xeb\x06\xe0\x29\xee\x06\x5f\x28\x0b\x07\x7e\x2b\xff\x06\x58\x2a\xf5\x06\x77\x28\x04\x07\x6b\x2b\x00\x07\x3c\x2a\xee\x06\x26\x28\x06\x07\x9c\x2b\xf3\x06\x40\x2a\xe3\x06\x70\x28\xff\x06\x12\x2b\xf4\x06\xe8\x29\xf5\x06\x82\x28\xec\x06\xe7\x2a\xeb\x06\x5c\x29\xef\x06\x29\x28\x0a\x07\x3d\x2b\x01\x07\x88\x29\xf5\x06\xe7\x27\xfc\x06\xa5\x2b\xf6\x06\xcf\x29\xe9\x06\x3e\x28\x01\x07\x66\x2b\x00\x07\xd8\x29\xf0\x06\xed\x27\x06\x07\x94\x2b\xe7\x06\x96\x29\xe2\x06\x56\x28\xed\x06\x99\x2b\xe9\x06\x5d\x2a\xe7\x06\x93\x28\xfd\x06\x45\x2b\xe7\x06\xd4\x29\xde\x06\x26\x28\xf9\x06\xcd\x2a\xf5\x06\x8c\x29\xe5\x06\xff\x27\xf4\x06\xde\x2a\xee\x06\xbb\x29\xf0\x06\xcb\x27\x04\x07\x55\x2b\xf1\x06\x81\x2a\xe9\x06\x11\x28\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xf9\x06\x82\x2b\xf6\x06\x0f\x2a\xdb\x06\x07\x28\xff\x06\x47\x2b\xf7\x06\xc4\x29\xfb\x06\x04\x29\xfa\x06\xf0\x2a\xf0\x06\x5b\x29\xed\x06\x07\x28\x03\x07\xb3\x2b\xe7\x06\x73\x29\xe5\x06\xf2\x27\xf4\x06\xc2\x2a\xec\x06\x1b\x29\xef\x06\x64\x27\xfd\x06\xa0\x2a\xf7\x06\x4e\x29\xe9\x06\x9b\x27\xf1\x06\x08\x2b\xec\x06\xa8\x29\xec\x06\xbe\x27\xf8\x06\xff\x2a\xf6\x06\xa4\x29\xeb\x06\xec\x27\x00\x07\x0e\x2b\xf4\x06\xce\x29\xee\x06\x56\x28\x03\x07\x51\x2b\xfd\x06\x09\x2a\xf3\x06\xf6\x27\xed\x06\x28\x2b\xe3\x06\xa6\x29\xe7\x06\x16\x28\xf8\x06\x8e\x2a\xf4\x06\x9c\x29\xe6\x06\x90\x27\xf4\x06\x7d\x2a\xf3\x06\x9f\x29\xe2\x06\x97\x27\xec\x06\x29\x2b\xec\x06\xb2\x29\xe7\x06\xe9\x27\xf8\x06\x1f\x2b\xec\x06\xb3\x29\xf1\x06\x0c\x28\x00\x07\xda\x2a\xf8\x06\xd4\x29\xf6\x06\x4b\x28\x07\x07\x9c\x2a\x05\x07\x07\x2a\x01\x07\x1e\x28\xff\x06\x0b\x2b\xfc\x06\xda\x29\xe7\x06\xf1\x27\xea\x06\x64\x2a\xe0\x06\x37\x29\xdf\x06\x9d\x27\xfd\x06\x93\x2a\xf1\x06\x0a\x29\xeb\x06\x5d\x27\xf6\x06\x26\x2b\xf8\x06\x3f\x2a\xee\x06\x16\x28\xf7\x06\xd1\x2a\xf5\x06\xd8\x29\xf1\x06\x29\x28\xfe\x06\x57\x2b\xfd\x06\x74\x2a\xe8\x06\x29\x28\x0c\x07\x3d\x2b\xf0\x06\xd7\x29\xf3\x06\x73\x28\xf5\x06\xce\x2a\xe9\x06\x10\x2a\xe8\x06\x0e\x28\xfa\x06\x8f\x2a\xf1\x06\xde\x29\xea\x06\x7f\x27\xe4\x06\x13\x2a\xe8\x06\x48\x29\xeb\x06\x59\x27\xf7\x06\x26\x2b\xed\x06\x0c\x2a\xe6\x06\x8d\x27\xfd\x06\x2d\x2b\xf9\x06\x69\x2a\xe8\x06\xf8\x27\xdc\x06\x08\x2b\xd6\x06\xdb\x29\xdf\x06\xee\x27\xf4\x06\x09\x2b\xf2\x06\x11\x2a\xed\x06\xe1\x27\xfd\x06\xf9\x2a\xee\x06\xc2\x29\xdf\x06\x1e\x28\xfb\x06\xc4\x2a\xf9\x06\x88\x29\xef\x06\xf1\x27\xf1\x06\xda\x2a\xf2\x06\xf9\x28\xe2\x06\x6e\x27\xfb\x06\x34\x2b\xf6\x06\x25\x29\xe6\x06\x91\x27\x03\x07\x96\x2b\xef\x06\x7f\x29\xed\x06\x26\x28\xf3\x06\x53\x2b\xe8\x06\x2b\x29\xe5\x06\x8a\x27\x00\x07\x11\x2b\xf0\x06\x23\x29\xe3\x06\x61\x27\xf3\x06\x1d\x2b\xf4\x06\x2c\x29\xf1\x06\xb3\x27\xfd\x06\x44\x2a\xec\x06\x0a\x29\xe1\x06\x7e\x27\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xf4\x06\xd3\x29\xe8\x06\x96\x28\xe1\x06\x03\x27\xfb\x06\x29\x2a\xeb\x06\xb7\x28\xf1\x06\x12\x27\x02\x07\xd5\x2a\xf2\x06\x1a\x29\xe9\x06\xb5\x27\xfe\x06\xde\x2a\xf4\x06\x58\x29\xed\x06\xda\x27\xf7\x06\x35\x2b\xee\x06\xaf\x29\xef\x06\xba\x27\x0c\x07\x28\x2b\xf6\x06\x72\x29\x02\x07\x98\x28\xf9\x06\x6c\x2b\xf0\x06\x7f\x29\xf0\x06\x06\x28\x01\x07\xf3\x2a\xf6\x06\x2c\x29\xf6\x06\x64\x27\x04\x07\xab\x2a\xf4\x06\x66\x29\xeb\x06\x6e\x27\xf6\x06\x1f\x2b\xef\x06\xee\x29\xea\x06\x11\x28\x11\x07\xbc\x2b\x0a\x07\xc0\x29\xf8\x06\x45\x28\x03\x07\x26\x2c\xfc\x06\xc2\x29\xf2\x06\xba\x27\x00\x07\xbe\x2b\xfb\x06\x4c\x29\xed\x06\xdc\x27\xff\x06\x7d\x2b\xf7\x06\x87\x29\xdb\x06\xa3\x27\xee\x06\xad\x2a\xe1\x06\x3a\x29\xf2\x06\x17\x27\xf4\x06\x5b\x2a\xe8\x06\x48\x29\xd9\x06\x3e\x27\xfe\x06\xc0\x2a\xf0\x06\xa0\x29\xee\x06\xb1\x27\xf7\x06\x3b\x2a\xf4\x06\xd2\x29\xe7\x06\x13\x28\xf6\x06\x90\x2a\xfd\x06\xab\x29\xf4\x06\xb6\x27\x02\x07\x04\x2b\xf3\x06\xa0\x29\xf2\x06\xa2\x27\x01\x07\x35\x2b\xf0\x06\x93\x29\xfa\x06\xee\x27\xeb\x06\xf7\x2a\xd9\x06\x23\x29\xd4\x06\xc9\x27\xf6\x06\x86\x2a\xef\x06\xfb\x28\xe7\x06\x3b\x27\x01\x07\xbd\x2a\xec\x06\x5f\x29\xe7\x06\x91\x27\xff\x06\xda\x2a\xf3\x06\x90\x29\xfc\x06\xdc\x27\xf5\x06\xd5\x2a\xde\x06\x78\x29\xe8\x06\x2d\x28\x0b\x07\x94\x2a\x00\x07\x70\x29\xfa\x06\xbd\x27\x04\x07\x5d\x2a\xf2\x06\x8a\x29\xf0\x06\xae\x27\x02\x07\x8c\x2a\xfd\x06\x40\x29\xf4\x06\xa7\x27\xef\x06\xc0\x29\xf1\x06\xdd\x28\xe2\x06\x1a\x27\xfd\x06\x7c\x2a\xf6\x06\x5f\x29\xee\x06\x67\x27\x10\x07\x4d\x2b\x00\x07\x6a\x29\xef\x06\x86\x27\xfa\x06\xb8\x2a\xf9\x06\xa4\x29\xf0\x06\x73\x27\xf7\x06\xb2\x2a\xfa\x06\xa6\x29\xeb\x06\x6b\x27\x01\x07\x5e\x2a\xfa\x06\x62\x29\xfc\x06\x85\x27\xf8\x06\xf9\x29\x01\x07\xc8\x29\xe3\x06\x3a\x27\xf3\x06\x11\x2a\xec\x06\x06\x29\xf3\x06\xf9\x26\xf6\x06\x72\x2a\xf4\x06\x6e\x29\xf2\x06\x46\x27\xf6\x06\x54\x2a\xf4\x06\xe4\x29\xec\x06\x00\x28\xec\x06\x65\x2a\xe6\x06\xb4\x29\xe3\x06\x47\x27\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfb\x06\x4a\x2a\xfa\x06\xfa\x29\xf0\x06\x93\x27\xf4\x06\x38\x2a\xfa\x06\xc4\x29\xf9\x06\x99\x27\xfc\x06\x13\x2a\xfb\x06\xb6\x29\xed\x06\xa2\x27\xfd\x06\x0c\x2a\xf6\x06\x16\x29\xec\x06\x67\x27\xf6\x06\xc5\x29\xf9\x06\x32\x29\xed\x06\x3a\x27\xf5\x06\x0b\x2a\xf2\x06\x8e\x29\xf5\x06\xe3\x27\xfa\x06\x5a\x2a\xea\x06\xd7\x29\xee\x06\x67\x27\xed\x06\x83\x2a\xdb\x06\xac\x29\xec\x06\x89\x27\xef\x06\x6c\x2a\xeb\x06\x9e\x29\xea\x06\x15\x28\xf3\x06\x75\x2a\xf2\x06\xc4\x29\xf0\x06\xe7\x27\x09\x07\x1b\x2a\xfe\x06\xa0\x29\xec\x06\x6c\x27\xfd\x06\xda\x29\xfa\x06\xcd\x28\xf2\x06\x0a\x27\xf3\x06\x6e\x2a\xf1\x06\x81\x29\xeb\x06\x82\x27\x07\x07\xc2\x2a\xfe\x06\xbd\x29\xf5\x06\x11\x28\xf6\x06\x5b\x2b\xde\x06\x3c\x29\xf0\x06\xcb\x27\x02\x07\x8b\x2b\xf5\x06\x6f\x29\xe6\x06\x0a\x28\x00\x07\x67\x2b\xe8\x06\x01\x29\xf1\x06\x37\x28\x02\x07\xee\x2a\xfd\x06\x67\x29\xf0\x06\xb3\x27\xf5\x06\x1f\x2a\xea\x06\x04\x29\xf4\x06\x2c\x27\x06\x07\xac\x2a\xfd\x06\x3e\x29\xec\x06\x77\x27\xff\x06\xdf\x2a\xf3\x06\x6c\x29\xed\x06\xaf\x27\xf8\x06\xb4\x2a\xf2\x06\x8f\x29\xed\x06\xee\x27\x02\x07\xc2\x2a\xfe\x06\x40\x29\x00\x07\xc4\x27\xfe\x06\x33\x2a\xfa\x06\xab\x29\xec\x06\x9d\x27\xfb\x06\x0c\x2a\xf1\x06\x1c\x29\xf2\x06\x77\x27\x06\x07\xc5\x29\xfe\x06\xc6\x28\xf3\x06\x08\x27\x01\x07\x04\x2a\x07\x07\x40\x29\xfb\x06\x43\x27\x09\x07\x68\x2a\xf7\x06\x5f\x29\xf6\x06\xb2\x27\x08\x07\x48\x2a\xfd\x06\x88\x29\xf3\x06\x7d\x27\xff\x06\x41\x2a\xfb\x06\x6f\x29\xe6\x06\x72\x27\x00\x07\x9b\x2a\xf8\x06\x79\x29\xfc\x06\xc0\x27\x0f\x07\xa5\x2a\x05\x07\xc2\x29\xfe\x06\xea\x27\x11\x07\x32\x2a\x0b\x07\x6f\x29\xf5\x06\x5d\x27\x05\x07\x4f\x2a\xfe\x06\xd6\x29\xf0\x06\xb3\x27\x0a\x07\xb5\x2a\xfc\x06\xd9\x29\xef\x06\xf6\x27\x02\x07\xe7\x2a\xf3\x06\xc4\x29\x00\x07\xc1\x27\x00\x07\x05\x2b\xf7\x06\xb0\x29\xf1\x06\xbd\x27\x02\x07\xb0\x2a\xf3\x06\x93\x29\xe9\x06\x54\x27\x08\x07\x89\x2a\x02\x07\xb9\x29\xf3\x06\x4a\x27\xfb\x06\x8c\x2a\xe5\x06\x00\x29\xeb\x06\x2a\x27\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe0\x06\x79\x2a\xc9\x06\x7f\x29\xf7\x06\x30\x27\xf9\x06\x57\x2a\xf5\x06\xb3\x29\xe8\x06\x4e\x27\xf6\x06\x67\x2a\xec\x06\xab\x29\xe9\x06\x54\x27\x05\x07\x1e\x2a\xf4\x06\xa4\x29\xf2\x06\x98\x27\xee\x06\x38\x2a\xef\x06\x34\x29\xee\x06\x90\x27\xf9\x06\xa8\x2a\xf6\x06\x90\x29\xea\x06\x72\x27\xf9\x06\x42\x2a\xef\x06\x27\x29\xd9\x06\xdc\x26\xfe\x06\x32\x2a\xee\x06\xfc\x28\xdf\x06\xba\x26\xfa\x06\x8f\x2a\xeb\x06\x9b\x29\xf3\x06\x83\x27\x09\x07\x77\x2a\xf9\x06\x9c\x29\xf1\x06\x64\x27\xf9\x06\x13\x2a\xe3\x06\x83\x29\xe6\x06\x4d\x27\xeb\x06\x41\x2a\xf2\x06\x95\x29\xf3\x06\x52\x27\xf6\x06\x13\x2a\xf7\x06\x83\x29\xe7\x06\x52\x27\xea\x06\xa8\x29\xe0\x06\x00\x29\xcf\x06\x00\x27\xdb\x06\x08\x2a\xcb\x06\xe5\x28\xe0\x06\xd0\x26\xef\x06\xf9\x29\xe8\x06\xea\x28\xe1\x06\x33\x27\xf3\x06\x24\x2a\xec\x06\x79\x29\xdf\x06\x46\x27\xf6\x06\x32\x2a\xf3\x06\x5c\x29\xe6\x06\x46\x27\xf9\x06\x11\x2a\xf7\x06\x34\x29\xe3\x06\x2a\x27\xec\x06\x07\x2a\xe7\x06\x18\x29\xe9\x06\x0c\x27\xf8\x06\xd0\x29\xee\x06\xf8\x28\xe4\x06\x25\x27\x01\x07\x65\x29\xf5\x06\xa9\x28\xe8\x06\xc0\x26\xf1\x06\xdd\x29\xf4\x06\xb9\x29\xe1\x06\xed\x26\xf8\x06\xec\x29\xef\x06\x34\x29\xf2\x06\x46\x27\xf0\x06\xff\x29\xf1\x06\x11\x29\xe9\x06\xf5\x26\xf4\x06\x4f\x2a\xea\x06\x31\x29\xf9\x06\x2c\x27\xf1\x06\xed\x29\xed\x06\x3b\x29\xef\x06\x40\x27\xf5\x06\xc8\x29\xf1\x06\xea\x28\xee\x06\xf6\x26\xcc\x06\x43\x29\xbf\x06\x7a\x28\xe2\x06\x78\x26\xf2\x06\xae\x29\xed\x06\xcc\x28\xde\x06\x9c\x26\xef\x06\xfe\x29\xec\x06\x4d\x29\xe1\x06\xd7\x26\xf6\x06\xb7\x29\xeb\x06\x30\x29\xe1\x06\x0c\x27\xf1\x06\x91\x29\xfd\x06\x11\x29\xe0\x06\x12\x27\xf5\x06\xbf\x29\xf5\x06\xae\x28\xf1\x06\xd7\x26\xf8\x06\xd8\x29\xe9\x06\xaa\x28\xe8\x06\xc5\x26\xd6\x06\x5d\x29\xd1\x06\x71\x28\xef\x06\x4f\x26\xd4\x06\x35\x29\xd8\x06\x52\x28\xdb\x06\x33\x26\xe9\x06\x8e\x29\xdc\x06\xe0\x28\xea\x06\xcb\x26\xf1\x06\xe6\x29\xfe\x06\x0c\x29\xf6\x06\xe7\x26\x0a\x07\xa3\x29\xfd\x06\x1a\x29\xe6\x06\xf4\x26\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xde\x06\xe0\x29\xcc\x06\x1c\x29\xe1\x06\x04\x27\x02\x07\xba\x29\xe8\x06\x2d\x29\xeb\x06\x0c\x27\xed\x06\x2c\x29\xeb\x06\xae\x28\xd9\x06\x83\x26\xeb\x06\x49\x29\xe9\x06\x65\x28\xeb\x06\x7e\x26\xf9\x06\xa2\x29\xed\x06\xdd\x28\xd5\x06\xe6\x26\xee\x06\xa8\x29\xe3\x06\xfe\x28\xd7\x06\x05\x27\xf7\x06\xe0\x29\xe4\x06\xc6\x28\xe7\x06\x09\x27\xda\x06\x2f\x2a\xcc\x06\x22\x29\xea\x06\x02\x27\x01\x07\x0e\x2a\xf4\x06\x61\x29\xe6\x06\x05\x27\xf9\x06\x7d\x29\xf3\x06\xa9\x28\xed\x06\xc4\x26\xf7\x06\x40\x29\xf7\x06\x86\x28\xeb\x06\xb6\x26\xe5\x06\xd2\x29\xf0\x06\x60\x29\xdf\x06\x00\x27\x0c\x07\xe9\x29\x04\x07\x38\x29\xf1\x06\x20\x27\xf6\x06\xfd\x29\xeb\x06\x15\x29\xe2\x06\x20\x27\xef\x06\xef\x29\xf4\x06\x2d\x29\xf0\x06\x53\x27\x02\x07\xf6\x29\xfc\x06\x6f\x29\xe7\x06\x21\x27\xf5\x06\xfc\x29\xf5\x06\x37\x29\xea\x06\x66\x27\x0a\x07\x9c\x29\xf7\x06\xd9\x28\xf1\x06\xd3\x26\xee\x06\xd2\x29\xdf\x06\x2d\x29\xe0\x06\x63\x27\x03\x07\x77\x2a\x06\x07\xfe\x29\xe7\x06\x77\x27\xe8\x06\x9a\x29\xea\x06\xa5\x29\xda\x06\x3c\x27\xef\x06\xf9\x29\xe9\x06\x65\x29\xe4\x06\x8d\x27\xfe\x06\xff\x29\xec\x06\xe9\x28\xe9\x06\x72\x27\xef\x06\xe7\x29\xed\x06\xfc\x28\xf3\x06\x51\x27\xf0\x06\x9a\x29\xe9\x06\x52\x28\xe5\x06\xcb\x26\xfd\x06\xd6\x29\xee\x06\x95\x28\xf7\x06\x55\x27\xeb\x06\x07\x2a\xe9\x06\x40\x29\xdc\x06\x51\x27\x00\x07\x3b\x2a\xfc\x06\x10\x29\xed\x06\x6b\x27\xf0\x06\x22\x2a\x03\x07\x2d\x29\xe3\x06\x21\x27\xf4\x06\x2b\x2a\xe8\x06\x5f\x29\xe0\x06\x1e\x27\xfe\x06\x4c\x2a\xf0\x06\xf0\x28\xfd\x06\x50\x27\xf3\x06\xb3\x29\xe9\x06\x7d\x28\xea\x06\xfa\x26\xf7\x06\xfc\x29\xe6\x06\xbe\x28\xe1\x06\xe9\x26\xeb\x06\x6e\x2a\xe1\x06\xf2\x28\xe2\x06\x79\x27\x0b\x07\x75\x2a\x01\x07\x12\x29\xf2\x06\x91\x27\xdc\x06\x34\x2a\xe3\x06\x3c\x29\xe4\x06\x62\x27\x09\x07\x96\x2a\xf4\x06\x5f\x29\xfa\x06\xa4\x27\x02\x07\x53\x2a\xf7\x06\x51\x29\xe6\x06\xab\x27\xf4\x06\x93\x2a\xe1\x06\x06\x29\x23\x07\x73\x27\xfb\x06\x80\x2a\xf7\x06\x08\x29\xf2\x06\x39\x27\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x06\x07\xa4\x2a\xf9\x06\x6c\x29\xf6\x06\xcc\x27\xe7\x06\xa8\x2a\xe3\x06\xc0\x29\xec\x06\x85\x27\xf4\x06\x7d\x2a\xf0\x06\xac\x29\xed\x06\xb1\x27\xf4\x06\x9c\x2a\xfb\x06\x59\x29\xfd\x06\x9d\x27\xfd\x06\xd2\x2a\xe9\x06\xbd\x29\x01\x07\xee\x27\x08\x07\x7f\x2a\xfa\x06\xef\x29\xf2\x06\xd2\x27\xfd\x06\x8d\x2a\xea\x06\x49\x29\xed\x06\x73\x27\xfe\x06\xc0\x2a\xf2\x06\x43\x2a\xea\x06\xf4\x27\xfe\x06\xfe\x2a\x03\x07\x0e\x2a\xf5\x06\x12\x28\x0b\x07\xb7\x2a\xf5\x06\xb7\x29\xf4\x06\x24\x28\xf5\x06\x05\x2b\xf6\x06\xdc\x29\xf3\x06\x1e\x28\xf5\x06\xf0\x2a\xf0\x06\xa8\x29\xe9\x06\x14\x28\xfa\x06\xbe\x2a\xf5\x06\x8f\x29\xea\x06\xcc\x27\x0c\x07\xd4\x2a\xf3\x06\x7c\x29\xf3\x06\xb8\x27\x01\x07\x04\x2b\xf7\x06\x06\x2a\xf0\x06\x30\x28\x06\x07\x36\x2b\xf5\x06\xc7\x29\xf0\x06\x1f\x28\xfb\x06\xf3\x2a\xec\x06\xc7\x29\xfc\x06\x06\x28\x03\x07\x29\x2b\xfa\x06\xdd\x29\xec\x06\xe7\x27\x06\x07\x5f\x2b\xfb\x06\xb7\x29\xf2\x06\x03\x28\x1a\x07\x4b\x2b\x07\x07\xc1\x29\xfd\x06\x35\x28\xfd\x06\x08\x2b\xf2\x06\x6d\x29\xf0\x06\x06\x28\x06\x07\x56\x2b\xfa\x06\xb1\x29\xee\x06\x26\x28\x00\x07\x39\x2b\xfe\x06\x1a\x2a\xed\x06\x3e\x28\xec\x06\x3a\x2b\xe8\x06\xd8\x29\xe0\x06\x5d\x28\x0a\x07\x4d\x2b\x02\x07\xc0\x29\xfa\x06\x27\x28\x14\x07\x89\x2b\xfb\x06\x98\x29\xfb\x06\x18\x28\x0f\x07\x3a\x2b\x08\x07\xdf\x29\xf7\x06\x07\x28\x23\x07\xf4\x2a\x10\x07\x3f\x29\x14\x07\xfa\x27\x35\x07\xeb\x2a\x28\x07\x2d\x29\x25\x07\xda\x27\x1b\x07\x84\x2a\x0a\x07\x39\x29\x08\x07\x82\x27\xcd\x06\xf1\x29\xbc\x06\xda\x28\xad\x06\xfd\x26\x8b\x06\x11\x2a\x74\x06\x85\x28\x6f\x06\xb3\x25\x6d\x06\x8c\x29\x56\x06\x81\x27\x51\x06\xb8\x24\xa8\x06\xf7\x28\x9e\x06\xad\x27\x9b\x06\xef\x25\x03\x07\xf8\x29\xea\x06\x2e\x28\x04\x07\xc6\x26\x16\x07\x12\x2a\x0c\x07\x91\x28\x0c\x07\x3b\x27\x09\x07\x6e\x2a\x06\x07\xfa\x28\x0b\x07\xd9\x27\x0c\x07\x79\x2a\x03\x07\xe1\x28\xfe\x06\x98\x27\x04\x07\x54\x2a\xf5\x06\xb9\x28\x02\x07\x64\x27\xea\x06\x66\x2a\xe7\x06\xa9\x28\xe6\x06\x4c\x27\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xf3\x06\x68\x2a\xea\x06\x88\x28\xe4\x06\x22\x27\xf4\x06\x56\x2a\xed\x06\xa9\x28\xf4\x06\x63\x27\xea\x06\x7a\x2a\xdf\x06\x95\x28\xe4\x06\x49\x27\xfc\x06\x53\x2a\xe7\x06\xe8\x28\xdd\x06\x6e\x27\xfc\x06\x96\x2a\xe8\x06\xae\x28\xea\x06\x55\x27\xf7\x06\x63\x2a\xec\x06\xa1\x28\xe9\x06\x6c\x27\xf4\x06\x10\x2a\xea\x06\x79\x28\xea\x06\x63\x27\xe5\x06\xe9\x29\xed\x06\xd4\x28\xd7\x06\x17\x27\xea\x06\xd8\x29\xdf\x06\x96\x28\xf2\x06\x3f\x27\xe7\x06\x07\x2a\xdc\x06\x82\x28\xd5\x06\x34\x27\xf8\x06\xb8\x29\xee\x06\xe0\x28\xee\x06\x3c\x27\xfb\x06\xfe\x29\xfc\x06\x4a\x28\xeb\x06\xdf\x26\xf1\x06\x7d\x29\xea\x06\x56\x28\xe8\x06\xfd\x26\xdc\x06\x88\x29\xdd\x06\x75\x28\xf0\x06\x02\x27\xfb\x06\xa4\x29\xf1\x06\x7e\x28\xec\x06\xe7\x26\xe8\x06\xc5\x29\xe4\x06\x81\x28\xdb\x06\xe9\x26\xec\x06\xab\x29\xe1\x06\x13\x28\xed\x06\x02\x27\xe8\x06\xa2\x29\xea\x06\x66\x28\xe5\x06\x11\x27\xde\x06\xc1\x29\xda\x06\xbd\x28\xdf\x06\x10\x27\xe8\x06\x35\x29\xe3\x06\x54\x28\xe3\x06\xae\x26\xf3\x06\x42\x29\xeb\x06\x15\x28\xe7\x06\xfe\x26\xdf\x06\x23\x29\xe5\x06\x17\x28\xda\x06\xb9\x26\xea\x06\x46\x29\xdf\x06\x2b\x28\xef\x06\xbf\x26\xef\x06\x32\x29\xec\x06\x21\x28\xf0\x06\xde\x26\xd9\x06\x4d\x29\xe0\x06\x76\x28\xe5\x06\xf2\x26\xef\x06\xa9\x29\xee\x06\xca\x28\xe4\x06\x0c\x27\xe5\x06\xdd\x29\xd8\x06\x8a\x28\xeb\x06\x16\x27\xf1\x06\x5a\x29\xe3\x06\x6d\x28\xdd\x06\xbc\x26\xef\x06\x32\x29\xe7\x06\x0e\x28\xe2\x06\xa5\x26\xec\x06\x18\x29\xdd\x06\xdf\x27\xea\x06\x7d\x26\xdd\x06\xb8\x28\xd6\x06\xfb\x27\xda\x06\x57\x26\xdd\x06\xa5\x28\xd1\x06\xca\x27\xde\x06\x6e\x26\xee\x06\xb1\x28\xe8\x06\x7f\x27\xe4\x06\x65\x26\xd5\x06\xc3\x28\xe4\x06\x56\x27\xd9\x06\x2c\x26\xea\x06\x87\x28\xea\x06\xa9\x27\xe4\x06\x43\x26\xf6\x06\xa2\x28\xeb\x06\xb7\x27\xe9\x06\x41\x26\xef\x06\x88\x28\xf2\x06\x9d\x27\xe3\x06\x10\x26\xf4\x06\x1d\x29\xf5\x06\xcb\x27\xef\x06\x38\x26\xea\x06\xa8\x28\xe2\x06\xc2\x27\xf9\x06\x46\x26\xf4\x06\xb5\x28\xeb\x06\xb2\x27\xe8\x06\x3f\x26\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe8\x06\x02\x29\xd6\x06\x7e\x27\xda\x06\x44\x26\xee\x06\xcb\x28\xde\x06\x91\x27\xe6\x06\x63\x26\xed\x06\xe1\x28\xe1\x06\xab\x27\xd5\x06\x3f\x26\xf1\x06\xb5\x28\xf3\x06\xa1\x27\xeb\x06\x39\x26\xe9\x06\xa8\x28\xe1\x06\xb3\x27\xe3\x06\x3a\x26\xdb\x06\xdb\x28\xcf\x06\xd9\x27\xda\x06\x5a\x26\xe2\x06\xb8\x28\xe0\x06\xde\x27\xdd\x06\x83\x26\xed\x06\x0e\x29\xe5\x06\xc6\x27\xec\x06\x7f\x26\xda\x06\xef\x28\xe0\x06\xc6\x27\xe7\x06\x95\x26\xf4\x06\xbe\x28\xec\x06\x17\x28\xfb\x06\x98\x26\xe2\x06\xd7\x28\xdc\x06\xb6\x27\xe6\x06\x5e\x26\xdb\x06\x87\x28\xe1\x06\xf3\x27\xdd\x06\x3b\x26\xfd\x06\xfd\x28\xfb\x06\xfb\x27\xeb\x06\x42\x26\xf0\x06\xde\x28\xf0\x06\xf3\x27\xe4\x06\x89\x26\xd9\x06\xb7\x28\xd4\x06\xff\x27\xd0\x06\x3d\x26\xe6\x06\xf7\x28\xe2\x06\xb7\x27\xdb\x06\x6f\x26\xca\x06\xd1\x28\xd6\x06\xf2\x27\xda\x06\x6c\x26\xea\x06\x8b\x28\xe1\x06\xbb\x27\xd7\x06\x26\x26\xf6\x06\xb5\x28\xf1\x06\x89\x27\xe3\x06\xd8\x25\xe5\x06\xbf\x28\xd7\x06\xba\x27\xd3\x06\xe5\x25\xe8\x06\xa5\x28\xdd\x06\x8a\x27\xf0\x06\x18\x26\xe8\x06\xcc\x28\xe2\x06\x58\x27\xd1\x06\xfd\x25\xdc\x06\x9d\x28\xdb\x06\xd3\x27\xdb\x06\xf0\x25\xe3\x06\x85\x28\xdc\x06\x63\x27\xd0\x06\xf3\x25\xef\x06\x88\x28\xea\x06\x5e\x27\xea\x06\x06\x26\xd2\x06\x5f\x28\xcf\x06\xb3\x27\xd8\x06\xfb\x25\xe6\x06\x94\x28\xe8\x06\x7b\x27\xd9\x06\xc2\x25\xf0\x06\x9b\x28\xe2\x06\xa6\x27\xd7\x06\x3c\x26\xdb\x06\xab\x28\xe0\x06\xe6\x27\xe5\x06\x48\x26\xe0\x06\x94\x28\xd7\x06\xc1\x27\xd9\x06\x14\x26\xdb\x06\xa6\x28\xce\x06\xe2\x27\xc5\x06\x3f\x26\xe2\x06\xab\x28\xde\x06\x9a\x27\xe2\x06\x31\x26\xe6\x06\xa6\x28\xe7\x06\xd1\x27\xe2\x06\x1e\x26\xef\x06\x8a\x28\xec\x06\xfb\x27\xdd\x06\x22\x26\xde\x06\xe3\x28\xd8\x06\xc1\x27\xdf\x06\x45\x26\xf7\x06\xd9\x28\xea\x06\xc6\x27\xf3\x06\x3c\x26\xf6\x06\xd1\x28\xf3\x06\x2b\x28\xf1\x06\x39\x26\xd5\x06\xf1\x28\xdd\x06\x11\x28\xec\x06\x69\x26\xed\x06\x81\x28\xf2\x06\x96\x27\xed\x06\x1b\x26\xe8\x06\xa2\x28\xf2\x06\xc9\x27\xe1\x06\x15\x26\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xef\x06\xd9\x28\xe0\x06\xb2\x27\xd9\x06\xf9\x25\xf7\x06\xa5\x28\xf8\x06\x91\x27\xf9\x06\x38\x26\xee\x06\xa9\x28\xf1\x06\xa7\x27\xe7\x06\x35\x26\xf0\x06\xa9\x28\xe7\x06\x50\x27\xe1\x06\xd1\x25\xee\x06\x6b\x28\xee\x06\x52\x27\xe6\x06\xcf\x25\xc8\x06\x9b\x28\xca\x06\x79\x27\xdf\x06\xd9\x25\xe8\x06\x7e\x28\xd9\x06\xbb\x27\xe3\x06\xf3\x25\xe4\x06\x86\x28\xe9\x06\x7f\x27\xe9\x06\xf6\x25\xdc\x06\x71\x28\xdb\x06\x67\x27\xda\x06\xa7\x25\xce\x06\x9c\x28\xd4\x06\x68\x27\xd5\x06\xe1\x25\xe4\x06\xd9\x28\xd6\x06\x7a\x27\xd2\x06\xcd\x25\xe2\x06\x87\x28\xe0\x06\xe9\x27\xd2\x06\xc6\x25\xe2\x06\xa4\x28\xd7\x06\xab\x27\xdc\x06\xeb\x25\xe5\x06\x64\x28\xe4\x06\x83\x27\xe6\x06\xdc\x25\x03\x07\x72\x28\xf5\x06\x89\x27\xf1\x06\xd5\x25\xe3\x06\x72\x28\xe4\x06\xc6\x27\xdc\x06\xdd\x25\xe8\x06\x75\x28\xe4\x06\x95\x27\xe8\x06\xfa\x25\xdc\x06\x75\x28\xdc\x06\x82\x27\xdc\x06\xe3\x25\xdf\x06\x70\x28\xe8\x06\x81\x27\xde\x06\xbb\x25\xdc\x06\x57\x28\xd6\x06\x79\x27\xd2\x06\xef\x25\xe1\x06\x5a\x28\xe3\x06\x7b\x27\xe3\x06\xc0\x25\xef\x06\x6b\x28\xe3\x06\x62\x27\xe7\x06\x8c\x25\xe4\x06\x33\x28\xcc\x06\x56\x27\xcf\x06\x90\x25\xe5\x06\x56\x28\xda\x06\x4e\x27\xd2\x06\xa7\x25\xe2\x06\x79\x28\xea\x06\x7b\x27\xe3\x06\xe4\x25\xf7\x06\x93\x28\xf1\x06\x87\x27\xe6\x06\xa5\x25\xf2\x06\x72\x28\xe2\x06\x3e\x27\xda\x06\x80\x25\xe0\x06\x50\x28\xe1\x06\x2f\x27\xd3\x06\xb5\x25\xdb\x06\x26\x28\xd1\x06\x2f\x27\xcf\x06\x6e\x25\xea\x06\x44\x28\xda\x06\x70\x27\xd6\x06\xa5\x25\xf4\x06\x3d\x28\xea\x06\x4b\x27\xe8\x06\x7a\x25\xe2\x06\x29\x28\xd8\x06\xe4\x26\xde\x06\x89\x25\xdf\x06\x25\x28\xd4\x06\x02\x27\xd8\x06\x33\x25\xe8\x06\xc6\x27\xe4\x06\xcc\x26\xe0\x06\x24\x25\xda\x06\xe1\x27\xd1\x06\x48\x27\xe7\x06\x9a\x25\xdb\x06\x15\x28\xd7\x06\x23\x27\xe0\x06\x91\x25\xe2\x06\x1c\x28\xd9\x06\x46\x27\xe2\x06\x5f\x25\xe1\x06\x15\x28\xde\x06\x3c\x27\xd5\x06\x37\x25\xd8\x06\x2b\x28\xe2\x06\x57\x27\xde\x06\x60\x25\xde\x06\xa4\x28\xda\x06\x53\x27\xd3\x06\x31\x25\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xde\x06\x45\x28\xd5\x06\x22\x27\xdb\x06\x25\x25\xde\x06\x32\x28\xe2\x06\x9f\x27\xe6\x06\x30\x25\xee\x06\x7d\x28\xd5\x06\x07\x27\xd6\x06\xa4\x24\xe9\x06\xa0\x28\xde\x06\xce\x26\xd1\x06\x5b\x24\xf8\x06\x78\x28\xe6\x06\x12\x27\xe1\x06\x4b\x24\xea\x06\x6c\x28\xdb\x06\x0a\x27\xdb\x06\x61\x24\xeb\x06\x1a\x29\xdd\x06\xc8\x26\xdc\x06\xd3\x24\xfe\x06\x1a\x2a\xe2\x06\xbf\x26\xed\x06\x38\x25\xe6\x06\x8d\x29\xda\x06\x02\x27\xe0\x06\x1b\x25\xf4\x06\xc9\x28\xdf\x06\x18\x27\xda\x06\x42\x25\xee\x06\x36\x28\xe6\x06\x5c\x27\xe8\x06\x42\x25\xdd\x06\x94\x28\xd9\x06\x42\x27\xe5\x06\x8b\x25\xf3\x06\x71\x28\xf3\x06\x86\x27\xec\x06\x9c\x25\xdd\x06\xd2\x28\xd6\x06\xbf\x27\xcf\x06\xbd\x25\xee\x06\x0f\x29\xe0\x06\xdf\x27\xe0\x06\xce\x25\xeb\x06\x75\x28\xe9\x06\x73\x27\xe3\x06\xd9\x25\xe9\x06\xad\x28\xda\x06\xd3\x27\xdb\x06\x10\x26\xdd\x06\x68\x28\xd0\x06\xdd\x27\xc4\x06\xeb\x25\xf3\x06\x78\x28\xe6\x06\xa9\x27\xea\x06\x13\x26\xdb\x06\x69\x28\xe3\x06\xda\x27\xdc\x06\xf7\x25\xe2\x06\x15\x28\xd9\x06\x38\x27\xe0\x06\xf9\x25\xdf\x06\xfd\x27\xdc\x06\x13\x27\xea\x06\xac\x25\xde\x06\xfb\x27\xe4\x06\x76\x27\xda\x06\xd3\x25\xd5\x06\x48\x28\xd3\x06\x8a\x27\xe1\x06\xdc\x25\xe7\x06\xfa\x27\xfa\x06\x5a\x27\xdf\x06\x8b\x25\xdb\x06\x02\x28\xd8\x06\x70\x27\xdb\x06\x7d\x25\xcd\x06\xf1\x27\xd2\x06\x3b\x27\xcb\x06\xb4\x25\xf4\x06\x29\x28\xe0\x06\x32\x27\xd6\x06\x81\x25\xe1\x06\xfd\x27\xe2\x06\xd4\x26\xd9\x06\x4e\x25\xd9\x06\x37\x28\xd7\x06\x28\x27\xdd\x06\x81\x25\xe4\x06\x44\x28\xe3\x06\x2a\x27\xdd\x06\xa2\x25\xe2\x06\x40\x28\xda\x06\x81\x27\xd5\x06\x6a\x25\xe0\x06\x1c\x28\xd3\x06\x2e\x27\xc9\x06\x4b\x25\xdf\x06\xe3\x27\xcf\x06\xe7\x26\xd1\x06\x3f\x25\xd7\x06\xfa\x27\xc6\x06\xe3\x26\xd1\x06\x66\x25\xe6\x06\x0d\x28\xdf\x06\xfe\x26\xd2\x06\x52\x25\xe1\x06\xf9\x27\xdf\x06\x50\x27\xdf\x06\x6f\x25\xd2\x06\x1e\x28\xc9\x06\x44\x27\xd9\x06\x6a\x25\xe9\x06\x3b\x28\xdd\x06\x2a\x27\xd7\x06\x73\x25\xe3\x06\x55\x28\xd7\x06\x1e\x27\xe3\x06\x5d\x25\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xdd\x06\x87\x28\xd3\x06\x50\x27\xd4\x06\xb9\x25\xe5\x06\x01\x29\xdc\x06\x36\x27\xda\x06\xc2\x25\xf2\x06\x27\x29\xe3\x06\xfc\x26\xe1\x06\xad\x25\xf3\x06\xdb\x28\xdd\x06\x32\x27\xd8\x06\x55\x25\xef\x06\xa2\x28\xdc\x06\x58\x27\xdb\x06\x81\x25\xe8\x06\x07\x28\xe3\x06\x4e\x27\xd3\x06\x7a\x25\xe2\x06\xf4\x27\xd3\x06\x25\x27\xd7\x06\x82\x25\xd6\x06\xf6\x27\xd9\x06\x27\x27\xd0\x06\x6e\x25\xd4\x06\x76\x28\xcc\x06\x1c\x27\xd3\x06\xcb\x25\xe1\x06\xaa\x28\xde\x06\x51\x27\xd5\x06\x9e\x25\xf1\x06\xe6\x28\xd5\x06\xc6\x26\xd6\x06\x52\x25\xe5\x06\xea\x28\xd8\x06\xf7\x26\xcf\x06\x9c\x25\xd3\x06\x58\x29\xce\x06\x05\x27\xda\x06\x83\x25\xd6\x06\x0d\x29\xcc\x06\x17\x27\xe4\x06\x35\x25\xef\x06\x60\x28\xea\x06\x48\x27\xe0\x06\x30\x25\xe8\x06\x48\x28\xdd\x06\x42\x27\xd8\x06\x24\x25\xe1\x06\x49\x28\xd8\x06\x08\x27\xc5\x06\x66\x25\xd4\x06\xa8\x28\xcf\x06\xeb\x26\xc8\x06\x71\x25\xe4\x06\xad\x28\xcd\x06\x36\x27\xd3\x06\xb4\x25\xdd\x06\x45\x28\xdc\x06\x74\x27\xe5\x06\x8b\x25\xdf\x06\xc7\x28\xcc\x06\x62\x27\xda\x06\xaa\x25\xe3\x06\xea\x28\xd2\x06\x2f\x27\xdd\x06\xde\x25\xdd\x06\x60\x28\xe0\x06\x88\x27\xe0\x06\xd9\x25\xdf\x06\x75\x28\xdd\x06\x7c\x27\xe0\x06\xd9\x25\xe4\x06\xba\x28\xd9\x06\x6c\x27\xdc\x06\xf6\x25\xdd\x06\xba\x28\xdf\x06\x9a\x27\xd8\x06\xf6\x25\xed\x06\xce\x28\xdd\x06\xba\x27\xe0\x06\xf5\x25\xf2\x06\x13\x29\xd8\x06\x5b\x27\xe0\x06\xdb\x25\xec\x06\x39\x29\xdd\x06\x63\x27\xe2\x06\x0a\x26\xe4\x06\x39\x29\xd7\x06\x88\x27\xcb\x06\x10\x26\xd5\x06\x56\x29\xc8\x06\x96\x27\xe0\x06\x08\x26\xe5\x06\xf9\x28\xd3\x06\x7d\x27\xd8\x06\x04\x26\xde\x06\xbc\x28\xda\x06\xbb\x27\xd3\x06\xe3\x25\xdb\x06\xb2\x28\xcf\x06\x8b\x27\xd5\x06\x10\x26\xda\x06\xad\x28\xd0\x06\x57\x27\xcc\x06\xce\x25\xe0\x06\x78\x28\xd3\x06\x99\x27\xd1\x06\xdd\x25\xd3\x06\xe7\x28\xd2\x06\x76\x27\xd5\x06\xce\x25\xde\x06\x7e\x28\xd8\x06\x80\x27\xd7\x06\xc0\x25\xe7\x06\x78\x28\xde\x06\xa6\x27\xd2\x06\xa2\x25\xd7\x06\x60\x28\xd1\x06\x2e\x27\xce\x06\x7b\x25\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xdc\x06\x83\x28\xd5\x06\x8b\x27\xd5\x06\xc3\x25\xda\x06\x55\x28\xe0\x06\x8d\x27\xc9\x06\xa4\x25\xe1\x06\x46\x28\xd9\x06\x6d\x27\xe6\x06\xad\x25\xea\x06\x59\x28\xe5\x06\x46\x27\xe2\x06\xdb\x25\xd8\x06\x44\x28\xdb\x06\x8b\x27\xd8\x06\xb9\x25\xd5\x06\x7a\x28\xd5\x06\x7d\x27\xd6\x06\xbe\x25\xe6\x06\x5c\x28\xed\x06\x67\x27\xdc\x06\xa1\x25\xe2\x06\x10\x28\xde\x06\xbc\x27\xdc\x06\xc3\x25\xdd\x06\x20\x28\xdf\x06\x6d\x27\xd7\x06\x0a\x26\xd4\x06\x55\x28\xcc\x06\x81\x27\xe3\x06\xe7\x25\xe5\x06\x6c\x28\xed\x06\x62\x27\xde\x06\xe7\x25\xe0\x06\x86\x28\xd4\x06\x73\x27\xdc\x06\xf4\x25\xec\x06\xc7\x28\xe3\x06\x7b\x27\xed\x06\xf2\x25\xb6\x06\x14\x29\xad\x06\xe2\x27\xce\x06\xb9\x25\xe0\x06\x72\x28\xd8\x06\x65\x27\xd7\x06\xc4\x25\xda\x06\x46\x28\xcc\x06\xa2\x27\xcf\x06\x99\x25\xeb\x06\x06\x28\xe4\x06\x53\x27\xdc\x06\x99\x25\xe0\x06\x21\x28\xdf\x06\x46\x27\xe0\x06\xc6\x25\xd4\x06\x7f\x28\xce\x06\x2c\x27\xd3\x06\xa1\x25\xeb\x06\xa4\x28\xe5\x06\x43\x27\xe7\x06\xde\x25\xef\x06\xc1\x28\xe9\x06\x34\x27\xec\x06\xa7\x25\xda\x06\xa0\x28\xcc\x06\x1f\x27\xd4\x06\xbe\x25\xda\x06\xa2\x28\xcc\x06\x29\x27\xd2\x06\xbe\x25\xe7\x06\xa0\x28\xe1\x06\x11\x27\xd7\x06\xbf\x25\xe5\x06\xf1\x27\xef\x06\xe4\x26\xda\x06\x93\x25\xd3\x06\xee\x27\xc7\x06\xcb\x26\xd4\x06\x2f\x25\xdd\x06\x4c\x28\xd4\x06\x1c\x27\xd5\x06\x84\x25\xd9\x06\x52\x28\xdc\x06\x20\x27\xea\x06\x53\x25\xb9\x06\x4c\x28\xb7\x06\xa8\x26\xcf\x06\x51\x25\xcb\x06\x4d\x28\xce\x06\x35\x27\xd1\x06\x65\x25\xc1\x06\x23\x28\xc2\x06\xf8\x26\xda\x06\x5b\x25\xe3\x06\x20\x28\xe2\x06\x22\x27\xcc\x06\x34\x25\xd1\x06\x3d\x28\xc2\x06\xf7\x26\xd7\x06\x4c\x25\xdd\x06\x4e\x28\xdc\x06\x05\x27\xcd\x06\x3a\x25\xe3\x06\xc5\x27\xd9\x06\x08\x27\xea\x06\x8e\x25\xe4\x06\xf4\x27\xd3\x06\xee\x26\xdb\x06\x6e\x25\xe6\x06\x2f\x28\xdc\x06\x2d\x27\xcf\x06\x51\x25\xd7\x06\x26\x28\xd7\x06\xdd\x26\xda\x06\x48\x25\xe4\x06\xd2\x27\xde\x06\xd6\x26\xdb\x06\x30\x25\xf1\x06\x49\x28\xf0\x06\x10\x27\xe7\x06\x2f\x25\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe9\x06\x60\x28\xdf\x06\xb8\x26\xdc\x06\x42\x25\xdc\x06\x4e\x28\xd5\x06\xb9\x26\xd5\x06\x55\x25\xe7\x06\x06\x28\xd3\x06\xa3\x26\xec\x06\x2f\x25\xce\x06\xc9\x27\xcf\x06\xbb\x26\xd5\x06\x65\x25\xd2\x06\xa8\x27\xdc\x06\xce\x26\xd5\x06\x53\x25\xdb\x06\xf0\x27\xd4\x06\xf3\x26\xe5\x06\x34\x25\xd2\x06\xf0\x27\xcd\x06\xb2\x26\xcd\x06\x1e\x25\xd1\x06\xa8\x27\xd3\x06\xf4\x26\xc8\x06\x22\x25\xea\x06\xca\x27\xde\x06\xcd\x26\xe4\x06\x43\x25\xd8\x06\xff\x27\xc9\x06\x77\x26\xd6\x06\x32\x25\xea\x06\xde\x27\xe1\x06\xaa\x26\xe6\x06\x58\x25\xcd\x06\x8f\x27\xcd\x06\xce\x26\xcc\x06\x51\x25\xd5\x06\xa7\x27\xca\x06\x94\x26\xd6\x06\x29\x25\xc5\x06\xc2\x27\xba\x06\xce\x26\xc2\x06\xfa\x24\xae\x06\x70\x28\x99\x06\x27\x27\xad\x06\xbe\x25\xc9\x06\xa8\x27\xc6\x06\xbb\x26\xc3\x06\x5b\x25\xe1\x06\x91\x27\xe3\x06\x5c\x26\xdd\x06\x0e\x25\xd8\x06\xa8\x27\xdd\x06\x7d\x26\xce\x06\x07\x25\xdf\x06\xa5\x27\xe7\x06\x13\x27\xd6\x06\x26\x25\xd0\x06\x8f\x27\xc8\x06\xec\x26\xcb\x06\x25\x25\xe6\x06\xa5\x27\xcf\x06\xb8\x26\xdc\x06\x29\x25\xd8\x06\xf9\x27\xca\x06\xd8\x26\xc7\x06\x4e\x25\xee\x06\xe5\x27\xe0\x06\xfe\x26\xe4\x06\x54\x25\xd0\x06\xf7\x27\xc0\x06\xb6\x26\xd5\x06\x6f\x25\xcc\x06\xfb\x27\xc6\x06\xdf\x26\xd6\x06\x41\x25\xd8\x06\xff\x27\xc7\x06\xd0\x26\xd0\x06\x50\x25\xd5\x06\x0b\x28\xd9\x06\xc6\x26\xd8\x06\x33\x25\xdc\x06\xd7\x27\xd7\x06\xc0\x26\xd8\x06\x30\x25\xd3\x06\xff\x27\xca\x06\xf3\x26\xcd\x06\x1d\x25\xcc\x06\xed\x27\xc0\x06\x08\x27\xcb\x06\x4a\x25\xe1\x06\x18\x28\xd4\x06\xfa\x26\xe4\x06\x40\x25\xd9\x06\x09\x28\xcd\x06\xe0\x26\xc9\x06\x36\x25\xd4\x06\xd7\x27\xcd\x06\xac\x26\xe4\x06\x3f\x25\xe2\x06\x92\x27\xde\x06\xe4\x26\xd8\x06\xf4\x24\xcc\x06\xaa\x27\xc7\x06\xf3\x26\xcc\x06\x23\x25\xb2\x06\x0b\x28\xab\x06\xe6\x26\xc4\x06\x3e\x25\xe1\x06\xea\x27\xd9\x06\xcc\x26\xd7\x06\x3a\x25\xe0\x06\xd8\x27\xd1\x06\xde\x26\xcc\x06\x57\x25\xdf\x06\xad\x27\xd5\x06\x14\x27\xd6\x06\x3d\x25\xc8\x06\xe8\x27\xc8\x06\xf3\x26\xcf\x06\x1f\x25\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe4\x06\xee\x27\xd3\x06\xfa\x26\xc3\x06\x28\x25\xdd\x06\x86\x27\xd5\x06\xde\x26\xd3\x06\x32\x25\xd5\x06\x58\x27\xd8\x06\xe6\x26\xdc\x06\x19\x25\xd7\x06\x18\x28\xce\x06\x02\x27\xc8\x06\x4a\x25\xd1\x06\xb2\x27\xd5\x06\x2a\x27\xc9\x06\x49\x25\xc4\x06\x7a\x27\xc3\x06\xdc\x26\xc0\x06\xf8\x24\xe1\x06\x74\x27\xde\x06\xdc\x26\xdc\x06\x4f\x25\xe0\x06\x87\x27\xd4\x06\x1c\x27\xe1\x06\x55\x25\xe4\x06\x88\x27\xd5\x06\xd0\x26\xdb\x06\x35\x25\xd1\x06\xa1\x27\xc9\x06\x0e\x27\xdc\x06\x36\x25\xb8\x06\xf2\x27\xb6\x06\x30\x27\xad\x06\x64\x25\xd0\x06\xd0\x27\xd0\x06\x18\x27\xcd\x06\x61\x25\xe3\x06\xfe\x27\xd2\x06\x0a\x27\xce\x06\x34\x25\xe4\x06\xd7\x27\xd2\x06\xf6\x26\xcc\x06\x49\x25\xbc\x06\x62\x28\xb6\x06\x26\x27\xb7\x06\x78\x25\xc9\x06\xf5\x27\xbd\x06\xe8\x26\xd8\x06\xed\x24\xde\x06\x0f\x28\xdb\x06\xd8\x26\xe1\x06\x33\x25\xf0\x06\xe1\x27\xe8\x06\x0a\x27\xdc\x06\x31\x25\xde\x06\x18\x28\xdd\x06\x16\x27\xcc\x06\x1d\x25\xd4\x06\x46\x28\xda\x06\x1c\x27\xda\x06\x3c\x25\xe2\x06\x0c\x28\xd5\x06\xce\x26\xd4\x06\xfc\x24\xd6\x06\xad\x27\xdb\x06\xd0\x26\xd9\x06\x45\x25\xd9\x06\xda\x27\xdd\x06\x27\x27\xcd\x06\x38\x25\xe3\x06\x51\x28\xd8\x06\x06\x27\xd7\x06\x54\x25\xca\x06\x5b\x28\xc4\x06\xfe\x26\xd7\x06\x32\x25\xcc\x06\x86\x28\xc1\x06\x14\x27\xca\x06\x51\x25\xd4\x06\x8b\x28\xda\x06\x93\x27\xd7\x06\x91\x25\xd5\x06\xfe\x28\xc8\x06\x74\x27\xc9\x06\x7f\x25\xd0\x06\x39\x29\xca\x06\x4f\x27\xc9\x06\x94\x25\xef\x06\xf5\x28\xd5\x06\x1b\x27\xe8\x06\x62\x25\xd6\x06\x02\x29\xc8\x06\x3c\x27\xd3\x06\x80\x25\xd9\x06\xee\x28\xc7\x06\x23\x27\xca\x06\x63\x25\xdc\x06\x9f\x28\xda\x06\xf1\x26\xd2\x06\x72\x25\xd9\x06\xb4\x28\xc3\x06\xed\x26\xc4\x06\x73\x25\xde\x06\xb4\x28\xd1\x06\xff\x26\xd1\x06\x20\x25\xe3\x06\xb9\x28\xd3\x06\xf1\x26\xd4\x06\x12\x25\xe6\x06\x5d\x28\xdc\x06\x3d\x27\xdf\x06\x1b\x25\xdf\x06\x68\x28\xda\x06\x41\x27\xcf\x06\x3e\x25\xd8\x06\x8c\x28\xd8\x06\x25\x27\xd0\x06\x61\x25\xdf\x06\xcc\x28\xd2\x06\xec\x26\xd4\x06\x7c\x25\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xdc\x06\x19\x29\xce\x06\x62\x27\xcf\x06\x5e\x25\xc8\x06\x72\x28\xbe\x06\x6f\x27\xd1\x06\x5a\x25\xd1\x06\x2d\x28\xd4\x06\x7e\x27\xd8\x06\x81\x25\xd3\x06\xd7\x27\xd5\x06\x4a\x27\xda\x06\x3f\x25\xcd\x06\xcb\x28\xc5\x06\x18\x27\xcd\x06\x65\x24\x7c\x07\x05\x9d\x81\x07\x97\x93\x7e\x07\xb9\x87\x00\x00\xb8\x14\x00\x00\x6d\x15\x00\x00\x0b\x16\x00\x00\xb9\x14\x00\x00\x6e\x15\x00\x00\x0d\x16\x00\x00\xb9\x14\x00\x00\x6e\x15\x00\x00\x1f\x16\x00\x00\xb9\x14\x00\x00\x6e\x15\x00\x00\x1e\x16\x00\x00\xb9\x14\x00\x00\x6e\x15\x00\x00\x1d\x16\xf8\x06\xc3\x28\x02\x07\x87\x27\xe2\x06\x8c\x24\x0b\x07\x6c\x28\xfe\x06\xb9\x27\xee\x06\x5c\x25\xfc\x06\xb5\x28\xfb\x06\x91\x27\xed\x06\xb1\x25\x0b\x07\xe7\x28\x08\x07\xc7\x27\xfc\x06\xee\x25\x0c\x07\x2d\x29\xff\x06\x0d\x28\xf8\x06\xef\x25\x0c\x07\x24\x29\xfb\x06\x90\x27\xf6\x06\xce\x25\xf6\x06\x4b\x29\xff\x06\xdb\x27\xf5\x06\xce\x25\x10\x07\xfd\x28\x07\x07\xb3\x27\xfc\x06\xe1\x25\x0d\x07\x04\x29\xf6\x06\x79\x27\xe9\x06\x9d\x25\x06\x07\x50\x29\xfb\x06\x8f\x27\xfa\x06\x97\x25\x04\x07\xec\x28\x06\x07\x4a\x27\xf2\x06\xa4\x25\x03\x07\xd2\x28\x06\x07\x54\x27\xf8\x06\x9b\x25\xf7\x06\x0f\x29\xf3\x06\x1e\x27\xf3\x06\x4c\x25\x14\x07\x39\x29\x07\x07\x4d\x27\xfd\x06\x38\x25\x01\x07\x03\x2a\xef\x06\x4a\x27\xf4\x06\xec\x25\x09\x07\x5a\x29\xf2\x06\x38\x27\xf4\x06\x87\x25\x08\x07\x13\x29\x01\x07\x95\x27\x00\x07\x19\x26\x02\x07\x06\x29\xf0\x06\x98\x27\xfd\x06\xc8\x25\x08\x07\xa9\x28\x03\x07\x70\x27\x03\x07\xa0\x25\x00\x07\xad\x28\xf3\x06\xdf\x26\xf1\x06\xef\x24\x04\x07\x4e\x28\xf8\x06\x16\x27\xf5\x06\x1d\x25\xfe\x06\xa0\x28\x00\x07\x58\x27\xeb\x06\x5b\x25\xf5\x06\xcb\x28\xf6\x06\x99\x27\xf9\x06\xc2\x25\x11\x07\xfd\x28\x01\x07\x7d\x27\xee\x06\x60\x25\x0e\x07\xbc\x28\x03\x07\xc3\x27\xfd\x06\x7f\x25\x15\x07\xe6\x28\xfd\x06\xbb\x27\xfa\x06\x86\x25\x03\x07\x6c\x28\x0c\x07\xbb\x27\xfa\x06\x1b\x25\x10\x07\x2e\x28\x09\x07\xb4\x27\xf4\x06\x13\x25\x05\x07\xa2\x28\xf4\x06\xa5\x27\xfe\x06\x99\x25\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x06\x07\xb5\x28\xfb\x06\xd7\x27\xfc\x06\x83\x25\x05\x07\x78\x28\x00\x07\x80\x27\xf5\x06\x3d\x25\xfd\x06\x44\x28\xf2\x06\x69\x27\xf4\x06\x46\x25\x00\x07\x37\x28\x04\x07\xa8\x27\xeb\x06\x5f\x25\x0a\x07\xdc\x27\x08\x07\x5d\x27\xf0\x06\x62\x25\xf4\x06\xf7\x27\xf1\x06\x0f\x27\xf3\x06\xd7\x24\xfa\x06\x02\x28\xe7\x06\x58\x27\xee\x06\x3d\x25\x07\x07\x45\x28\x01\x07\x78\x27\xf1\x06\x53\x25\x05\x07\x25\x28\x00\x07\x85\x27\xf1\x06\x42\x25\x02\x07\x26\x28\x02\x07\xd6\x27\xf3\x06\x98\x25\x02\x07\x33\x28\x03\x07\xc8\x27\xec\x06\x93\x25\xf8\x06\x71\x28\xf8\x06\xb9\x27\xf6\x06\xee\x25\xf8\x06\x15\x28\xf2\x06\x42\x27\xee\x06\x3d\x25\x06\x07\x52\x28\xfe\x06\x84\x27\xf0\x06\x99\x25\x0e\x07\x59\x28\x07\x07\xc0\x27\xf9\x06\xda\x25\x04\x07\xa9\x28\x02\x07\xa8\x27\x0b\x07\x1d\x26\x05\x07\x7c\x28\xf4\x06\x80\x27\xef\x06\xcf\x25\x00\x07\xa0\x28\xf3\x06\x74\x27\xea\x06\xc9\x25\x03\x07\xd9\x28\xf4\x06\xde\x27\xea\x06\xaf\x25\xf7\x06\x51\x28\xef\x06\x44\x27\xe8\x06\x53\x25\xfc\x06\x5a\x28\xfb\x06\xc7\x27\xf2\x06\xa1\x25\xf9\x06\xef\x28\xfc\x06\xe2\x27\xed\x06\xf0\x25\xf9\x06\xa2\x28\xf7\x06\xa8\x27\xef\x06\xf8\x25\xe2\x06\x94\x28\xea\x06\xaf\x27\xeb\x06\x02\x26\xff\x06\xbe\x28\xf1\x06\xd2\x27\xeb\x06\xf4\x25\xfc\x06\xd6\x28\xf6\x06\xb4\x27\xe6\x06\x2a\x26\x03\x07\x4c\x28\xf4\x06\x80\x27\xfc\x06\xc9\x25\xfd\x06\x57\x28\x00\x07\xc0\x27\x00\x07\xd1\x25\x07\x07\x82\x28\xff\x06\xd0\x27\xfa\x06\xc5\x25\x0a\x07\xc9\x28\xfc\x06\xc7\x27\x01\x07\xc9\x25\xfa\x06\x8f\x28\xf8\x06\x02\x28\xf2\x06\x7f\x25\x07\x07\x8c\x28\x04\x07\x83\x27\xf2\x06\x6a\x25\x07\x07\xba\x28\xf2\x06\x75\x27\xf9\x06\xbd\x25\x02\x07\x63\x28\xf2\x06\x39\x27\xf1\x06\x98\x25\xdc\x06\xfe\x27\xe7\x06\x38\x27\xe7\x06\x30\x25\xfd\x06\x21\x28\x01\x07\xab\x27\xec\x06\xaf\x25\x09\x07\x4d\x28\xfd\x06\x8f\x27\xee\x06\xb0\x25\x05\x07\xc3\x28\xf5\x06\x61\x27\xed\x06\x00\x26\x02\x07\x7f\x29\xf6\x06\x97\x27\xea\x06\xb7\x25\x07\x07\x95\x28\x0b\x07\xa1\x27\xfe\x06\xcf\x25\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x00\x07\x63\x28\x05\x07\xd6\x27\xed\x06\xac\x25\xfd\x06\x9c\x28\xff\x06\x7b\x27\xf3\x06\x67\x25\x0c\x07\xdb\x28\xfb\x06\xf2\x27\xe9\x06\xcb\x25\x09\x07\xd7\x28\x01\x07\x27\x28\xe9\x06\x9c\x25\xed\x06\x99\x28\xed\x06\xcf\x27\xfd\x06\xf4\x25\x01\x07\xf4\x28\xf9\x06\xca\x27\xf1\x06\xdf\x25\xf4\x06\xc0\x28\x0a\x07\x12\x28\xf8\x06\xf9\x25\xf1\x06\x78\x28\xf2\x06\xd6\x27\xf5\x06\xec\x25\x06\x07\x81\x28\xf9\x06\x64\x27\xe8\x06\x69\x25\x04\x07\x92\x28\xf6\x06\x8f\x27\xf0\x06\xc4\x25\x04\x07\xc0\x28\x05\x07\xc6\x27\x00\x07\xe6\x25\xfe\x06\xf4\x28\xf3\x06\x8d\x27\xdc\x06\xa7\x25\x1a\x07\xa0\x28\x0f\x07\xa4\x27\xf7\x06\xa5\x25\xfa\x06\xd0\x28\xf5\x06\x7d\x27\xe5\x06\xde\x25\xe8\x06\x78\x28\xe0\x06\x5a\x27\xe5\x06\x6d\x25\x0a\x07\x3f\x28\x02\x07\xff\x26\xee\x06\x1e\x25\xf7\x06\x62\x28\xed\x06\x3e\x27\xeb\x06\x51\x25\xfc\x06\xc3\x28\xf5\x06\x50\x27\xeb\x06\xc4\x25\x07\x07\xd0\x28\xfa\x06\x52\x27\xf3\x06\xa1\x25\x03\x07\x90\x28\xee\x06\x1f\x27\x02\x07\x86\x25\x02\x07\x72\x28\xf7\x06\x45\x27\xf5\x06\x86\x25\x08\x07\x07\x28\xfa\x06\x35\x27\xf7\x06\x96\x25\x00\x07\x07\x28\xee\x06\xda\x26\xef\x06\x2c\x25\x03\x07\x25\x28\xf2\x06\x05\x27\xf2\x06\x8b\x25\x0d\x07\x9d\x28\x06\x07\x6e\x27\xfc\x06\xa0\x25\xf3\x06\xfa\x28\xe8\x06\x89\x27\xf6\x06\x93\x25\x05\x07\xfd\x28\xfe\x06\x74\x27\xff\x06\xd0\x25\x0c\x07\x5e\x29\xef\x06\x69\x27\x0b\x07\xd8\x25\x09\x07\xfa\x28\x0a\x07\xbc\x27\x05\x07\x04\x26\xf7\x06\x82\x28\xf2\x06\x78\x27\xdf\x06\xa0\x25\x06\x07\x68\x28\x02\x07\xac\x27\xf7\x06\x98\x25\x04\x07\xf9\x28\xfa\x06\xd6\x27\xf1\x06\x0a\x26\xf7\x06\x46\x29\xe8\x06\xc2\x27\xf3\x06\xfb\x25\x0d\x07\xf5\x28\xff\x06\xca\x27\xf2\x06\xcd\x25\x0d\x07\x13\x29\x09\x07\xa3\x27\xfd\x06\x1d\x26\x09\x07\x32\x29\xfc\x06\xb1\x27\xfc\x06\x1d\x26\x0a\x07\xf5\x28\xfe\x06\xc2\x27\xfb\x06\x06\x26\x04\x07\x2c\x29\xf6\x06\x98\x27\xf5\x06\xac\x25\x01\x07\xe3\x28\xfb\x06\xfb\x27\xe7\x06\x04\x26\x03\x07\xb5\x28\xf7\x06\x07\x28\xed\x06\x1c\x26\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x04\x07\xcb\x28\x01\x07\x22\x28\xef\x06\xd6\x25\x0c\x07\xf8\x28\xff\x06\x1b\x28\xf2\x06\x9c\x25\xfc\x06\xb5\x28\xf7\x06\xe4\x27\xf2\x06\xbe\x25\xfc\x06\xb5\x28\xf3\x06\xaf\x27\xf2\x06\xb0\x25\x08\x07\x64\x28\xfd\x06\x34\x27\xe6\x06\x34\x25\xf9\x06\x6f\x28\x05\x07\x9f\x27\xf0\x06\xac\x25\xf1\x06\xab\x28\xf5\x06\xed\x27\xec\x06\xdb\x25\x03\x07\x71\x28\x02\x07\xf8\x27\xfe\x06\xf2\x25\x09\x07\x9f\x28\x0a\x07\xd5\x27\xfc\x06\xe7\x25\xff\x06\xe4\x28\xfd\x06\x16\x28\xfb\x06\xd6\x25\xfd\x06\xde\x28\xf5\x06\x18\x28\xee\x06\x18\x26\x03\x07\xcc\x28\xf2\x06\xa6\x27\xf3\x06\x96\x25\xfb\x06\xe4\x28\x00\x07\x4a\x28\xfb\x06\x03\x26\xee\x06\xad\x28\xe9\x06\x1e\x28\xfc\x06\x1d\x26\xec\x06\x29\x29\xe3\x06\x34\x28\xee\x06\xe5\x25\xf8\x06\x2d\x29\xea\x06\x18\x28\xee\x06\x07\x26\xfc\x06\xc9\x28\x06\x07\x1a\x28\xfe\x06\xed\x25\xfc\x06\xd0\x28\x02\x07\x1e\x28\xf4\x06\x0a\x26\xfa\x06\x9d\x28\xf0\x06\x32\x28\xfb\x06\xe9\x25\xf2\x06\xea\x28\xe8\x06\x0e\x28\xf8\x06\xb4\x25\x16\x07\x2d\x29\x1d\x07\x0e\x28\x04\x07\x15\x26\x08\x07\x0a\x29\x0d\x07\x26\x28\xfe\x06\x33\x26\xf7\x06\xc7\x28\xf9\x06\xe8\x27\xff\x06\x37\x26\x02\x07\x8f\x28\xf8\x06\xfd\x27\xef\x06\xe6\x25\xf9\x06\xf1\x28\xf9\x06\xad\x27\xed\x06\xed\x25\x0b\x07\xf1\x28\xff\x06\x86\x27\xf6\x06\xb9\x25\xe6\x06\x09\x29\xe0\x06\x69\x27\xea\x06\xd4\x25\x01\x07\x04\x29\xfc\x06\xe0\x27\xfb\x06\x40\x26\xfe\x06\x24\x29\xf7\x06\xdb\x27\xee\x06\x45\x26\x04\x07\xef\x28\x06\x07\x05\x28\xfc\x06\x06\x26\x0d\x07\xe1\x28\x07\x07\xb4\x27\xf5\x06\xac\x25\x10\x07\x1a\x29\xfe\x06\xb0\x27\xfa\x06\xbb\x25\xf5\x06\x7c\x28\xf6\x06\x8f\x27\xf6\x06\x7d\x25\x0b\x07\x2b\x28\xff\x06\x1a\x27\xf2\x06\xf5\x24\xd2\x06\x2d\x29\xc0\x06\x4c\x27\xe1\x06\xe8\x24\x10\x07\x0b\x29\x09\x07\x3c\x27\xeb\x06\x07\x25\x0f\x07\xad\x28\x09\x07\xb6\x27\xed\x06\x30\x25\xf7\x06\xae\x28\xf9\x06\xa1\x27\xe8\x06\x2d\x25\x0a\x07\x29\x29\xef\x06\x82\x27\xea\x06\x70\x25\x05\x07\x0b\x29\xf2\x06\xc1\x27\xf6\x06\x80\x25\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0f\x07\xa4\x28\xf7\x06\x5e\x27\xf3\x06\x46\x25\x06\x07\x04\x29\xf9\x06\x91\x27\xfe\x06\x8f\x25\x16\x07\xb8\x29\x00\x07\xe5\x27\xf9\x06\xd6\x25\xf7\x06\xdb\x29\xed\x06\xc3\x27\xfd\x06\xd0\x25\x12\x07\xfe\x29\xf8\x06\x9e\x27\x09\x07\xa3\x25\x11\x07\x80\x29\x12\x07\x95\x27\x09\x07\xf0\x25\x11\x07\x10\x29\xfc\x06\xd0\x27\xf5\x06\xc2\x25\xfc\x06\xbb\x28\xff\x06\x6b\x27\xf0\x06\x41\x25\xfc\x06\xa6\x28\x04\x07\xb1\x27\xf8\x06\x8f\x25\xfa\x06\x9c\x28\xf8\x06\xa4\x27\xf0\x06\xaf\x25\x11\x07\x7f\x28\x0d\x07\xb2\x27\xfd\x06\x72\x25\x0c\x07\x1a\x29\x0b\x07\xa4\x27\xf0\x06\x1b\x25\x0b\x07\x18\x29\x00\x07\x48\x27\xf3\x06\xf6\x24\x14\x07\x5e\x29\x05\x07\x74\x27\xf9\x06\x04\x25\x1d\x07\x55\x29\x0f\x07\x5c\x27\xfa\x06\x16\x25\x04\x07\xf8\x28\xfa\x06\x32\x27\xfc\x06\xd5\x24\x0a\x07\xc9\x28\x06\x07\xe5\x27\xee\x06\x59\x25\x1d\x07\xe7\x28\x0d\x07\x0b\x28\xfe\x06\xa4\x25\x17\x07\x75\x28\x11\x07\xb3\x27\x08\x07\x93\x25\xfb\x06\x25\x28\xf9\x06\xbf\x27\xf4\x06\x79\x25\x07\x07\xf6\x27\x09\x07\xd1\x27\x04\x07\xaf\x25\xfb\x06\xd1\x27\xf1\x06\x42\x27\xf2\x06\x38\x25\xff\x06\xe3\x27\xf7\x06\x0f\x27\xf3\x06\x25\x25\xf8\x06\xbf\x28\xf1\x06\x79\x27\xf3\x06\x98\x25\xf1\x06\xbf\x28\xf1\x06\xbb\x27\xf7\x06\x8c\x25\x0d\x07\x22\x28\x0c\x07\xf6\x27\x02\x07\xb9\x25\x05\x07\xa1\x28\xf8\x06\xdd\x27\x05\x07\xba\x25\x01\x07\x6c\x28\x01\x07\xbb\x27\xfb\x06\xc9\x25\x12\x07\x21\x28\x09\x07\xaf\x27\xfa\x06\xd7\x25\x00\x07\xa2\x27\x03\x07\x27\x27\xfb\x06\x49\x25\xff\x06\xa2\x27\xfe\x06\x57\x27\x01\x07\x88\x25\x0f\x07\x21\x28\xfb\x06\x92\x27\xf7\x06\xa3\x25\x02\x07\x2e\x28\x04\x07\xbf\x27\xf4\x06\xb0\x25\x05\x07\x21\x28\xf6\x06\xce\x27\xef\x06\xc8\x25\xff\x06\x25\x28\xfe\x06\xa6\x27\xec\x06\xbd\x25\xf5\x06\x7a\x28\xfa\x06\xed\x27\xe9\x06\xe3\x25\x08\x07\x26\x28\xf4\x06\x5c\x27\xef\x06\x5c\x25\xfc\x06\x15\x28\xf8\x06\xad\x27\xeb\x06\xb2\x25\x14\x07\x85\x28\x13\x07\x1d\x28\xff\x06\xf7\x25\x01\x07\x82\x28\x04\x07\xd9\x27\xfb\x06\xec\x25\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x08\x07\x53\x28\x04\x07\xc6\x27\xf4\x06\xae\x25\xfc\x06\x5c\x28\xfa\x06\xc1\x27\xf9\x06\xb6\x25\xf4\x06\x82\x28\xef\x06\xcf\x27\xf5\x06\xe2\x25\x03\x07\x46\x28\xfe\x06\x63\x27\xf1\x06\x6b\x25\xe7\x06\xaa\x28\xca\x06\xc2\x27\xd7\x06\xa1\x25\xf0\x06\x9d\x28\xf4\x06\x06\x28\xf6\x06\xcf\x25\x0d\x07\xeb\x28\x04\x07\x9a\x27\xf8\x06\xd4\x25\x10\x07\xbb\x29\xfc\x06\x91\x27\xfe\x06\x09\x26\x15\x07\xf3\x29\xfc\x06\x89\x27\xfb\x06\x15\x26\xf9\x06\xb8\x28\x01\x07\x8a\x27\xf2\x06\xd3\x25\x09\x07\x27\x28\xfc\x06\x57\x27\xfc\x06\x71\x25\xff\x06\x40\x28\xf2\x06\x2a\x27\xf6\x06\x75\x25\x0c\x07\xcb\x28\x09\x07\xa2\x27\xff\x06\xcf\x25\xf8\x06\x9f\x28\xfa\x06\xf2\x27\xe6\x06\xaf\x25\xfb\x06\xbe\x28\xee\x06\x7e\x27\xf5\x06\xc8\x25\xf8\x06\x5c\x28\xe9\x06\xa1\x27\xf9\x06\xac\x25\x01\x07\x4c\x28\x05\x07\xff\x27\xeb\x06\xaf\x25\x04\x07\x37\x28\x0f\x07\x9b\x27\xf3\x06\x4c\x25\x09\x07\x25\x28\xfc\x06\x2a\x27\xf3\x06\x45\x25\x03\x07\x78\x28\xfb\x06\xca\x27\xef\x06\x96\x25\xfd\x06\x7c\x28\xfb\x06\xad\x27\xf3\x06\xa4\x25\x08\x07\xa5\x28\xff\x06\xb3\x27\xec\x06\xae\x25\x03\x07\x7f\x28\xfd\x06\xa7\x27\xfb\x06\xdb\x25\x06\x07\x69\x28\x08\x07\x35\x28\xf6\x06\xdc\x25\xfc\x06\x5e\x28\xf7\x06\xa1\x27\xf4\x06\xb2\x25\x0d\x07\x0f\x28\x04\x07\x57\x27\xfd\x06\x69\x25\xef\x06\x3c\x28\xed\x06\xd5\x27\xf1\x06\xae\x25\xfe\x06\x9d\x28\x07\x07\x0e\x28\xe0\x06\xe7\x25\x04\x07\xb4\x28\xf8\x06\xd0\x27\xfc\x06\x0e\x26\x03\x07\x72\x28\x00\x07\x94\x27\xf7\x06\xe1\x25\x03\x07\x67\x28\x05\x07\xdf\x27\xfa\x06\xab\x25\xf3\x06\xa7\x28\x00\x07\xcf\x27\xed\x06\x81\x25\x00\x07\xfb\x27\x03\x07\x7f\x27\xeb\x06\x36\x25\x04\x07\x69\x28\xfd\x06\xb3\x27\xf0\x06\x8c\x25\x0a\x07\x98\x28\x0a\x07\x7d\x28\xf8\x06\xf5\x25\xf9\x06\x9f\x28\xf3\x06\xf0\x27\xfb\x06\xde\x25\x00\x07\x76\x28\x03\x07\xed\x27\xf3\x06\x7c\x25\x0b\x07\x9e\x28\xfc\x06\x15\x28\xe9\x06\xb7\x25\x0e\x07\x57\x28\x08\x07\xae\x27\xff\x06\xab\x25\xfa\x06\x1f\x28\xf1\x06\x5a\x27\xeb\x06\x41\x25\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x08\x07\x80\x28\x06\x07\xe1\x27\xf1\x06\x98\x25\xff\x06\x8e\x28\xfa\x06\xf2\x27\xee\x06\x8b\x25\xfa\x06\xb8\x28\xee\x06\xca\x27\xf2\x06\xe6\x25\x0e\x07\xa7\x28\x04\x07\x00\x28\xf8\x06\xdb\x25\xfe\x06\x54\x28\x02\x07\xdb\x27\xe7\x06\xa3\x25\x05\x07\x6f\x28\xf9\x06\xcd\x27\xf1\x06\xf2\x25\x00\x07\x45\x28\xfc\x06\x76\x27\xf3\x06\x3f\x25\x04\x07\x3a\x28\xff\x06\x61\x27\xf0\x06\x84\x25\x0f\x07\x97\x28\x05\x07\xa4\x27\xf8\x06\xcb\x25\xe3\x06\xe9\x28\xe2\x06\xf3\x27\xf6\x06\x24\x26\x04\x07\x68\x28\x05\x07\x02\x28\xee\x06\xae\x25\x06\x07\xc8\x28\xfe\x06\xd8\x27\xed\x06\xdf\x25\xf8\x06\xe7\x28\xee\x06\xef\x27\xf0\x06\xf0\x25\x04\x07\x76\x28\x0a\x07\x36\x28\xfc\x06\xf8\x25\xe8\x06\x92\x28\xdf\x06\x0e\x28\xec\x06\x9e\x25\x03\x07\xbf\x28\xfa\x06\x2e\x28\xee\x06\xdb\x25\x00\x07\xdc\x28\xfe\x06\xf7\x27\xec\x06\xf2\x25\xfd\x06\xad\x28\xf7\x06\xec\x27\xef\x06\xc5\x25\x05\x07\xdd\x28\xf1\x06\x18\x28\xee\x06\xd4\x25\x07\x07\x1f\x29\x0b\x07\xed\x27\x02\x07\x1d\x26\x05\x07\xb2\x28\xef\x06\xdc\x27\xf2\x06\x9c\x25\x04\x07\x57\x28\x02\x07\xba\x27\xfb\x06\xaf\x25\x06\x07\xa3\x28\x07\x07\x67\x28\xed\x06\x1a\x26\x08\x07\xcc\x28\x0d\x07\x3c\x28\xfd\x06\x50\x26\x08\x07\xf7\x28\x03\x07\x3c\x28\x07\x07\x4c\x26\x0b\x07\xcd\x28\x09\x07\x2b\x28\xf8\x06\x0d\x26\xfe\x06\xa1\x28\xfe\x06\x18\x28\xf4\x06\x0b\x26\xf3\x06\xcd\x28\xeb\x06\xf1\x27\xeb\x06\xe1\x25\xfa\x06\x7d\x28\xea\x06\xa5\x27\xed\x06\x81\x25\x02\x07\x7f\x28\x02\x07\x0f\x28\xf2\x06\xa4\x25\xf3\x06\xbb\x28\xf9\x06\x4c\x28\xf0\x06\xf7\x25\xfb\x06\x85\x28\xec\x06\xff\x27\xeb\x06\xe1\x25\xf8\x06\x7d\x28\xf8\x06\xea\x27\xe8\x06\xd3\x25\xfd\x06\xa0\x28\xfc\x06\x02\x28\xf1\x06\xc9\x25\xf8\x06\x8f\x28\x01\x07\x07\x28\xf4\x06\xd8\x25\xff\x06\xf4\x27\xfa\x06\x60\x27\xf4\x06\x67\x25\x07\x07\x34\x28\xf3\x06\x60\x27\xf1\x06\x4a\x25\x00\x07\x62\x28\xfc\x06\xaa\x27\xf5\x06\xc4\x25\x04\x07\x9e\x28\x03\x07\xe7\x27\xf8\x06\xd1\x25\x05\x07\x9a\x28\xf2\x06\xfb\x27\x00\x07\xe6\x25\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x04\x07\x9e\x28\x08\x07\xc4\x27\xec\x06\xaf\x25\xe5\x06\x5f\x28\xe2\x06\x13\x28\xef\x06\xc9\x25\x11\x07\x11\x28\x0e\x07\xaa\x27\x02\x07\x7b\x25\xfa\x06\xfd\x27\x04\x07\x87\x27\xe7\x06\x46\x25\xfb\x06\x63\x28\xf8\x06\xa1\x27\xec\x06\xab\x25\xff\x06\x5b\x28\x07\x07\xfe\x27\xf2\x06\x02\x26\x0b\x07\xab\x28\x02\x07\x50\x28\xf9\x06\x00\x26\x14\x07\xd3\x28\x0e\x07\x27\x28\x01\x07\xe6\x25\xfd\x06\xd6\x28\xf9\x06\x0f\x28\xec\x06\xe6\x25\x00\x07\x82\x28\x02\x07\xb1\x27\xe7\x06\x7f\x25\xfc\x06\x3a\x28\xf9\x06\xa9\x27\xee\x06\x4c\x25\x00\x07\xa0\x28\xf4\x06\x1b\x28\xf4\x06\xed\x25\x01\x07\xa3\x28\x00\x07\x0f\x28\xec\x06\xee\x25\x05\x07\xcb\x28\xf9\x06\xe0\x27\xf2\x06\xe5\x25\x02\x07\xbc\x28\xff\x06\xef\x27\xf4\x06\x9d\x25\x01\x07\xd3\x28\x00\x07\x2a\x28\xfa\x06\xcb\x25\x12\x07\xcd\x28\x00\x07\x7e\x27\xfb\x06\x5b\x25\x02\x07\xe0\x28\xfa\x06\x38\x27\xf8\x06\x29\x25\xff\x06\xde\x28\xf5\x06\xdc\x27\xf7\x06\xa3\x25\xfd\x06\xef\x28\xf7\x06\x3b\x28\xf9\x06\xd1\x25\xfd\x06\x02\x29\xf9\x06\x13\x28\xd9\x06\xc9\x25\x11\x07\x19\x29\x07\x07\xe4\x27\xfa\x06\xec\x25\x0c\x07\xec\x28\x05\x07\x31\x28\xf8\x06\xbe\x25\xfd\x06\xee\x28\xf5\x06\x0b\x28\xf5\x06\xe7\x25\xf3\x06\xc8\x28\xe5\x06\x97\x27\xf6\x06\xa1\x25\x06\x07\xd8\x28\x04\x07\xf7\x27\xec\x06\xd8\x25\x07\x07\x2b\x29\xfa\x06\x0f\x28\xf8\x06\x21\x26\xfc\x06\x2d\x29\xf5\x06\x1b\x28\xe8\x06\x07\x26\x0f\x07\xfc\x28\xfb\x06\x04\x28\xf3\x06\x21\x26\x10\x07\x47\x29\xf8\x06\x1c\x28\xfe\x06\xf0\x25\x00\x07\x0d\x29\x05\x07\x42\x28\xf8\x06\x24\x26\x0d\x07\xc2\x28\xfb\x06\x0b\x28\x01\x07\xd8\x25\x0b\x07\xfb\x28\x00\x07\xd5\x27\xf2\x06\xf4\x25\x15\x07\xf1\x28\x0d\x07\x43\x28\xf9\x06\x45\x26\x0d\x07\xe1\x28\x06\x07\x49\x28\x12\x07\x0f\x26\x08\x07\x01\x29\xed\x06\xfe\x27\xf8\x06\x0b\x26\x02\x07\xae\x28\xf9\x06\xe4\x27\xf3\x06\xf2\x25\x12\x07\xaf\x28\xfb\x06\xca\x27\x00\x07\x07\x26\x02\x07\x99\x28\x06\x07\x96\x27\xfb\x06\xac\x25\x06\x07\x77\x28\xfc\x06\x87\x27\xfd\x06\xa3\x25\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x09\x07\xe6\x28\x08\x07\x22\x28\xf9\x06\x47\x26\x08\x07\x07\x29\x07\x07\x3a\x28\x02\x07\x48\x26\x16\x07\x30\x29\x0b\x07\x1c\x28\x03\x07\x45\x26\x15\x07\x2a\x29\x0c\x07\x29\x28\x00\x07\x45\x26\xfa\x06\xea\x28\xfa\x06\x20\x28\xf6\x06\xf2\x25\xff\x06\x6b\x28\xf6\x06\xb4\x27\xec\x06\x9a\x25\xf5\x06\x81\x28\xea\x06\x82\x27\xec\x06\x8e\x25\x09\x07\x1a\x29\x00\x07\x0c\x28\xf3\x06\x2f\x26\x04\x07\x23\x29\xfc\x06\x25\x28\xfa\x06\x41\x26\xf1\x06\x49\x29\xe5\x06\x35\x28\xeb\x06\x2c\x26\x0b\x07\xb0\x29\xfa\x06\x67\x28\xfe\x06\x65\x26\x15\x07\x42\x29\x12\x07\x5d\x28\x04\x07\x4f\x26\x04\x07\x57\x29\xf9\x06\x1e\x28\xf8\x06\x42\x26\xf6\x06\x03\x29\xeb\x06\xdc\x27\xf5\x06\xfd\x25\x0f\x07\x79\x29\x0e\x07\x4b\x28\xfb\x06\x6a\x26\x16\x07\xa6\x29\x08\x07\x6c\x28\xf2\x06\x6a\x26\xfb\x06\xe5\x29\xf8\x06\x35\x28\xe9\x06\x20\x26\x0f\x07\xbe\x29\xfd\x06\x18\x28\xf3\x06\x14\x26\x13\x07\xa3\x29\xf9\x06\x68\x28\x03\x07\x6f\x26\x1e\x07\x1f\x29\x15\x07\xf9\x27\x1b\x07\x15\x26\x53\x07\x51\x28\x46\x07\x3b\x27\x45\x07\xb7\x25\x61\x07\x66\x28\x5d\x07\x79\x27\x52\x07\x5b\x25\x31\x07\x44\x28\x25\x07\xfe\x26\x1c\x07\x08\x25\x49\x06\x32\x28\x41\x06\xdb\x26\x36\x06\xc2\x23\x37\x06\xec\x27\x27\x06\x74\x26\x2b\x06\x8e\x23\xc4\x06\x75\x27\xbc\x06\xce\x26\xa3\x06\x78\x24\x3c\x07\xe8\x27\x36\x07\xe3\x26\x39\x07\x50\x25\x39\x07\x87\x28\x16\x07\x50\x27\x1c\x07\xbc\x25\x09\x07\xbc\x28\xf3\x06\xc1\x27\xe8\x06\xc6\x25\xd5\x06\xd2\x28\xd3\x06\x9b\x27\xdb\x06\xbc\x25\xd5\x06\xee\x28\xcf\x06\xd5\x27\xbf\x06\xc3\x25\xd8\x06\x3a\x29\xd0\x06\xae\x27\xc5\x06\xf0\x25\xd7\x06\x0a\x29\xd4\x06\xb6\x27\xd8\x06\x2e\x26\xdf\x06\x0f\x29\xc7\x06\xbf\x27\xca\x06\xf2\x25\xf9\x06\x18\x29\xe2\x06\xc2\x27\xdc\x06\xe7\x25\xe4\x06\xf5\x28\xcc\x06\xb7\x27\xd1\x06\x31\x26\xda\x06\x13\x29\xdf\x06\x01\x28\xca\x06\xcb\x25\xdc\x06\x5a\x29\xca\x06\xf9\x27\xd7\x06\xec\x25\xdb\x06\xe1\x28\xda\x06\xbd\x27\xcc\x06\xbb\x25\xe6\x06\x85\x28\xe3\x06\xf6\x27\xdb\x06\xcb\x25\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xcf\x06\xb8\x28\xc0\x06\x97\x27\xc9\x06\xc7\x25\xdf\x06\x8c\x28\xdc\x06\xda\x27\xdd\x06\xee\x25\xd7\x06\x8e\x28\xdd\x06\xea\x27\xd0\x06\xe4\x25\xf7\x06\xad\x28\xe7\x06\xb7\x27\xd8\x06\x12\x26\xf0\x06\xb2\x28\xdd\x06\x2e\x28\xea\x06\xbc\x25\xe5\x06\x3f\x28\xea\x06\xdb\x27\xcb\x06\xa2\x25\xee\x06\x68\x28\xe3\x06\x9f\x27\xde\x06\x95\x25\xe2\x06\x4d\x28\xd7\x06\x7e\x27\xdf\x06\xae\x25\xdf\x06\x70\x28\xd3\x06\xbb\x27\xbd\x06\xab\x25\xd5\x06\xa9\x28\xcd\x06\xb1\x27\xd4\x06\xac\x25\xe2\x06\x00\x29\xde\x06\xd5\x27\xc7\x06\xe6\x25\xcd\x06\x00\x29\xc6\x06\xf3\x27\xc3\x06\xc7\x25\xd8\x06\x8b\x28\xe0\x06\xa2\x27\xce\x06\xde\x25\xe4\x06\x3b\x28\xdb\x06\x6b\x27\xe0\x06\xbc\x25\xce\x06\x56\x28\xcd\x06\x74\x27\xd6\x06\x78\x25\xea\x06\x26\x28\xe8\x06\x72\x27\xde\x06\x79\x25\xe7\x06\x37\x28\xde\x06\x68\x27\xcf\x06\x72\x25\xd1\x06\x48\x28\xd8\x06\x6e\x27\xc8\x06\xa5\x25\xe0\x06\xba\x28\xce\x06\x57\x27\xd6\x06\x59\x25\xbf\x06\x72\x28\xb3\x06\x8b\x27\xd6\x06\x57\x25\xd8\x06\x08\x28\xd2\x06\x6e\x27\xcd\x06\x49\x25\xcd\x06\x0a\x28\xc6\x06\x54\x27\xc5\x06\x7f\x25\xdc\x06\x0a\x28\xd9\x06\x6f\x27\xd1\x06\x55\x25\xcc\x06\x32\x28\xb8\x06\x54\x27\xc5\x06\x52\x25\xda\x06\x67\x28\xce\x06\x57\x27\xce\x06\x58\x25\xe5\x06\xa8\x28\xdb\x06\x72\x27\xd0\x06\x95\x25\xc9\x06\x7c\x28\xc3\x06\x79\x27\xc2\x06\x69\x25\xcd\x06\x36\x28\xd9\x06\x5e\x27\xc7\x06\x65\x25\xd2\x06\x14\x28\xc5\x06\x66\x27\xc6\x06\x49\x25\xdb\x06\x14\x28\xdc\x06\x5b\x27\xcc\x06\x4d\x25\xd3\x06\x03\x28\xd2\x06\x6f\x27\xcd\x06\x5b\x25\xc5\x06\x13\x28\xd2\x06\x24\x27\xc8\x06\x48\x25\xc2\x06\x32\x28\xbe\x06\x5b\x27\xc6\x06\x6d\x25\xc5\x06\x18\x28\xc2\x06\x4f\x27\xcc\x06\x88\x25\xca\x06\xb7\x27\xd1\x06\x62\x27\xd7\x06\x64\x25\xc9\x06\x9d\x27\xcc\x06\x26\x27\xc2\x06\x28\x25\xc3\x06\xea\x27\xb5\x06\x0e\x27\xcc\x06\x4a\x25\xd9\x06\xe3\x27\xd9\x06\x1e\x27\xcf\x06\x7e\x25\xcf\x06\x13\x28\xd0\x06\x30\x27\xbf\x06\x22\x25\xda\x06\xc6\x27\xd5\x06\x2f\x27\xd2\x06\x4c\x25\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xaf\x06\xaf\x27\xaf\x06\x3f\x27\xc9\x06\x29\x25\xe2\x06\x91\x27\xe2\x06\x12\x27\xd8\x06\x1f\x25\xb5\x06\x2f\x28\xaf\x06\x00\x27\xc7\x06\xfc\x24\xdb\x06\x84\x27\xc8\x06\xef\x26\xc5\x06\xf8\x24\xd2\x06\x80\x27\xd1\x06\xb7\x26\xd0\x06\x14\x25\xbd\x06\xa5\x27\xc2\x06\x13\x27\xca\x06\xf5\x24\xd4\x06\x8b\x27\xcb\x06\xc7\x26\xc4\x06\xdb\x24\xcd\x06\x4e\x27\xcd\x06\x9b\x26\xc5\x06\x64\x24\xd1\x06\xda\x27\xcb\x06\xf6\x26\xc0\x06\xa4\x24\xda\x06\xa5\x27\xde\x06\x03\x27\xc2\x06\xb0\x24\xc0\x06\x7c\x27\xc5\x06\xaf\x26\xc2\x06\xb7\x24\xe0\x06\xaa\x27\xd3\x06\x0e\x27\xc7\x06\xe2\x24\xc4\x06\x98\x27\xc0\x06\xfc\x26\xd2\x06\x1f\x25\xd8\x06\xd7\x27\xd2\x06\xd3\x26\xd3\x06\x16\x25\xca\x06\xa2\x27\xc2\x06\xfb\x26\xb9\x06\xed\x24\xd2\x06\xd3\x27\xd1\x06\x00\x27\xcb\x06\x05\x25\xd8\x06\xaa\x27\xd1\x06\x10\x27\xc5\x06\x04\x25\xda\x06\xa2\x27\xdc\x06\xbb\x26\xd6\x06\xfe\x24\xd0\x06\xe0\x27\xc6\x06\xee\x26\xbc\x06\xf5\x24\xd2\x06\xb4\x27\xd7\x06\x2b\x27\xcb\x06\xee\x24\xd3\x06\xc9\x27\xd0\x06\x24\x27\xc7\x06\x1e\x25\xd7\x06\x20\x28\xc6\x06\x4e\x27\xd3\x06\x1d\x25\xd9\x06\xe8\x27\xda\x06\x40\x27\xd0\x06\x05\x25\xe5\x06\x9a\x27\xcf\x06\x38\x27\xcc\x06\x1b\x25\xbf\x06\x19\x28\xb9\x06\x18\x27\xc4\x06\x31\x25\xbe\x06\xa8\x27\xc5\x06\x22\x27\xc6\x06\xf6\x24\xdf\x06\x0b\x28\xdc\x06\x7d\x27\xce\x06\x0f\x25\xd5\x06\x0b\x28\xd3\x06\x63\x27\xdb\x06\x28\x25\xcc\x06\x29\x28\xcd\x06\x2b\x27\xce\x06\x21\x25\xdc\x06\x4d\x28\xd5\x06\x4e\x27\xd3\x06\x04\x25\xde\x06\x11\x28\xd9\x06\x18\x27\xd0\x06\x12\x25\xe0\x06\x08\x28\xde\x06\x28\x27\xd4\x06\x00\x25\xdb\x06\x04\x28\xd5\x06\xf2\x26\xcb\x06\xed\x24\xce\x06\x08\x28\xcc\x06\x00\x27\xd3\x06\x10\x25\xdf\x06\x13\x28\xd8\x06\x30\x27\xd7\x06\x17\x25\xe0\x06\x29\x28\xce\x06\x57\x27\xc2\x06\xdc\x24\xc8\x06\x2b\x28\xca\x06\x62\x27\xd1\x06\xfa\x24\xd7\x06\xf6\x27\xd2\x06\x0a\x27\xc6\x06\xf9\x24\xc3\x06\x13\x28\xca\x06\x70\x27\xd5\x06\x18\x25\xd8\x06\xc6\x27\xca\x06\x28\x27\xcd\x06\x00\x25\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xce\x06\xe7\x27\xc7\x06\x04\x27\xcc\x06\xf4\x24\xd8\x06\xea\x27\xde\x06\x66\x27\xd3\x06\x31\x25\xcc\x06\x0d\x28\xc5\x06\x3a\x27\xc3\x06\x1a\x25\xcd\x06\xc6\x27\xc2\x06\xfa\x26\xc9\x06\x21\x25\xd5\x06\xcd\x27\xdd\x06\x24\x27\xcf\x06\x0c\x25\xdc\x06\xe8\x27\xd1\x06\x2b\x27\xce\x06\x1f\x25\xd7\x06\xf7\x27\xd8\x06\x52\x27\xc5\x06\x1f\x25\xd9\x06\x1c\x28\xd2\x06\x68\x27\xcd\x06\x16\x25\xd9\x06\x52\x28\xd9\x06\x52\x27\xd5\x06\x73\x25\xca\x06\x88\x28\xc7\x06\xbd\x27\xd5\x06\x62\x25\xdb\x06\x86\x28\xd5\x06\xd9\x27\xc6\x06\x73\x25\xdc\x06\x72\x28\xd4\x06\x9d\x27\xcd\x06\x73\x25\xd4\x06\x2b\x28\xdd\x06\xa1\x27\xc7\x06\x13\x25\xce\x06\xb9\x27\xcc\x06\x1e\x27\xd1\x06\x35\x25\xed\x06\x29\x28\xe1\x06\x8a\x27\xcd\x06\x26\x25\xcf\x06\x70\x28\xbf\x06\x97\x27\xd5\x06\x44\x25\xe1\x06\x8a\x28\xd6\x06\xa1\x27\xd0\x06\x62\x25\xeb\x06\xa0\x28\xdf\x06\x97\x27\xd6\x06\x47\x25\xd9\x06\x0d\x28\xca\x06\x6a\x27\xc2\x06\x0b\x25\xe2\x06\x02\x28\xcd\x06\xf3\x26\xda\x06\x23\x25\xd9\x06\xfd\x27\xdf\x06\x23\x27\xc9\x06\xe3\x24\xcd\x06\xcd\x27\xce\x06\x1a\x27\xca\x06\x03\x25\xd8\x06\xef\x27\xe0\x06\x22\x27\xda\x06\x0e\x25\xe7\x06\xd5\x27\xd9\x06\x4e\x27\xd4\x06\x13\x25\xe4\x06\x11\x28\xdb\x06\x36\x27\xc9\x06\x31\x25\xd6\x06\xce\x27\xce\x06\x14\x27\xcb\x06\x32\x25\xd6\x06\xde\x27\xc8\x06\xfb\x26\xcb\x06\x16\x25\xd2\x06\x90\x27\xd2\x06\xf4\x26\xcb\x06\x0f\x25\xd2\x06\xdd\x27\xd3\x06\x0f\x27\xcb\x06\xe9\x24\xce\x06\x79\x27\xd0\x06\xc0\x26\xcc\x06\xd4\x24\xc2\x06\x22\x28\xb7\x06\xd6\x26\xd2\x06\xc9\x24\xd5\x06\xe2\x27\xc9\x06\x04\x27\xd7\x06\x00\x25\xd8\x06\x0c\x28\xda\x06\xff\x26\xc7\x06\xd4\x24\xe1\x06\x3a\x28\xdb\x06\x22\x27\xd8\x06\xd8\x24\xd2\x06\xef\x27\xcc\x06\xce\x26\xc6\x06\xd0\x24\xd1\x06\x52\x28\xce\x06\xfa\x26\xbb\x06\xbb\x24\xcb\x06\x88\x28\xcc\x06\x03\x28\xcc\x06\xcd\x24\xda\x06\x62\x28\xd1\x06\x57\x27\xd1\x06\xd3\x24\xe3\x06\x1c\x29\xd6\x06\x52\x27\xcd\x06\x52\x25\xd8\x06\x7f\x29\xbd\x06\x07\x27\xce\x06\x60\x25\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe0\x06\x26\x29\xd4\x06\x22\x27\xd6\x06\x77\x25\xee\x06\xc8\x28\xe4\x06\x66\x27\xd3\x06\x0c\x25\xdf\x06\x3b\x28\xdd\x06\x68\x27\xcb\x06\xf4\x24\xd5\x06\xf4\x27\xd1\x06\x5f\x27\xcb\x06\xfe\x24\xd6\x06\xfe\x27\xd1\x06\x1b\x27\xc8\x06\xe0\x24\xd9\x06\x34\x28\xd6\x06\x68\x27\xc2\x06\x1a\x25\xde\x06\x37\x28\xd4\x06\x7a\x27\xd9\x06\x60\x25\xe7\x06\x67\x28\xda\x06\x28\x27\xd8\x06\x2e\x25\xd6\x06\x21\x28\xc7\x06\x3c\x27\xcc\x06\x12\x25\xce\x06\xb6\x27\xcc\x06\xf3\x27\xc9\x06\xf5\x24\xd8\x06\xf5\x27\xda\x06\x36\x27\xc7\x06\x2d\x25\xdd\x06\x12\x28\xcc\x06\x6e\x27\xc2\x06\x17\x25\xd1\x06\x25\x28\xc5\x06\xa2\x27\xcd\x06\x26\x25\xdc\x06\x17\x28\xd2\x06\x67\x27\xd8\x06\x35\x25\xcf\x06\x0e\x28\xc5\x06\x42\x27\xc8\x06\x53\x25\xe9\x06\xa6\x27\xd8\x06\x5e\x27\xd6\x06\x0b\x25\xd6\x06\x33\x28\xd2\x06\x3a\x27\xe3\x06\x1e\x25\xe1\x06\x21\x28\xe1\x06\xba\x27\xd4\x06\x2a\x25\xd9\x06\x4f\x28\xce\x06\x58\x27\xda\x06\x2e\x25\xea\x06\x15\x28\xe6\x06\x58\x27\xd6\x06\x10\x25\xd7\x06\x7e\x28\xdd\x06\x91\x27\xd7\x06\x68\x25\xd1\x06\x52\x28\xbf\x06\x32\x27\xd8\x06\x95\x25\xe4\x06\x09\x28\xda\x06\x3b\x27\xcf\x06\x18\x25\xe0\x06\x3e\x28\xdc\x06\x22\x27\xd4\x06\x14\x25\xd2\x06\x12\x28\xca\x06\x2e\x27\xc6\x06\x64\x25\xec\x06\x3f\x28\xdf\x06\x36\x27\xd1\x06\xf8\x24\xd8\x06\xd4\x27\xdf\x06\xed\x27\xc5\x06\x18\x25\xdb\x06\xed\x27\xd1\x06\x57\x27\xd0\x06\x38\x25\xd5\x06\xeb\x27\xc6\x06\x81\x27\xd5\x06\x55\x25\xd4\x06\xec\x27\xda\x06\x5e\x27\xce\x06\x56\x25\xe8\x06\x4b\x28\xd1\x06\x50\x27\xd2\x06\x43\x25\xde\x06\x9d\x28\xd6\x06\x4b\x27\xc8\x06\x2c\x25\xe9\x06\xf3\x28\xdf\x06\x79\x27\xd2\x06\x46\x25\xd7\x06\x31\x29\xdb\x06\xbf\x27\xc9\x06\x47\x25\xd8\x06\x60\x29\xd1\x06\xd3\x27\xcf\x06\x31\x25\xdf\x06\x12\x29\xce\x06\xcf\x27\xd6\x06\x73\x25\xd1\x06\x67\x28\xc7\x06\x86\x27\xc6\x06\x17\x25\xd4\x06\xe0\x27\xe4\x06\x91\x27\xd3\x06\x1b\x25\xde\x06\xe6\x27\xde\x06\x55\x27\xd9\x06\x28\x25\xd3\x06\x27\x28\xd5\x06\x60\x27\xc6\x06\xfd\x24\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xde\x06\x65\x28\xd3\x06\xff\x26\xd9\x06\x23\x25\xdf\x06\x81\x28\xd7\x06\x17\x27\xda\x06\x1d\x25\xc8\x06\xf5\x28\xb7\x06\x48\x27\xd3\x06\x2a\x25\xe4\x06\x0b\x29\xcf\x06\x3c\x27\xd9\x06\x2c\x25\xe2\x06\x4d\x29\xd0\x06\xf9\x26\xcf\x06\x22\x25\xd4\x06\x2b\x29\xc2\x06\x03\x27\xc9\x06\x00\x25\xc3\x06\x7b\x28\xbe\x06\x39\x27\xd0\x06\xb9\x24\xe3\x06\x68\x28\xe1\x06\x46\x27\xcd\x06\xb5\x24\xe5\x06\x83\x28\xcd\x06\x2d\x27\xd7\x06\x00\x25\xe6\x06\x15\x29\xdb\x06\x32\x27\xc2\x06\x1d\x25\xcb\x06\x1d\x29\xb9\x06\x71\x27\xc8\x06\xc9\x24\xc9\x06\x75\x28\xc8\x06\x51\x27\xce\x06\x9d\x24\xdd\x06\x8d\x28\xce\x06\x3d\x27\xc9\x06\x9d\x24\xc5\x06\x6d\x28\xb8\x06\x26\x27\xcd\x06\x6f\x24\xd9\x06\x3a\x28\xcd\x06\x18\x27\xd2\x06\x8d\x24\xd5\x06\x2a\x28\xcf\x06\xeb\x26\xcb\x06\xb7\x24\xd9\x06\x4d\x28\xd1\x06\x4d\x27\xd1\x06\x9d\x24\xd6\x06\x56\x28\xc6\x06\x28\x27\xc7\x06\xa4\x24\xd5\x06\x76\x28\xd0\x06\xd8\x26\xce\x06\x82\x24\xe6\x06\x48\x28\xd4\x06\xd5\x26\xc9\x06\x10\x24\xd1\x06\x51\x28\xc8\x06\x83\x26\xc7\x06\xc9\x23\xda\x06\x22\x28\xce\x06\x5c\x26\xba\x06\x82\x23\xcf\x06\x3d\x28\xc7\x06\x42\x26\xbf\x06\xb2\x23\xd5\x06\x19\x28\xd3\x06\x8e\x26\xbc\x06\xee\x23\xc6\x06\xca\x27\xc9\x06\xed\x26\xdb\x06\x69\x24\xcc\x06\xb7\x27\xd8\x06\x0d\x27\xcf\x06\x87\x24\xe2\x06\x07\x28\xd7\x06\x1f\x27\xd2\x06\xb3\x24\xda\x06\xd9\x27\xcc\x06\x17\x27\xc1\x06\x92\x24\xd7\x06\xe6\x27\xd2\x06\x05\x27\xd4\x06\xaa\x24\xd4\x06\x15\x28\xd0\x06\x25\x27\xd2\x06\xe7\x24\xdf\x06\x27\x28\xe6\x06\x2d\x27\xd8\x06\x21\x25\xdd\x06\x40\x28\xd7\x06\x70\x27\xd3\x06\x25\x25\xbd\x06\x52\x28\xb2\x06\x6b\x27\xcb\x06\x55\x25\xbb\x06\x4d\x28\xbe\x06\x75\x27\xc4\x06\x1d\x25\xd9\x06\xed\x27\xd7\x06\x19\x27\xcf\x06\x08\x25\xc9\x06\xf0\x27\xbd\x06\x0f\x27\xcb\x06\xe0\x24\xf0\x06\x10\x28\xdf\x06\x1a\x27\xd3\x06\xe0\x24\xdd\x06\x0e\x28\xe3\x06\x4a\x27\xce\x06\x03\x25\xd9\x06\x25\x28\xd5\x06\xfe\x26\xcc\x06\xc2\x24\xaf\x06\xc3\x27\xa8\x06\x13\x27\xc8\x06\xeb\x24\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xcf\x06\xac\x27\xd0\x06\xf1\x26\xbe\x06\xc1\x24\xde\x06\xd4\x27\xd2\x06\xef\x26\xcf\x06\xdc\x24\xd5\x06\x0a\x28\xc9\x06\xc1\x26\xc5\x06\x13\x25\xe5\x06\x1d\x28\xd7\x06\xb2\x26\xc8\x06\xd3\x24\xe9\x06\x21\x28\xc7\x06\x11\x27\xc9\x06\xcb\x24\xe5\x06\x7c\x28\xe2\x06\x3d\x27\xda\x06\x06\x25\xe8\x06\x63\x28\xda\x06\x20\x27\xd8\x06\xe8\x24\xda\x06\x14\x28\xd7\x06\xbe\x26\xcd\x06\xaf\x24\xb4\x06\x9b\x27\xc0\x06\x03\x27\xc5\x06\xfb\x24\xe2\x06\xf0\x27\xd5\x06\x15\x27\xca\x06\xba\x24\xe7\x06\x35\x28\xe3\x06\x24\x27\xcc\x06\xe4\x24\xe5\x06\xd8\x28\xda\x06\x0e\x27\xdb\x06\x31\x25\xdf\x06\x1c\x29\xdb\x06\x6c\x27\xd5\x06\x3a\x25\xf0\x06\x18\x29\xda\x06\x79\x27\xde\x06\x55\x25\xcf\x06\xdb\x28\xb4\x06\x3b\x27\xd7\x06\x1e\x25\xd7\x06\x6a\x28\xce\x06\xf7\x26\xd4\x06\x03\x25\xde\x06\x48\x28\xd2\x06\x22\x27\xcd\x06\x11\x25\xce\x06\x0d\x28\xc8\x06\x1c\x27\xca\x06\xf5\x24\xc6\x06\x4b\x28\xc3\x06\x45\x27\xc1\x06\xe3\x24\xe7\x06\xcc\x28\xe2\x06\x59\x27\xe4\x06\x53\x25\xe1\x06\xe0\x28\xdf\x06\xa6\x27\xda\x06\x62\x25\xd6\x06\x8c\x28\xc9\x06\x6f\x27\xc0\x06\x17\x25\xde\x06\x72\x28\xc4\x06\x36\x27\xde\x06\xd6\x24\xe5\x06\x5a\x28\xdf\x06\x1c\x27\xd4\x06\xb7\x24\xe0\x06\x31\x28\xd1\x06\x2e\x27\xcf\x06\x78\x24\xc9\x06\x9d\x27\xc7\x06\xfc\x26\xc2\x06\x5e\x24\xdf\x06\xe5\x27\xdc\x06\xfc\x26\xd8\x06\x9f\x24\xcf\x06\x8c\x28\xc4\x06\xf1\x26\xb7\x06\x54\x24\xdd\x06\xea\x27\xd2\x06\xaf\x26\xbe\x06\x2b\x24\xe7\x06\x02\x28\xd6\x06\xcd\x26\xc0\x06\xca\x23\xc5\x06\xd2\x27\xbf\x06\xab\x26\xc6\x06\x05\x24\xe0\x06\x2f\x28\xce\x06\xd8\x26\xc6\x06\x32\x24\xd3\x06\x1b\x28\xd3\x06\xdc\x26\xc2\x06\x93\x24\xdd\x06\x31\x28\xd9\x06\x09\x27\xd1\x06\x91\x24\xcc\x06\x3c\x28\xce\x06\x41\x27\xc8\x06\xc8\x24\xcc\x06\xe5\x27\xc9\x06\x2a\x27\xcb\x06\xd8\x24\xdb\x06\x1e\x28\xd4\x06\xfc\x26\xd6\x06\xad\x24\xe9\x06\x2a\x28\xd8\x06\xc9\x26\xcd\x06\xc1\x24\xdc\x06\xc4\x27\xcc\x06\xb6\x26\xcf\x06\x80\x24\xde\x06\xdd\x27\xd3\x06\xcf\x26\xd8\x06\x75\x24\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xd9\x06\x25\x28\xd1\x06\x0f\x27\xc7\x06\x7a\x24\xd7\x06\x35\x28\xd5\x06\x05\x27\xcf\x06\xaf\x24\xdf\x06\x1d\x28\xd1\x06\xd2\x26\xc5\x06\x5f\x24\xd7\x06\xfc\x27\xc8\x06\xaf\x26\xd8\x06\x75\x24\xde\x06\xd4\x27\xd7\x06\xc1\x26\xd1\x06\x89\x24\xcc\x06\xb7\x27\xbc\x06\xca\x26\xcd\x06\x66\x24\xdf\x06\xe4\x27\xd4\x06\xf0\x26\xd7\x06\x95\x24\xdc\x06\xe1\x27\xc9\x06\xbc\x26\xc7\x06\x9d\x24\xd4\x06\x07\x28\xd2\x06\xd9\x26\xd3\x06\x87\x24\xdb\x06\xd6\x27\xd3\x06\xa2\x26\xc6\x06\x1f\x24\xe2\x06\xf0\x27\xc9\x06\xed\x26\xd3\x06\x85\x24\xdd\x06\xcc\x27\xd3\x06\xa7\x26\xc4\x06\x4c\x24\xe3\x06\x89\x27\xd5\x06\xad\x26\xcc\x06\x26\x24\xd0\x06\x07\x28\xcc\x06\xf0\x26\xbf\x06\x22\x24\xd5\x06\xd3\x27\xcd\x06\xa3\x26\xb7\x06\x28\x24\xca\x06\xfe\x27\xc4\x06\xfe\x26\xc9\x06\x42\x24\xbe\x06\x09\x28\xbc\x06\x09\x27\xc4\x06\x94\x24\xd0\x06\xdf\x27\xce\x06\x02\x27\xc1\x06\x75\x24\xcb\x06\xfa\x27\xc1\x06\x17\x27\xbe\x06\xad\x24\xdc\x06\xb4\x27\xd6\x06\xc9\x26\xd0\x06\x70\x24\xd5\x06\xa9\x27\xca\x06\xc2\x26\xc4\x06\x5f\x24\xd7\x06\xdb\x27\xd5\x06\xcf\x26\xcd\x06\xbe\x24\xd9\x06\xe4\x27\xd4\x06\xbc\x26\xc4\x06\xbb\x24\xe2\x06\x09\x28\xcb\x06\xac\x26\xc7\x06\xd4\x24\xe5\x06\xed\x27\xd6\x06\xaa\x26\xcb\x06\xa0\x24\xc5\x06\xb6\x27\xb8\x06\xad\x26\xc7\x06\xb0\x24\xd4\x06\x74\x27\xce\x06\xc1\x26\xd2\x06\xa4\x24\xd1\x06\xbe\x27\xce\x06\x94\x26\xd2\x06\xa7\x24\xd6\x06\x97\x27\xca\x06\xde\x26\xc9\x06\xc4\x24\xc8\x06\xf9\x27\xb2\x06\xcc\x26\xc2\x06\xf8\x24\xb5\x06\x25\x28\xb7\x06\x05\x27\xd1\x06\x1c\x25\xd9\x06\xea\x27\xc5\x06\xb3\x26\xcf\x06\xc1\x24\xc5\x06\x99\x27\xb8\x06\x24\x27\xc2\x06\xaf\x24\xd7\x06\x4b\x27\xd7\x06\xdf\x26\xd4\x06\xbc\x24\xc3\x06\x8f\x27\xb7\x06\xfa\x26\xbf\x06\xb0\x24\xce\x06\x81\x27\xc8\x06\x14\x27\xca\x06\xe8\x24\xd3\x06\xc6\x27\xd9\x06\x14\x27\xcd\x06\xde\x24\xe1\x06\x15\x28\xd9\x06\xef\x26\xd6\x06\xf8\x24\xd2\x06\xe1\x27\xcd\x06\x24\x27\xc5\x06\x06\x25\xd0\x06\xd0\x27\xcd\x06\x34\x27\xd5\x06\x0c\x25\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xbe\x06\x99\x27\xc9\x06\x45\x27\xbb\x06\xbf\x24\xe0\x06\xa0\x27\xdf\x06\x39\x27\xd2\x06\xc7\x24\xd6\x06\x17\x28\xd7\x06\xa2\x27\xca\x06\xc6\x24\xe9\x06\x02\x28\xe1\x06\x5b\x27\xd8\x06\xf4\x24\xd7\x06\x82\x28\xd1\x06\xab\x27\xcd\x06\x30\x25\xed\x06\x9e\x28\xe8\x06\xbe\x27\xdd\x06\x1b\x25\xcd\x06\x6e\x28\xc1\x06\x7b\x27\xd2\x06\x20\x25\xdf\x06\x5a\x28\xd3\x06\x4f\x27\xcf\x06\xdc\x24\xe5\x06\x50\x28\xcf\x06\x4b\x27\xd3\x06\xe1\x24\xc8\x06\x69\x28\xbe\x06\x78\x27\xc7\x06\x02\x25\xdd\x06\x0b\x28\xd0\x06\x3f\x27\xcf\x06\x1e\x25\xe1\x06\x87\x28\xcf\x06\x43\x27\xc0\x06\x04\x25\xd4\x06\xba\x28\xd1\x06\x84\x27\xcc\x06\x40\x25\xd6\x06\x87\x28\xd8\x06\x91\x27\xc9\x06\x40\x25\xe2\x06\x6b\x28\xd2\x06\x6c\x27\xd9\x06\x23\x25\xdd\x06\xbe\x28\xdc\x06\x75\x27\xd0\x06\x17\x25\xdc\x06\xd5\x28\xbe\x06\x5e\x27\xbb\x06\x22\x25\xd7\x06\x08\x29\xd9\x06\x88\x27\xc9\x06\x12\x25\xd5\x06\x4a\x29\xd3\x06\x90\x27\xdc\x06\x5b\x25\xdf\x06\x7a\x29\xcd\x06\x97\x27\xcc\x06\x9c\x25\xe3\x06\x4e\x29\xcd\x06\x8b\x27\xc6\x06\x37\x25\xe4\x06\x21\x29\xe3\x06\x6e\x27\xd2\x06\x3f\x25\xf1\x06\x2b\x29\xd9\x06\xa1\x27\xcf\x06\x44\x25\xcb\x06\x0f\x29\xca\x06\x56\x27\xce\x06\x18\x25\xf3\x06\x65\x29\xde\x06\x7a\x27\xce\x06\x4e\x25\xee\x06\x14\x29\xe6\x06\xc3\x27\xe3\x06\x35\x25\xea\x06\x45\x29\xd2\x06\xe9\x27\xd1\x06\x60\x25\xe2\x06\x95\x29\xce\x06\xdb\x27\xc7\x06\x4f\x25\xe5\x06\xd6\x28\xd7\x06\x7a\x27\xdb\x06\x25\x25\xde\x06\xb9\x28\xcd\x06\x6e\x27\xd1\x06\xfc\x24\xf1\x06\xdb\x28\xdd\x06\x8b\x27\xdc\x06\xf6\x24\xd9\x06\x49\x29\xc6\x06\x6e\x27\xd7\x06\x4b\x25\xd4\x06\xdf\x28\xc1\x06\x52\x27\xdb\x06\x99\x25\xe2\x06\xc8\x28\xcf\x06\x48\x27\xd3\x06\x4c\x25\xd5\x06\x72\x28\xc6\x06\x6c\x27\xd7\x06\x6f\x25\xd9\x06\x24\x28\xd6\x06\x36\x27\xdc\x06\x36\x25\xd1\x06\xae\x28\xb6\x06\xfe\x26\xc6\x06\x48\x24\x00\x00\xa9\x14\x00\x00\x5d\x15\x00\x00\xf8\x15\x00\x00\xa9\x14\x00\x00\x5d\x15\x00\x00\xf9\x15\x00\x00\xa9\x14\x00\x00\x5d\x15\x00\x00\xfb\x15\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x00\x00\xb9\x14\x00\x00\x5d\x15\x00\x00\x0d\x16\x00\x00\xb9\x14\x00\x00\x5e\x15\x00\x00\x0d\x16\x00\x00\xb9\x14\x00\x00\x5f\x15\x6a\x08\xff\xff\xe2\x06\x39\x28\xe7\x06\x74\x26\xbf\x06\xad\x23\xee\x06\xb0\x27\xde\x06\x7a\x26\xcf\x06\x3c\x24\xe4\x06\xfe\x27\xd9\x06\x8b\x26\xd7\x06\xdb\x24\xee\x06\x18\x28\xdc\x06\x90\x26\xd6\x06\xea\x24\xe3\x06\xc1\x28\xd3\x06\xc6\x26\xd6\x06\xfc\x24\xf8\x06\x3c\x28\xe1\x06\x1a\x26\xd4\x06\x82\x24\xdb\x06\x88\x28\xd1\x06\x54\x26\xd4\x06\x80\x24\xec\x06\x55\x28\xe1\x06\x6e\x26\xdf\x06\x4e\x25\xe9\x06\x3d\x28\xcf\x06\x4a\x26\xd4\x06\xba\x24\xdf\x06\x4d\x28\xd5\x06\x39\x26\xd2\x06\xa5\x24\xdc\x06\x46\x28\xd9\x06\x65\x26\xd3\x06\xa1\x24\xec\x06\x83\x28\xdb\x06\x50\x26\xd6\x06\x8e\x24\xd7\x06\x4e\x28\xc3\x06\xeb\x25\xcf\x06\x1d\x24\xec\x06\x29\x28\xdb\x06\x30\x26\xd6\x06\x29\x24\xed\x06\xc3\x28\xe1\x06\x4a\x26\xcf\x06\x9f\x24\xf1\x06\x70\x28\xde\x06\x4f\x26\xcf\x06\xac\x24\xdc\x06\x55\x28\xe1\x06\xa1\x26\xc9\x06\x7c\x24\xd3\x06\x59\x28\xbf\x06\x44\x26\xd2\x06\x61\x24\xe4\x06\x06\x28\xd5\x06\x71\x26\xd3\x06\x87\x24\xec\x06\x1c\x28\xda\x06\x53\x26\xdb\x06\x42\x24\xe8\x06\x9a\x27\xcf\x06\xc2\x25\xc7\x06\xe5\x23\xf7\x06\x35\x28\xe0\x06\x2d\x26\xd5\x06\x1d\x24\xe6\x06\x3a\x28\xdd\x06\x48\x26\xc9\x06\x61\x24\xe4\x06\xa5\x27\xd1\x06\x18\x26\xcd\x06\x6c\x24\xfe\x06\xd4\x27\xf3\x06\x59\x26\xdd\x06\x75\x24\xee\x06\xd0\x27\xd7\x06\x79\x26\xd4\x06\x3c\x24\xe6\x06\x84\x27\xda\x06\x21\x26\xcc\x06\x14\x24\xdc\x06\x5f\x27\xd4\x06\xd9\x25\xc9\x06\xe0\x23\xdf\x06\xec\x27\xdd\x06\x77\x26\xc6\x06\x31\x24\xf7\x06\x24\x28\xda\x06\x3a\x26\xca\x06\x80\x24\xdc\x06\xd8\x27\xc7\x06\x6f\x26\xc2\x06\x87\x24\xed\x06\xee\x27\xe7\x06\x58\x26\xd7\x06\x82\x24\xed\x06\x8d\x27\xe3\x06\x76\x26\xdb\x06\x64\x24\xe9\x06\x94\x27\xd6\x06\x6e\x26\xd9\x06\x71\x24\xe7\x06\x1f\x27\xe4\x06\x1b\x26\xd1\x06\x1f\x24\xef\x06\x29\x27\xe5\x06\x61\x26\xd0\x06\x35\x24\xdf\x06\x8c\x27\xd9\x06\x83\x26\xd3\x06\x5c\x24\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xf0\x06\x6b\x27\xd8\x06\x41\x26\xd3\x06\x6e\x24\xd4\x06\x2e\x27\xd8\x06\x86\x26\xbe\x06\x7c\x24\xf6\x06\x5a\x27\xe1\x06\x31\x26\xef\x06\x9b\x24\xde\x06\x5a\x27\xdb\x06\x5d\x26\xc6\x06\x96\x24\xe4\x06\x20\x27\xd2\x06\x0d\x26\xc9\x06\xfb\x23\xdc\x06\x25\x27\xd3\x06\x21\x26\xcb\x06\x30\x24\xed\x06\xb4\x27\xd4\x06\xac\x26\xce\x06\xb3\x24\xe8\x06\xf8\x27\xe1\x06\x75\x26\xcb\x06\x87\x24\xeb\x06\x00\x28\xe8\x06\x6e\x26\xd5\x06\x8c\x24\xe9\x06\xd4\x27\xdf\x06\xa1\x26\xdb\x06\xd5\x24\xd6\x06\xaa\x27\xc8\x06\x95\x26\xd1\x06\xe0\x24\xe6\x06\xec\x27\xd5\x06\x2c\x26\xd3\x06\x93\x24\xe5\x06\xf1\x27\xdf\x06\x4e\x26\xcf\x06\xbb\x24\xe6\x06\x18\x28\xd6\x06\x84\x26\xd2\x06\xdd\x24\xd9\x06\xfa\x27\xd6\x06\x8d\x26\xcd\x06\xb8\x24\xeb\x06\xf0\x27\xd7\x06\xa0\x26\xc0\x06\x82\x24\xe3\x06\xb9\x27\xdb\x06\x4e\x26\xc7\x06\xcc\x24\xe6\x06\xbd\x27\xd5\x06\x6c\x26\xcd\x06\xa6\x24\xe7\x06\x5b\x27\xd2\x06\x03\x26\xc9\x06\xfe\x23\xea\x06\xba\x27\xd6\x06\x1b\x26\xc4\x06\x5f\x24\xe4\x06\xd2\x27\xd4\x06\x1c\x26\xca\x06\xc9\x24\xf7\x06\x32\x28\xd9\x06\x3a\x26\xc9\x06\x96\x24\xe3\x06\xd0\x27\xd5\x06\xaf\x26\xcf\x06\xa9\x24\xe0\x06\xa7\x27\xd7\x06\x49\x26\xcb\x06\x9b\x24\xea\x06\xeb\x27\xd4\x06\x1b\x26\xd0\x06\xad\x24\xe6\x06\xb8\x27\xde\x06\x12\x26\xcb\x06\x34\x24\xd4\x06\x82\x27\xc0\x06\xf7\x25\xba\x06\x51\x24\xec\x06\x7a\x27\xd9\x06\x75\x26\xce\x06\xac\x24\xd3\x06\xbc\x27\xca\x06\x53\x26\xbe\x06\x85\x24\xe5\x06\xdb\x27\xd0\x06\x51\x26\xcc\x06\x8f\x24\xee\x06\x3b\x28\xc9\x06\x2d\x26\xd0\x06\x85\x24\xe8\x06\xec\x27\xe0\x06\x55\x26\xcd\x06\x87\x24\xd8\x06\x18\x28\xc6\x06\x64\x26\xda\x06\xb2\x24\xf7\x06\xca\x27\xe1\x06\x00\x26\xce\x06\x3b\x24\xeb\x06\x3d\x28\xdd\x06\x3c\x26\xc5\x06\x3b\x24\xed\x06\xe9\x27\xe0\x06\x2c\x26\xd6\x06\x8a\x24\xeb\x06\xaa\x27\xd7\x06\x4c\x26\xdb\x06\xcc\x24\xf1\x06\x31\x28\xd7\x06\x7f\x26\xc9\x06\xbc\x24\xf3\x06\x67\x28\xdc\x06\x7c\x26\xd1\x06\xc6\x24\xe5\x06\x1c\x28\xdf\x06\xc2\x26\xd8\x06\xe3\x24\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xdd\x06\x68\x28\xd6\x06\xb2\x26\xd0\x06\xa3\x24\xed\x06\x91\x28\xdf\x06\x83\x26\xcb\x06\xaa\x24\xe8\x06\x59\x28\xcd\x06\x81\x26\xd2\x06\xe2\x24\xf0\x06\xf4\x27\xe1\x06\x7b\x26\xd1\x06\xc7\x24\xec\x06\xe3\x27\xdb\x06\x65\x26\xda\x06\xc8\x24\xf4\x06\xf0\x27\xdd\x06\x6f\x26\xd9\x06\xb3\x24\xec\x06\x1d\x28\xde\x06\x77\x26\xd0\x06\xec\x24\xe9\x06\xf0\x27\xd4\x06\x58\x26\xd5\x06\x77\x24\xe8\x06\x08\x28\xd7\x06\x43\x26\xcf\x06\x76\x24\xea\x06\x27\x28\xd8\x06\x7d\x26\xcf\x06\xd0\x24\xe9\x06\x18\x28\xca\x06\x44\x26\xcc\x06\xbc\x24\xf7\x06\x27\x28\xe2\x06\x73\x26\xd5\x06\xaf\x24\xde\x06\xd7\x27\xd9\x06\x78\x26\xcf\x06\xbb\x24\xed\x06\x07\x28\xdc\x06\x6c\x26\xd4\x06\xc8\x24\xd4\x06\xd0\x27\xcd\x06\x97\x26\xc5\x06\xcf\x24\xdf\x06\x1d\x28\xd0\x06\x5d\x26\xd3\x06\xa5\x24\xeb\x06\x2a\x28\xdd\x06\xb2\x26\xdc\x06\xcf\x24\xea\x06\x3c\x28\xda\x06\x60\x26\xc7\x06\x92\x24\xd5\x06\x3a\x28\xc4\x06\x64\x26\xbf\x06\x68\x24\xef\x06\xba\x27\xdb\x06\x10\x26\xd4\x06\x80\x24\xe5\x06\xc9\x27\xd3\x06\x1b\x26\xcd\x06\x74\x24\xe8\x06\x6f\x27\xce\x06\xc8\x25\xd6\x06\x70\x24\xec\x06\x36\x27\xda\x06\x96\x25\xd9\x06\x21\x24\xcd\x06\xd1\x27\xc5\x06\xe4\x25\xc7\x06\x37\x24\xee\x06\x5a\x28\xdf\x06\xe1\x25\xc7\x06\x65\x24\xf9\x06\x67\x28\xe1\x06\x13\x26\xd7\x06\x44\x24\xeb\x06\x21\x28\xdc\x06\x01\x26\xd7\x06\x83\x24\xf4\x06\xf1\x27\xe6\x06\x35\x26\xd7\x06\x9b\x24\xef\x06\xa5\x27\xd3\x06\xf5\x25\xd1\x06\x37\x24\xe4\x06\x68\x27\xd5\x06\x98\x25\xc4\x06\xfb\x23\xe6\x06\x2a\x27\xca\x06\xdb\x25\xc6\x06\x0d\x24\xde\x06\x80\x27\xca\x06\x00\x26\xcc\x06\x28\x24\xec\x06\x94\x27\xd2\x06\xe5\x25\xdd\x06\x42\x24\xe4\x06\xc5\x27\xde\x06\xff\x25\xd7\x06\x50\x24\xea\x06\xf4\x27\xdf\x06\x2b\x26\xca\x06\x32\x24\xe5\x06\xde\x27\xca\x06\x43\x26\xc4\x06\x1c\x24\xed\x06\x8e\x27\xdc\x06\xf7\x25\xcc\x06\xc6\x23\xf6\x06\xc4\x27\xdd\x06\xf5\x25\xc9\x06\xf7\x23\xeb\x06\xb5\x27\xd1\x06\xe5\x25\xc5\x06\x06\x24\xe7\x06\x45\x27\xd3\x06\x2b\x26\xc9\x06\xe5\x23\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xec\x06\xdc\x26\xe5\x06\x21\x26\xd9\x06\xf7\x23\xe9\x06\x35\x27\xda\x06\xf5\x25\xcd\x06\xf0\x23\xf2\x06\x86\x27\xcd\x06\xc8\x25\xd0\x06\x2b\x24\xdf\x06\x8d\x27\xd1\x06\xcd\x25\xd6\x06\xaf\x23\xe3\x06\x5d\x27\xdc\x06\xcc\x25\xcc\x06\xc0\x23\xef\x06\x5b\x27\xe5\x06\x48\x26\xdc\x06\x56\x24\xe3\x06\x51\x27\xdf\x06\x38\x26\xd3\x06\x7b\x24\xf3\x06\x6a\x27\xeb\x06\x43\x26\xd3\x06\x36\x24\xeb\x06\x74\x27\xdc\x06\x09\x26\xd1\x06\x3b\x24\xee\x06\x64\x27\xd4\x06\xc2\x25\xd1\x06\x36\x24\xe0\x06\x2d\x27\xdb\x06\xe7\x25\xce\x06\xff\x23\xea\x06\x1c\x27\xe3\x06\xcc\x25\xd2\x06\x06\x24\xed\x06\xc4\x27\xd3\x06\xf5\x25\xd4\x06\x58\x24\xf8\x06\x8b\x27\xe8\x06\xe1\x25\xe8\x06\x6a\x24\xfc\x06\x23\x27\xe0\x06\xf9\x25\xd9\x06\x24\x24\xf6\x06\x78\x27\xe2\x06\xe1\x25\xd1\x06\x36\x24\xe5\x06\x8a\x27\xec\x06\xdc\x25\xd0\x06\x40\x24\xfc\x06\xc0\x27\xe4\x06\xd8\x25\xd4\x06\x18\x24\xe7\x06\x70\x27\xde\x06\x62\x25\xd1\x06\xf4\x23\xf2\x06\xc7\x27\xde\x06\xed\x25\xc6\x06\xff\x23\xe2\x06\xb8\x27\xcd\x06\xb4\x25\xb9\x06\x28\x24\xf5\x06\x6c\x27\xe0\x06\xfd\x25\xd5\x06\x25\x24\xe5\x06\x37\x27\xe4\x06\xd8\x25\xce\x06\x3d\x24\xee\x06\xe2\x26\xe7\x06\xe5\x25\xca\x06\x1c\x24\xd2\x06\xf0\x26\xd2\x06\xbd\x25\xca\x06\xe2\x23\xe2\x06\x05\x27\xd9\x06\x39\x25\xc7\x06\x87\x23\xe6\x06\x6a\x27\xe1\x06\xa1\x25\xca\x06\xf9\x23\xe5\x06\x63\x27\xd8\x06\xc5\x25\xc8\x06\xf1\x23\xeb\x06\x2d\x27\xca\x06\xa4\x25\xcb\x06\xf7\x23\xdf\x06\x24\x27\xd5\x06\xec\x25\xc7\x06\xd6\x23\xe6\x06\x05\x27\xd9\x06\xb9\x25\xca\x06\xea\x23\xe2\x06\x0f\x27\xca\x06\x86\x25\xd5\x06\xfb\x23\xea\x06\xe9\x26\xd6\x06\x90\x25\xd4\x06\xcf\x23\xee\x06\x28\x27\xd5\x06\x71\x25\xd2\x06\xa0\x23\xfc\x06\xbf\x27\xe4\x06\x74\x25\xd9\x06\x15\x24\xdb\x06\x1e\x28\xc3\x06\xb4\x25\xbc\x06\x3a\x24\xf1\x06\xaa\x27\xdb\x06\x62\x25\xd8\x06\x3d\x24\xe9\x06\x66\x27\xdd\x06\x8d\x25\xd5\x06\x16\x24\xf6\x06\x43\x27\xdf\x06\x6c\x25\xca\x06\xf8\x23\xdb\x06\xe6\x26\xd7\x06\x64\x25\xc2\x06\xb5\x23\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xd9\x06\xa0\x26\xda\x06\x58\x25\xc5\x06\x85\x23\xea\x06\x6e\x26\xe5\x06\xe9\x25\xd5\x06\xff\x23\xed\x06\xa5\x26\xe9\x06\xc9\x25\xdb\x06\x0d\x24\xed\x06\x42\x27\xe0\x06\xa5\x25\xd2\x06\x00\x24\xf2\x06\xa0\x27\xd2\x06\x7a\x25\xd1\x06\xf8\x23\xe7\x06\xdf\x27\xd5\x06\xb1\x25\xc2\x06\xe1\x23\xe4\x06\x23\x27\xc5\x06\x70\x25\xc4\x06\xab\x23\xee\x06\xda\x26\xe3\x06\x38\x25\xce\x06\x4b\x23\xe5\x06\x30\x27\xd2\x06\x8a\x25\xc9\x06\xd2\x23\xe3\x06\xd1\x26\xd1\x06\xbc\x25\xd5\x06\xa2\x23\xf6\x06\x8d\x26\xe6\x06\x9c\x25\xde\x06\xb1\x23\xde\x06\x2c\x26\xe4\x06\xb0\x25\xcf\x06\x9c\x23\xf0\x06\x7d\x26\xd7\x06\x94\x25\xc6\x06\x7f\x23\xe2\x06\x53\x26\xcd\x06\x76\x25\xbb\x06\x8c\x23\xde\x06\x88\x26\xc5\x06\x2c\x25\xbd\x06\x18\x23\xe5\x06\xe5\x26\xe7\x06\xa1\x25\xc6\x06\xa7\x23\xe5\x06\xb9\x26\xde\x06\xb5\x25\xcc\x06\xcc\x23\xe7\x06\x92\x26\xd5\x06\x8d\x25\xd7\x06\xd2\x23\xf4\x06\xe2\x26\xe0\x06\xa9\x25\xda\x06\xda\x23\xf6\x06\x8f\x26\xd8\x06\x81\x25\xd9\x06\xc9\x23\xe2\x06\x70\x26\xe0\x06\xa4\x25\xd2\x06\xa3\x23\xe4\x06\x34\x26\xda\x06\x72\x25\xd3\x06\x74\x23\xe9\x06\x84\x26\xd5\x06\x7c\x25\xc8\x06\x56\x23\xda\x06\x8a\x26\xc8\x06\x9e\x25\xc6\x06\xb9\x23\xdb\x06\x62\x26\xd7\x06\xa9\x25\xc2\x06\xc5\x23\xdf\x06\xbf\x26\xc7\x06\xc6\x25\xd8\x06\xd7\x23\xe3\x06\xab\x26\xdd\x06\xdb\x25\xd2\x06\xd8\x23\xee\x06\xbb\x26\xe5\x06\x27\x26\xd8\x06\xf5\x23\xe2\x06\xbe\x26\xe7\x06\xf0\x25\xca\x06\xab\x23\xde\x06\x9b\x26\xd7\x06\xbc\x25\xd3\x06\xc1\x23\xed\x06\xb0\x26\xdf\x06\x05\x26\xd0\x06\xff\x23\xe4\x06\xa4\x26\xd7\x06\xf8\x25\xca\x06\xba\x23\xe2\x06\xa0\x26\xe5\x06\xc5\x25\xd3\x06\xc0\x23\xe2\x06\xa0\x26\xd7\x06\xb9\x25\xcc\x06\xe2\x23\xef\x06\x9e\x26\xda\x06\xdf\x25\xc1\x06\xbd\x23\xed\x06\xa7\x26\xdf\x06\xb1\x25\xd8\x06\xb9\x23\xe4\x06\x98\x26\xe0\x06\xa8\x25\xc1\x06\x92\x23\xf2\x06\xeb\x26\xd3\x06\xb0\x25\xc9\x06\xec\x23\xf5\x06\x8f\x27\xd7\x06\xd4\x25\xd9\x06\xdf\x23\xf2\x06\xd5\x27\xd4\x06\xa4\x25\xc8\x06\xee\x23\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfc\x06\x10\x28\xe1\x06\xc1\x25\xdb\x06\x36\x24\xf8\x06\xb6\x27\xe6\x06\xc4\x25\xdc\x06\x0d\x24\xde\x06\x18\x27\xca\x06\xd1\x25\xce\x06\xf8\x23\xdb\x06\x01\x27\xd1\x06\x9a\x25\xbe\x06\x82\x23\xea\x06\x73\x27\xd5\x06\xcc\x25\xd0\x06\x1a\x24\xe8\x06\x71\x27\xce\x06\xb5\x25\xd7\x06\x3d\x24\xe0\x06\xee\x26\xd4\x06\xb4\x25\xcf\x06\xea\x23\xf0\x06\xd8\x26\xf0\x06\xfb\x25\xdc\x06\x79\x24\xe5\x06\xa4\x26\xd6\x06\xdf\x25\xd9\x06\xc0\x23\xe5\x06\xe1\x26\xe1\x06\xec\x25\xd8\x06\xed\x23\xf2\x06\x08\x27\xed\x06\xeb\x25\xdd\x06\xc9\x23\xf8\x06\xe7\x26\xdf\x06\xf7\x25\xcd\x06\xcb\x23\xec\x06\xde\x26\xdb\x06\xfd\x25\xe1\x06\xee\x23\xe0\x06\xbf\x26\xdf\x06\xdb\x25\xdb\x06\xd7\x23\xef\x06\xe7\x26\xdf\x06\xa0\x25\xcd\x06\x0a\x24\xe7\x06\xab\x26\xe1\x06\xf5\x25\xc5\x06\xbe\x23\xef\x06\x9b\x26\xe0\x06\xdc\x25\xdd\x06\xd2\x23\xed\x06\xa9\x26\xd1\x06\x7a\x25\xc9\x06\x7e\x23\xdd\x06\xab\x26\xd2\x06\xc1\x25\xd4\x06\xc7\x23\xeb\x06\xf1\x26\xe3\x06\x9c\x25\xcc\x06\xba\x23\xe0\x06\x91\x26\xdb\x06\x04\x26\xc9\x06\xad\x23\xed\x06\x01\x27\xe2\x06\xb7\x25\xd0\x06\xb4\x23\xe9\x06\xb2\x26\xde\x06\xe1\x25\xcf\x06\xad\x23\xf3\x06\xe6\x26\xe0\x06\xba\x25\xcd\x06\xc9\x23\xe3\x06\xc3\x26\xcd\x06\x91\x25\xc9\x06\x9e\x23\xe3\x06\xe0\x26\xd6\x06\x94\x25\xc6\x06\x83\x23\xec\x06\xf3\x26\xde\x06\x04\x26\xcd\x06\x12\x24\xeb\x06\xc5\x26\xe0\x06\x0d\x26\xce\x06\x0e\x24\xe5\x06\xb9\x26\xd6\x06\xd2\x25\xcb\x06\xc8\x23\xe1\x06\xee\x26\xd3\x06\xe7\x25\xd3\x06\xe0\x23\xdf\x06\xbd\x26\xdf\x06\x23\x26\xc9\x06\xdb\x23\xeb\x06\xb2\x26\xe3\x06\xe4\x25\xbf\x06\xad\x23\xeb\x06\xab\x26\xd7\x06\x9d\x25\xca\x06\x9e\x23\xce\x06\x40\x27\xc8\x06\x6e\x26\xb7\x06\x3b\x24\xdc\x06\x74\x26\xdc\x06\xba\x25\xcd\x06\xab\x23\xe7\x06\xad\x26\xdd\x06\x9f\x25\xc7\x06\xa1\x23\xef\x06\x7a\x26\xe5\x06\x9c\x25\xd9\x06\x87\x23\xee\x06\x73\x26\xdd\x06\x90\x25\xce\x06\x94\x23\xe4\x06\x97\x26\xd7\x06\xbe\x25\xc6\x06\x6f\x23\xe0\x06\x49\x26\xda\x06\x52\x25\xbd\x06\xfc\x22\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xd5\x06\x7c\x26\xcb\x06\xdd\x25\xc0\x06\x33\x23\xe8\x06\x8d\x26\xdf\x06\xbb\x25\xc5\x06\x75\x23\xe4\x06\x80\x26\xda\x06\x93\x25\xd1\x06\x54\x23\xe2\x06\x71\x26\xe2\x06\x90\x25\xce\x06\x79\x23\xe5\x06\x9c\x26\xe3\x06\xbc\x25\xcf\x06\xd2\x23\xe8\x06\xb2\x26\xdb\x06\xb4\x25\xca\x06\x9a\x23\xd7\x06\x73\x26\xd1\x06\x9c\x25\xce\x06\x6f\x23\xed\x06\xaf\x26\xe5\x06\x7e\x25\xd8\x06\x79\x23\xcd\x06\xba\x26\xc6\x06\xaa\x25\xce\x06\x8d\x23\xee\x06\x8f\x26\xdc\x06\xa3\x25\xd9\x06\x94\x23\xf6\x06\x63\x26\xe1\x06\x6d\x25\xdb\x06\x60\x23\xdd\x06\x6c\x26\xda\x06\x71\x25\xd0\x06\x46\x23\xe0\x06\x82\x26\xe5\x06\x56\x25\xcb\x06\x72\x23\xe9\x06\x34\x26\xd9\x06\x37\x25\xc9\x06\x1e\x23\xd3\x06\x4c\x26\xc6\x06\x52\x25\xb6\x06\x35\x23\xec\x06\x65\x26\xdd\x06\x60\x25\xc5\x06\x5b\x23\xe9\x06\x56\x26\xe2\x06\x76\x25\xd2\x06\x66\x23\xe3\x06\x1f\x26\xd8\x06\x8a\x25\xd2\x06\x3f\x23\xe8\x06\x12\x26\xdc\x06\x4d\x25\xcf\x06\x68\x23\xe2\x06\x29\x26\xd4\x06\x6a\x25\xc6\x06\x33\x23\xeb\x06\x03\x26\xe4\x06\xeb\x24\xd3\x06\xdf\x22\xdf\x06\xe1\x25\xe0\x06\xda\x24\xca\x06\xfe\x22\xe6\x06\x17\x26\xd0\x06\x30\x25\xc4\x06\x4e\x23\xf2\x06\x2d\x26\xe3\x06\x4c\x25\xd8\x06\x48\x23\xd8\x06\x1d\x26\xda\x06\x42\x25\xcb\x06\x0e\x23\xe7\x06\xf5\x25\xd9\x06\x31\x25\xd2\x06\x37\x23\xe6\x06\x10\x26\xda\x06\x56\x25\xc8\x06\x49\x23\xe2\x06\xf0\x25\xd6\x06\x0f\x25\xc6\x06\xee\x22\xdd\x06\xae\x25\xce\x06\xe6\x24\xc2\x06\xdf\x22\xde\x06\x38\x26\xc7\x06\x44\x25\xc5\x06\x3f\x23\xea\x06\x21\x26\xe6\x06\x6e\x25\xcf\x06\x38\x23\xd6\x06\x14\x26\xdf\x06\x51\x25\xc2\x06\x40\x23\xec\x06\x14\x26\xe0\x06\x66\x25\xcc\x06\x47\x23\xec\x06\x2b\x26\xdb\x06\x38\x25\xcd\x06\x60\x23\xe4\x06\x21\x26\xe4\x06\x7e\x25\xd4\x06\x2b\x23\xd5\x06\xaf\x25\xc8\x06\xfd\x24\xc3\x06\x1c\x23\xe1\x06\x3b\x26\xd1\x06\x5f\x25\xc5\x06\x5b\x23\xe9\x06\x1a\x26\xe4\x06\xa9\x25\xdc\x06\x95\x23\xf0\x06\x37\x26\xe0\x06\x85\x25\xcd\x06\x7a\x23\xf1\x06\x3d\x26\xdb\x06\x96\x25\xd6\x06\x64\x23\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe7\x06\x5b\x26\xe2\x06\x90\x25\xd1\x06\x8e\x23\xea\x06\x6d\x26\xe2\x06\xa8\x25\xd1\x06\x80\x23\xeb\x06\x03\x26\xe1\x06\x32\x25\xd9\x06\x01\x23\xef\x06\x4f\x26\xe4\x06\x6b\x25\xdd\x06\xa3\x23\xe6\x06\x6f\x26\xe1\x06\x6d\x25\xd5\x06\xbe\x23\xeb\x06\x84\x26\xe6\x06\x9c\x25\xd2\x06\x68\x23\xe3\x06\x4d\x26\xdf\x06\x73\x25\xd1\x06\x7e\x23\xe5\x06\xa8\x26\xd0\x06\x51\x25\xcf\x06\x66\x23\xfc\x06\x6b\x26\xdf\x06\x6b\x25\xdc\x06\x70\x23\xfc\x06\x1f\x26\xe3\x06\x21\x25\xc8\x06\xef\x22\xdb\x06\x6d\x26\xcd\x06\x50\x25\xcf\x06\x52\x23\xf7\x06\x97\x26\xeb\x06\x91\x25\xd1\x06\xab\x23\xd6\x06\x60\x26\xcc\x06\x7e\x25\xc3\x06\x87\x23\xe6\x06\x78\x26\xe5\x06\x88\x25\xca\x06\x75\x23\xfc\x06\x83\x26\xe4\x06\x5b\x25\xcf\x06\xa0\x23\xda\x06\x62\x26\xd7\x06\x5f\x25\xdc\x06\xc9\x23\xe6\x06\x40\x26\xe0\x06\x4f\x25\xcc\x06\x52\x23\xdf\x06\x2f\x26\xd8\x06\x23\x25\xdf\x06\x4a\x23\xeb\x06\x4d\x26\xe7\x06\x7d\x25\xdd\x06\x6c\x23\xd6\x06\xa7\x26\xd5\x06\xca\x25\xbc\x06\x7c\x23\xf4\x06\xc7\x26\xe3\x06\xa6\x25\xdd\x06\x7a\x23\xed\x06\xb1\x26\xe6\x06\x9f\x25\xda\x06\xbb\x23\xea\x06\xb6\x26\xd6\x06\x92\x25\xd4\x06\x99\x23\xee\x06\xcb\x26\xcf\x06\xa1\x25\xc5\x06\x78\x23\x03\x07\xac\x26\xec\x06\x83\x25\xdf\x06\x71\x23\xee\x06\xdf\x26\xe6\x06\xe3\x25\xd7\x06\xd1\x23\xee\x06\xb5\x26\xe9\x06\xb1\x25\xdb\x06\xf6\x23\xf4\x06\xac\x26\xdf\x06\xb0\x25\xe4\x06\xe6\x23\xd7\x06\x27\x27\xd1\x06\xee\x25\xd5\x06\x32\x24\xef\x06\xd5\x26\xe5\x06\xe2\x25\xd2\x06\xf5\x23\xdf\x06\x0a\x27\xd9\x06\x34\x26\xcc\x06\x16\x24\xfc\x06\xf0\x26\xe6\x06\xf6\x25\xdb\x06\xca\x23\xec\x06\x29\x27\xef\x06\x22\x26\xc9\x06\x12\x24\xef\x06\x51\x27\xe6\x06\xdd\x25\xdd\x06\x0d\x24\xfc\x06\x36\x27\xe8\x06\x14\x26\xd1\x06\x12\x24\xea\x06\x3d\x27\xdf\x06\xd9\x25\xd9\x06\xf2\x23\xeb\x06\x05\x27\xdf\x06\x3d\x26\xd8\x06\x3d\x24\xeb\x06\x15\x27\xed\x06\x39\x26\xdb\x06\x32\x24\xf1\x06\x33\x27\xe2\x06\xf5\x25\xd7\x06\xf1\x23\xfd\x06\x60\x27\xe8\x06\x50\x26\xcf\x06\x13\x24\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xed\x06\x8e\x27\xd4\x06\x3f\x26\xd4\x06\x4a\x24\xee\x06\x83\x27\xe3\x06\xfc\x25\xd7\x06\x49\x24\xf1\x06\x91\x27\xeb\x06\x49\x26\xe4\x06\x48\x24\xe9\x06\x74\x27\xe1\x06\xd7\x25\xd7\x06\x3a\x24\xf9\x06\x6b\x27\xe6\x06\xeb\x25\xd5\x06\xfb\x23\xf2\x06\x2b\x27\xe0\x06\x79\x25\xd6\x06\xe2\x23\xf8\x06\x4c\x27\xe0\x06\x95\x25\xda\x06\x02\x24\xe9\x06\x91\x27\xd8\x06\xe8\x25\xc5\x06\x33\x24\xe3\x06\x4d\x27\xd9\x06\x01\x26\xcc\x06\x0c\x24\xed\x06\x78\x27\xe5\x06\x04\x26\xd4\x06\x1c\x24\xe6\x06\x48\x27\xd4\x06\xaa\x25\xd8\x06\x3d\x24\x0a\x07\x5a\x27\xf8\x06\x9e\x25\xdb\x06\x1e\x24\x2f\x07\xef\x26\x1c\x07\xd0\x25\x23\x07\xd8\x23\x48\x07\x85\x26\x3f\x07\x19\x25\x30\x07\x29\x23\xe1\x06\x28\x26\xc1\x06\xf6\x24\xb6\x06\xde\x22\x2e\x06\x5d\x26\x17\x06\x46\x24\x1f\x06\xb6\x21\x3c\x06\xfc\x26\x22\x06\x09\x25\x1e\x06\x29\x22\xc9\x06\x1e\x26\xcc\x06\x49\x25\xba\x06\x34\x23\x37\x07\x69\x26\x2d\x07\x89\x25\x2e\x07\xb2\x23\x25\x07\xef\x26\x22\x07\xbd\x25\x14\x07\x30\x24\xf0\x06\x71\x27\xe4\x06\x45\x26\xf4\x06\x70\x24\xe8\x06\x16\x28\xd6\x06\x50\x26\xcc\x06\x7c\x24\xde\x06\x5c\x28\xd8\x06\x68\x26\xc9\x06\xa0\x24\xf0\x06\xc3\x27\xdb\x06\x40\x26\xcf\x06\xa1\x24\xe1\x06\x65\x27\xd8\x06\x50\x26\xc9\x06\x3d\x24\xe5\x06\x9b\x27\xd3\x06\x4c\x26\xcc\x06\x63\x24\xdf\x06\x81\x27\xdb\x06\x2d\x26\xcd\x06\x4c\x24\xe9\x06\x46\x27\xd4\x06\x19\x26\xd3\x06\x51\x24\xdc\x06\xc5\x27\xc8\x06\x3f\x26\xbf\x06\x5e\x24\xd0\x06\xf6\x27\xc0\x06\x5d\x26\xc2\x06\x58\x24\xe8\x06\x5a\x27\xe4\x06\x20\x26\xce\x06\x67\x24\xd5\x06\x67\x27\xc5\x06\x33\x26\xcf\x06\x7d\x24\xd6\x06\x7f\x27\xd0\x06\x25\x26\xca\x06\x07\x24\xe1\x06\x71\x27\xda\x06\x39\x26\xd0\x06\x39\x24\xd2\x06\x39\x27\xd0\x06\x7c\x26\xc6\x06\x57\x24\xed\x06\x66\x27\xe6\x06\x34\x26\xd3\x06\x52\x24\xe8\x06\xa8\x27\xe1\x06\x49\x26\xca\x06\x84\x24\xd7\x06\x2c\x27\xcb\x06\x0f\x26\xd6\x06\x3e\x24\xde\x06\xee\x26\xd8\x06\x05\x26\xd0\x06\x18\x24\xd6\x06\x07\x27\xcb\x06\xdf\x25\xcb\x06\xf0\x23\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xd6\x06\xe0\x26\xcd\x06\xee\x25\xc2\x06\xac\x23\xd8\x06\xf8\x26\xd0\x06\xdf\x25\xc0\x06\xd6\x23\xd9\x06\xd3\x26\xd3\x06\x09\x26\xc7\x06\xd6\x23\xcf\x06\x13\x27\xd1\x06\x11\x26\xc0\x06\xed\x23\xcf\x06\xd9\x26\xcd\x06\xf3\x25\xc2\x06\xfa\x23\xcd\x06\xbd\x26\xcf\x06\x12\x26\xbd\x06\xb8\x23\xe6\x06\x9b\x26\xdc\x06\xca\x25\xc7\x06\xb3\x23\xbc\x06\xcf\x26\xad\x06\xc6\x25\xca\x06\x8f\x23\xd3\x06\x97\x26\xd5\x06\xc8\x25\xbf\x06\x9d\x23\xe0\x06\xde\x26\xd8\x06\xbb\x25\xcc\x06\x9f\x23\xe3\x06\x22\x27\xd5\x06\x17\x26\xcd\x06\x31\x24\xd0\x06\x12\x27\xc6\x06\x2b\x26\xc0\x06\xfc\x23\xde\x06\xa0\x26\xc7\x06\xba\x25\xc7\x06\xc2\x23\xdd\x06\x50\x26\xd4\x06\x6b\x25\xd4\x06\x80\x23\xdb\x06\x49\x26\xce\x06\x56\x25\xc3\x06\x60\x23\xdd\x06\x55\x26\xc4\x06\x59\x25\xc3\x06\x6d\x23\xe1\x06\x7b\x26\xd8\x06\x73\x25\xc5\x06\x59\x23\xcd\x06\x80\x26\xc2\x06\x83\x25\xb2\x06\x90\x23\xdc\x06\x6f\x26\xd0\x06\x48\x25\xc2\x06\x73\x23\xd0\x06\x0d\x26\xc8\x06\x15\x25\xc9\x06\x6b\x23\xd2\x06\x0f\x26\xd2\x06\x50\x25\xc7\x06\x61\x23\xc9\x06\x13\x26\xbb\x06\x54\x25\xce\x06\x77\x23\xca\x06\x59\x26\xbe\x06\x47\x25\xc1\x06\x67\x23\xe4\x06\x3a\x26\xd3\x06\x69\x25\xbe\x06\x52\x23\xd4\x06\x69\x26\xcd\x06\x8c\x25\xbc\x06\x7a\x23\xcb\x06\xe4\x26\xbf\x06\xf8\x25\xb3\x06\x15\x24\xd1\x06\x3a\x26\xcc\x06\x90\x25\xb9\x06\xa4\x23\xd7\x06\x16\x26\xd4\x06\x75\x25\xd0\x06\xab\x23\xd3\x06\x48\x26\xbc\x06\x65\x25\xbc\x06\x72\x23\xdb\x06\x35\x26\xda\x06\x84\x25\xc4\x06\x71\x23\xcf\x06\x7d\x26\xbd\x06\x9c\x25\xb8\x06\x70\x23\xd3\x06\x97\x26\xd1\x06\xe9\x25\xc8\x06\xc5\x23\xdc\x06\xe4\x26\xcf\x06\x22\x26\xc4\x06\xc3\x23\xca\x06\x7b\x26\xcc\x06\xd8\x25\xb4\x06\x88\x23\xc3\x06\x4d\x26\xd3\x06\x93\x25\xb6\x06\x9a\x23\xdf\x06\x5f\x26\xcd\x06\x81\x25\xb4\x06\x4a\x23\xcd\x06\x7b\x26\xd1\x06\x93\x25\xbb\x06\x4d\x23\xc6\x06\x5a\x26\xb8\x06\x90\x25\xb1\x06\xa6\x23\xc9\x06\xb2\x26\xb6\x06\xaf\x25\xc1\x06\xa1\x23\xc4\x06\xbf\x26\xb5\x06\xec\x25\xbe\x06\xd7\x23\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe2\x06\xc7\x26\xd8\x06\xd5\x25\xc7\x06\xb4\x23\xd3\x06\x5f\x26\xd4\x06\xa5\x25\xb6\x06\x5e\x23\xdc\x06\x3c\x26\xcc\x06\xa8\x25\xc4\x06\x86\x23\xc9\x06\x73\x26\xcb\x06\xa6\x25\xc5\x06\x8c\x23\xd5\x06\x66\x26\xd2\x06\xaf\x25\xc1\x06\x91\x23\xca\x06\x69\x26\xd0\x06\xbc\x25\xc7\x06\x89\x23\xd4\x06\xfb\x26\xc2\x06\xf2\x25\xb7\x06\xbb\x23\xd6\x06\xde\x26\xcb\x06\x02\x26\xb3\x06\x8a\x23\xcd\x06\x3c\x26\xc7\x06\x64\x25\xbf\x06\x89\x23\xcb\x06\x7f\x26\xc1\x06\x90\x25\xbe\x06\x67\x23\xd8\x06\x3a\x26\xc6\x06\x51\x25\xba\x06\x0e\x23\xd4\x06\x29\x26\xd8\x06\x63\x25\xc2\x06\x32\x23\xd0\x06\x36\x26\xcd\x06\x96\x25\xbc\x06\x22\x23\xd6\x06\xbe\x26\xc9\x06\x71\x25\xbc\x06\x47\x23\xc8\x06\x22\x27\xc8\x06\x1d\x26\xca\x06\xca\x23\xbf\x06\x81\x26\xa3\x06\xe5\x25\xb6\x06\x57\x23\xd2\x06\x61\x26\xcd\x06\x84\x25\xca\x06\x69\x23\xdd\x06\x40\x26\xd4\x06\x59\x25\xb1\x06\x24\x23\xd4\x06\x48\x26\xc7\x06\x7b\x25\xb0\x06\x2f\x23\xdf\x06\x74\x26\xcd\x06\x44\x25\xb7\x06\x67\x23\xb5\x06\x44\x26\xa6\x06\x97\x25\xbc\x06\x4b\x23\xdc\x06\xb5\x26\xd5\x06\xd5\x25\xc4\x06\x61\x23\xcd\x06\x9a\x26\xc3\x06\x86\x25\xad\x06\x38\x23\xcf\x06\x07\x26\xc7\x06\x16\x25\xb1\x06\x0d\x23\xbb\x06\x2c\x26\xbe\x06\x6b\x25\xbb\x06\x18\x23\xda\x06\xe2\x25\xd2\x06\x47\x25\xcf\x06\x3f\x23\xd9\x06\x36\x26\xd2\x06\x74\x25\xba\x06\x14\x23\xdb\x06\x4b\x26\xd1\x06\x6f\x25\xbc\x06\x57\x23\xd4\x06\x9f\x26\xcc\x06\x87\x25\xb2\x06\x69\x23\xce\x06\x74\x26\xcb\x06\x87\x25\xac\x06\x36\x23\xd0\x06\x54\x26\xbc\x06\x53\x25\xb5\x06\x32\x23\xd7\x06\xec\x25\xd0\x06\x16\x25\xc4\x06\x48\x23\xd6\x06\x02\x26\xc8\x06\x18\x25\xb4\x06\xef\x22\xd8\x06\x24\x26\xc0\x06\x10\x25\xb3\x06\xd9\x22\xd8\x06\xf5\x25\xcb\x06\x1a\x25\xc5\x06\x13\x23\xb6\x06\x6c\x26\xa9\x06\x54\x25\xb5\x06\xf3\x22\xb8\x06\x16\x26\xab\x06\x4d\x25\xc3\x06\xd4\x22\xe0\x06\xae\x25\xd8\x06\xfc\x24\xbd\x06\x66\x22\xd3\x06\xb1\x25\xc3\x06\xc2\x24\xb5\x06\x6f\x22\xcf\x06\xa1\x25\xce\x06\xb6\x24\xbc\x06\x78\x22\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xd4\x06\xba\x25\xcc\x06\xe5\x24\xb7\x06\xa0\x22\xce\x06\xb2\x25\xbc\x06\xe1\x24\xb2\x06\x9d\x22\xdb\x06\xf3\x25\xd1\x06\xf4\x24\xbc\x06\xbe\x22\xde\x06\x1d\x26\xc2\x06\xfa\x24\xc6\x06\xc5\x22\xdb\x06\xc1\x25\xca\x06\xaf\x24\xbb\x06\x9d\x22\xda\x06\x7e\x25\xd6\x06\xe5\x24\xc2\x06\x68\x22\xe2\x06\x63\x25\xd5\x06\xb1\x24\xc0\x06\x50\x22\xd8\x06\xb7\x25\xd5\x06\xb2\x24\xc3\x06\x7f\x22\xc3\x06\xbc\x25\xb4\x06\x30\x25\xc5\x06\x96\x22\xce\x06\xc7\x25\xc4\x06\x02\x25\xc8\x06\xad\x22\xda\x06\x3e\x26\xc6\x06\x39\x25\xbc\x06\x01\x23\xc6\x06\xbb\x25\xd2\x06\xbf\x24\xb2\x06\x77\x22\xbd\x06\xd2\x25\xb1\x06\xce\x24\xa3\x06\xb1\x22\xd1\x06\x57\x25\xbc\x06\xba\x24\xbc\x06\xb3\x22\xd3\x06\x90\x25\xbf\x06\xc0\x24\xc9\x06\x9f\x22\xe0\x06\x41\x25\xdf\x06\xe9\x24\xcc\x06\x88\x22\xd8\x06\x95\x25\xd1\x06\x30\x25\xca\x06\xca\x22\xdb\x06\x99\x25\xe1\x06\xee\x24\xc7\x06\xcd\x22\xcb\x06\x8e\x25\xc2\x06\x73\x24\xb9\x06\xaf\x22\xdd\x06\x71\x25\xc7\x06\x94\x24\xc0\x06\x9f\x22\xbe\x06\x52\x25\xaf\x06\xbf\x24\xc7\x06\xb2\x22\xdb\x06\x3b\x25\xcf\x06\x89\x24\xc4\x06\xc4\x22\xcb\x06\x7a\x25\xcd\x06\xac\x24\xc5\x06\xd0\x22\xe2\x06\x6b\x25\xd6\x06\x8d\x24\xc9\x06\xc1\x22\xd9\x06\x82\x25\xcd\x06\xbc\x24\xb5\x06\xc6\x22\xe8\x06\x8c\x25\xd0\x06\xcd\x24\xc9\x06\xd0\x22\xd1\x06\x91\x25\xbf\x06\xa3\x24\xbd\x06\x8b\x22\xdc\x06\xfb\x25\xd4\x06\x66\x24\xce\x06\xac\x22\xd0\x06\x90\x25\xbb\x06\xad\x24\xc5\x06\xcd\x22\xd8\x06\x7d\x25\xda\x06\xca\x24\xc6\x06\xd3\x22\xe4\x06\x26\x26\xd1\x06\x7a\x24\xc8\x06\xf3\x22\xf2\x06\x43\x27\xc5\x06\x81\x24\xcb\x06\x2c\x23\xdc\x06\xcc\x26\xc8\x06\x6f\x24\xc5\x06\x20\x23\xd2\x06\xe7\x25\xc3\x06\x80\x24\xbd\x06\xc7\x22\xda\x06\x5e\x25\xcd\x06\xb9\x24\xc0\x06\xb8\x22\xb4\x06\x76\x25\xab\x06\x74\x24\xcc\x06\xb1\x22\xcd\x06\x64\x25\xcd\x06\xb2\x24\xbf\x06\xb7\x22\xd9\x06\x96\x25\xd1\x06\x63\x24\xc9\x06\xda\x22\xc8\x06\x26\x26\xb5\x06\x98\x24\xbd\x06\xc6\x22\xd7\x06\xd3\x25\xcd\x06\xec\x24\xba\x06\xec\x22\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xdb\x06\x87\x25\xc7\x06\xb7\x24\xd4\x06\x0c\x23\xe7\x06\x62\x25\xd1\x06\x9b\x24\xc4\x06\xc8\x22\xd1\x06\x75\x25\xce\x06\x94\x24\xd2\x06\xf3\x22\xc4\x06\x2e\x25\xd0\x06\xfc\x24\xbb\x06\xbf\x22\xa8\x06\x64\x25\x94\x06\xec\x24\xbd\x06\xd4\x22\xcf\x06\x77\x25\xcc\x06\xde\x24\xc2\x06\xdf\x22\xd6\x06\xbb\x25\xd1\x06\xfc\x24\xc8\x06\xf5\x22\xdb\x06\x87\x25\xca\x06\xd6\x24\xcc\x06\xdc\x22\xce\x06\x7f\x25\xc3\x06\x91\x24\xb6\x06\xbe\x22\xd9\x06\x71\x25\xd3\x06\xda\x24\xcb\x06\xb2\x22\xcd\x06\x60\x25\xcb\x06\xbb\x24\xb7\x06\xac\x22\xdc\x06\xa2\x25\xce\x06\xd6\x24\xc2\x06\xac\x22\xe0\x06\xb6\x25\xc5\x06\x00\x25\xc3\x06\xbf\x22\xd7\x06\x5c\x26\xd3\x06\x73\x25\xc1\x06\x33\x23\xde\x06\x53\x26\xcb\x06\x34\x25\xb9\x06\x09\x23\xd3\x06\xbf\x25\xce\x06\xdb\x24\xb8\x06\xca\x22\xc0\x06\xc6\x25\xb3\x06\xd7\x24\xb3\x06\xb2\x22\xbb\x06\x7c\x25\xbe\x06\x2a\x25\xbd\x06\xcd\x22\xd7\x06\x97\x25\xd1\x06\xe8\x24\xbb\x06\xe6\x22\xd4\x06\x8e\x25\xcf\x06\x01\x25\xc2\x06\x18\x23\xd4\x06\x33\x26\xc1\x06\x3d\x25\xb2\x06\x50\x23\xd4\x06\xed\x25\xd2\x06\x3c\x25\xbe\x06\x3b\x23\xd9\x06\x04\x26\xd7\x06\x00\x25\xc1\x06\xfe\x22\xca\x06\xf5\x25\xcb\x06\xdd\x24\xb4\x06\x0a\x23\xd4\x06\x0b\x26\xd5\x06\xda\x24\xc6\x06\x03\x23\xd1\x06\x30\x26\xd0\x06\xc0\x24\xca\x06\xfe\x22\xd5\x06\xb4\x26\xc0\x06\xc7\x24\xc3\x06\x0d\x23\xe1\x06\xb5\x26\xd5\x06\x6a\x25\xc5\x06\x65\x23\xcc\x06\x51\x26\xc1\x06\xa9\x25\xd1\x06\x67\x23\xc9\x06\x70\x25\xaf\x06\x28\x25\xbe\x06\x12\x23\xc4\x06\x9b\x25\xc5\x06\xda\x24\xc3\x06\xde\x22\xd1\x06\xa0\x25\xc5\x06\xeb\x24\xc7\x06\xc8\x22\xcc\x06\x9e\x25\xc6\x06\x9f\x24\xbe\x06\xa6\x22\xda\x06\x96\x25\xce\x06\xab\x24\xc5\x06\xf1\x22\xb5\x06\x18\x26\xa7\x06\xa4\x24\xb2\x06\xc2\x22\xd4\x06\x4d\x26\xc5\x06\x7b\x24\xb6\x06\xf0\x22\xc0\x06\x3d\x26\xa8\x06\x3a\x24\xbd\x06\xc6\x22\xc2\x06\xed\x25\xac\x06\x5c\x24\xb9\x06\xaf\x22\xcb\x06\x67\x25\xc3\x06\x4c\x24\xc1\x06\xc2\x22\xcd\x06\x37\x25\xbd\x06\x8f\x24\xb3\x06\x9b\x22\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xd3\x06\x62\x25\xc1\x06\x9f\x24\xb9\x06\xa1\x22\xcd\x06\x0b\x26\xbc\x06\x8b\x24\xb6\x06\xe9\x22\xcf\x06\x40\x26\xc6\x06\xca\x24\xc0\x06\xfe\x22\xd3\x06\x96\x25\xd3\x06\x9f\x24\xb4\x06\x9d\x22\xd3\x06\x6e\x25\xba\x06\x55\x24\xb1\x06\xa4\x22\xcd\x06\x2b\x25\xc9\x06\x16\x24\xbe\x06\x58\x22\xc6\x06\x79\x25\xa8\x06\x1a\x24\xa7\x06\x6f\x22\xac\x06\xce\x24\xa1\x06\x35\x24\xbe\x06\x59\x22\xbd\x06\x00\x25\xaf\x06\x3a\x24\xbd\x06\x7a\x22\xbc\x06\x2f\x25\xab\x06\xf4\x23\xb1\x06\x4a\x22\xd6\x06\x61\x25\xbe\x06\x0a\x24\xb0\x06\x42\x22\xc3\x06\x6a\x25\xad\x06\xd7\x23\xae\x06\x5d\x22\xbf\x06\x8a\x25\xaf\x06\x1a\x24\xac\x06\x2e\x22\xc5\x06\xce\x25\xc3\x06\x37\x24\xa4\x06\x54\x22\xca\x06\xc3\x25\xba\x06\x33\x24\xb7\x06\x81\x22\xc9\x06\x1e\x25\xb2\x06\x2e\x24\xb9\x06\x75\x22\xae\x06\x14\x25\xa5\x06\x46\x24\xb5\x06\x40\x22\xb7\x06\x07\x25\xad\x06\x65\x24\xa5\x06\x9e\x22\xd2\x06\x0b\x25\xcb\x06\x58\x24\xb6\x06\x5c\x22\xcc\x06\x08\x25\xc0\x06\x12\x24\xb9\x06\x6e\x22\xc3\x06\xfa\x24\xc6\x06\x3e\x24\xc4\x06\x5f\x22\xc3\x06\xb3\x24\xbe\x06\x66\x24\xb7\x06\x73\x22\xce\x06\x34\x25\xc4\x06\x45\x24\xbe\x06\x55\x22\xc1\x06\x61\x25\xb3\x06\x32\x24\xa5\x06\x7c\x22\xc0\x06\x2f\x25\xbb\x06\x49\x24\xb9\x06\x75\x22\xd6\x06\xfd\x24\xcb\x06\x66\x24\xc2\x06\x46\x22\xd4\x06\x1d\x25\xc4\x06\x3e\x24\xaf\x06\x4e\x22\xba\x06\xf4\x24\xa9\x06\x52\x24\xb6\x06\x5f\x22\xce\x06\x17\x25\xc9\x06\x70\x24\xb6\x06\x7e\x22\xbf\x06\x3c\x25\xb6\x06\x5c\x24\xa3\x06\x79\x22\xcf\x06\xf1\x24\xcb\x06\x8f\x24\xbf\x06\x7e\x22\xcc\x06\x34\x25\xce\x06\x8c\x24\xba\x06\x87\x22\xca\x06\xc7\x24\xc4\x06\x54\x24\xbb\x06\x6e\x22\xc3\x06\x2e\x25\xbb\x06\x48\x24\xa7\x06\x56\x22\xd5\x06\x38\x25\xc6\x06\x06\x24\xc1\x06\x63\x22\xbf\x06\x26\x25\xb4\x06\x0c\x24\xad\x06\x3d\x22\xc5\x06\x52\x25\xc4\x06\x25\x24\xc0\x06\x3b\x22\xc0\x06\xbc\x25\xbb\x06\x4e\x24\xa3\x06\x2e\x22\xd1\x06\xdd\x25\xbf\x06\x71\x24\xb4\x06\x80\x22\xb3\x06\x5b\x25\x9f\x06\x70\x24\xac\x06\x80\x22\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xc5\x06\xf0\x24\xbf\x06\x59\x24\xb8\x06\x6f\x22\xd0\x06\x0d\x25\xcd\x06\x39\x24\xc2\x06\x54\x22\xd5\x06\x1d\x25\xd1\x06\x1b\x24\xc3\x06\x47\x22\xd2\x06\xf1\x24\xcc\x06\xf6\x23\xbe\x06\x80\x22\xc3\x06\x1a\x25\xac\x06\xe4\x23\xbb\x06\x5f\x22\xcf\x06\x58\x25\xc9\x06\xc8\x23\xb7\x06\x1e\x22\xca\x06\x31\x25\xcd\x06\x0e\x24\xc0\x06\x38\x22\xbe\x06\x15\x25\xa6\x06\x0f\x24\xb9\x06\x38\x22\xc6\x06\xb5\x24\xb5\x06\xe7\x23\xb2\x06\x26\x22\xc2\x06\xba\x24\xb9\x06\xdc\x23\xc4\x06\x3d\x22\xd5\x06\xdc\x24\xcf\x06\x2a\x24\xc3\x06\x26\x22\xdc\x06\xfb\x24\xcb\x06\x3b\x24\xc6\x06\x63\x22\xd2\x06\x6b\x25\xc5\x06\x3f\x24\xc4\x06\x8f\x22\xcf\x06\x95\x25\xca\x06\x12\x24\xbf\x06\x5a\x22\xd0\x06\xf7\x24\xc2\x06\x14\x24\xcb\x06\x37\x22\xd6\x06\xf7\x24\xc5\x06\x06\x24\xbd\x06\x11\x22\xd1\x06\xd4\x24\xc1\x06\xcc\x23\xc6\x06\x1b\x22\xcc\x06\xc5\x24\xc8\x06\xf4\x23\xb6\x06\xfc\x21\xc6\x06\xff\x24\xb8\x06\xf4\x23\xb4\x06\x1f\x22\xbf\x06\x33\x25\xbb\x06\x32\x24\xb3\x06\x61\x22\xd1\x06\x11\x25\xc8\x06\x02\x24\xbe\x06\x0c\x22\xcf\x06\xc5\x24\xc4\x06\xb9\x23\xb7\x06\xef\x21\xcb\x06\x92\x24\xc6\x06\x95\x23\xb5\x06\xc2\x21\xc7\x06\x85\x24\xc4\x06\x95\x23\xc1\x06\xcc\x21\xd6\x06\xcd\x24\xc7\x06\xc1\x23\xc5\x06\xde\x21\xc4\x06\xb1\x24\xad\x06\xae\x23\xb9\x06\xd4\x21\xc4\x06\x56\x24\xba\x06\xd3\x23\xae\x06\xc9\x21\xbf\x06\x70\x24\xb5\x06\x82\x23\xab\x06\xc1\x21\xcd\x06\xa9\x24\xbc\x06\xa2\x23\xbe\x06\xa9\x21\xad\x06\x91\x24\x9a\x06\x8e\x23\xba\x06\xac\x21\xca\x06\x5f\x24\xbe\x06\x8e\x23\xbb\x06\x92\x21\xb9\x06\xda\x24\xac\x06\xc0\x23\x9e\x06\xba\x21\xba\x06\x7d\x24\xad\x06\xc0\x23\xb3\x06\xb9\x21\xd3\x06\x8e\x24\xc3\x06\x96\x23\xc7\x06\xb7\x21\xca\x06\x65\x24\xc5\x06\x68\x23\xa9\x06\xa7\x21\xc4\x06\x15\x24\xb7\x06\x89\x23\xaf\x06\xa5\x21\xd0\x06\x4c\x24\xbc\x06\x9a\x23\xb0\x06\x92\x21\xc4\x06\x42\x24\xc7\x06\x79\x23\xbd\x06\xa7\x21\xae\x06\x7f\x24\xac\x06\x6f\x23\xb1\x06\xb3\x21\xc3\x06\x66\x24\xbe\x06\x82\x23\xbb\x06\x8f\x21\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xc2\x06\x6a\x24\xbc\x06\xc7\x23\xac\x06\x9e\x21\xaa\x06\x8e\x24\xad\x06\xbe\x23\xb5\x06\x9a\x21\xbb\x06\x6e\x24\xa8\x06\xd1\x23\xaa\x06\x9e\x21\x9e\x06\x5d\x24\x90\x06\x7e\x23\xa4\x06\x60\x21\xae\x06\x04\x24\xa1\x06\x5f\x23\xa8\x06\x08\x21\xb9\x06\xc7\x23\xb5\x06\x0d\x23\xa2\x06\x85\x20\xb9\x06\x33\x24\xb5\x06\xf9\x22\xae\x06\x76\x20\xca\x06\x20\x24\xc1\x06\x60\x23\xac\x06\xa2\x20\xcb\x06\x8a\x24\xb5\x06\xb4\x23\xa8\x06\x3c\x21\xa5\x06\x83\x24\x9e\x06\x99\x23\xad\x06\x8b\x21\x96\x06\x63\x24\x93\x06\xd4\x23\xac\x06\x97\x21\xbf\x06\xff\x23\xc7\x06\x92\x23\xb3\x06\x5a\x21\xae\x06\x05\x24\x95\x06\xa2\x23\x8e\x06\x8e\x21\xad\x06\xd9\x23\xa6\x06\x7e\x23\xa1\x06\x8c\x21\xa1\x06\x54\x24\x8d\x06\x7f\x23\xb1\x06\xa0\x21\xb6\x06\x52\x24\xaf\x06\x83\x23\xaa\x06\x93\x21\xb7\x06\x7a\x24\xb5\x06\xae\x23\xaa\x06\x99\x21\xab\x06\xf2\x23\xa4\x06\x75\x23\xa1\x06\x79\x21\x96\x06\x4f\x24\x83\x06\x81\x23\x9a\x06\x91\x21\xb9\x06\x2f\x24\xc1\x06\x38\x23\xa4\x06\xbd\x21\xaf\x06\x8a\x24\xa2\x06\x95\x23\x9c\x06\xca\x21\xc1\x06\x46\x24\xa8\x06\xb8\x23\xad\x06\xf9\x21\xb8\x06\x84\x24\xa9\x06\xc8\x23\xa7\x06\xf5\x21\xa3\x06\xc8\x24\x9d\x06\xb9\x23\xc0\x06\x15\x22\xbf\x06\x4f\x24\xbf\x06\x91\x23\xa8\x06\xac\x21\xab\x06\x43\x24\x9e\x06\xa9\x23\x90\x06\xa7\x21\xb7\x06\x65\x24\xbb\x06\xcf\x23\xa7\x06\xac\x21\xa0\x06\x2f\x24\xa3\x06\xb9\x23\xa9\x06\xb6\x21\xb6\x06\x5f\x24\xa7\x06\xad\x23\x9e\x06\xe3\x21\xcf\x06\x74\x24\xbd\x06\xc4\x23\xa8\x06\xd9\x21\xc9\x06\xbf\x24\xc3\x06\x1d\x24\xa4\x06\xb1\x21\xb1\x06\xb2\x24\xa7\x06\xc4\x23\xb2\x06\xa4\x21\xc5\x06\x65\x24\xad\x06\x8a\x23\xa5\x06\x79\x21\xbf\x06\x29\x24\xaa\x06\x97\x23\xa2\x06\x6f\x21\xc0\x06\x33\x24\xb5\x06\x97\x23\xac\x06\x64\x21\xc3\x06\x46\x24\xb9\x06\x9c\x23\xa2\x06\x98\x21\xbc\x06\xa2\x24\xbd\x06\xdf\x23\xa2\x06\x9d\x21\xaf\x06\xb6\x24\xa7\x06\xf7\x23\x93\x06\xf0\x21\xac\x06\xf0\x24\x96\x06\xf4\x23\x9b\x06\x9b\x21\xbd\x06\x98\x24\xa9\x06\x8e\x23\xb9\x06\x8e\x21\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xcd\x06\xa3\x24\xb9\x06\x76\x23\xb4\x06\x90\x21\xbe\x06\x5c\x24\xba\x06\x7e\x23\xa5\x06\x88\x21\xab\x06\x70\x24\xa3\x06\x85\x23\xa5\x06\x86\x21\x96\x06\xd1\x24\x8a\x06\xa6\x23\x90\x06\x9c\x21\xc2\x06\x8f\x24\xba\x06\xad\x23\xab\x06\x7c\x21\xad\x06\xa7\x24\x99\x06\xc0\x23\x92\x06\xd2\x21\xc1\x06\xbb\x24\xb5\x06\x92\x23\xae\x06\xd1\x21\xb9\x06\x82\x24\xb2\x06\x72\x23\xaf\x06\x92\x21\xc8\x06\xf9\x24\xb8\x06\x87\x23\xa2\x06\x77\x21\xc5\x06\xea\x24\xb1\x06\x91\x23\xa6\x06\x96\x21\xc6\x06\xfd\x24\xc1\x06\x7f\x24\xb2\x06\x03\x22\xce\x06\x8a\x25\xc0\x06\xd5\x23\xbd\x06\x14\x22\xb0\x06\x6f\x25\xa2\x06\xf3\x23\xab\x06\xe3\x21\xc7\x06\x3e\x25\xb5\x06\x68\x23\xab\x06\x1b\x22\xb1\x06\x36\x25\xa2\x06\x8f\x23\x98\x06\x12\x22\xb2\x06\x51\x25\xb4\x06\x67\x23\xa8\x06\x9a\x21\xc0\x06\x2e\x25\xa8\x06\x81\x23\x9a\x06\xa2\x21\xbc\x06\x2b\x25\xa8\x06\x7b\x23\x94\x06\xcb\x21\xcf\x06\x44\x25\xb5\x06\x77\x23\xa7\x06\xe3\x21\xba\x06\x25\x25\xa1\x06\xa0\x23\x9f\x06\xe1\x21\x8c\x06\xeb\x24\x81\x06\xbc\x23\x6a\x06\xd3\x21\xa5\x06\x09\x25\x97\x06\x99\x23\x88\x06\xcb\x21\xb8\x06\x8a\x24\xa0\x06\x44\x23\xa8\x06\xc8\x21\xaa\x06\xcf\x24\x96\x06\x4c\x23\xa8\x06\xfd\x21\xc2\x06\x16\x25\xa7\x06\x64\x23\xa7\x06\xe9\x21\xb7\x06\xd8\x24\xae\x06\xaa\x23\xa9\x06\xca\x21\xba\x06\x6b\x25\xab\x06\x2b\x24\xb7\x06\xf5\x21\xb9\x06\x31\x24\xad\x06\x97\x23\xa0\x06\x7d\x21\x9b\x06\xc5\x24\x86\x06\x6f\x23\xa1\x06\xbe\x20\x7d\x07\x1c\x8e\x7c\x07\x39\x86\x71\x07\x69\x7b\x00\x00\xbb\x14\x00\x00\x80\x15\x00\x00\x20\x16\x00\x00\xb9\x14\x00\x00\x80\x15\x00\x00\x1f\x16\x00\x00\xd9\x14\x00\x00\x91\x15\x00\x00\x31\x16\x00\x00\xd8\x14\x00\x00\x91\x15\x00\x00\x31\x16\x25\x09\xff\xff\x1d\x09\xff\xff\x2c\x09\xff\xff\xd6\x06\x3c\x25\xc8\x06\x77\x23\xb6\x06\x44\x21\xcb\x06\x68\x24\xc0\x06\xaf\x23\xb0\x06\xcc\x21\xcb\x06\xcb\x24\xc4\x06\xca\x23\xc2\x06\x0f\x22\xd4\x06\xd5\x24\xc8\x06\x1d\x24\xb4\x06\x01\x22\xd4\x06\x49\x25\xc2\x06\xb1\x23\xc2\x06\x1f\x22\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xdb\x06\x29\x25\xc2\x06\x99\x23\xbe\x06\xd9\x21\xd2\x06\xfd\x24\xc4\x06\x37\x23\xb2\x06\x9a\x21\xc6\x06\xdc\x24\xc1\x06\xc8\x23\xc0\x06\xf6\x21\xca\x06\x1a\x25\xb5\x06\x81\x23\xbc\x06\x00\x22\xdf\x06\x54\x25\xc8\x06\xd2\x23\xb6\x06\xe0\x21\xd7\x06\x05\x25\xca\x06\xa9\x23\xb5\x06\xec\x21\xdb\x06\x82\x25\xbe\x06\x9a\x23\xbe\x06\x12\x22\xb1\x06\xc1\x25\xa3\x06\xd3\x23\xb4\x06\x3b\x22\xdd\x06\xff\x25\xc3\x06\xf2\x23\xb9\x06\xf2\x21\xe0\x06\xdd\x25\xcf\x06\x09\x24\xbc\x06\x02\x22\xd2\x06\x89\x25\xcf\x06\xf1\x23\xb6\x06\x37\x22\xdc\x06\x9c\x25\xbb\x06\xc7\x23\xc2\x06\x02\x22\xdd\x06\x3f\x25\xc4\x06\xce\x23\xb4\x06\x09\x22\xd0\x06\x73\x25\xba\x06\xee\x23\xbe\x06\x12\x22\xdf\x06\x66\x25\xcb\x06\xe1\x23\xb8\x06\x04\x22\xe3\x06\x8d\x25\xc7\x06\xb4\x23\xbc\x06\xe0\x21\xc6\x06\x52\x25\xbb\x06\x1a\x24\xb8\x06\x41\x22\xd5\x06\x06\x25\xd9\x06\x05\x24\xb9\x06\x1f\x22\xdd\x06\xd2\x24\xc0\x06\xb1\x23\xb7\x06\xf9\x21\xd9\x06\xda\x24\xcb\x06\xce\x23\xba\x06\xb9\x21\xce\x06\xc7\x24\xbd\x06\xc2\x23\xb4\x06\xb6\x21\xb2\x06\xc1\x24\xaa\x06\xab\x23\xb5\x06\x6a\x21\xcd\x06\xe0\x24\xc4\x06\x84\x23\xae\x06\xac\x21\xd5\x06\x03\x25\xc6\x06\xbc\x23\xb9\x06\x42\x22\xc6\x06\x11\x25\xca\x06\xd8\x23\xbe\x06\xda\x21\xcb\x06\xf7\x24\xc3\x06\xad\x23\xb5\x06\xe5\x21\xcf\x06\xcf\x24\xc8\x06\x9c\x23\xb2\x06\xbc\x21\xd1\x06\x84\x24\xc2\x06\xcb\x23\xbe\x06\xc4\x21\xd6\x06\xb5\x24\xce\x06\xcc\x23\xc3\x06\xc9\x21\xd3\x06\xd6\x24\xc2\x06\x8c\x23\xae\x06\xd7\x21\xdb\x06\x7b\x24\xd0\x06\xc0\x23\xbe\x06\xac\x21\xc6\x06\x51\x24\xc8\x06\xf5\x23\xc1\x06\x09\x22\xcf\x06\x78\x24\xc0\x06\xf1\x23\xb9\x06\x1e\x22\xc9\x06\x70\x24\xb4\x06\xcf\x23\xc3\x06\x17\x22\xcf\x06\x5a\x24\xbe\x06\xbd\x23\xb0\x06\xef\x21\xc9\x06\x7d\x24\xc2\x06\xeb\x23\xbb\x06\x1a\x22\xd0\x06\xb9\x24\xcd\x06\xda\x23\xb5\x06\x1d\x22\xbb\x06\x11\x25\x9e\x06\x31\x24\xa1\x06\x3f\x22\xcc\x06\xc6\x24\xb7\x06\x1c\x24\xbf\x06\x3d\x22\xd9\x06\xf7\x24\xcb\x06\x02\x24\xbe\x06\x2b\x22\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xdb\x06\xbc\x24\xc6\x06\xe1\x23\xc1\x06\xfb\x21\xd5\x06\x86\x24\xcf\x06\xc0\x23\xb6\x06\x1d\x22\xd1\x06\xbc\x24\xc3\x06\x8e\x23\xb6\x06\x01\x22\xcf\x06\xbd\x24\xca\x06\xc3\x23\xb8\x06\x16\x22\xdf\x06\xbc\x24\xc6\x06\x7b\x23\xad\x06\xac\x21\xdb\x06\xc3\x24\xc7\x06\xb8\x23\xbf\x06\xfb\x21\xbf\x06\x6e\x24\xb7\x06\x96\x23\xb2\x06\xcc\x21\xd2\x06\x7d\x24\xcf\x06\xa0\x23\xb2\x06\x02\x22\xcc\x06\x93\x24\xb2\x06\x75\x23\xad\x06\xdb\x21\xc4\x06\x9a\x24\xb8\x06\x86\x23\xb5\x06\x34\x22\xc5\x06\x7f\x24\xb4\x06\xce\x23\xbb\x06\x0c\x22\xcb\x06\x9b\x24\xb6\x06\x8d\x23\xa1\x06\xd0\x21\xd0\x06\xbd\x24\xbd\x06\x6b\x23\xa5\x06\x12\x22\xd7\x06\x9f\x24\xc1\x06\xa5\x23\xb1\x06\xf0\x21\xbc\x06\x92\x24\xba\x06\xb5\x23\xab\x06\x0c\x22\xc3\x06\x7d\x24\xbd\x06\x7d\x23\xa9\x06\xd3\x21\xc9\x06\x9e\x24\xac\x06\x9a\x23\xaf\x06\xeb\x21\xba\x06\xb1\x24\xa4\x06\xa9\x23\xba\x06\xfb\x21\xcd\x06\x8d\x24\xbb\x06\x95\x23\xac\x06\xc8\x21\xd0\x06\x6b\x24\xd0\x06\xa9\x23\xb9\x06\xf3\x21\xe3\x06\xb0\x24\xba\x06\x7a\x23\xb7\x06\xdb\x21\xcf\x06\xb1\x24\xc7\x06\x59\x23\xb0\x06\xbd\x21\xd4\x06\x97\x24\xbb\x06\x57\x23\xb9\x06\xc4\x21\xc9\x06\x8c\x24\xb9\x06\x61\x23\xa7\x06\xaa\x21\xd7\x06\x8f\x24\xc4\x06\x60\x23\xb3\x06\x9a\x21\xca\x06\x72\x24\xc7\x06\x59\x23\xb6\x06\xb3\x21\xc6\x06\x6b\x24\xc4\x06\x61\x23\xb7\x06\x4a\x21\xc7\x06\x85\x24\xc2\x06\x5d\x23\xad\x06\x51\x21\xcf\x06\x5a\x24\xbd\x06\x30\x23\xb6\x06\x9d\x21\xbd\x06\x80\x24\xbc\x06\x45\x23\xb7\x06\x85\x21\xd2\x06\x66\x24\xb8\x06\x36\x23\xb3\x06\x72\x21\xcc\x06\x8c\x24\xb9\x06\x24\x23\xa9\x06\x5d\x21\xcc\x06\x8c\x24\xb4\x06\x56\x23\xab\x06\xba\x21\xc2\x06\x40\x24\xc7\x06\x4e\x23\xb1\x06\x5c\x21\xd0\x06\x70\x24\xc4\x06\x60\x23\xb4\x06\x7a\x21\xd8\x06\xdc\x24\xb6\x06\x38\x23\xb9\x06\xcc\x21\xc8\x06\x67\x24\xc5\x06\x2e\x23\xb7\x06\xc5\x21\xd3\x06\x6a\x24\xc4\x06\x68\x23\xb8\x06\x96\x21\xe0\x06\x95\x24\xbc\x06\x2d\x23\xbe\x06\xb6\x21\xda\x06\xa2\x24\xc8\x06\x37\x23\xc2\x06\xd5\x21\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xc6\x06\xa2\x24\xb3\x06\xf0\x22\x9c\x06\x76\x21\xd8\x06\xba\x24\xd2\x06\x38\x23\xbd\x06\x8e\x21\xc4\x06\x95\x24\xbc\x06\x4e\x23\xa8\x06\xa4\x21\xd7\x06\x9b\x24\xca\x06\x79\x23\xba\x06\xd5\x21\xd1\x06\x75\x24\xc1\x06\x42\x23\xb7\x06\xd0\x21\xd4\x06\x20\x24\xc3\x06\x39\x23\xac\x06\xae\x21\xcc\x06\x38\x24\xb8\x06\x30\x23\xc7\x06\xb0\x21\xcf\x06\x3c\x24\xc0\x06\xe9\x22\xa3\x06\x4b\x21\xcf\x06\x9f\x24\xbc\x06\xe7\x22\xad\x06\x63\x21\xd9\x06\xed\x24\xbb\x06\xf8\x22\xc2\x06\xab\x21\xd2\x06\xc3\x24\xbf\x06\x34\x23\xbd\x06\xa1\x21\xc5\x06\x97\x24\xc3\x06\x06\x23\xaf\x06\x60\x21\xd4\x06\x7d\x24\xbc\x06\xed\x22\xb4\x06\x96\x21\xc8\x06\x2b\x24\xc6\x06\x0f\x23\xaf\x06\x98\x21\xca\x06\x2e\x24\xb3\x06\x14\x23\xb9\x06\x40\x21\xcc\x06\x0b\x24\xb7\x06\xd0\x22\xbf\x06\x42\x21\xe0\x06\xcd\x24\xbe\x06\xe4\x22\xaf\x06\xb2\x21\xd0\x06\x84\x24\xcd\x06\x20\x23\xb7\x06\xac\x21\xe2\x06\xa2\x24\xce\x06\x12\x23\xb8\x06\x8b\x21\xd3\x06\x73\x24\xbd\x06\x04\x23\xaa\x06\x75\x21\xce\x06\x91\x24\xcc\x06\x3a\x23\xb7\x06\x92\x21\xcc\x06\x56\x24\xbb\x06\xdc\x22\xb0\x06\x83\x21\xd4\x06\x08\x24\xbf\x06\x9c\x22\xa9\x06\x10\x21\xc7\x06\xea\x23\xb3\x06\x08\x23\xb1\x06\x56\x21\xd4\x06\x5c\x24\xc1\x06\xb7\x22\xb2\x06\x66\x21\xdd\x06\x88\x24\xbf\x06\xc1\x22\xb9\x06\x4d\x21\xe2\x06\x55\x24\xc7\x06\xe0\x22\xae\x06\x44\x21\xc4\x06\x10\x24\xbd\x06\xc0\x22\xa4\x06\x2d\x21\xcc\x06\xec\x23\xb2\x06\x5a\x22\xb0\x06\x27\x21\xd9\x06\xd2\x23\xab\x06\x25\x22\xb1\x06\x00\x21\xc4\x06\xda\x23\xb5\x06\x41\x22\xb6\x06\x1b\x21\xb7\x06\xaa\x23\xa7\x06\xaf\x22\xb3\x06\x59\x21\xba\x06\x1b\x24\xbf\x06\xd6\x22\xa8\x06\x0b\x21\xd5\x06\x21\x24\xc0\x06\xda\x22\xac\x06\x3b\x21\xda\x06\x2a\x24\xc9\x06\xf0\x22\xc1\x06\x73\x21\xd6\x06\x28\x24\xc4\x06\x1b\x23\xb1\x06\x58\x21\xc5\x06\xe1\x23\xb0\x06\xbb\x22\xa5\x06\x07\x21\xc3\x06\xf1\x23\xbb\x06\xce\x22\xac\x06\x2e\x21\xcd\x06\x11\x24\xbc\x06\xfa\x22\xab\x06\x79\x21\xd2\x06\x21\x24\xc5\x06\x11\x23\xb4\x06\x6d\x21\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xd0\x06\xee\x23\xc8\x06\x07\x23\xc0\x06\x35\x21\xe6\x06\xdb\x23\xcf\x06\xfd\x22\xb2\x06\xf7\x20\xd2\x06\x1c\x24\xc8\x06\xd8\x22\xbe\x06\x15\x21\xdd\x06\x26\x24\xd0\x06\xdb\x22\xc0\x06\xb5\x20\xc0\x06\x40\x24\xb4\x06\xe2\x22\xb3\x06\xea\x20\xd9\x06\x73\x24\xc3\x06\x0e\x23\xc1\x06\x48\x21\xd8\x06\x2a\x24\xcc\x06\x29\x23\xaf\x06\x4b\x21\xd2\x06\x32\x24\xc4\x06\x25\x23\xb4\x06\x4b\x21\xd2\x06\xa2\x24\xac\x06\x05\x23\xab\x06\x75\x21\xde\x06\xd0\x24\xc1\x06\x31\x23\xc4\x06\x8a\x21\xdf\x06\xad\x24\xc8\x06\x15\x23\xb8\x06\x7f\x21\xdf\x06\x91\x24\xb7\x06\xde\x22\xa8\x06\x4f\x21\xd5\x06\xa3\x24\xc4\x06\x69\x23\xb6\x06\x64\x21\xe1\x06\x99\x24\xdc\x06\x35\x23\xb7\x06\x87\x21\xee\x06\x7d\x24\xc4\x06\xf1\x22\xcf\x06\xae\x21\xe3\x06\x67\x24\xd5\x06\x57\x23\xce\x06\xc1\x21\xf7\x06\xa6\x24\xe1\x06\x57\x23\xe0\x06\xec\x21\xf4\x06\x0d\x25\xe3\x06\x5d\x23\xcf\x06\xda\x21\xfb\x06\x2d\x25\xe0\x06\x82\x23\xce\x06\xb7\x21\xf1\x06\xb4\x24\xe4\x06\x6b\x23\xdb\x06\x0f\x22\xf1\x06\x0a\x25\xd0\x06\xad\x23\xcc\x06\xf3\x21\x01\x07\xdc\x24\xe4\x06\x6c\x23\xde\x06\xeb\x21\x00\x07\xee\x24\xf6\x06\xa1\x23\xe1\x06\xdd\x21\xff\x06\xd3\x24\xf7\x06\x9b\x23\xef\x06\x02\x22\xf0\x06\xdd\x24\xee\x06\x9d\x23\xe7\x06\x16\x22\x04\x07\x3a\x25\xeb\x06\x9d\x23\xdd\x06\xec\x21\xfe\x06\x78\x25\xe1\x06\xc9\x23\xd6\x06\x3b\x22\x05\x07\xcc\x25\xe8\x06\x7f\x23\xe5\x06\x12\x22\x00\x07\xb8\x25\xe0\x06\x75\x23\xe2\x06\x05\x22\x03\x07\x49\x25\xee\x06\x78\x23\xf2\x06\xa7\x21\xed\x06\xe5\x24\xcf\x06\x8c\x23\xcf\x06\x72\x21\x03\x07\xe1\x24\xfa\x06\x7a\x23\xe7\x06\x87\x21\x03\x07\x8a\x24\xf7\x06\x67\x23\xdc\x06\xae\x21\xe9\x06\x79\x24\xe0\x06\xbd\x23\xe3\x06\xba\x21\xef\x06\x32\x24\xdb\x06\x8b\x23\xd4\x06\xb0\x21\xff\x06\x99\x24\xe2\x06\x9f\x23\xe1\x06\xbe\x21\x00\x07\xd8\x24\xf2\x06\x9e\x23\xe4\x06\x9e\x21\x05\x07\x0f\x25\xe3\x06\x57\x23\xda\x06\xcb\x21\x08\x07\xdf\x24\xe6\x06\x6f\x23\xe7\x06\xc3\x21\x04\x07\xed\x24\xed\x06\x46\x23\xde\x06\xac\x21\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xf8\x06\xa0\x24\xe3\x06\x58\x23\xdb\x06\x99\x21\xf4\x06\x5c\x24\xde\x06\x73\x23\xce\x06\x61\x21\xfc\x06\xf4\x23\xe2\x06\x4d\x23\xd3\x06\x65\x21\xfa\x06\x08\x24\xe2\x06\x3f\x23\xde\x06\x4c\x21\xf2\x06\xfe\x23\xea\x06\x70\x23\xd4\x06\x58\x21\xf1\x06\x02\x24\xee\x06\x34\x23\xdd\x06\x6c\x21\xe2\x06\x10\x24\xd3\x06\x4b\x23\xcb\x06\x76\x21\xf9\x06\x2f\x24\xe0\x06\xec\x22\xd8\x06\x33\x21\x09\x07\x54\x24\x05\x07\x53\x24\xe4\x06\x5e\x21\xee\x06\x2a\x24\xe7\x06\x2f\x23\xbb\x06\x42\x21\x00\x07\xf7\x23\xe6\x06\x23\x23\xd5\x06\x24\x21\x02\x07\x03\x24\xd5\x06\x25\x23\xca\x06\xea\x20\xf1\x06\x08\x24\xd8\x06\x11\x23\xd9\x06\x14\x21\xfd\x06\x5e\x24\xd5\x06\x20\x23\xcb\x06\x31\x21\xe9\x06\x3b\x24\xe0\x06\xd3\x23\xdc\x06\xae\x21\xe5\x06\x2d\x24\xd3\x06\x92\x23\xd2\x06\xcc\x21\xd6\x06\xf0\x23\xc5\x06\x50\x23\xc4\x06\xb3\x21\xe6\x06\xf2\x23\xd1\x06\x20\x23\xc2\x06\x91\x21\xbf\x06\x85\x23\xc0\x06\x3e\x23\xb4\x06\x8a\x21\xbd\x06\xbf\x23\xb2\x06\x5a\x23\xb6\x06\x60\x21\xd2\x06\xd4\x23\xb7\x06\x1e\x23\xb3\x06\xe4\x21\xbc\x06\xc6\x23\xbd\x06\xfc\x22\xa6\x06\x42\x21\xc4\x06\xda\x23\xb0\x06\x2f\x23\xb1\x06\x63\x21\xd6\x06\xd0\x23\xcb\x06\xce\x23\xaa\x06\x65\x21\xc5\x06\xd8\x23\xb3\x06\x0d\x23\xb2\x06\x71\x21\xd4\x06\xc7\x23\xcc\x06\x12\x23\xbc\x06\xa3\x21\xc7\x06\xcc\x23\xbc\x06\x1f\x23\xa1\x06\x6d\x21\xcf\x06\xb6\x23\xc1\x06\xe4\x22\xb1\x06\x6d\x21\xcc\x06\xca\x23\xb8\x06\x0b\x23\xb9\x06\x70\x21\xd2\x06\x24\x24\xbe\x06\x13\x23\xad\x06\x63\x21\xde\x06\x85\x24\xc4\x06\x20\x23\xb9\x06\xac\x21\xd1\x06\xe9\x24\xbe\x06\xf0\x22\xb5\x06\xb0\x21\xcc\x06\xf9\x24\xc1\x06\xff\x22\xbc\x06\xc5\x21\xd4\x06\xb3\x24\xba\x06\xe6\x22\xa6\x06\x91\x21\xe2\x06\x43\x24\xcf\x06\x37\x23\xc6\x06\x7d\x21\xcf\x06\x0c\x24\xb7\x06\xe0\x22\xb5\x06\x33\x21\xc5\x06\x2d\x24\xba\x06\xa5\x22\xae\x06\x24\x21\xdc\x06\x47\x24\xbf\x06\xdf\x22\xc1\x06\x6c\x21\xc1\x06\xe5\x23\xc7\x06\x0f\x23\xb6\x06\x6a\x21\xcc\x06\xbf\x23\xc1\x06\x26\x23\xc0\x06\x8d\x21\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xd2\x06\xe4\x23\xc6\x06\x07\x23\xbe\x06\x7a\x21\xc9\x06\xcb\x23\xc0\x06\x05\x23\xa9\x06\x73\x21\xad\x06\xea\x23\xa9\x06\x18\x23\xa3\x06\x50\x21\xc3\x06\x2b\x24\xb8\x06\x01\x23\xa9\x06\x52\x21\xcd\x06\x21\x24\xbf\x06\x35\x23\xaa\x06\x74\x21\xe1\x06\x37\x24\xd1\x06\x38\x23\xba\x06\x8c\x21\xd2\x06\x30\x24\xbe\x06\x10\x23\xa7\x06\x58\x21\xd0\x06\x04\x24\xbe\x06\x1c\x23\xa7\x06\x45\x21\xc6\x06\xff\x23\xc0\x06\x52\x23\xa8\x06\x85\x21\xd9\x06\x32\x24\xce\x06\x62\x23\xb0\x06\x88\x21\xcb\x06\x4d\x24\xbd\x06\x2c\x23\xb8\x06\x8b\x21\xc2\x06\x36\x24\xc7\x06\x28\x23\xa1\x06\x66\x21\xc9\x06\x30\x24\xab\x06\x50\x23\xb9\x06\x83\x21\xcf\x06\x36\x24\xb7\x06\x34\x23\xb2\x06\x5f\x21\xbc\x06\x3e\x24\xaf\x06\x27\x23\xb0\x06\x83\x21\xca\x06\x34\x24\xbe\x06\x4a\x23\xb1\x06\x6b\x21\xcb\x06\x37\x24\xc0\x06\x4e\x23\xb4\x06\x84\x21\xc9\x06\xdb\x23\xbe\x06\x3b\x23\xbc\x06\x74\x21\xcc\x06\xea\x23\xae\x06\x20\x23\xae\x06\x71\x21\xd2\x06\x28\x24\xca\x06\x68\x23\xa7\x06\xa2\x21\xcf\x06\x38\x24\xbd\x06\x33\x23\xa7\x06\x80\x21\xd7\x06\x1a\x24\xbe\x06\x23\x23\xb6\x06\x7e\x21\xaf\x06\x3b\x24\x9d\x06\x6a\x23\x9c\x06\x81\x21\xd5\x06\x26\x24\xba\x06\x2f\x23\xa7\x06\x74\x21\xc6\x06\x2e\x24\xb7\x06\x27\x23\xb9\x06\xaa\x21\xbe\x06\xef\x23\xbc\x06\x3e\x23\xaf\x06\x84\x21\xc6\x06\xec\x23\xc3\x06\x6e\x23\xb4\x06\xa4\x21\xde\x06\x43\x24\xc4\x06\x53\x23\xbd\x06\xac\x21\xd2\x06\x07\x24\xc7\x06\x4e\x23\xb5\x06\x80\x21\xc2\x06\x49\x24\xb9\x06\x43\x23\xbd\x06\x8e\x21\xcf\x06\x25\x24\xb4\x06\x32\x23\xb5\x06\xc3\x21\xcd\x06\x43\x24\xcb\x06\x29\x23\xbb\x06\x88\x21\xc9\x06\x09\x24\xbf\x06\x33\x23\xac\x06\x58\x21\xc6\x06\x1a\x24\xbd\x06\x45\x23\xaa\x06\xa7\x21\xd1\x06\x4a\x24\xbb\x06\x88\x23\xac\x06\xdc\x21\xc6\x06\xea\x23\xca\x06\x64\x23\xb3\x06\xd8\x21\xd5\x06\x55\x24\xba\x06\x89\x23\xc2\x06\xf1\x21\xd4\x06\x4d\x24\xc6\x06\xb5\x23\xbd\x06\xf8\x21\xdf\x06\xae\x24\xc6\x06\xb9\x23\xb8\x06\xfc\x21\xc3\x06\x8f\x24\xbe\x06\x79\x23\xba\x06\xcd\x21\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xcc\x06\x90\x24\xbd\x06\x8a\x23\xba\x06\x10\x22\xd7\x06\x57\x24\xc9\x06\x7b\x23\xb4\x06\xe9\x21\xcc\x06\x4d\x24\xc0\x06\x98\x23\xb5\x06\xd2\x21\xbd\x06\x1f\x24\xc4\x06\x9f\x23\xb4\x06\xd6\x21\xd4\x06\x2a\x24\xcb\x06\x95\x23\xb8\x06\xd7\x21\xd5\x06\x79\x24\xb8\x06\x4c\x23\xbb\x06\x09\x22\xcf\x06\x70\x24\xc1\x06\x3f\x23\xba\x06\xb2\x21\xd6\x06\x74\x24\xbb\x06\xa1\x23\xae\x06\xb0\x21\xdd\x06\x97\x24\xc9\x06\x7d\x23\xbc\x06\xe0\x21\xd9\x06\x53\x24\xcd\x06\x58\x23\xbf\x06\xdf\x21\xc3\x06\x3a\x24\xc2\x06\x88\x23\xbe\x06\xa4\x21\xcb\x06\x25\x24\xcb\x06\x97\x23\xb2\x06\xbd\x21\xce\x06\x48\x24\xce\x06\x48\x23\xbd\x06\xb4\x21\xd2\x06\x2a\x24\xc5\x06\x25\x23\xab\x06\x61\x21\xcc\x06\x62\x24\xc1\x06\x14\x23\xa8\x06\xaa\x21\xca\x06\x32\x24\xcc\x06\x65\x23\xb1\x06\xe8\x21\xcf\x06\x2f\x24\xcd\x06\x91\x23\xbd\x06\xd9\x21\xd1\x06\x32\x24\xca\x06\x94\x23\xb1\x06\xc5\x21\xd7\x06\x80\x24\xc7\x06\x99\x23\xb8\x06\xeb\x21\xd0\x06\x15\x24\xc0\x06\x7a\x23\xc0\x06\xda\x21\xc4\x06\xb6\x24\xb8\x06\x9f\x23\xb2\x06\xea\x21\xce\x06\xa2\x24\xbe\x06\x8d\x23\xba\x06\x12\x22\xbe\x06\x41\x24\xc5\x06\xc8\x23\xba\x06\x0f\x22\xd5\x06\x80\x24\xd3\x06\xa1\x23\xc5\x06\x13\x22\xda\x06\x47\x24\xd0\x06\xf5\x23\xb1\x06\xe3\x21\xe3\x06\x3b\x24\xcb\x06\xa1\x23\xb3\x06\xde\x21\xd4\x06\x1b\x24\xca\x06\x79\x23\xbd\x06\x04\x22\xce\x06\x34\x24\xca\x06\x32\x23\xae\x06\xcb\x21\xc7\x06\x2d\x24\xb7\x06\x1c\x23\xb0\x06\xc1\x21\xcc\x06\x74\x24\xc6\x06\x5b\x23\xb5\x06\x06\x22\xd8\x06\x41\x24\xd0\x06\x9a\x23\xb9\x06\xf7\x21\xd1\x06\x3b\x24\xc9\x06\x86\x23\xb9\x06\x03\x22\xb9\x06\x97\x24\xb7\x06\x88\x23\xb8\x06\xfb\x21\xdc\x06\x84\x24\xd5\x06\x74\x23\xc7\x06\x5a\x22\xd7\x06\x4b\x24\xb7\x06\x92\x23\xbc\x06\xe0\x21\xd5\x06\xd3\x24\xc5\x06\xab\x23\xc7\x06\x10\x22\xc3\x06\x6f\x24\xc8\x06\x9f\x23\xb5\x06\x3b\x22\xda\x06\xa9\x24\xdb\x06\x97\x23\xc5\x06\x31\x22\xd5\x06\x86\x24\xcc\x06\x73\x23\xb8\x06\x2a\x22\xe7\x06\x8a\x24\xd6\x06\xbb\x23\xc1\x06\x22\x22\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xd5\x06\xa3\x24\xc8\x06\x96\x23\xb1\x06\x3b\x22\xc8\x06\xb4\x24\xc1\x06\xab\x23\xc0\x06\x4e\x22\xd4\x06\xe4\x24\xbd\x06\xac\x23\xb5\x06\xfb\x21\xdd\x06\xe6\x24\xc5\x06\xaf\x23\xb0\x06\x30\x22\xbd\x06\xd3\x24\xb9\x06\xb3\x23\xc1\x06\x4c\x22\xd4\x06\xb8\x24\xca\x06\xca\x23\xc1\x06\x6b\x22\xdd\x06\xea\x24\xc2\x06\x6a\x23\xb5\x06\x3b\x22\xca\x06\xba\x24\xc4\x06\xa9\x23\xb4\x06\x42\x22\xcd\x06\x90\x24\xce\x06\xd7\x23\xc8\x06\x1b\x22\xdc\x06\x9a\x24\xd0\x06\x96\x23\xc5\x06\x0c\x22\xda\x06\xa7\x24\xbf\x06\xba\x23\xb9\x06\x50\x22\xca\x06\xbf\x24\xba\x06\x02\x24\xb7\x06\x30\x22\xca\x06\xcc\x24\xbf\x06\xd4\x23\xb5\x06\x3c\x22\xd2\x06\xec\x24\xc1\x06\x9e\x23\xba\x06\x4d\x22\xe5\x06\xe5\x24\xd0\x06\xe8\x23\xb9\x06\x29\x22\xe1\x06\xcc\x24\xce\x06\xff\x23\xc3\x06\x26\x22\xe3\x06\xdd\x24\xce\x06\xbe\x23\xc8\x06\x06\x22\xe2\x06\xe2\x24\xcf\x06\xcd\x23\xbe\x06\x0b\x22\xd5\x06\xb4\x24\xc5\x06\xfc\x23\xb8\x06\x29\x22\xdd\x06\xde\x24\xc2\x06\xc6\x23\xb6\x06\x03\x22\xdf\x06\x13\x25\xc4\x06\xe2\x23\xc0\x06\x32\x22\xdf\x06\xee\x24\xc5\x06\x05\x24\xcd\x06\x66\x22\xd7\x06\x03\x25\xc5\x06\x27\x24\xc1\x06\x58\x22\xe0\x06\xfa\x24\xd8\x06\x36\x24\xc1\x06\x7c\x22\xd2\x06\x37\x25\xcf\x06\x1f\x24\xcc\x06\x7d\x22\xdf\x06\x2b\x25\xd1\x06\x68\x24\xcb\x06\xc9\x22\xcf\x06\x41\x25\xc9\x06\x1e\x24\xbb\x06\x9e\x22\xd2\x06\xe5\x24\xce\x06\x5a\x24\xc3\x06\x75\x22\xdd\x06\x46\x25\xbe\x06\x2b\x24\xc3\x06\x7b\x22\xeb\x06\x3d\x25\xd4\x06\x1f\x24\xd5\x06\x98\x22\xd4\x06\x35\x25\xca\x06\x50\x24\xce\x06\xf2\x22\xd4\x06\xc2\x25\xc4\x06\x70\x24\xb9\x06\x0c\x23\xe1\x06\x83\x25\xce\x06\x52\x24\xbd\x06\xd1\x22\xe4\x06\x5c\x25\xdc\x06\x61\x24\xd4\x06\xa8\x22\xe0\x06\x60\x25\xd5\x06\x32\x24\xc2\x06\x9e\x22\xdb\x06\x40\x25\xc5\x06\x3b\x24\xb7\x06\xa9\x22\xe5\x06\x41\x25\xcd\x06\x57\x24\xc4\x06\xb2\x22\xe1\x06\x72\x25\xcd\x06\x06\x24\xbd\x06\xa2\x22\xde\x06\x42\x25\xd4\x06\xdc\x23\xd0\x06\x61\x22\xe5\x06\x7c\x25\xd9\x06\x12\x24\xc0\x06\x74\x22\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xca\x06\x81\x25\xc8\x06\xdd\x23\xb7\x06\xb6\x22\xc8\x06\x80\x25\xa6\x06\xcf\x23\xa3\x06\x82\x22\xa9\x06\x77\x25\x90\x06\x14\x24\x85\x06\x6c\x22\xf0\x06\xc5\x24\xc6\x06\x99\x23\xd8\x06\x1c\x22\x3e\x07\x70\x24\x2e\x07\x25\x23\x24\x07\xc3\x21\xc9\x07\x0e\x24\xa6\x07\x71\x22\x99\x07\x21\x21\xee\x07\xee\x23\xd8\x07\x71\x22\xc9\x07\xee\x20\xa5\x06\x40\x24\x89\x06\xa6\x22\x7b\x06\x0e\x20\x82\x06\xac\x22\x6b\x06\x49\x21\x4c\x06\x3e\x1e\x78\x07\x42\x22\x66\x07\x59\x21\x54\x07\x37\x1f\x91\x07\xab\x22\x80\x07\xd0\x21\x74\x07\xd1\x1f\x0f\x07\x0b\x23\xf8\x06\xec\x21\xdf\x06\x16\x20\xb7\x06\x64\x23\xa4\x06\x59\x22\xab\x06\x84\x20\x80\x06\xb6\x23\x79\x06\xa3\x22\x7e\x06\xba\x20\x70\x06\xf0\x23\x5c\x06\x89\x22\x75\x06\xba\x20\x77\x06\x0e\x24\x69\x06\x6a\x22\x70\x06\x98\x20\x9b\x06\x87\x23\x8b\x06\x40\x22\x8c\x06\x5a\x20\x9a\x06\x57\x23\x96\x06\x58\x22\x81\x06\x92\x20\xb9\x06\x8c\x23\x9f\x06\x54\x22\x97\x06\x83\x20\xa2\x06\x76\x23\x9a\x06\x76\x22\x87\x06\x84\x20\xb9\x06\xe8\x23\xa0\x06\x4b\x22\x92\x06\x9e\x20\x7d\x06\xd0\x23\x6a\x06\x76\x22\x83\x06\xb8\x20\xa8\x06\x90\x23\x9f\x06\x81\x22\x98\x06\xb5\x20\x86\x06\x88\x23\x7f\x06\x5e\x22\x9f\x06\xc8\x20\x9a\x06\x34\x23\x97\x06\x64\x22\x8a\x06\xb4\x20\x8a\x06\x4b\x23\x7a\x06\x79\x22\x94\x06\x92\x20\xaa\x06\x2a\x23\xb1\x06\x7d\x22\x98\x06\x9c\x20\x87\x06\x4b\x23\x73\x06\x4c\x22\x91\x06\xae\x20\xa9\x06\x29\x23\x97\x06\x24\x22\x8e\x06\x85\x20\x9b\x06\x36\x23\x96\x06\x07\x22\x82\x06\x7d\x20\x98\x06\x0d\x23\x91\x06\x55\x22\x86\x06\x6c\x20\xac\x06\x29\x23\x9b\x06\x5d\x22\x82\x06\x61\x20\x94\x06\x12\x23\x88\x06\x65\x22\x82\x06\x7a\x20\x93\x06\x2d\x23\x84\x06\x59\x22\x95\x06\x94\x20\x93\x06\xf9\x22\x91\x06\x99\x22\x7b\x06\x84\x20\x98\x06\x12\x23\x88\x06\x31\x22\x80\x06\x8c\x20\xa0\x06\xeb\x22\x8d\x06\x0c\x22\x7e\x06\x66\x20\xa6\x06\xbd\x22\x8c\x06\x41\x22\x7e\x06\x7c\x20\xaf\x06\xdf\x22\x9e\x06\x39\x22\x85\x06\x32\x20\x9f\x06\xfb\x22\x8b\x06\x56\x22\x80\x06\x57\x20\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xa7\x06\x0b\x23\xab\x06\x84\x22\x87\x06\x6c\x20\xa3\x06\x46\x23\x8a\x06\x3e\x22\x8d\x06\x90\x20\xa3\x06\x49\x23\x9a\x06\x75\x22\x83\x06\x9d\x20\x9a\x06\x08\x23\x9c\x06\x76\x22\x8a\x06\x90\x20\xa2\x06\x2d\x23\x96\x06\x5e\x22\x86\x06\xa3\x20\x9f\x06\x12\x23\x90\x06\x4b\x22\x8a\x06\x96\x20\xa7\x06\x10\x23\x94\x06\x6b\x22\x83\x06\x7b\x20\x8d\x06\xea\x22\x90\x06\xa1\x22\x82\x06\x78\x20\x9c\x06\xb5\x22\x89\x06\x2b\x22\x91\x06\x5c\x20\xa4\x06\xdb\x22\x91\x06\x07\x22\x8b\x06\x3c\x20\xa2\x06\xbd\x22\x88\x06\x07\x22\x90\x06\x2d\x20\x9d\x06\x9c\x22\x95\x06\x3a\x22\x81\x06\x4d\x20\x94\x06\xd7\x22\x8e\x06\x29\x22\x87\x06\x52\x20\x86\x06\xf8\x22\x79\x06\x36\x22\x74\x06\x6b\x20\x90\x06\xe1\x22\x92\x06\x3d\x22\x87\x06\x2b\x20\xa2\x06\xbc\x22\x95\x06\x2f\x22\x8c\x06\x31\x20\xaa\x06\xac\x22\x9f\x06\x49\x22\x8b\x06\x46\x20\xa6\x06\xf3\x22\x9e\x06\x35\x22\x8d\x06\x30\x20\x94\x06\xbb\x22\x8d\x06\x45\x22\x82\x06\x35\x20\x92\x06\xfc\x22\x80\x06\x2a\x22\x88\x06\x2c\x20\x73\x06\xf0\x22\x6b\x06\x50\x22\x75\x06\x17\x20\x91\x06\xd6\x22\x82\x06\x09\x22\x8a\x06\x28\x20\x9b\x06\xca\x22\x91\x06\x02\x22\x8c\x06\xf1\x1f\xae\x06\x11\x23\x92\x06\x44\x22\x8b\x06\x34\x20\x82\x06\xd6\x22\x71\x06\x46\x22\x81\x06\x2e\x20\x76\x06\xdb\x22\x6f\x06\x09\x22\x7d\x06\x1d\x20\x91\x06\xc0\x22\x91\x06\x6a\x22\x7e\x06\x2a\x20\xa8\x06\xf3\x22\x94\x06\x25\x22\x87\x06\x19\x20\x9c\x06\xf3\x22\x9a\x06\x5b\x22\x83\x06\x30\x20\xa8\x06\xdf\x22\x9a\x06\x5b\x22\x85\x06\x2b\x20\x8c\x06\xc9\x22\x78\x06\x7d\x22\x89\x06\x3a\x20\x73\x06\x19\x23\x6e\x06\x81\x22\x7e\x06\x56\x20\x92\x06\x4b\x23\x82\x06\xb1\x22\x81\x06\x47\x20\x8d\x06\x2a\x23\x82\x06\x60\x22\x71\x06\x3a\x20\x91\x06\xce\x22\x99\x06\x40\x22\x86\x06\x3e\x20\x9b\x06\xd6\x22\x98\x06\x4e\x22\x80\x06\x1c\x20\x86\x06\xc8\x22\x77\x06\x4e\x22\x81\x06\x38\x20\x99\x06\xad\x22\x8b\x06\x35\x22\x87\x06\x59\x20\xab\x06\xeb\x22\x92\x06\x56\x22\x7d\x06\x3a\x20\x96\x06\xf2\x22\x7c\x06\x47\x22\x86\x06\x63\x20\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xa4\x06\xa3\x22\x93\x06\x6d\x22\x86\x06\x50\x20\x96\x06\xdb\x22\x98\x06\x47\x22\x76\x06\x2f\x20\x97\x06\xbc\x22\x93\x06\x29\x22\x86\x06\x70\x20\x9a\x06\xcf\x22\x96\x06\x29\x22\x86\x06\x55\x20\x95\x06\xdc\x22\x94\x06\x55\x22\x85\x06\x6c\x20\xb2\x06\x0c\x23\x9d\x06\x44\x22\x92\x06\x54\x20\x9f\x06\x96\x23\x80\x06\x47\x22\x90\x06\x3e\x20\x8c\x06\xe8\x22\x88\x06\x34\x22\x85\x06\x43\x20\x97\x06\xd8\x22\x95\x06\x5e\x22\x86\x06\x55\x20\x9a\x06\x0a\x23\x87\x06\x2c\x22\x8a\x06\x10\x20\x92\x06\xcd\x22\x89\x06\x22\x22\x78\x06\x35\x20\x96\x06\xdf\x22\x95\x06\x75\x22\x86\x06\x25\x20\xa6\x06\xe1\x22\x8e\x06\x5b\x22\x89\x06\x34\x20\xad\x06\x5a\x23\xa2\x06\x6f\x22\x95\x06\x51\x20\xb5\x06\x48\x23\x95\x06\x5b\x22\x89\x06\x25\x20\x9b\x06\xff\x22\x95\x06\x5b\x22\x77\x06\x2b\x20\x9c\x06\xde\x22\x88\x06\x51\x22\x89\x06\x27\x20\x9f\x06\xce\x22\x91\x06\x68\x22\x86\x06\x32\x20\xa8\x06\xf6\x22\x9d\x06\x71\x22\x94\x06\x75\x20\xab\x06\x20\x23\x9d\x06\x9d\x22\x93\x06\x62\x20\xa7\x06\x47\x23\xa0\x06\x97\x22\x8e\x06\x83\x20\xb6\x06\xbc\x23\x99\x06\xad\x22\x8f\x06\x71\x20\x93\x06\x62\x23\x74\x06\x61\x22\x7f\x06\x56\x20\xa8\x06\x31\x23\x87\x06\x51\x22\x89\x06\x54\x20\x8c\x06\x61\x23\x79\x06\x75\x22\x88\x06\x5e\x20\x97\x06\xfd\x22\x99\x06\x74\x22\x8a\x06\x7b\x20\xa5\x06\x33\x23\x98\x06\x8a\x22\x82\x06\x58\x20\xa4\x06\x7b\x23\x9b\x06\x93\x22\x84\x06\xa0\x20\xa5\x06\x6d\x23\x93\x06\xa9\x22\x83\x06\x85\x20\xaf\x06\xc7\x23\x8f\x06\x8a\x22\x87\x06\x38\x20\x9b\x06\x38\x23\x86\x06\x91\x22\x8b\x06\x3d\x20\x87\x06\xfd\x22\x80\x06\x61\x22\x86\x06\x50\x20\x9d\x06\xdc\x22\x90\x06\x8a\x22\x89\x06\x41\x20\x9b\x06\x5e\x23\x8e\x06\x62\x22\x84\x06\x36\x20\x9a\x06\xec\x23\x8f\x06\x2c\x23\x87\x06\x4e\x20\x88\x06\x0d\x23\x77\x06\x7d\x22\x81\x06\x49\x20\xa4\x06\x39\x23\x96\x06\x83\x22\x81\x06\x58\x20\xa5\x06\x1e\x23\xa0\x06\x77\x22\x7f\x06\x48\x20\x9a\x06\x01\x23\x84\x06\x35\x22\x8e\x06\x49\x20\x90\x06\xc8\x22\x9a\x06\x46\x22\x7e\x06\x32\x20\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x9d\x06\x23\x23\xa7\x06\x69\x22\x86\x06\x2e\x20\x8a\x06\xcd\x22\x8c\x06\x75\x22\x7c\x06\x2c\x20\xaa\x06\x0d\x23\x9a\x06\x44\x22\x81\x06\x23\x20\xaa\x06\x5b\x23\x92\x06\x19\x22\x7c\x06\x40\x20\xa9\x06\x25\x23\x9d\x06\x46\x22\x80\x06\x59\x20\x9d\x06\xb4\x22\x8d\x06\x43\x22\x7d\x06\x57\x20\xa0\x06\x08\x23\x7a\x06\x46\x22\x7f\x06\x67\x20\xa5\x06\xde\x22\x98\x06\x6f\x22\x7d\x06\x80\x20\xa6\x06\xf4\x22\x86\x06\x7b\x22\x7e\x06\x5a\x20\x98\x06\xc5\x22\x99\x06\x75\x22\x89\x06\x51\x20\x9c\x06\xcd\x22\x98\x06\x38\x22\x81\x06\x62\x20\x96\x06\xd3\x22\x77\x06\x62\x22\x8c\x06\x75\x20\x9d\x06\xde\x22\x8b\x06\x4f\x22\x88\x06\x6c\x20\xa5\x06\xc6\x22\x9c\x06\x68\x22\x8f\x06\x99\x20\x7d\x06\x00\x23\x71\x06\x86\x22\x8c\x06\x87\x20\x9a\x06\x16\x23\xa2\x06\xb7\x22\x84\x06\x98\x20\xab\x06\xdb\x23\x98\x06\x04\x23\x8b\x06\xbf\x20\xa0\x06\xeb\x23\x9d\x06\x0b\x23\x8a\x06\xfe\x20\xa7\x06\x96\x23\x9b\x06\xb4\x22\x99\x06\xa6\x20\xae\x06\xad\x23\x9c\x06\x8b\x22\x88\x06\x92\x20\xa1\x06\x7e\x23\x97\x06\xd6\x22\x87\x06\x96\x20\x95\x06\x62\x23\x9d\x06\xa5\x22\x8c\x06\xb0\x20\xb4\x06\x0d\x24\x96\x06\xd3\x22\x8d\x06\xfd\x20\xbd\x06\xd5\x24\x93\x06\xac\x22\x89\x06\x23\x21\xaf\x06\xdd\x24\xa1\x06\xcb\x22\x90\x06\x26\x21\xa9\x06\xed\x23\x9e\x06\xc0\x22\x88\x06\xf9\x20\x9e\x06\x55\x23\x94\x06\xd6\x22\x9a\x06\xd3\x20\x9c\x06\x74\x23\x93\x06\xac\x22\x80\x06\x99\x20\xac\x06\x79\x23\x9b\x06\x78\x22\x99\x06\x9f\x20\xac\x06\x53\x23\x95\x06\xa9\x22\x86\x06\x95\x20\xa9\x06\xa3\x23\x94\x06\xad\x22\x7f\x06\xa6\x20\x8c\x06\x9c\x23\x86\x06\x9f\x22\x80\x06\xa7\x20\xa8\x06\x4b\x23\x9f\x06\xad\x22\x90\x06\x95\x20\xa3\x06\x51\x23\x9e\x06\x91\x22\x80\x06\xab\x20\x96\x06\x46\x23\x97\x06\x87\x22\x97\x06\x8b\x20\x9c\x06\x21\x23\x96\x06\x61\x22\x86\x06\x83\x20\xa6\x06\x29\x23\x9c\x06\x92\x22\x8c\x06\xa6\x20\xa5\x06\x36\x23\x9b\x06\x99\x22\x84\x06\x8d\x20\xac\x06\x8b\x23\x9a\x06\xbd\x22\x94\x06\xc6\x20\xa0\x06\x40\x23\xa6\x06\x88\x22\x84\x06\x7a\x20\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb2\x06\x33\x23\x9d\x06\x82\x22\x8b\x06\x8a\x20\xa5\x06\x0d\x23\xa1\x06\x77\x22\x89\x06\x77\x20\xa2\x06\x16\x23\x8e\x06\x96\x22\x90\x06\x6f\x20\xa4\x06\x2e\x23\x95\x06\x52\x22\x8b\x06\x80\x20\x9f\x06\x33\x23\x97\x06\x56\x22\x76\x06\x56\x20\x91\x06\x21\x23\x95\x06\x62\x22\x89\x06\x6f\x20\xa9\x06\x42\x23\x8f\x06\x40\x22\x7f\x06\x2e\x20\x8e\x06\x0e\x23\x7e\x06\x47\x22\x7f\x06\x48\x20\xa7\x06\x06\x23\xae\x06\x57\x22\x93\x06\x65\x20\x9c\x06\x21\x23\x8c\x06\x61\x22\x86\x06\x5d\x20\xa8\x06\x05\x23\x97\x06\x71\x22\x8b\x06\x7d\x20\xa9\x06\x0d\x23\x9c\x06\x9f\x22\x8d\x06\x9d\x20\xa5\x06\x3a\x23\x95\x06\xbb\x22\x89\x06\x99\x20\xa6\x06\x72\x23\x93\x06\xb5\x22\x97\x06\xa2\x20\xa6\x06\x65\x23\x9a\x06\x8a\x22\x8c\x06\x80\x20\xb3\x06\x7f\x23\x93\x06\x47\x22\x89\x06\x81\x20\xa1\x06\xa4\x23\x8e\x06\x60\x22\x8b\x06\x5d\x20\xa9\x06\xdf\x23\x92\x06\x7f\x22\x81\x06\x61\x20\xb9\x06\xe4\x23\xa5\x06\x87\x22\x8e\x06\x50\x20\x9e\x06\x0f\x24\x95\x06\x9d\x22\x8c\x06\xb4\x20\xa1\x06\x01\x24\x8c\x06\xb8\x22\x81\x06\x8f\x20\x9f\x06\x3c\x23\xa4\x06\xa6\x22\x7f\x06\x70\x20\xa5\x06\x17\x23\x85\x06\x72\x22\x68\x06\x4f\x20\xae\x06\x2c\x23\xa7\x06\x92\x22\x7a\x06\x3c\x20\x8e\x06\x19\x23\x84\x06\x46\x22\x76\x06\x3f\x20\xa1\x06\x76\x23\x93\x06\x74\x22\x88\x06\x54\x20\xa6\x06\xc4\x23\x98\x06\x25\x22\x92\x06\x76\x20\xa7\x06\x7d\x24\x91\x06\x50\x22\x89\x06\x95\x20\xa1\x06\x8f\x24\x8f\x06\x47\x22\x98\x06\xca\x20\x98\x06\x08\x24\x80\x06\x29\x22\x7c\x06\x64\x20\x89\x06\x1f\x23\x73\x06\x3e\x22\x8a\x06\x44\x20\x96\x06\x03\x23\x88\x06\x19\x22\x8b\x06\x0f\x20\x9d\x06\xdd\x22\xa4\x06\x27\x22\x92\x06\x44\x20\x91\x06\x3f\x23\x7f\x06\xe8\x21\x88\x06\x46\x20\x8c\x06\x6c\x23\x6e\x06\x34\x22\x7b\x06\xf2\x1f\x7c\x06\xe8\x22\x73\x06\xf1\x21\x7f\x06\xfc\x1f\x90\x06\x39\x23\x81\x06\x2b\x22\x86\x06\xd8\x1f\xa3\x06\x16\x23\x89\x06\xe4\x21\x7e\x06\xfa\x1f\xa3\x06\x00\x23\x91\x06\x15\x22\x85\x06\x06\x20\x96\x06\x9f\x22\x97\x06\x0e\x22\x82\x06\x12\x20\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x82\x06\xf8\x22\x81\x06\x21\x22\x87\x06\x38\x20\x86\x06\x74\x23\x77\x06\x82\x22\x8e\x06\x5f\x20\x9c\x06\x71\x23\x87\x06\x48\x22\x8a\x06\x34\x20\xac\x06\x6f\x23\x93\x06\x19\x22\x87\x06\x4e\x20\x9f\x06\x77\x23\x97\x06\x67\x22\x83\x06\x34\x20\x97\x06\x86\x23\x81\x06\x44\x22\x82\x06\x22\x20\xa6\x06\x5b\x23\x97\x06\x24\x22\x84\x06\x22\x20\xa6\x06\x33\x23\x98\x06\x1c\x22\x7c\x06\x29\x20\xad\x06\x09\x23\xa6\x06\x6d\x22\x88\x06\x2d\x20\xa8\x06\x58\x23\x8f\x06\x2c\x22\x84\x06\x19\x20\x92\x06\x29\x23\x81\x06\x1d\x22\x7f\x06\x03\x20\x8b\x06\xdc\x22\x89\x06\x2e\x22\x7e\x06\xf5\x1f\x9f\x06\xdc\x22\x89\x06\x2f\x22\x7b\x06\xde\x1f\x9c\x06\xce\x22\x96\x06\x25\x22\x8a\x06\x09\x20\x9a\x06\x01\x23\x78\x06\x0c\x22\x84\x06\x03\x20\x99\x06\x07\x23\xa6\x06\x57\x22\x77\x06\x24\x20\x8b\x06\x3c\x23\x94\x06\x93\x22\x82\x06\x14\x20\x90\x06\x2b\x23\x8e\x06\x0f\x23\x79\x06\x12\x20\xa6\x06\xfb\x22\x97\x06\x2b\x22\x82\x06\x12\x20\x9d\x06\xb5\x22\x93\x06\x26\x22\x81\x06\x06\x20\x93\x06\xe5\x22\x79\x06\x14\x22\x83\x06\x0a\x20\x88\x06\x05\x23\x7b\x06\xe8\x21\x75\x06\xec\x1f\xa3\x06\xf3\x22\x98\x06\x4f\x22\x7d\x06\xdf\x1f\x9d\x06\x6c\x22\x9c\x06\x2d\x22\x87\x06\xf9\x1f\x96\x06\xbe\x22\x94\x06\xee\x21\x7f\x06\xe8\x1f\x9a\x06\xd5\x22\x94\x06\x2c\x22\x82\x06\x21\x20\xa5\x06\xc3\x22\x8c\x06\xda\x21\x85\x06\xfc\x1f\x8c\x06\xa9\x22\x86\x06\x00\x22\x7a\x06\xf0\x1f\x79\x06\x08\x23\x71\x06\x05\x22\x7c\x06\xef\x1f\x8c\x06\x09\x23\x82\x06\x20\x22\x78\x06\xe9\x1f\xa4\x06\xed\x22\x8e\x06\xfe\x21\x84\x06\xbd\x1f\x9e\x06\xea\x22\xa3\x06\xd6\x21\x7b\x06\xd7\x1f\xa2\x06\x72\x22\x98\x06\xf9\x21\x87\x06\xca\x1f\x9b\x06\xb7\x22\x89\x06\xe7\x21\x90\x06\xf2\x1f\xb0\x06\xf9\x22\x9c\x06\xcf\x21\x82\x06\xe4\x1f\x6f\x06\x36\x23\x56\x06\x05\x22\x6a\x06\xe9\x1f\x85\x06\x25\x23\x67\x06\xcf\x21\x8e\x06\x02\x20\x97\x06\x79\x23\x93\x06\xdd\x21\x77\x06\xdd\x1f\x96\x06\x63\x23\x8b\x06\xec\x21\x7b\x06\xec\x1f\xa7\x06\x1d\x23\x95\x06\xe0\x21\x92\x06\xec\x1f\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x99\x06\xd5\x22\x9c\x06\x11\x22\x76\x06\xc4\x1f\x98\x06\xe1\x22\x8b\x06\x02\x22\x80\x06\x11\x20\x9f\x06\xb2\x22\x8f\x06\x04\x22\x78\x06\xf9\x1f\x7a\x06\x38\x23\x7a\x06\x02\x22\x79\x06\x1e\x20\xa9\x06\x1b\x23\x93\x06\x0e\x22\x84\x06\x00\x20\xa0\x06\x0f\x23\x98\x06\xfd\x21\x7b\x06\xfa\x1f\x9d\x06\x1f\x23\x94\x06\xf4\x21\x74\x06\xf7\x1f\x93\x06\x06\x23\x80\x06\xcc\x21\x73\x06\xea\x1f\x95\x06\xd7\x22\x8d\x06\xfe\x21\x8e\x06\xef\x1f\x88\x06\xcd\x22\x77\x06\xe9\x21\x85\x06\xd8\x1f\x85\x06\x96\x22\x78\x06\x44\x22\x6e\x06\x08\x20\x9a\x06\xd9\x22\x89\x06\x12\x22\x75\x06\x0c\x20\x98\x06\x28\x23\x98\x06\x07\x22\x78\x06\xf2\x1f\x80\x06\xfa\x22\x73\x06\xeb\x21\x80\x06\xdc\x1f\x8e\x06\xe5\x22\x74\x06\xe8\x21\x79\x06\xc7\x1f\xa7\x06\xcf\x22\x91\x06\xf3\x21\x81\x06\xc8\x1f\x9e\x06\xe1\x22\x9b\x06\xb1\x21\x87\x06\xae\x1f\x95\x06\xf0\x22\x8c\x06\xc1\x21\x87\x06\xa6\x1f\xa5\x06\x95\x22\x92\x06\x0e\x22\x83\x06\xd7\x1f\x76\x06\xcc\x22\x6f\x06\x10\x22\x80\x06\xbd\x1f\x98\x06\xc0\x22\x88\x06\xc1\x21\x7b\x06\xbe\x1f\x96\x06\xd3\x22\x7c\x06\xd1\x21\x72\x06\xb5\x1f\x8e\x06\xa5\x22\x78\x06\xd4\x21\x74\x06\xa9\x1f\x9f\x06\xb0\x22\xa1\x06\xcd\x21\x87\x06\x9f\x1f\x9c\x06\xba\x22\x9b\x06\xd9\x21\x83\x06\xac\x1f\x83\x06\xd0\x22\x74\x06\xc2\x21\x7a\x06\xcb\x1f\xa1\x06\x1d\x23\x7f\x06\xc4\x21\x76\x06\xc6\x1f\x91\x06\x95\x22\x9e\x06\x1c\x22\x8a\x06\xd8\x1f\x9b\x06\x96\x22\x90\x06\xc2\x21\x7b\x06\xbb\x1f\x97\x06\xb0\x22\x82\x06\xa6\x21\x80\x06\x8c\x1f\x94\x06\x92\x22\x86\x06\xa2\x21\x73\x06\x78\x1f\x8e\x06\xae\x22\x80\x06\xd3\x21\x7e\x06\xa3\x1f\x73\x06\xdd\x22\x6f\x06\x97\x21\x7a\x06\xb5\x1f\x93\x06\xec\x22\x89\x06\x77\x21\x80\x06\xa2\x1f\x92\x06\xf8\x22\x82\x06\x84\x21\x85\x06\xd1\x1f\x78\x06\xa2\x22\x69\x06\x99\x21\x58\x06\x9d\x1f\x97\x06\x71\x22\x87\x06\xb0\x21\x6f\x06\x78\x1f\x9f\x06\x71\x22\x92\x06\x8b\x21\x80\x06\x86\x1f\x97\x06\x6c\x22\x98\x06\xa5\x21\x78\x06\x52\x1f\x93\x06\x8e\x22\x86\x06\x98\x21\x69\x06\x89\x1f\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x7d\x06\xe6\x22\x70\x06\xf1\x21\x6d\x06\x8b\x1f\x83\x06\x9a\x22\x6f\x06\xb0\x21\x71\x06\x7d\x1f\x9a\x06\x71\x22\x7a\x06\x60\x21\x6e\x06\x75\x1f\x96\x06\x4a\x22\x7f\x06\x70\x21\x7b\x06\x63\x1f\x92\x06\x30\x22\x86\x06\xaf\x21\x81\x06\x6a\x1f\x71\x06\x73\x22\x6e\x06\xe2\x21\x5b\x06\x6f\x1f\x8a\x06\x8e\x22\x87\x06\xcd\x21\x70\x06\x5e\x1f\x8a\x06\x15\x23\x70\x06\xa0\x21\x68\x06\xa2\x1f\x7e\x06\xb1\x22\x7d\x06\x93\x21\x74\x06\x67\x1f\x96\x06\x76\x22\x92\x06\xb4\x21\x7c\x06\x5e\x1f\x8f\x06\x41\x22\x88\x06\x77\x21\x7c\x06\x82\x1f\x90\x06\x7e\x22\x77\x06\x62\x21\x77\x06\x53\x1f\x89\x06\x63\x22\x81\x06\x78\x21\x7e\x06\x71\x1f\x74\x06\x64\x22\x7b\x06\xad\x21\x7c\x06\x68\x1f\x9c\x06\x62\x22\x8b\x06\xb8\x21\x77\x06\x80\x1f\x6e\x06\xe0\x22\x5d\x06\xd1\x21\x75\x06\x90\x1f\x76\x06\xbd\x22\x63\x06\x3e\x22\x4b\x06\xcb\x1f\x92\x06\x67\x22\x8b\x06\xad\x21\x7e\x06\x6f\x1f\x9e\x06\x08\x22\x89\x06\x74\x21\x71\x06\x64\x1f\x75\x06\x39\x22\x7b\x06\x87\x21\x66\x06\x52\x1f\x9b\x06\x84\x22\x8a\x06\xac\x21\x83\x06\x7a\x1f\x88\x06\xf1\x21\x8a\x06\x6f\x21\x73\x06\x56\x1f\x93\x06\x0d\x22\x93\x06\x8d\x21\x7e\x06\x34\x1f\x97\x06\x09\x22\x90\x06\x78\x21\x84\x06\x6b\x1f\x90\x06\xe0\x21\x9b\x06\xa9\x21\x7d\x06\x71\x1f\x98\x06\x21\x22\x80\x06\xb8\x21\x75\x06\x3f\x1f\x8c\x06\x2e\x22\x86\x06\x7e\x21\x83\x06\x49\x1f\x86\x06\x6e\x22\x7c\x06\x99\x21\x7d\x06\x4b\x1f\x92\x06\x76\x22\x7f\x06\xab\x21\x7f\x06\x65\x1f\x85\x06\x8f\x22\x76\x06\xbe\x21\x6f\x06\xb4\x1f\x81\x06\x7d\x22\x7b\x06\x83\x21\x7b\x06\x46\x1f\x9f\x06\xa4\x22\x8e\x06\xfb\x21\x76\x06\x5e\x1f\x94\x06\x85\x22\x83\x06\xa8\x21\x68\x06\x59\x1f\xa3\x06\x35\x23\x8c\x06\x9c\x21\x82\x06\x42\x1f\x9b\x06\xad\x22\x99\x06\xd7\x21\x99\x06\xac\x1f\xa2\x06\x95\x22\x98\x06\xb7\x21\x80\x06\x83\x1f\x9d\x06\x04\x23\x88\x06\xce\x21\x86\x06\xb8\x1f\x9c\x06\x2b\x23\x93\x06\x19\x22\x80\x06\xa6\x1f\xaa\x06\xcc\x22\x97\x06\x08\x22\x77\x06\x6b\x1f\x88\x06\x17\x23\x70\x06\xa1\x21\x8b\x06\x90\x1f\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x87\x06\xc0\x22\x7a\x06\xad\x21\x7c\x06\x72\x1f\x92\x06\xad\x22\x80\x06\x82\x21\x7b\x06\xbd\x1f\x8a\x06\xd4\x22\x6c\x06\x93\x21\x78\x06\x9b\x1f\x96\x06\xbd\x22\x77\x06\x75\x21\x86\x06\x59\x1f\x9a\x06\x44\x23\x85\x06\x42\x21\x82\x06\x90\x1f\x8c\x06\x19\x23\x69\x06\x4d\x21\x79\x06\x80\x1f\x71\x06\x62\x23\x59\x06\x9c\x21\x77\x06\xb1\x1f\xa5\x06\x29\x23\x8d\x06\x75\x21\x75\x06\x86\x1f\xa8\x06\x26\x23\x91\x06\x3e\x21\x88\x06\x86\x1f\x77\x06\x05\x23\x67\x06\x93\x21\x85\x06\x78\x1f\x8f\x06\x77\x22\x8d\x06\x3f\x21\x7c\x06\x4e\x1f\x9c\x06\xb4\x22\x84\x06\x3b\x21\x73\x06\xad\x1e\x96\x06\xde\x22\x7f\x06\x62\x21\x73\x06\x87\x1e\x90\x06\x4a\x22\x7c\x06\x2f\x21\x6f\x06\x91\x1e\x8a\x06\x87\x22\x6c\x06\x4d\x21\x77\x06\xad\x1e\x93\x06\xe4\x22\x90\x06\x8b\x21\x77\x06\x21\x1f\x89\x06\x1f\x23\x84\x06\xe6\x21\x70\x06\x92\x1f\xa8\x06\xcf\x22\x9b\x06\xfc\x21\x8e\x06\x82\x1f\x9d\x06\x2a\x23\x87\x06\x99\x21\x79\x06\x4b\x1f\x88\x06\x57\x22\x7c\x06\x71\x21\x7f\x06\x79\x1f\x7a\x06\x0e\x23\x6f\x06\x77\x21\x77\x06\xac\x1e\xec\x08\xff\xff\xec\x08\xff\xff\xee\x08\xff\xff\x00\x00\x0a\x15\x00\x00\xc5\x15\x00\x00\x7b\x16\x00\x00\x0a\x15\x00\x00\xc5\x15\x00\x00\x7b\x16\x00\x00\x1a\x15\x00\x00\xd7\x15\x00\x00\x7b\x16\x00\x00\x1a\x15\x00\x00\xd7\x15\x00\x00\x7e\x16\x11\x09\xff\xff\x08\x09\xff\xff\x09\x09\xff\xff\xb5\x06\x06\x25\x9e\x06\xe2\x22\x99\x06\xa5\x20\x7a\x06\x09\x24\x71\x06\x47\x23\x93\x06\x51\x21\xba\x06\x87\x24\x95\x06\x5e\x23\x94\x06\x84\x21\xb4\x06\xaa\x24\xa5\x06\x4c\x23\x9b\x06\x9f\x21\x85\x06\xe2\x24\x73\x06\x52\x23\x9e\x06\xc5\x21\xcc\x06\x02\x25\xb6\x06\x95\x23\xa3\x06\xd7\x21\xd7\x06\x7a\x26\xad\x06\xa2\x23\xaf\x06\xf8\x21\xbc\x06\x76\x25\x98\x06\xa0\x23\x94\x06\x1c\x22\xc0\x06\xe6\x24\xaa\x06\x2a\x23\x97\x06\xc0\x21\xaf\x06\xe1\x24\x96\x06\xa0\x23\xa1\x06\xa1\x21\xa2\x06\xf5\x24\x92\x06\x5e\x23\xad\x06\xd1\x21\xbf\x06\xf5\x24\xb5\x06\x70\x23\xa1\x06\xc0\x21\xcd\x06\x7f\x25\xb2\x06\x65\x23\xa4\x06\x16\x22\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xce\x06\x60\x26\xa0\x06\x7d\x23\x9f\x06\x78\x22\xc8\x06\x22\x26\xad\x06\xc9\x23\xbd\x06\xbf\x22\xc0\x06\xaa\x25\xa4\x06\xa0\x23\xa7\x06\x25\x22\xc9\x06\x73\x25\xb3\x06\x7b\x23\x9d\x06\x0c\x22\xcb\x06\x18\x25\xb0\x06\x4e\x23\xa6\x06\xd1\x21\x9e\x06\xe0\x24\x84\x06\x93\x23\x9b\x06\xf8\x21\xb0\x06\x0f\x25\x9c\x06\x69\x23\x9b\x06\xe6\x21\xc5\x06\x7a\x25\xad\x06\xa2\x23\xa3\x06\xfb\x21\xc5\x06\xeb\x25\xb0\x06\xd6\x23\xb0\x06\x30\x22\xb0\x06\x07\x25\x9e\x06\x93\x23\x96\x06\xe1\x21\x96\x06\xc1\x24\x7a\x06\x59\x23\xa0\x06\x85\x21\xb7\x06\xa0\x24\xa4\x06\x64\x23\x9b\x06\x7a\x21\x9d\x06\xa3\x24\x7d\x06\x5e\x23\x8b\x06\x50\x21\xb5\x06\xd9\x24\x96\x06\x5a\x23\x9b\x06\x33\x21\xa6\x06\xde\x24\x96\x06\x83\x23\x8b\x06\x23\x21\xb8\x06\x16\x25\xa3\x06\xc2\x23\x99\x06\x25\x21\xc9\x06\xc8\x24\xb3\x06\x5a\x23\x95\x06\x82\x20\xad\x06\x83\x24\xa3\x06\x1e\x23\x9c\x06\x92\x20\xc3\x06\x43\x24\xa6\x06\x05\x23\xaa\x06\xb2\x20\xac\x06\x55\x24\xa5\x06\x59\x23\x99\x06\x1c\x21\xb8\x06\x92\x24\xb3\x06\x50\x23\x9d\x06\x60\x21\xae\x06\xd4\x24\xaa\x06\x8e\x23\x92\x06\x64\x21\xd1\x06\x2c\x25\xa5\x06\xf2\x23\xac\x06\x3c\x22\xbf\x06\xa0\x24\xaa\x06\xd3\x23\x9c\x06\xf1\x21\xc0\x06\x32\x24\xae\x06\xc2\x23\x98\x06\xb8\x21\xb4\x06\x2c\x24\xb2\x06\x77\x23\xa2\x06\xa1\x21\xba\x06\x3a\x24\x8c\x06\x48\x23\x98\x06\x8d\x21\xbe\x06\x55\x24\xa4\x06\x41\x23\xa6\x06\x9b\x21\xac\x06\x2f\x24\xad\x06\x5d\x23\xaf\x06\x8e\x21\xb7\x06\xf2\x24\xa4\x06\x79\x23\x99\x06\xb5\x21\xc4\x06\x05\x25\xaf\x06\x96\x23\xa6\x06\xca\x21\xc0\x06\x9c\x24\x9e\x06\x4a\x23\xa6\x06\x84\x21\xbd\x06\xac\x24\x9c\x06\x44\x23\x9e\x06\x8b\x21\xb7\x06\x72\x24\xb8\x06\x73\x23\x9e\x06\x89\x21\xae\x06\x17\x24\xa7\x06\x64\x23\x9f\x06\x81\x21\xb8\x06\xa0\x24\xad\x06\x46\x23\x9f\x06\x98\x21\xb9\x06\xe4\x24\xa9\x06\xaf\x23\x9a\x06\xcf\x21\xcd\x06\xfd\x24\xae\x06\x7c\x23\xa9\x06\xce\x21\xbd\x06\x45\x24\xb8\x06\x36\x23\x93\x06\x7c\x21\xb8\x06\x7b\x24\xae\x06\xfd\x22\xac\x06\x78\x21\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb8\x06\x2c\x24\xa4\x06\x21\x23\xa4\x06\x4e\x21\xc6\x06\x26\x24\xb1\x06\x01\x23\x99\x06\xe9\x20\xa2\x06\x51\x24\x9a\x06\x48\x23\x97\x06\xe8\x20\xc4\x06\x8b\x24\xb1\x06\x99\x23\x9d\x06\x37\x21\x97\x06\x02\x25\x8f\x06\xc0\x23\x97\x06\x75\x21\xaf\x06\xb2\x24\x9a\x06\xa1\x23\xa3\x06\x5c\x21\xb1\x06\xa0\x24\xa0\x06\x09\x23\x9b\x06\x54\x21\xb5\x06\x32\x24\xa6\x06\x17\x23\x92\x06\x28\x21\xa7\x06\x62\x24\x92\x06\x47\x23\x9e\x06\x6d\x21\xb3\x06\x48\x24\xb0\x06\x47\x23\x9c\x06\x55\x21\xb0\x06\x4c\x24\x97\x06\x0b\x23\x97\x06\x53\x21\xb9\x06\x93\x24\xa8\x06\x71\x23\x93\x06\x95\x21\xba\x06\x7f\x24\xb4\x06\x43\x23\x96\x06\x9f\x21\xc8\x06\x44\x24\xb6\x06\x50\x23\x9c\x06\x7a\x21\xb8\x06\x6c\x24\xad\x06\x49\x23\xa0\x06\x9f\x21\xbc\x06\xa4\x24\xad\x06\x45\x23\x8d\x06\x9a\x21\xa4\x06\xf4\x24\x79\x06\x78\x23\x7e\x06\xe6\x21\xc4\x06\xf7\x24\xa9\x06\x80\x23\xa6\x06\xbb\x21\xc4\x06\x49\x25\xac\x06\xdc\x23\x9b\x06\x19\x22\xb5\x06\xf4\x24\xa6\x06\xaf\x23\x9c\x06\xf5\x21\xba\x06\x8b\x24\xa6\x06\x40\x23\x94\x06\xaf\x21\x98\x06\x6b\x24\x88\x06\x55\x23\x94\x06\xaf\x21\xba\x06\xb8\x24\x9c\x06\x4c\x23\xa2\x06\xaa\x21\xb9\x06\xc8\x24\x99\x06\x6a\x23\x8a\x06\xec\x21\xc1\x06\x95\x24\xb1\x06\x50\x23\xac\x06\xc5\x21\xb6\x06\x53\x25\x9d\x06\xc4\x23\xab\x06\xf9\x21\xb8\x06\x23\x25\xad\x06\x95\x23\xa8\x06\x09\x22\xb4\x06\xd7\x24\xa2\x06\x78\x23\x9b\x06\x97\x21\xc3\x06\x50\x24\xae\x06\x4e\x23\xa9\x06\xa5\x21\xbd\x06\x84\x24\xac\x06\x72\x23\xa4\x06\xa4\x21\xb5\x06\x84\x24\x9c\x06\x32\x23\x9d\x06\x9b\x21\xc2\x06\x0e\x25\xab\x06\x3e\x23\x95\x06\x98\x21\xbe\x06\x2a\x25\xa5\x06\xbb\x23\xa8\x06\x04\x22\xb4\x06\x34\x25\xb5\x06\x86\x23\xa9\x06\xb2\x21\xbd\x06\x9a\x24\xa5\x06\x3b\x23\x95\x06\x73\x21\xbd\x06\x8b\x24\xb6\x06\x3b\x23\x9c\x06\x6b\x21\xa3\x06\x97\x24\x90\x06\x3e\x23\x8a\x06\x6c\x21\xb2\x06\x26\x24\xa9\x06\x43\x23\xa1\x06\x6e\x21\xb5\x06\x55\x24\xa6\x06\x3a\x23\x94\x06\x44\x21\xcd\x06\xe3\x24\xb2\x06\x76\x23\xaf\x06\x9c\x21\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff", 0x000f000);
ret = usb_bulk_write(devh, 0x00000001, buf, 0x000f000, 4686);
printf("8292 bulk write returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(63*1000);
memcpy(buf, "\x6c\x1c\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000002, 0x0000000, buf, 0x0000004, 1000);
printf("8293 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\xc5\x06\x5d\x25\xae\x06\x04\x24\xa7\x06\xeb\x21\xc6\x06\x1b\x25\xb2\x06\x93\x23\x90\x06\xb5\x21\xd7\x06\xff\x24\xaa\x06\x29\x23\x98\x06\x8a\x21\xc1\x06\x93\x24\xb7\x06\x34\x23\xa4\x06\x74\x21\xc4\x06\x95\x24\xb0\x06\x49\x23\x9b\x06\x8a\x21\xb8\x06\x50\x24\xb2\x06\x70\x23\xa3\x06\x8d\x21\xb7\x06\x80\x24\xb2\x06\x7c\x23\xa0\x06\xb2\x21\xb8\x06\x4b\x25\xab\x06\xd5\x23\x9a\x06\xea\x21\xbc\x06\x00\x25\xad\x06\x7a\x23\x9f\x06\xd2\x21\xb2\x06\xc4\x24\x9b\x06\x14\x23\x90\x06\xa3\x21\xb9\x06\x97\x24\x9b\x06\x2c\x23\x9a\x06\xdf\x21\xbe\x06\x8d\x24\xa9\x06\x4c\x23\x95\x06\xc3\x21\x8d\x06\xe4\x24\x7d\x06\x68\x23\x8f\x06\xd2\x21\xb3\x06\xa5\x24\x9d\x06\x7e\x23\x9c\x06\xc4\x21\xad\x06\xc4\x24\x9a\x06\xb6\x23\x9f\x06\x15\x22\xba\x06\xe1\x24\xb5\x06\xf8\x23\xab\x06\x40\x22\xba\x06\xb2\x24\xb0\x06\x65\x23\x91\x06\xd4\x21\xc6\x06\xcb\x24\xb1\x06\x51\x23\x9b\x06\xd0\x21\xb5\x06\x96\x24\xb0\x06\x51\x23\xa1\x06\xd0\x21\xbb\x06\x83\x24\xb3\x06\x91\x23\x94\x06\xb7\x21\xc7\x06\xd7\x24\xa6\x06\x4d\x23\x98\x06\xe6\x21\xa6\x06\x24\x25\x96\x06\x84\x23\x99\x06\x3e\x22\xb1\x06\xef\x24\x9a\x06\x87\x23\xa6\x06\x08\x22\xc0\x06\xb9\x24\xb2\x06\x78\x23\xa5\x06\x0e\x22\xb2\x06\x84\x24\x9f\x06\x8c\x23\x9b\x06\x19\x22\xad\x06\xd0\x24\xad\x06\xa3\x23\xa0\x06\x21\x22\xc6\x06\x04\x25\xb0\x06\x8e\x23\xa9\x06\x3b\x22\xbe\x06\x24\x25\xa5\x06\x90\x23\xa0\x06\x06\x22\xb5\x06\x84\x25\xaa\x06\x3d\x24\xa4\x06\x6a\x22\xb7\x06\x40\x25\xac\x06\x55\x24\x96\x06\x73\x22\xac\x06\xf4\x24\xab\x06\xdf\x23\x9c\x06\xff\x21\xb4\x06\xeb\x24\xa8\x06\xc9\x23\xaa\x06\x35\x22\xa5\x06\xf5\x24\xa1\x06\xc8\x23\x98\x06\x02\x22\xb8\x06\xd5\x24\xaf\x06\xa5\x23\xa2\x06\x18\x22\xbe\x06\xd3\x24\xb4\x06\xb8\x23\x97\x06\xfa\x21\xb9\x06\x23\x25\xad\x06\x05\x24\x9b\x06\x6b\x22\xbb\x06\x8c\x25\xb4\x06\x58\x24\xae\x06\xc2\x22\xb5\x06\xfd\x24\xad\x06\xe6\x23\xb1\x06\x46\x22\xc4\x06\x0c\x25\xb0\x06\xa8\x23\x8e\x06\xf9\x21\xac\x06\xa6\x24\xa4\x06\xcc\x23\x9c\x06\xea\x21\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xc0\x06\xce\x24\xac\x06\xa8\x23\x8e\x06\xc5\x21\xb8\x06\x38\x25\xa1\x06\x5b\x23\x99\x06\xf9\x21\xd2\x06\x5e\x25\xac\x06\xe6\x23\xa5\x06\x14\x22\xc1\x06\xc9\x25\xb0\x06\x1b\x24\xa4\x06\x3b\x22\xb1\x06\x1f\x25\xaa\x06\xd1\x23\x8f\x06\x09\x22\xc1\x06\x14\x25\x95\x06\x9a\x23\x90\x06\x13\x22\xb8\x06\xc9\x24\xad\x06\x80\x23\xad\x06\x16\x22\xbf\x06\x78\x24\xad\x06\x9a\x23\xa7\x06\xfe\x21\xbe\x06\x83\x24\xac\x06\x60\x23\xaa\x06\xdb\x21\xa1\x06\xfa\x24\x97\x06\xd7\x23\x8c\x06\x01\x22\xbb\x06\x61\x25\xa4\x06\xc8\x23\x9f\x06\x37\x22\xb5\x06\x13\x25\xaf\x06\x79\x23\xa8\x06\xf2\x21\xb5\x06\x9e\x24\x92\x06\xa7\x23\xae\x06\xcb\x21\xc6\x06\x8c\x24\xa6\x06\x77\x23\xa2\x06\xf9\x21\xaa\x06\xac\x24\x9f\x06\x7c\x23\xa0\x06\xee\x21\xc2\x06\xc1\x24\xa4\x06\x67\x23\x9f\x06\xf8\x21\xbc\x06\xb2\x24\xa7\x06\x68\x23\x9c\x06\x09\x22\xcf\x06\x6d\x25\xae\x06\x18\x24\xaa\x06\x8c\x22\xcc\x06\xd2\x25\xbe\x06\x42\x24\xaf\x06\xab\x22\xc9\x06\xe3\x25\xb5\x06\x82\x23\xaf\x06\x4f\x22\xc4\x06\x8b\x25\xb0\x06\x64\x23\xac\x06\x25\x22\xbf\x06\x28\x25\xad\x06\x6b\x23\xa4\x06\x00\x22\xb8\x06\xd4\x24\x98\x06\x6e\x23\x9e\x06\xe8\x21\xbb\x06\xce\x24\xa9\x06\x65\x23\xa3\x06\x03\x22\xb5\x06\x5b\x25\xaf\x06\x46\x24\x9a\x06\x41\x22\xc8\x06\x3e\x25\xba\x06\x66\x24\x99\x06\x95\x22\xc4\x06\x8d\x24\xa7\x06\xc5\x23\xae\x06\x2a\x22\xc0\x06\xb3\x24\xa8\x06\xa5\x23\xa1\x06\xd1\x21\xbf\x06\x22\x25\xaf\x06\x90\x23\x9e\x06\x15\x22\xcd\x06\x52\x25\xa6\x06\x65\x23\xac\x06\x09\x22\xc4\x06\x32\x25\xae\x06\xa6\x23\x9f\x06\x0d\x22\xb4\x06\x77\x25\xb3\x06\x0e\x24\xa5\x06\x63\x22\xd3\x06\xf9\x25\xba\x06\x33\x24\xa8\x06\xbc\x22\xbf\x06\x5a\x25\xb4\x06\xda\x23\xa0\x06\x3b\x22\xb4\x06\x9c\x24\xa5\x06\xa8\x23\xa4\x06\x21\x22\xc4\x06\xd0\x24\xb6\x06\xa8\x23\xaa\x06\x0b\x22\xc4\x06\xa8\x24\xbb\x06\xd3\x23\xb9\x06\x42\x22\xbf\x06\xac\x24\xa7\x06\xe9\x23\xa7\x06\x44\x22\xb1\x06\x0f\x25\xa6\x06\xe9\x23\xa1\x06\x54\x22\xb8\x06\xa3\x25\xb6\x06\x8a\x24\xb4\x06\xf8\x22\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xc3\x06\x24\x25\xac\x06\xf4\x23\x9d\x06\x4b\x22\xac\x06\xa2\x24\xa5\x06\xbb\x23\x9a\x06\x10\x22\xc7\x06\x9f\x24\xc0\x06\xeb\x23\xb0\x06\x35\x22\xac\x06\x95\x24\xb1\x06\xce\x23\x9d\x06\x4e\x22\xa6\x06\xd9\x24\x9b\x06\xbc\x23\xa1\x06\x1a\x22\xce\x06\x0b\x25\xb2\x06\xf6\x23\xab\x06\x33\x22\xc7\x06\x48\x25\xbb\x06\xa3\x24\xa8\x06\xab\x22\xcf\x06\xfd\x24\xb3\x06\x1c\x24\xac\x06\x58\x22\xa8\x06\x2e\x25\x8b\x06\xde\x23\xab\x06\x2c\x22\xae\x06\x92\x24\x9e\x06\xc2\x23\x98\x06\x52\x22\xbd\x06\x85\x24\xb7\x06\x9e\x23\xa2\x06\xea\x21\xb4\x06\x53\x24\xb0\x06\x75\x23\xa3\x06\x1d\x22\xac\x06\xb0\x24\xa3\x06\xb8\x23\xa4\x06\x0f\x22\xbe\x06\xf4\x24\xb2\x06\x4d\x24\xa0\x06\x69\x22\xbb\x06\xf7\x24\x98\x06\xe2\x23\x90\x06\x7e\x22\xa0\x06\x7f\x24\x8b\x06\x9e\x23\xa2\x06\x0e\x22\xb1\x06\x5e\x24\x9f\x06\x84\x23\x84\x06\xa8\x21\xa6\x06\x6c\x24\xa5\x06\x6e\x23\xa0\x06\xbd\x21\xa7\x06\xae\x24\xa1\x06\x65\x23\xaa\x06\xb8\x21\xae\x06\x7a\x24\xa3\x06\xca\x23\x94\x06\xa6\x21\xc0\x06\xf9\x24\xa4\x06\x03\x24\xa0\x06\x1d\x22\xb9\x06\x56\x25\xb3\x06\x54\x24\x9b\x06\x9b\x22\xc0\x06\x2a\x25\x9c\x06\x06\x24\xa1\x06\x23\x22\xc0\x06\xe4\x25\xa6\x06\x78\x23\x99\x06\x1e\x22\xcb\x06\xf5\x25\xad\x06\xac\x23\xaa\x06\x33\x22\xc6\x06\x44\x25\xac\x06\xaf\x23\x9c\x06\x24\x22\xbe\x06\xab\x24\xb6\x06\xdc\x23\x9a\x06\x39\x22\xbb\x06\x5a\x25\xaf\x06\x09\x24\xb5\x06\x85\x22\x98\x06\x86\x25\x96\x06\x0e\x24\xab\x06\x96\x22\xb0\x06\xec\x24\x9a\x06\x96\x23\xa3\x06\x0e\x22\xac\x06\x9b\x24\xa3\x06\xc6\x23\xa4\x06\x2e\x22\xc3\x06\x9f\x24\xb0\x06\x8b\x23\xa4\x06\x04\x22\xc1\x06\xd5\x24\xb1\x06\xfa\x23\xac\x06\x38\x22\xbf\x06\x82\x24\xa9\x06\x03\x24\xa5\x06\x3d\x22\xb8\x06\x1a\x25\x9f\x06\x03\x24\xae\x06\x8d\x22\xcd\x06\x4c\x25\xb2\x06\xba\x24\xaa\x06\x27\x23\xd0\x06\xfb\x24\xb0\x06\x25\x24\xbc\x06\x8d\x22\xc9\x06\x01\x25\xa6\x06\xe5\x23\xa9\x06\x43\x22\xc0\x06\xc4\x24\xba\x06\xc9\x23\xac\x06\x4a\x22\xbd\x06\xdd\x24\xb3\x06\xf2\x23\x9d\x06\x54\x22\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xa2\x06\xf0\x24\x9f\x06\x06\x24\xae\x06\x65\x22\xbf\x06\x96\x25\xa8\x06\x10\x24\xaa\x06\xc6\x22\xc2\x06\xe8\x25\xb8\x06\xe6\x24\xa2\x06\x22\x23\xb1\x06\xbd\x25\xae\x06\xd8\x24\xaa\x06\xf8\x22\xb8\x06\x3b\x25\xb2\x06\x72\x24\xb3\x06\x90\x22\xbe\x06\x10\x25\xb4\x06\x18\x24\x9f\x06\x74\x22\xb8\x06\x02\x25\xaf\x06\x3d\x24\xb1\x06\x6e\x22\xbd\x06\x0c\x25\xab\x06\x2c\x24\xa7\x06\x7e\x22\xb7\x06\x7d\x25\xb5\x06\x40\x24\xa1\x06\x94\x22\xbb\x06\xe1\x25\xb1\x06\x3c\x25\xa3\x06\x31\x23\xb7\x06\x95\x25\xb4\x06\xb9\x24\xae\x06\x15\x23\xa7\x06\xf9\x24\xaf\x06\x54\x24\xae\x06\xa3\x22\xbb\x06\x0b\x25\xb0\x06\x00\x24\xab\x06\x55\x22\xb8\x06\x01\x25\x9d\x06\xeb\x23\xa7\x06\x3a\x22\xa6\x06\xef\x24\x9d\x06\xff\x23\xa6\x06\x4c\x22\xc0\x06\x4f\x25\xb2\x06\x07\x24\x9c\x06\x72\x22\xc5\x06\xc7\x25\xc4\x06\x8a\x24\xa4\x06\x08\x23\xa7\x06\xbe\x25\xa1\x06\x57\x24\xa7\x06\xff\x22\xbe\x06\x2c\x25\xa9\x06\xf3\x23\x9f\x06\x81\x22\xad\x06\xea\x24\x96\x06\xdf\x23\xad\x06\x9a\x22\xbe\x06\x38\x25\xb0\x06\xe6\x23\xaf\x06\x67\x22\xbd\x06\xe3\x24\xa9\x06\xe4\x23\xa8\x06\x47\x22\xc0\x06\x43\x25\xa9\x06\xe4\x23\xae\x06\x5f\x22\xd1\x06\xda\x25\xb4\x06\x4b\x24\xac\x06\xc5\x22\xce\x06\xfe\x25\xc4\x06\x98\x24\xb5\x06\x5d\x23\xd1\x06\x90\x25\xb4\x06\x19\x24\xa7\x06\xae\x22\xac\x06\x15\x25\x96\x06\x07\x24\xa4\x06\x5f\x22\xbc\x06\x28\x25\xb9\x06\xf8\x23\xa0\x06\x55\x22\xb8\x06\x41\x25\x99\x06\xde\x23\xa2\x06\x9a\x22\x97\x06\x4c\x25\x81\x06\x56\x24\x91\x06\xaf\x22\xbb\x06\x15\x26\xaf\x06\x5e\x24\xb2\x06\xdf\x22\xca\x06\x3e\x26\xc1\x06\xf0\x24\xb3\x06\x4c\x23\xa7\x06\xae\x25\xa1\x06\xb3\x24\xad\x06\xda\x22\xb6\x06\x36\x25\xaf\x06\x24\x24\xa2\x06\x7c\x22\xae\x06\x3e\x25\xa5\x06\x0f\x24\x9e\x06\xb9\x22\xb3\x06\x26\x25\xad\x06\x4b\x24\xac\x06\xa6\x22\xc4\x06\x45\x25\xaa\x06\x43\x24\xa3\x06\xa1\x22\xb3\x06\xa3\x25\xa8\x06\x55\x24\xa6\x06\xf0\x22\xcd\x06\x08\x26\xb1\x06\x25\x25\xb0\x06\x58\x23\xc8\x06\xcf\x25\xb7\x06\xe2\x24\xa4\x06\x2c\x23\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb5\x06\x96\x25\xa7\x06\x7a\x24\xa1\x06\xef\x22\xc4\x06\x2f\x25\xb8\x06\x47\x24\xae\x06\xd9\x22\xbd\x06\x47\x25\xb9\x06\x2e\x24\xb0\x06\xaa\x22\xc7\x06\x5d\x25\xaa\x06\x6c\x24\xad\x06\xc6\x22\xc8\x06\xac\x25\xad\x06\x93\x24\xa6\x06\xcd\x22\xaf\x06\x5d\x26\xb0\x06\x51\x25\xae\x06\x90\x23\xb7\x06\x6d\x26\xc3\x06\x25\x25\xb1\x06\x8e\x23\xb5\x06\xdf\x25\xb7\x06\xa7\x24\xae\x06\x25\x23\x99\x06\x9e\x25\x99\x06\x92\x24\x9a\x06\xe2\x22\xb4\x06\xb9\x25\xb2\x06\x84\x24\xa9\x06\xf3\x22\xbf\x06\x5e\x25\xb3\x06\x91\x24\xa3\x06\xc7\x22\xab\x06\x9a\x25\x9f\x06\x9b\x24\xb4\x06\x22\x23\xbc\x06\x26\x26\xbb\x06\x44\x25\xb4\x06\x87\x23\xc0\x06\x38\x26\xbd\x06\xa3\x25\xb2\x06\xbe\x23\xd5\x06\x21\x26\xab\x06\xa0\x24\xc3\x06\x8c\x23\xc9\x06\xb2\x25\xbb\x06\x87\x24\xb5\x06\x34\x23\xc5\x06\x82\x25\xb8\x06\x7a\x24\xba\x06\x30\x23\xbf\x06\x7b\x25\xb7\x06\x53\x24\xb6\x06\x2d\x23\xbd\x06\xaa\x25\xaf\x06\xa4\x24\xba\x06\x39\x23\xd5\x06\x6d\x26\xbe\x06\x05\x25\xad\x06\xaa\x23\xc6\x06\x34\x26\xb0\x06\x85\x25\xb1\x06\xd0\x23\xb3\x06\x87\x25\xb6\x06\xc6\x24\xaf\x06\x1f\x23\xbd\x06\x64\x25\xba\x06\x5e\x24\xb6\x06\x1e\x23\xad\x06\x50\x25\xa7\x06\x3c\x24\xa4\x06\xe9\x22\xba\x06\x56\x25\xb6\x06\x3e\x24\xb4\x06\xed\x22\xbf\x06\x31\x25\xa5\x06\x19\x24\xa8\x06\xbb\x22\xba\x06\x81\x25\xb7\x06\x5f\x24\xad\x06\xef\x22\xc8\x06\xf3\x25\xb8\x06\xce\x24\xbf\x06\x8f\x23\xb3\x06\xac\x25\xa5\x06\x7c\x24\xa0\x06\x34\x23\xbd\x06\x76\x25\xbd\x06\x56\x24\xc5\x06\xff\x22\xc6\x06\x16\x25\xaf\x06\x1e\x24\xb6\x06\xae\x22\xb4\x06\x6f\x25\xa9\x06\xe8\x23\xb4\x06\xd3\x22\xc9\x06\x5c\x25\xb4\x06\x1f\x24\xb6\x06\xc0\x22\x98\x06\x8e\x25\x90\x06\x4c\x24\x9e\x06\xd8\x22\xb7\x06\x06\x26\xa1\x06\x96\x24\xb3\x06\x50\x23\xc4\x06\xeb\x25\xa2\x06\x60\x24\xbb\x06\x36\x23\xb8\x06\x5a\x25\xac\x06\xee\x23\xa4\x06\xf3\x22\xc2\x06\x28\x25\xc6\x06\x1e\x24\xb2\x06\xf6\x22\xc2\x06\x68\x25\xb5\x06\x08\x24\xbc\x06\xef\x22\xc1\x06\x83\x25\xbb\x06\x08\x24\xb3\x06\xbf\x22\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xc0\x06\x91\x25\xb7\x06\x41\x24\xa8\x06\xca\x22\xd2\x06\x35\x26\xb7\x06\xa6\x24\xaf\x06\x5a\x23\xc4\x06\xfc\x25\xb1\x06\xad\x24\xb8\x06\x72\x23\xbd\x06\x75\x25\xb0\x06\x5a\x24\xb3\x06\x0f\x23\xbc\x06\x32\x25\xac\x06\x2e\x24\xb6\x06\xd7\x22\xbd\x06\x4a\x25\xa6\x06\x4d\x24\xa6\x06\xf5\x22\xb5\x06\x85\x25\xb0\x06\x48\x24\xab\x06\xd0\x22\xc0\x06\xae\x25\xba\x06\x9d\x24\xaf\x06\x2c\x23\xc4\x06\x86\x26\xb2\x06\xfa\x24\xaf\x06\xb7\x23\xd3\x06\xe0\x26\xc4\x06\x28\x25\xb8\x06\x44\x24\xb1\x06\x42\x26\x94\x06\x01\x25\x93\x06\xbb\x23\xbf\x06\xaf\x25\xb4\x06\x8f\x24\xb4\x06\x4a\x23\xc6\x06\x67\x25\xb7\x06\x9e\x24\xb3\x06\x3b\x23\xc7\x06\xa5\x25\xae\x06\x67\x24\xba\x06\x4d\x23\xc0\x06\xf3\x25\xb2\x06\xd5\x24\xa9\x06\x8c\x23\xc3\x06\x57\x26\xc5\x06\x38\x25\xc2\x06\xdf\x23\xb2\x06\xa3\x26\xb3\x06\xa8\x25\xb8\x06\x95\x24\xbd\x06\x58\x26\xb0\x06\x22\x25\xad\x06\xea\x23\xb5\x06\xec\x25\xae\x06\x0f\x25\xb1\x06\xb1\x23\xbd\x06\xf7\x25\xb5\x06\xac\x24\xb0\x06\xbd\x23\xce\x06\xf5\x25\xbb\x06\xf2\x24\xb5\x06\x8c\x23\xc4\x06\xf6\x25\xb4\x06\xe4\x24\xb1\x06\xb2\x23\xc3\x06\xb4\x26\xbc\x06\x92\x25\xb7\x06\x01\x24\xbc\x06\x69\x27\xa6\x06\xc0\x25\xb7\x06\xd2\x24\xc7\x06\xf8\x26\xb9\x06\x4f\x25\xa8\x06\xf3\x23\xc5\x06\x40\x26\xb0\x06\x0a\x25\xb0\x06\xcd\x23\xb2\x06\x30\x26\xa7\x06\xd7\x24\xa3\x06\xa8\x23\xba\x06\x3c\x26\xa0\x06\xce\x24\xab\x06\xb0\x23\xc0\x06\x11\x26\xaf\x06\xca\x24\xb2\x06\xa7\x23\xc7\x06\x6d\x26\xc1\x06\xee\x24\xb1\x06\xb5\x23\xbc\x06\xe5\x26\xb5\x06\x82\x25\xba\x06\x4a\x24\xc7\x06\xea\x26\xb8\x06\x66\x25\xb5\x06\x06\x24\xbd\x06\x86\x26\xbb\x06\xdb\x24\xb5\x06\xc0\x23\xb0\x06\x16\x26\xa2\x06\x95\x24\x9f\x06\xdd\x23\xa5\x06\x22\x26\x93\x06\x7c\x24\x9c\x06\x7f\x23\xd5\x06\xf9\x25\xc1\x06\x77\x24\xcd\x06\xa6\x23\x30\x07\xfb\x25\x21\x07\x91\x24\x1f\x07\x8f\x23\xb2\x07\x4c\x26\xac\x07\x1a\x25\xa4\x07\xe9\x23\x96\x07\xd0\x25\x92\x07\xe3\x24\x98\x07\x62\x23\x96\x06\xf9\x25\x91\x06\x00\x24\x83\x06\x93\x21\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x73\x06\x08\x22\x63\x06\x18\x20\x52\x06\x2a\x1d\x4e\x07\xfe\x20\x30\x07\xf3\x1f\x62\x07\x0e\x1e\x7e\x07\x2e\x21\x6f\x07\x1f\x20\x5f\x07\x4f\x1e\x05\x07\x6a\x21\xf3\x06\x74\x20\xe8\x06\x92\x1e\xa5\x06\xaf\x21\x93\x06\xb1\x20\x99\x06\xeb\x1e\x7c\x06\xce\x21\x76\x06\xc6\x20\x6a\x06\xcd\x1e\x6a\x06\x09\x22\x66\x06\x17\x21\x63\x06\x02\x1f\x7c\x06\x2c\x22\x7b\x06\xe6\x20\x74\x06\xfd\x1e\x8f\x06\xf7\x21\x82\x06\xa5\x20\x77\x06\xbf\x1e\x9b\x06\xcc\x21\x8f\x06\xa5\x20\x81\x06\xbb\x1e\x81\x06\xed\x21\x71\x06\xab\x20\x80\x06\xe1\x1e\x7c\x06\x1b\x22\x69\x06\x00\x21\x89\x06\xe4\x1e\x89\x06\xeb\x21\x7f\x06\xe7\x20\x85\x06\xee\x1e\x7f\x06\x5d\x22\x78\x06\x24\x21\x76\x06\x44\x1f\xa6\x06\xab\x22\xa0\x06\x95\x21\x96\x06\x6a\x1f\x97\x06\xf7\x21\x9a\x06\x14\x21\x8d\x06\x22\x1f\x93\x06\xa1\x21\x8f\x06\xe0\x20\x8d\x06\x05\x1f\x7e\x06\x99\x21\x6b\x06\xa7\x20\x7c\x06\xfb\x1e\x81\x06\x75\x21\x7e\x06\xb1\x20\x7c\x06\xe4\x1e\x9c\x06\x88\x21\x99\x06\xcb\x20\x82\x06\xda\x1e\x8a\x06\x52\x21\x95\x06\x1d\x21\x70\x06\xce\x1e\x8a\x06\x85\x21\x8e\x06\xf4\x20\x73\x06\x01\x1f\x86\x06\x76\x21\x72\x06\xde\x20\x78\x06\x02\x1f\x68\x06\x64\x21\x54\x06\xa5\x20\x7b\x06\xbc\x1e\x8f\x06\x56\x21\x7c\x06\xa9\x20\x95\x06\xcb\x1e\x81\x06\x53\x21\x84\x06\xaf\x20\x8d\x06\xbf\x1e\x7f\x06\x2e\x21\x69\x06\x61\x20\x8d\x06\xa4\x1e\xa2\x06\x54\x21\x8b\x06\x6a\x20\x95\x06\x9d\x1e\x64\x06\x84\x21\x6c\x06\xd0\x20\x8c\x06\x9a\x1e\x89\x06\x76\x21\x82\x06\xc3\x20\x76\x06\x7a\x1e\x8a\x06\x23\x21\x8e\x06\x97\x20\x7d\x06\x81\x1e\x65\x06\x6e\x21\x61\x06\x6c\x20\x85\x06\xb0\x1e\x88\x06\x46\x21\x91\x06\x9a\x20\x7d\x06\x80\x1e\x8b\x06\x72\x21\x8e\x06\x8e\x20\x86\x06\xac\x1e\x8b\x06\xa2\x21\x7d\x06\xa2\x20\x7f\x06\xac\x1e\xa3\x06\xe0\x21\x8f\x06\x47\x21\x89\x06\x05\x1f\xa0\x06\x04\x22\x97\x06\x6c\x21\x83\x06\xf6\x1e\x92\x06\x71\x21\x8c\x06\xd0\x20\x86\x06\xbf\x1e\x94\x06\x39\x21\x99\x06\xa1\x20\x86\x06\xb7\x1e\x84\x06\x44\x21\x83\x06\xb7\x20\x84\x06\xc6\x1e\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x8c\x06\x39\x21\x93\x06\x9d\x20\x8a\x06\xc6\x1e\x86\x06\xbc\x21\x7b\x06\xb9\x20\x7c\x06\xb3\x1e\x92\x06\xe4\x21\xa3\x06\x1f\x21\x9b\x06\x0a\x1f\x89\x06\x30\x22\x82\x06\x43\x21\x95\x06\x5c\x1f\xa6\x06\x90\x21\x99\x06\xda\x20\x96\x06\x08\x1f\xa2\x06\x68\x21\x98\x06\xca\x20\x90\x06\xce\x1e\x9e\x06\x94\x21\x90\x06\x96\x20\x94\x06\xce\x1e\x7e\x06\xa2\x21\x72\x06\xa5\x20\x82\x06\xcb\x1e\x8d\x06\x75\x21\x8c\x06\xa6\x20\x86\x06\xe0\x1e\x86\x06\xac\x21\x8d\x06\xe0\x20\x8e\x06\x10\x1f\x8f\x06\xf6\x21\x8c\x06\x11\x21\x86\x06\x23\x1f\x94\x06\x8d\x21\x82\x06\xe8\x20\x7e\x06\xdc\x1e\x7d\x06\x58\x21\x7e\x06\xa9\x20\x7a\x06\xdd\x1e\x85\x06\x34\x21\x90\x06\xc2\x20\x7d\x06\xe4\x1e\x89\x06\x5a\x21\x7c\x06\x9e\x20\x81\x06\xca\x1e\x8a\x06\x60\x21\x86\x06\xb7\x20\x77\x06\xc9\x1e\x95\x06\xb6\x21\x92\x06\xee\x20\x77\x06\xff\x1e\x7d\x06\xd2\x21\x74\x06\x31\x21\x7d\x06\x15\x1f\x97\x06\xb5\x21\x8e\x06\xfc\x20\x84\x06\xeb\x1e\x82\x06\x68\x21\x7f\x06\xaa\x20\x8d\x06\xec\x1e\x96\x06\x8d\x21\x87\x06\xbf\x20\x8e\x06\xe7\x1e\x7f\x06\x28\x21\x8b\x06\xbb\x20\x89\x06\xf0\x1e\x92\x06\x7a\x21\x8e\x06\xd7\x20\x87\x06\x0e\x1f\x91\x06\xc5\x21\x8a\x06\x1f\x21\x88\x06\x3d\x1f\x96\x06\x5d\x22\x9c\x06\x90\x21\x89\x06\x7f\x1f\x83\x06\x3a\x22\x87\x06\x79\x21\x76\x06\x8c\x1f\x9c\x06\xd2\x21\x8c\x06\xb6\x20\x7d\x06\x0d\x1f\x54\x06\xb1\x21\x45\x06\xd3\x20\x78\x06\x10\x1f\x80\x06\xb3\x21\x79\x06\xfa\x20\x82\x06\x3a\x1f\x97\x06\xa2\x21\x98\x06\x15\x21\x8c\x06\x2b\x1f\x99\x06\xb9\x21\x98\x06\x2d\x21\x8e\x06\x26\x1f\x7d\x06\x4e\x22\x75\x06\x4c\x21\x90\x06\x42\x1f\x7d\x06\x85\x22\x6d\x06\x85\x21\x83\x06\x99\x1f\x97\x06\x10\x22\x96\x06\x4b\x21\x88\x06\x53\x1f\x93\x06\xd9\x21\x97\x06\x45\x21\x90\x06\x44\x1f\x7a\x06\xb1\x21\x7c\x06\x25\x21\x83\x06\x48\x1f\x8e\x06\xd4\x21\x8b\x06\x2f\x21\x8f\x06\x62\x1f\x8f\x06\xb5\x21\x97\x06\x25\x21\x8d\x06\x7b\x1f\x8a\x06\x3a\x22\x93\x06\x50\x21\x8c\x06\x71\x1f\x94\x06\x7b\x22\x8f\x06\xca\x21\x93\x06\xe8\x1f\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x84\x06\x39\x22\x83\x06\x84\x21\x7d\x06\xac\x1f\x7a\x06\xab\x21\x76\x06\x4c\x21\x7c\x06\x3a\x1f\x82\x06\xb4\x21\x82\x06\x28\x21\x86\x06\x58\x1f\x9c\x06\xca\x21\x98\x06\x21\x21\x96\x06\x80\x1f\x86\x06\xe0\x21\x8a\x06\x75\x21\x8c\x06\x66\x1f\x86\x06\x2c\x22\x8a\x06\x5d\x21\x96\x06\x8a\x1f\x84\x06\xbd\x22\x7e\x06\xe3\x21\x88\x06\xbe\x1f\x6d\x06\x79\x22\x6f\x06\x88\x21\x6f\x06\xb4\x1f\x84\x06\xfa\x21\x89\x06\x68\x21\x7c\x06\xa6\x1f\x85\x06\x10\x22\x82\x06\x84\x21\x86\x06\x9e\x1f\x89\x06\x1f\x22\x7a\x06\x71\x21\x7d\x06\xaf\x1f\x8c\x06\x23\x22\x7d\x06\x80\x21\x82\x06\xa6\x1f\x93\x06\x6b\x22\x89\x06\xb9\x21\x80\x06\x97\x1f\x98\x06\xa5\x22\x93\x06\x1a\x22\x8d\x06\xef\x1f\x9f\x06\xb4\x22\x9c\x06\x0a\x22\x8a\x06\x0d\x20\x99\x06\x47\x22\x9d\x06\x94\x21\x85\x06\xdf\x1f\x8b\x06\x2f\x22\x82\x06\x82\x21\x86\x06\xc0\x1f\x99\x06\x45\x22\x8a\x06\x7e\x21\x83\x06\xdd\x1f\x8f\x06\x53\x22\x8d\x06\xcb\x21\x86\x06\xf4\x1f\xa5\x06\x5d\x22\x94\x06\xc3\x21\x8a\x06\xb3\x1f\x7b\x06\x7f\x22\x86\x06\x18\x22\x89\x06\x11\x20\x97\x06\xdd\x22\x8d\x06\x04\x22\x88\x06\xeb\x1f\x96\x06\xb2\x22\x98\x06\xb9\x21\x82\x06\xbc\x1f\x7f\x06\x65\x22\x8c\x06\xdd\x21\x89\x06\xc7\x1f\x9a\x06\x50\x22\x9b\x06\xa9\x21\x7e\x06\x05\x20\x7d\x06\x77\x22\x85\x06\xe6\x21\x84\x06\xe4\x1f\x92\x06\xa0\x22\x90\x06\x0c\x22\x81\x06\x0e\x20\xa0\x06\x08\x23\x9d\x06\x0a\x22\x7b\x06\x14\x20\x9d\x06\x6a\x23\x81\x06\x81\x22\x8f\x06\x4c\x20\x91\x06\xdc\x22\x82\x06\x64\x22\x7e\x06\x19\x20\x8c\x06\xc8\x22\x9b\x06\x20\x22\x8d\x06\x1f\x20\xa6\x06\xd8\x22\x99\x06\x53\x22\x8f\x06\x31\x20\x84\x06\xfd\x22\x87\x06\x7d\x22\x8d\x06\x39\x20\x82\x06\x16\x23\x7c\x06\x4f\x22\x7d\x06\x0a\x20\x75\x06\x87\x23\x61\x06\xae\x22\x80\x06\xfd\x1f\x87\x06\x89\x23\x81\x06\x42\x23\x8c\x06\x78\x20\x96\x06\x92\x23\x8f\x06\xf5\x22\x87\x06\x50\x20\x99\x06\x82\x23\x99\x06\xd9\x22\x8f\x06\x6a\x20\x81\x06\x63\x23\x7e\x06\xbe\x22\x96\x06\x9c\x20\x8f\x06\x6c\x23\x9e\x06\xfd\x22\x7f\x06\xea\x20\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x90\x06\x59\x23\x90\x06\xfb\x22\x90\x06\x08\x21\x7a\x06\xd0\x23\x72\x06\x36\x23\x8d\x06\x3e\x21\x96\x06\x52\x24\x86\x06\x98\x23\x81\x06\x4f\x21\xa0\x06\x2f\x24\x91\x06\x3e\x23\x86\x06\x47\x21\x92\x06\xc5\x23\x89\x06\x17\x23\x93\x06\x43\x21\x99\x06\xa9\x23\x99\x06\x24\x23\x84\x06\x32\x21\x8d\x06\xb3\x23\x8e\x06\x43\x23\x9c\x06\x5b\x21\xa2\x06\xd4\x23\x8e\x06\x28\x23\x9a\x06\x86\x21\x95\x06\xce\x23\x99\x06\x85\x23\x93\x06\xa8\x21\x95\x06\x4e\x24\x96\x06\x9e\x23\x9b\x06\xc1\x21\x98\x06\xa2\x24\x8c\x06\xaa\x23\x8d\x06\xd0\x21\x9d\x06\x71\x24\x92\x06\x7d\x23\x91\x06\xdc\x21\x99\x06\x84\x24\x8e\x06\xce\x23\x95\x06\x0d\x22\xaa\x06\xc8\x24\x9d\x06\xe9\x23\x97\x06\x27\x22\x9c\x06\x4b\x25\x99\x06\x07\x24\x95\x06\x5d\x22\xb1\x06\xf7\x25\xa2\x06\x27\x24\x95\x06\x92\x22\xa9\x06\xcf\x26\x95\x06\x80\x24\xa2\x06\xad\x22\xb8\x06\x42\x26\xa6\x06\xca\x24\xaa\x06\x02\x23\xaa\x06\x42\x25\xa6\x06\xc9\x24\x9a\x06\xdc\x22\xa9\x06\x40\x25\xa0\x06\x99\x24\xa2\x06\xf2\x22\xb2\x06\x66\x25\xb2\x06\xb9\x24\xa9\x06\x08\x23\xb6\x06\x64\x25\xa8\x06\xd4\x24\xa4\x06\x07\x23\xb5\x06\xa3\x25\xb7\x06\x31\x25\xaa\x06\x38\x23\x9b\x06\x4e\x26\x97\x06\x9d\x25\xaa\x06\x5a\x23\xaa\x06\x35\x26\xb0\x06\xf4\x25\xaa\x06\xe0\x23\xbd\x06\x5e\x26\xac\x06\xc1\x25\xad\x06\xae\x23\xa8\x06\x28\x26\x9c\x06\x78\x25\xac\x06\xbb\x23\x9b\x06\x30\x26\x87\x06\x72\x25\xb1\x06\xc1\x23\xbe\x06\x30\x26\xb7\x06\xd5\x25\xa7\x06\xa8\x23\xb0\x06\x35\x26\xb7\x06\xe1\x25\xa9\x06\x00\x24\xb6\x06\x9b\x26\xb7\x06\x56\x26\xae\x06\x23\x24\xbe\x06\xfd\x26\xb6\x06\xe0\x26\xb8\x06\xaa\x24\xc1\x06\x11\x27\xae\x06\x3a\x26\xb7\x06\x69\x24\xc0\x06\xe7\x26\xb4\x06\x1b\x26\xa8\x06\x35\x24\xc6\x06\x56\x27\xaf\x06\x2a\x26\xb3\x06\x48\x24\xba\x06\xc7\x26\xbe\x06\x55\x26\xae\x06\x59\x24\xbf\x06\x55\x27\xa4\x06\x78\x26\xa4\x06\x86\x24\xae\x06\x7d\x27\xa5\x06\x2a\x27\xb7\x06\xc2\x24\xb5\x06\x0b\x28\xb4\x06\x9a\x27\xa4\x06\xf9\x24\xae\x06\xde\x27\x9e\x06\xbf\x26\xb0\x06\x91\x24\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xd0\x06\x8a\x27\xc6\x06\xbf\x26\xb5\x06\x5a\x24\xc9\x06\x6b\x27\xba\x06\xf9\x26\xb6\x06\xc9\x24\xbf\x06\x98\x27\xbf\x06\x31\x27\xb9\x06\x3f\x25\xbb\x06\xfc\x27\xb1\x06\x86\x27\xc3\x06\x9f\x25\xc0\x06\x10\x28\xc5\x06\x2e\x28\xc5\x06\xf9\x25\xd6\x06\xec\x28\xd5\x06\xb8\x28\xcd\x06\x72\x26\xc2\x06\x3b\x29\xc6\x06\x8e\x28\xc9\x06\x43\x26\xd8\x06\x19\x29\xbe\x06\x07\x28\xbc\x06\x19\x26\xae\x06\x23\x29\xae\x06\x29\x28\xbc\x06\x3e\x26\xc9\x06\xb5\x29\xae\x06\x46\x28\xc8\x06\x83\x26\xcf\x06\xe6\x29\xbf\x06\x6d\x28\xc7\x06\x72\x26\xbf\x06\xcf\x29\xb8\x06\xb7\x28\xbf\x06\xcc\x26\xc7\x06\x54\x2a\xbc\x06\x91\x29\xc5\x06\x35\x27\xcf\x06\xa7\x2a\xcd\x06\x6d\x2a\xb1\x06\x08\x28\xd7\x06\xa3\x29\xdf\x06\x8a\x29\xce\x06\x7b\x27\xdb\x06\xe6\x29\xdb\x06\x6f\x29\xd8\x06\x89\x27\xd8\x06\x23\x2a\xcc\x06\x6f\x29\xd7\x06\xa7\x27\xca\x06\xb2\x2a\xcc\x06\xea\x29\xbe\x06\xb9\x27\xc3\x06\x6b\x2b\xae\x06\xe2\x29\xd6\x06\x1b\x28\xeb\x06\x65\x2c\xd5\x06\x70\x2a\xd1\x06\x76\x28\xf1\x06\xd3\x2c\xd9\x06\x0b\x2b\xd5\x06\xc8\x28\xbc\x06\x60\x2c\xac\x06\xf7\x2a\xd0\x06\xcd\x28\xed\x06\xa1\x2b\xe2\x06\x84\x2a\xd4\x06\xf1\x28\xd1\x06\x70\x2b\xcc\x06\xeb\x2a\xdc\x06\x1e\x29\xe9\x06\x12\x2c\xdd\x06\xfe\x2a\xd6\x06\x95\x29\xdd\x06\x0f\x2c\xce\x06\x07\x2b\xd8\x06\xa3\x29\xde\x06\xf7\x2c\xc3\x06\xa2\x2b\xdc\x06\xce\x29\xea\x06\x53\x2d\xe2\x06\x17\x2c\xd8\x06\x4a\x2a\xdf\x06\xf2\x2c\xda\x06\x18\x2c\xe5\x06\x66\x2a\xbf\x06\x19\x2d\xc2\x06\x8d\x2c\xd8\x06\x75\x2a\xc6\x06\x3d\x2d\xce\x06\x99\x2c\xd5\x06\xef\x2a\xdb\x06\x2e\x2d\xd8\x06\xfd\x2c\xda\x06\x18\x2b\xd8\x06\xc5\x2d\xda\x06\x37\x2d\xdf\x06\x73\x2b\xe2\x06\x81\x2e\xd8\x06\x4a\x2d\xd7\x06\x0d\x2c\xf8\x06\x2d\x2f\xdc\x06\xf1\x2d\xdd\x06\x49\x2c\xeb\x06\x36\x2f\xde\x06\x57\x2e\xd8\x06\x32\x2c\xcf\x06\x86\x2f\xb9\x06\x93\x2e\xd1\x06\x66\x2c\xf1\x06\x98\x2f\xeb\x06\x53\x2e\xd6\x06\xa5\x2c\xf7\x06\xbe\x2f\xe5\x06\xd9\x2e\xec\x06\x32\x2d\xeb\x06\xc8\x2f\xef\x06\x9b\x2f\xf2\x06\x5b\x2d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xf2\x06\x5b\x30\xe8\x06\xd0\x2f\xea\x06\xd6\x2d\xee\x06\x6d\x31\xe1\x06\x9b\x30\xde\x06\x83\x2e\xdd\x06\xed\x31\xc6\x06\xac\x30\xe9\x06\xa2\x2e\xe1\x06\x16\x31\xf1\x06\xe0\x30\xe5\x06\xa9\x2e\x05\x07\xb5\x31\xfe\x06\x29\x31\xf8\x06\xe9\x2e\xeb\x06\x8e\x31\xf3\x06\xa7\x31\xe2\x06\x63\x2f\xec\x06\x20\x32\xfa\x06\x35\x32\xf0\x06\xda\x2f\xe9\x06\x33\x33\xda\x06\x4d\x32\xf2\x06\x5b\x30\xfb\x06\x4e\x34\xea\x06\xbd\x33\xf6\x06\x19\x31\x05\x07\x87\x34\x00\x07\x0f\x34\xfe\x06\xaf\x31\x0f\x07\x67\x34\x00\x07\x9b\x33\xf7\x06\x63\x31\xf7\x06\x5a\x34\xfe\x06\x7c\x33\xf7\x06\xd2\x31\xff\x06\xdb\x34\xff\x06\x04\x34\x00\x07\x31\x32\x0c\x07\x72\x35\xff\x06\x6d\x34\x07\x07\xf5\x32\xe7\x06\x12\x36\xe1\x06\x49\x35\xfe\x06\x2a\x33\xf0\x06\x46\x36\xf9\x06\x34\x36\xfe\x06\x8d\x33\x03\x07\x4f\x37\x0a\x07\xf9\x36\x0b\x07\xbb\x34\x07\x07\x71\x37\xe5\x06\xd9\x36\xfd\x06\x96\x34\xe3\x06\x70\x38\xd5\x06\x1d\x37\x06\x07\xb7\x34\xfd\x06\x48\x38\x06\x07\x5e\x37\x07\x07\x60\x35\xff\x06\xf6\x38\xfe\x06\xe8\x37\x0e\x07\xe3\x35\x0e\x07\x89\x39\x0b\x07\x0f\x38\x09\x07\x2a\x36\x20\x07\xac\x3a\x11\x07\x15\x39\x14\x07\x4b\x37\x19\x07\x0b\x3c\x10\x07\x11\x3b\x08\x07\xd6\x37\x04\x07\x07\x3b\x0d\x07\x71\x3a\x04\x07\x86\x37\x0c\x07\x3a\x3b\x10\x07\x56\x3a\x15\x07\xa8\x38\x02\x07\xa6\x3b\x08\x07\xca\x3a\x11\x07\xa7\x38\x10\x07\x9e\x3c\x03\x07\x71\x3b\x07\x07\x45\x39\x12\x07\xf6\x3c\x19\x07\x1b\x3c\x1c\x07\xf4\x39\x14\x07\xf2\x3e\x08\x07\x18\x3d\x15\x07\xbd\x3a\x29\x07\x94\x3f\x1f\x07\x8e\x3e\x21\x07\xe9\x3b\x1a\x07\x12\x3f\x11\x07\xb5\x3d\x13\x07\xca\x3b\x04\x07\x33\x3f\xf3\x06\x61\x3e\x17\x07\x2c\x3c\xff\x06\xc9\x40\xfb\x06\x67\x40\x13\x07\x3a\x3e\x1c\x07\x45\x40\x1c\x07\xc4\x3f\x21\x07\x97\x3d\x25\x07\xf9\x40\x26\x07\x8f\x40\x24\x07\x9f\x3e\x18\x07\x78\x42\x1a\x07\x70\x41\x22\x07\xec\x3e\x29\x07\xa5\x43\x2b\x07\x3f\x42\x1b\x07\xcf\x3f\x1d\x07\xb5\x43\x15\x07\x6a\x42\x1f\x07\xec\x3f\x29\x07\x9d\x43\x35\x07\x62\x42\x25\x07\x51\x40\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x24\x07\x2f\x44\x2c\x07\x7a\x42\x30\x07\x04\x41\x1b\x07\xda\x44\x10\x07\x24\x44\x15\x07\x29\x42\x32\x07\x26\x45\x2c\x07\x79\x44\x2a\x07\x7c\x42\x3c\x07\x39\x46\x25\x07\x4d\x45\x23\x07\x25\x43\x34\x07\xcd\x47\x2d\x07\x38\x46\x2c\x07\x86\x44\x29\x07\x2b\x48\x30\x07\xfa\x47\x37\x07\x52\x44\x2b\x07\xf9\x48\x1b\x07\x48\x47\x34\x07\xa3\x44\x21\x07\xe7\x48\x28\x07\x72\x47\x1e\x07\xa0\x45\x1e\x07\xa3\x4a\x12\x07\xa6\x48\x33\x07\x6d\x46\x38\x07\x53\x4a\x2e\x07\x68\x49\x38\x07\x74\x47\x27\x07\x2a\x4c\x2c\x07\x82\x4b\x35\x07\x5e\x48\x2d\x07\x7b\x4d\x2a\x07\x3b\x4c\x38\x07\xdd\x49\x3d\x07\x54\x4f\x35\x07\xcc\x4e\x2f\x07\x60\x4b\x31\x07\x94\x50\x2d\x07\x99\x4f\x28\x07\xb0\x4c\x2c\x07\xe3\x50\x28\x07\x61\x4f\x30\x07\x59\x4c\x39\x07\x53\x50\x36\x07\x8d\x4f\x3a\x07\xf5\x4c\x46\x07\xa2\x51\x31\x07\xd7\x4f\x3a\x07\xa5\x4d\x36\x07\xfa\x51\x40\x07\xbc\x51\x38\x07\x63\x4e\x3e\x07\x79\x54\x36\x07\x48\x52\x40\x07\x8c\x4f\x36\x07\x83\x54\x3c\x07\x47\x54\x39\x07\x54\x50\x40\x07\xd9\x55\x39\x07\x8a\x54\x38\x07\x0d\x51\x47\x07\xc3\x55\x49\x07\x9f\x54\x40\x07\x18\x52\x40\x07\x2f\x56\x46\x07\x64\x55\x48\x07\x27\x53\x45\x07\x70\x57\x48\x07\x93\x56\x43\x07\xf5\x53\x4b\x07\x46\x59\x38\x07\x5a\x58\x46\x07\xee\x55\x3f\x07\x36\x5c\x31\x07\xcd\x5a\x31\x07\xef\x56\x4e\x07\xc8\x5d\x49\x07\xc9\x5b\x4c\x07\x6b\x59\x55\x07\x38\x5f\x52\x07\x74\x5d\x4c\x07\x7f\x5a\x4c\x07\x30\x5d\x4c\x07\xb4\x5d\x4e\x07\x2b\x5a\x56\x07\x65\x5e\x56\x07\x02\x5f\x4b\x07\x61\x5b\x4d\x07\xaa\x60\x4c\x07\xb8\x5f\x4e\x07\x25\x5c\x44\x07\xc2\x62\x3e\x07\x96\x60\x4e\x07\x54\x5e\x57\x07\x11\x65\x43\x07\x72\x61\x53\x07\x72\x60\x64\x07\x96\x68\x54\x07\xfe\x65\x5b\x07\x1c\x62\x66\x07\x5a\x68\x58\x07\xac\x66\x5f\x07\xd4\x62\x5a\x07\x7a\x68\x50\x07\x9f\x65\x5c\x07\x06\x63\x5d\x07\x80\x68\x5b\x07\x72\x67\x58\x07\xb7\x63\x50\x07\x11\x6a\x4f\x07\x7b\x69\x5b\x07\x35\x65\x5d\x07\x79\x6b\x58\x07\x25\x6a\x54\x07\x46\x67\x5a\x07\x14\x6d\x5e\x07\xab\x6b\x60\x07\x0f\x69\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x64\x07\x35\x72\x54\x07\x41\x70\x66\x07\xf4\x6b\x64\x07\x51\x73\x5a\x07\xe9\x71\x57\x07\xb9\x6d\x5c\x07\xd6\x73\x51\x07\xc9\x70\x65\x07\x64\x6e\x64\x07\xe4\x73\x71\x07\xb0\x71\x60\x07\xbc\x6e\x5f\x07\x1c\x77\x5a\x07\x49\x74\x55\x07\xb1\x70\x61\x07\x4f\x7d\x5b\x07\xfe\x7a\x56\x07\x1b\x75\x63\x07\xd4\x78\x65\x07\xdf\x77\x64\x07\x93\x72\x60\x07\xfc\x7a\x63\x07\x74\x79\x5c\x07\x87\x74\x64\x07\xee\x7e\x63\x07\xc3\x7d\x69\x07\x78\x78\x65\x07\x23\x80\x5e\x07\xcf\x7c\x61\x07\x8a\x77\x71\x07\xa5\x7e\x6a\x07\xb0\x7b\x66\x07\xed\x78\x71\x07\x6e\x80\x69\x07\xbb\x7d\x6b\x07\x52\x7b\x6c\x07\x00\x82\x71\x07\x22\x80\x5f\x07\x5a\x7b\x70\x07\x71\x83\x74\x07\x8d\x81\x6c\x07\x15\x7e\x71\x07\x74\x86\x6b\x07\xd5\x84\x68\x07\x89\x80\x67\x07\x35\x8e\x5f\x07\x68\x8a\x6d\x07\x14\x84\x6f\x07\x09\x8b\x66\x07\x4d\x87\x7a\x07\x38\x85\x6a\x07\xa8\x8a\x67\x07\x37\x89\x69\x07\x05\x85\x72\x07\xda\x8d\x6a\x07\x5f\x8a\x73\x07\x26\x87\x70\x07\x0d\x90\x6b\x07\xb5\x8c\x6e\x07\x57\x88\x7d\x07\xba\x93\x6f\x07\xe8\x90\x74\x07\xc1\x8b\x76\x07\x9a\x96\x75\x07\x64\x94\x79\x07\x71\x8e\x74\x07\x47\x9b\x75\x07\x5b\x98\x7d\x07\xf4\x90\x82\x07\xb4\x9c\x70\x07\x9f\x95\x78\x07\xb0\x90\x87\x07\xd9\x9c\x72\x07\x68\x95\x7c\x07\x9e\x91\x73\x07\x9b\x9e\x78\x07\xef\x98\x74\x07\x20\x93\x6b\x07\xdb\xa0\x7a\x07\xcb\x9b\x76\x07\x9d\x97\x7a\x07\x4a\xa2\x7f\x07\xba\x9c\x79\x07\x4c\x98\x7e\x07\x93\xa6\x7e\x07\x3f\x9f\x79\x07\x5c\x9b\x8c\x07\x9c\xae\x86\x07\x64\xa4\x85\x07\xff\x9f\x87\x07\xf6\xb1\x89\x07\xfc\xa9\x82\x07\x3a\xa3\x81\x07\xa7\xb1\x7e\x07\x60\xa9\x7a\x07\x61\xa3\x79\x07\x38\xb1\x79\x07\xc3\xa9\x84\x07\x5f\xa5\x88\x07\x55\xb2\x89\x07\x0c\xac\x90\x07\xc9\xa7\x91\x07\x5a\xb4\x90\x07\xa3\xad\x8d\x07\xf2\xa9\x83\x07\xed\xb8\x8c\x07\x47\xb1\x80\x07\xc4\xac\x8b\x07\xb2\xc1\x87\x07\x61\xb8\x7f\x07\xe0\xb2\x82\x07\x9f\xc8\x8e\x07\x37\xc2\x84\x07\x8e\xb9\x8b\x07\x09\xe2\x87\x07\x6e\xd3\x89\x07\xe1\xd1\x8c\x07\xf8\xf8\x8b\x07\xe2\xe6\x91\x07\x41\xe5\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x97\x07\xff\xff\x8f\x07\x90\xfc\x95\x07\xff\xff\xa9\x07\xff\xff\x96\x07\xff\xff\xa6\x07\xff\xff\x9d\x07\xff\xff\x99\x07\xff\xff\x9d\x07\xff\xff\xa9\x07\xff\xff\xad\x07\xff\xff\xa8\x07\xff\xff\xb1\x07\xff\xff\xb1\x07\xff\xff\xb2\x07\xff\xff\xb1\x07\xff\xff\xa7\x07\xff\xff\xa9\x07\xff\xff\xbc\x07\xff\xff\xb8\x07\xff\xff\xaf\x07\xff\xff\xba\x07\xff\xff\xae\x07\xff\xff\xbb\x07\xff\xff\xc0\x07\xff\xff\xb6\x07\xff\xff\xbf\x07\xff\xff", 0x0001c6c);
ret = usb_bulk_write(devh, 0x00000001, buf, 0x0001c6c, 1436);
printf("8294 bulk write returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(9*1000);
memcpy(buf, "\x6c\x6c\x6c\x6c", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000005, 0x0000000, buf, 0x0000004, 1000);
printf("8295 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x6c\x6c\x6c\x6c", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000c0, 0x0000000, buf, 0x0000004, 1000);
printf("8296 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(6*1000);
memcpy(buf, "\xf4\x00\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8297 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8298 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8299 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x96\x25\x96\x25", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8300 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(5*1000);
memcpy(buf, "\xa0\x00\xa1\xf4\xa2\x0f\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x10\x7e\x00\x7f\x00", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("8301 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(17*1000);
memcpy(buf, "\x00\x10\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000002, 0x0000000, buf, 0x0000004, 1000);
printf("8302 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x10\x0e\x10\x0e\x10\x0e\x10\x0e\x10\x0e\xd1\x0d\xb7\x0d\xa4\x0d\x93\x0d\x84\x0d\x77\x0d\x6b\x0d\x5f\x0d\x55\x0d\x4b\x0d\x41\x0d\x38\x0d\x2f\x0d\x27\x0d\x1e\x0d\x17\x0d\x0f\x0d\x07\x0d\x00\x0d\xf9\x0c\xf2\x0c\xec\x0c\xe5\x0c\xdf\x0c\xd8\x0c\xd2\x0c\xcc\x0c\xc6\x0c\xc0\x0c\xbb\x0c\xb5\x0c\xaf\x0c\xaa\x0c\xa5\x0c\x9f\x0c\x9a\x0c\x95\x0c\x90\x0c\x8b\x0c\x86\x0c\x81\x0c\x7c\x0c\x77\x0c\x73\x0c\x6e\x0c\x69\x0c\x65\x0c\x60\x0c\x5c\x0c\x57\x0c\x53\x0c\x4f\x0c\x4a\x0c\x46\x0c\x42\x0c\x3e\x0c\x3a\x0c\x36\x0c\x31\x0c\x2d\x0c\x29\x0c\x25\x0c\x22\x0c\x1e\x0c\x1a\x0c\x16\x0c\x12\x0c\x0e\x0c\x0b\x0c\x07\x0c\x03\x0c\xff\x0b\xfc\x0b\xf8\x0b\xf5\x0b\xf1\x0b\xed\x0b\xea\x0b\xe6\x0b\xe3\x0b\xdf\x0b\xdc\x0b\xd9\x0b\xd5\x0b\xd2\x0b\xce\x0b\xcb\x0b\xc8\x0b\xc4\x0b\xc1\x0b\xbe\x0b\xbb\x0b\xb7\x0b\xb4\x0b\xb1\x0b\xae\x0b\xab\x0b\xa7\x0b\xa4\x0b\xa1\x0b\x9e\x0b\x9b\x0b\x98\x0b\x95\x0b\x92\x0b\x8f\x0b\x8c\x0b\x89\x0b\x86\x0b\x83\x0b\x80\x0b\x7d\x0b\x7a\x0b\x77\x0b\x74\x0b\x71\x0b\x6e\x0b\x6c\x0b\x6c\x0b\x6c\x0b\x6c\x0b\x6c\x0b\x6c\x0b\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x6c\x0b\x6c\x0b\x6c\x0b\x6c\x0b\x6c\x0b\x71\x0b\x77\x0b\x7d\x0b\x82\x0b\x88\x0b\x8e\x0b\x94\x0b\x99\x0b\x9f\x0b\xa5\x0b\xab\x0b\xb0\x0b\xb6\x0b\xbc\x0b\xc1\x0b\xc7\x0b\xcd\x0b\xd3\x0b\xd8\x0b\xde\x0b\xe4\x0b\xea\x0b\xef\x0b\xf5\x0b\xfb\x0b\x00\x0c\x06\x0c\x0c\x0c\x12\x0c\x17\x0c\x1d\x0c\x23\x0c\x29\x0c\x2e\x0c\x34\x0c\x3a\x0c\x3f\x0c\x45\x0c\x4b\x0c\x51\x0c\x56\x0c\x5c\x0c\x62\x0c\x68\x0c\x6d\x0c\x73\x0c\x79\x0c\x7e\x0c\x84\x0c\x8a\x0c\x90\x0c\x95\x0c\x9b\x0c\xa1\x0c\xa7\x0c\xac\x0c\xb2\x0c\xb8\x0c\xbe\x0c\xc3\x0c\xc9\x0c\xcf\x0c\xd4\x0c\xda\x0c\xe0\x0c\xe6\x0c\xeb\x0c\xf1\x0c\xf7\x0c\xfd\x0c\x02\x0d\x08\x0d\x0e\x0d\x13\x0d\x19\x0d\x1f\x0d\x25\x0d\x2a\x0d\x30\x0d\x36\x0d\x3c\x0d\x41\x0d\x47\x0d\x4d\x0d\x52\x0d\x58\x0d\x5e\x0d\x64\x0d\x69\x0d\x6f\x0d\x75\x0d\x7b\x0d\x80\x0d\x86\x0d\x8c\x0d\x91\x0d\x97\x0d\x9d\x0d\xa3\x0d\xa8\x0d\xae\x0d\xb4\x0d\xba\x0d\xbf\x0d\xc5\x0d\xcb\x0d\xd0\x0d\xd6\x0d\xdc\x0d\xe2\x0d\xe7\x0d\xed\x0d\xf3\x0d\xf9\x0d\xfe\x0d\x04\x0e\x0a\x0e\x10\x0e\x10\x0e\x10\x0e\x10\x0e\x10\x0e\x10\x0e\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x10\x0e\x10\x0e\x10\x0e\x10\x0e\x10\x0e\xd1\x0d\xb7\x0d\xa4\x0d\x93\x0d\x84\x0d\x77\x0d\x6b\x0d\x5f\x0d\x55\x0d\x4b\x0d\x41\x0d\x38\x0d\x2f\x0d\x27\x0d\x1e\x0d\x17\x0d\x0f\x0d\x07\x0d\x00\x0d\xf9\x0c\xf2\x0c\xec\x0c\xe5\x0c\xdf\x0c\xd8\x0c\xd2\x0c\xcc\x0c\xc6\x0c\xc0\x0c\xbb\x0c\xb5\x0c\xaf\x0c\xaa\x0c\xa5\x0c\x9f\x0c\x9a\x0c\x95\x0c\x90\x0c\x8b\x0c\x86\x0c\x81\x0c\x7c\x0c\x77\x0c\x73\x0c\x6e\x0c\x69\x0c\x65\x0c\x60\x0c\x5c\x0c\x57\x0c\x53\x0c\x4f\x0c\x4a\x0c\x46\x0c\x42\x0c\x3e\x0c\x3a\x0c\x36\x0c\x31\x0c\x2d\x0c\x29\x0c\x25\x0c\x22\x0c\x1e\x0c\x1a\x0c\x16\x0c\x12\x0c\x0e\x0c\x0b\x0c\x07\x0c\x03\x0c\xff\x0b\xfc\x0b\xf8\x0b\xf5\x0b\xf1\x0b\xed\x0b\xea\x0b\xe6\x0b\xe3\x0b\xdf\x0b\xdc\x0b\xd9\x0b\xd5\x0b\xd2\x0b\xce\x0b\xcb\x0b\xc8\x0b\xc4\x0b\xc1\x0b\xbe\x0b\xbb\x0b\xb7\x0b\xb4\x0b\xb1\x0b\xae\x0b\xab\x0b\xa7\x0b\xa4\x0b\xa1\x0b\x9e\x0b\x9b\x0b\x98\x0b\x95\x0b\x92\x0b\x8f\x0b\x8c\x0b\x89\x0b\x86\x0b\x83\x0b\x80\x0b\x7d\x0b\x7a\x0b\x77\x0b\x74\x0b\x71\x0b\x6e\x0b\x6c\x0b\x6c\x0b\x6c\x0b\x6c\x0b\x6c\x0b\x6c\x0b\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x6c\x0b\x6c\x0b\x6c\x0b\x6c\x0b\x6c\x0b\x71\x0b\x77\x0b\x7d\x0b\x82\x0b\x88\x0b\x8e\x0b\x94\x0b\x99\x0b\x9f\x0b\xa5\x0b\xab\x0b\xb0\x0b\xb6\x0b\xbc\x0b\xc1\x0b\xc7\x0b\xcd\x0b\xd3\x0b\xd8\x0b\xde\x0b\xe4\x0b\xea\x0b\xef\x0b\xf5\x0b\xfb\x0b\x00\x0c\x06\x0c\x0c\x0c\x12\x0c\x17\x0c\x1d\x0c\x23\x0c\x29\x0c\x2e\x0c\x34\x0c\x3a\x0c\x3f\x0c\x45\x0c\x4b\x0c\x51\x0c\x56\x0c\x5c\x0c\x62\x0c\x68\x0c\x6d\x0c\x73\x0c\x79\x0c\x7e\x0c\x84\x0c\x8a\x0c\x90\x0c\x95\x0c\x9b\x0c\xa1\x0c\xa7\x0c\xac\x0c\xb2\x0c\xb8\x0c\xbe\x0c\xc3\x0c\xc9\x0c\xcf\x0c\xd4\x0c\xda\x0c\xe0\x0c\xe6\x0c\xeb\x0c\xf1\x0c\xf7\x0c\xfd\x0c\x02\x0d\x08\x0d\x0e\x0d\x13\x0d\x19\x0d\x1f\x0d\x25\x0d\x2a\x0d\x30\x0d\x36\x0d\x3c\x0d\x41\x0d\x47\x0d\x4d\x0d\x52\x0d\x58\x0d\x5e\x0d\x64\x0d\x69\x0d\x6f\x0d\x75\x0d\x7b\x0d\x80\x0d\x86\x0d\x8c\x0d\x91\x0d\x97\x0d\x9d\x0d\xa3\x0d\xa8\x0d\xae\x0d\xb4\x0d\xba\x0d\xbf\x0d\xc5\x0d\xcb\x0d\xd0\x0d\xd6\x0d\xdc\x0d\xe2\x0d\xe7\x0d\xed\x0d\xf3\x0d\xf9\x0d\xfe\x0d\x04\x0e\x0a\x0e\x10\x0e\x10\x0e\x10\x0e\x10\x0e\x10\x0e\x10\x0e\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0001000);
ret = usb_bulk_write(devh, 0x00000001, buf, 0x0001000, 1245);
printf("8303 bulk write returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(11*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000005, 0x0000000, buf, 0x0000004, 1000);
printf("8304 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000c0, 0x0000000, buf, 0x0000004, 1000);
printf("8305 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(15*1000);
memcpy(buf, "\xa0\x00\xa1\x00\xa2\x00\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x01\x7e\x00\x79\x40", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("8306 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x00\x02\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8307 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000200, 1030);
printf("8308 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x5f\x02\x5f\x02", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8309 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa0\x01\xa0\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8310 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8311 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x02\x5f\x02", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8312 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa1\x00\xa2\x24\xa1\x00\xa2\x22\xa1\x00\xa2\x1a\xa1\x00\xa2\x23\xa1\x00\xa2\x24\xa1\x00\xa2\x22\xa1\x00\xa2\x1a\xa1\x00\xa2\x23\xa1\x00\xa2\x24\xa1\x00\xa2\x22\xa1\x00\xa2\x1a\xa1\x00\xa2\x23\xa1\x00\xa2\x24\xa1\x00\xa2\x22\xa1\x00\xa2\x1a\xa1\x00\xa2\x23", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("8313 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa1\x00\xa2\x24\xa1\x00\xa2\x22\xa1\x00\xa2\x1a\xa1\x00\xa2\x23\xa1\x00\xa2\x24\xa1\x00\xa2\x22\xa1\x00\xa2\x1a\xa1\x00\xa2\x23\xa1\x00\xa2\x24\xa1\x00\xa2\x22\xa1\x00\xa2\x1a\xa1\x00\xa2\x23\xa1\x00\xa2\x24\xa1\x00\xa2\x22\xa1\x00\xa2\x1a\xa1\x00\xa2\x23", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("8314 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa1\x00\xa2\x24\xa1\x00\xa2\x22\xa1\x00\xa2\x1a\xa1\x00\xa2\x23\xa1\x00\xa2\x24\xa1\x00\xa2\x22\xa1\x00\xa2\x1a\xa1\x00\xa2\x23\xa1\x00\xa2\x24\xa1\x00\xa2\x22\xa1\x00\xa2\x1a\xa1\x00\xa2\x23\xa1\x00\xa2\x24\xa1\x00\xa2\x22\xa1\x00\xa2\x1a\xa1\x00\xa2\x23", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("8315 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8316 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x02\x5f\x02", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8317 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa0\x00\xa0\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8318 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8319 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x01\x5f\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8320 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x60\x08\x61\x0b\x62\x0e\x63\x11\x64\x14\x65\x17\x66\x02\x67\x05\x68\x08\x69\x50\x6a\x01\x6b\x0c\x6d\x48\x6e\x94\x6f\x0e\x70\x50\x71\xbe\x72\x0e\x73\xe8\x74\x96\x75\x0e\x76\xf0\x77\xc0\x78\x0e\x79\x48\x7a\x2b\x7b\x0e\x7c\x50\x7d\x55\x7e\x0e\x7f\xe8\x80\x2d", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("8321 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x81\x0e\x82\xf0\x83\x57\x84\x0e\x85\x48\x86\xfd\x87\x0e\x88\x50\x89\x3c\x8a\x0f\x8b\xe8\x8c\xff\x8d\x0e\x8e\xf0\x8f\x3e\x90\x0f\x9a\x00\x9b\x15\x9d\x04\x9e\x00\x9f\x00\xa0\x0e\xa1\x00\xa2\x69\xa3\x0e\xa4\x00\xa5\xd2\xa6\x0e\xa7\xff\xa8\x68\xa9\x0e\xaa\xff", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("8322 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xab\xd1\xac\x0e\xad\xff\xae\x3a\xaf\x0f\xb0\x4b\xb1\x01\xb9\x57\xba\x0a\xcd\x00\xce\x0f\xd4\x00\xd5\x8e\xd6\xe3\xd7\x38\xec\x00\xed\x00\xee\xc0\xef\x00\xf0\x00\xf1\x00\xf2\x00\xf3\x30\xf4\x38\xf5\x00\xf6\x01\xf7\x0a\xf8\xaa\xf9\x00\xfa\x55\xfb\x00\xfc\x69", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("8323 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xfd\x00\xfd\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8324 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8325 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x02\x5f\x02", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8326 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x60\x41\x61\x23\x62\x41\x63\x14\x64\x41\x65\x14\x66\x32\x67\x14\x68\x32\x69\x14\x6a\x32\x6b\x05\x6c\x32\x6d\x05\x6e\x32\x6f\x14\x70\x40\x71\x05\x72\x00\x73\x40\x74\x05\x75\x00\x76\x40\x77\x05\x78\x00\x79\x40\x7a\x05\x7b\x00\x7c\x80\x7d\x0a\x7e\x00\x7f\x80", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("8327 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x80\x0a\x81\x00\x82\x80\x83\x0a\x84\x00\x85\x80\x86\x0a\x87\x00\x88\xc0\x89\x0f\x8a\x00\x8b\xc0\x8c\x0f\x8d\x00\x8e\xc0\x8f\x0f\x90\x00\x91\xc0\x92\x0f\x93\x00\xb0\x00\xb1\x00\xb2\x00\xb3\x00\xb4\x00\xb5\x00\xb6\x00\xb7\x00\xb8\x00\xb9\x00\xba\x00\xbb\x00", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("8328 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xbc\x00\xbd\x00\xbe\x00\xbf\x00\xc0\x00\xc1\x00\xc2\x00\xc3\x00\xc4\x00\xc5\x00\xc6\x00\xc7\x00\xc8\x00\xc9\x00\xca\x00\xcb\x00\xcc\x00\xcd\x00\xce\x00\xcf\x00", 0x0000028);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000028, 1000);
printf("8329 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8330 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x01\x5f\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8331 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xb3\x00\xb4\x00\xb5\x00\xb6\x00\xb7\x01\xb8\x00", 0x000000c);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x000000c, 1000);
printf("8332 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8333 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x58\x01\x5e\x01\x82\x00\x83\x38\x84\x8e\x85\xe3\x8a\x03\x8e\x00\x90\x64\x91\x00\x94\x30\x95\xa7\x96\x25\x9b\x3d\x9d\x3f\x9e\x00\x9f\x40\xa0\x00\xa1\x00\xa2\x00\xa3\xff\xa4\xfe\xa5\x0d\xa6\x41\xab\x00\xae\xc3\xaf\x43\xb0\x08\xb1\x07\xb2\x14\xb3\x01\xb4\x7b", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("8334 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xb5\x00\xb6\x70\xb7\x05\xc9\x00\xca\x00\xcb\x03\xcc\x00\xcd\x3c\xce\x3c\xcf\x3c\xd0\x07\xd8\x05\xd9\x3c\xda\x54\xdb\x00\xdc\x01\xde\x01\xdf\x17\xe0\x2c\xe1\x01\xe2\x00\xe3\x00\xe4\x00\xe5\xc8\xe6\x00\xe7\x02\xe8\x00\xe9\x02\xea\x2c\xeb\x01\xec\x80\xed\x00", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("8335 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xee\x34\xef\x80\xf0\xb4\xf1\x71\xf2\x00\xf3\x0c\xf5\x10\xf6\x00\xf7\x03\xf8\x02\xf9\x0a\xfa\x37\xfb\x77\xfc\x00\xfd\x6c\xfe\x0b\xff\x40", 0x0000022);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000022, 1000);
printf("8336 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(148*1000);
memcpy(buf, "\xf8\x02\xf4\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8337 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(9*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8338 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8339 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8340 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8341 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(9*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8342 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8343 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8344 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8345 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(9*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8346 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8347 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8348 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8349 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(8*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8350 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8351 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8352 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8353 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(9*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8354 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8355 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8356 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8357 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(9*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8358 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8359 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8360 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8361 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(9*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8362 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8363 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8364 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8365 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(9*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8366 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8367 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8368 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8369 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(8*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8370 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8371 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8372 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8373 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(8*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8374 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8375 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8376 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8377 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(9*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8378 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8379 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8380 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(6*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8381 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(6*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8382 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8383 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8384 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(19*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8385 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(14*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8386 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8387 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8388 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8389 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(8*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8390 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8391 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8392 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(5*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8393 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(8*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8394 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8395 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8396 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8397 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(9*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8398 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8399 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8400 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8401 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(8*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8402 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8403 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8404 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8405 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(9*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8406 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8407 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8408 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8409 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(8*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8410 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8411 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8412 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8413 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8414 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8415 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8416 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8417 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(9*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8418 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8419 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8420 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(6*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8421 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(7*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8422 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8423 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8424 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8425 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(8*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8426 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8427 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8428 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8429 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(9*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8430 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8431 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8432 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8433 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(8*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8434 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8435 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8436 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8437 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(14*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8438 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8439 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8440 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8441 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(14*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8442 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8443 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8444 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8445 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(9*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8446 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8447 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8448 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8449 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(9*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8450 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8451 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8452 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8453 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(8*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8454 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8455 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8456 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8457 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(9*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8458 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8459 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8460 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8461 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(9*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8462 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8463 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8464 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8465 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(8*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8466 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8467 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8468 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8469 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(9*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8470 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8471 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8472 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8473 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(8*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8474 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8475 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8476 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8477 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(9*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8478 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8479 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8480 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8481 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(9*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8482 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8483 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8484 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8485 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(9*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8486 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8487 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8488 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8489 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8490 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8491 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8492 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8493 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(7*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8494 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8495 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8496 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8497 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(8*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8498 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8499 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8500 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8501 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(8*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8502 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8503 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8504 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8505 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(9*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8506 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8507 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8508 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8509 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8510 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8511 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8512 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8513 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(8*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8514 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8515 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8516 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8517 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(9*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8518 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8519 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8520 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8521 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(6*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8522 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8523 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8524 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8525 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(8*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8526 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8527 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8528 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8529 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(9*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8530 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8531 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8532 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8533 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(7*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8534 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8535 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8536 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8537 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(8*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8538 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8539 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8540 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8541 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(8*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8542 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8543 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8544 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8545 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(18*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8546 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8547 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8548 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8549 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(9*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8550 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8551 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8552 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8553 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(9*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8554 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8555 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8556 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8557 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(8*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8558 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8559 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8560 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8561 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(8*1000);
memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8562 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8563 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("8564 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("8565 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(25*1000);
memcpy(buf, "\x7c\x00\x7d\xbd\x7e\x03\x7f\x00", 0x0000008);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000008, 1000);
printf("8566 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(14*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8567 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(25*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8568 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(107*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8569 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8570 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8571 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8572 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8573 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8574 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(102*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8575 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(277*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8576 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(24*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8577 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(115*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8578 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8579 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8580 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8581 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8582 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(116*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8583 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(99*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8584 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(451*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8585 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(31*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8586 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8587 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(116*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8588 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(119*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8589 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8590 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8591 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8592 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(89*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8593 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(408*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8594 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(26*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8595 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(116*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8596 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(124*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8597 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8598 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(124*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8599 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(117*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8600 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8601 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(91*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8602 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(411*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8603 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(32*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8604 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8605 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(120*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8606 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8607 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8608 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(118*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8609 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(107*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8610 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(93*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8611 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(346*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8612 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(50*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8613 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(148*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8614 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8615 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(118*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8616 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(114*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8617 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(107*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8618 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(119*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8619 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(102*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8620 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(404*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8621 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(46*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8622 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(115*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8623 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(121*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8624 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(122*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8625 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(115*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8626 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8627 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(118*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8628 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(99*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8629 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(258*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8630 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(25*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8631 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(117*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8632 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(120*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8633 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(132*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8634 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(139*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8635 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(107*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8636 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(894*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8637 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(89*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8638 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(451*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8639 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(26*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8640 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8641 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8642 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8643 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8644 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(115*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8645 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(125*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8646 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(95*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8647 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(390*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8648 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(30*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8649 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8650 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8651 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8652 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(115*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8653 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(107*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8654 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8655 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(96*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8656 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(382*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8657 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(31*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8658 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(119*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8659 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(116*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8660 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(143*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8661 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(118*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8662 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(125*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8663 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8664 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(98*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8665 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(433*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8666 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(28*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8667 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8668 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(124*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8669 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(115*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8670 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8671 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(127*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8672 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(124*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8673 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(97*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8674 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(432*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8675 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(29*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8676 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(107*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8677 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(118*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8678 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(120*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8679 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(134*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8680 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8681 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(117*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8682 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(96*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8683 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(392*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8684 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(26*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8685 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(114*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8686 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(129*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8687 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8688 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8689 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(133*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8690 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(105*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8691 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(86*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8692 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(347*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8693 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(47*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8694 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(131*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8695 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(106*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8696 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(155*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8697 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8698 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(119*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8699 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(885*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8700 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(93*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8701 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(264*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8702 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(45*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8703 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(127*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8704 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(106*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8705 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(107*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8706 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(124*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8707 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8708 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(107*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8709 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(97*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8710 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(230*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8711 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(25*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8712 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(114*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8713 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8714 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8715 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(139*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8716 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8717 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8718 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(90*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8719 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(365*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8720 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(38*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8721 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(114*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8722 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(156*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8723 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(118*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8724 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(117*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8725 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(142*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8726 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(114*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8727 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(100*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8728 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(410*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8729 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(31*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8730 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8731 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(119*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8732 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8733 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(117*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8734 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(122*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8735 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(117*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8736 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(93*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8737 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(397*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8738 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(24*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8739 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(118*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8740 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8741 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8742 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(122*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8743 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8744 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(104*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8745 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(88*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8746 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(350*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8747 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(24*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8748 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8749 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8750 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(119*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8751 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(120*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8752 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(142*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8753 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8754 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(91*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8755 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(337*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8756 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(26*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8757 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(117*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8758 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(116*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8759 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8760 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(125*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8761 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8762 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8763 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(94*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8764 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(295*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8765 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(69*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8766 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8767 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(141*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8768 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(877*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8769 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(119*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8770 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(170*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8771 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(117*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8772 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(99*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8773 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(309*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8774 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(54*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8775 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(130*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8776 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8777 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8778 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8779 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8780 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(106*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8781 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(94*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8782 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(226*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8783 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(40*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8784 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(106*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8785 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(117*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8786 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(116*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8787 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8788 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(118*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8789 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8790 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(147*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8791 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(375*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8792 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(30*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8793 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(106*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8794 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(106*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8795 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8796 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8797 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(115*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8798 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(114*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8799 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(104*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8800 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(389*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8801 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(26*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8802 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8803 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8804 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8805 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(106*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8806 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(128*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8807 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(114*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8808 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(90*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8809 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(378*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8810 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(26*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8811 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(120*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8812 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8813 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8814 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8815 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(160*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8816 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(123*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8817 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(89*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8818 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(333*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8819 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(25*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8820 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(118*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8821 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(123*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8822 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8823 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8824 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8825 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(119*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8826 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(94*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8827 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(375*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8828 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(30*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8829 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8830 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(117*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8831 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(122*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8832 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(119*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8833 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(114*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8834 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(881*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8835 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(87*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8836 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(412*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8837 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(34*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8838 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(119*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8839 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8840 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(130*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8841 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(119*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8842 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(124*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8843 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8844 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(97*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8845 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(359*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8846 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(24*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8847 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(188*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8848 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(144*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8849 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(107*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8850 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8851 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8852 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8853 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(97*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8854 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(412*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8855 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(26*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8856 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(132*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8857 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(105*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8858 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(117*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8859 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8860 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(117*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8861 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(119*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8862 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(126*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8863 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(272*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8864 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(25*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8865 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8866 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8867 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(116*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8868 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(129*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8869 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8870 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(142*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8871 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(91*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8872 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(436*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8873 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(26*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8874 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(123*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8875 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(107*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8876 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(118*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8877 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(132*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8878 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8879 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8880 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(101*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8881 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(446*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8882 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(25*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8883 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8884 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(107*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8885 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8886 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8887 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8888 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(116*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8889 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(91*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8890 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(513*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8891 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(24*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8892 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8893 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8894 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8895 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8896 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8897 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(883*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8898 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(90*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8899 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(466*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8900 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(46*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8901 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8902 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8903 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(114*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8904 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(115*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8905 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(127*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8906 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8907 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(92*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8908 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(490*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8909 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(26*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8910 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8911 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(120*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8912 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8913 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8914 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(160*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8915 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(156*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8916 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(90*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8917 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(418*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8918 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8919 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8920 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8921 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(106*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8922 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8923 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(107*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8924 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8925 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(95*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8926 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(473*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8927 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(37*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8928 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8929 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(116*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8930 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8931 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8932 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8933 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(117*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8934 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(89*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8935 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(304*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8936 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(26*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8937 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(105*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8938 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8939 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(107*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8940 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8941 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(119*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8942 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8943 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(93*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8944 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(453*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8945 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(25*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8946 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(106*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8947 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(107*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8948 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8949 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8950 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(106*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8951 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8952 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(88*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8953 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(425*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8954 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(26*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8955 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8956 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8957 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(103*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8958 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(122*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8959 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(104*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8960 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(876*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8961 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(87*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8962 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(443*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8963 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(25*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8964 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(116*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8965 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(104*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8966 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(115*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8967 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(106*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8968 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8969 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(107*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8970 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(89*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8971 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(458*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8972 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(27*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8973 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(104*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8974 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(128*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8975 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(106*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8976 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8977 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(106*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8978 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8979 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(90*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8980 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(480*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8981 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(26*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8982 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8983 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8984 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(107*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8985 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(106*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8986 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(105*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8987 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(117*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8988 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(96*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8989 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(467*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8990 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(26*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8991 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8992 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8993 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(106*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8994 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(115*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8995 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(106*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8996 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(107*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("8997 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(92*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("8998 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(422*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("8999 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(25*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9000 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9001 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9002 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9003 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9004 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9005 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(106*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9006 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(90*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("9007 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(426*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("9008 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(28*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9009 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(118*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9010 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(106*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9011 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(123*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9012 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(106*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9013 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9014 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9015 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(89*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("9016 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(279*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("9017 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(27*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9018 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9019 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(107*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9020 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9021 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(106*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9022 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(106*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9023 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(875*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9024 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(90*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("9025 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(422*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("9026 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(32*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9027 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9028 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9029 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(116*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9030 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9031 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(107*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9032 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(107*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9033 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(90*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("9034 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(437*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("9035 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(26*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9036 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(103*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9037 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9038 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(107*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9039 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9040 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(107*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9041 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9042 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(90*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("9043 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(495*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("9044 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(25*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9045 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9046 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(103*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9047 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9048 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(106*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9049 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(117*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9050 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9051 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(93*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("9052 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(472*1000);
memcpy(buf, "\x7c\x70\x7d\x36\x7e\x03\x7f\x00", 0x0000008);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000008, 1000);
printf("9053 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(11*1000);
memcpy(buf, "\xe0\x6c\x06\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("9054 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(24*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9055 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(107*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9056 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9057 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(126*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9058 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9059 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("9060 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(93*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x00084c0, 3039);
printf("9061 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(36*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("9062 bulk read returned %d, bytes: ", ret);fwrite( buf, ret, 1, file );
print_bytes(buf, ret);
printf("\n");
usleep(968*1000);
memcpy(buf, "\xf4\x00\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("9063 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("9064 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("9065 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x02\xa0\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("9066 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(9*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("9067 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x01\xa0\x00\x04\x00\x00\x00\xfe\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("9068 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(23*1000);
memcpy(buf, "\x02\xa0\x05\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("9069 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(5*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("9070 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x01\xa0\x05\x01\x81\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("9071 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x02\xa0\x36\x02\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("9072 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(6*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("9073 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x01\xa0\x46\x02\x00\xc6\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("9074 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(23*1000);
memcpy(buf, "\x64\x64\x64\x64", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("9075 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x65\x65\x65\x65", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("9076 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x16\x16\x16\x16", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("9077 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x17\x17\x17\x17", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("9078 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x64\x64\x64\x64", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("9079 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x65\x65\x65\x65", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("9080 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x44\x44\x44\x44", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("9081 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x45\x45\x45\x45", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("9082 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x94\x31\x92\x57", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("9083 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(9*1000);
memcpy(buf, "\x8b\x0b\x8b\x0b", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("9084 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("9085 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x0a\x8b\x0a", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("9086 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("9087 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x09\x8b\x09", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("9088 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("9089 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(502*1000);
memcpy(buf, "\x8b\x00\x8b\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("9090 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("9091 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x96\x21\x96\x21", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("9092 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xf3\x22\xfd\xc4\xfe\x09\xa6\x41\xf6\x00\x96\x21\xe4\x01\xe2\x40\xe3\x1f\xe4\x00\x95\xa7\xf4\x01", 0x0000018);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000018, 1000);
printf("9093 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x00\x00\x86\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("9094 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x04\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("9095 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");

fclose(file);
{
#define BPL 7656 //2551*3

    FILE *file;
    file = fopen( "tmpfile.raw", "rb" );
    FILE *f;
    f = fopen( "img.pnm", "wb" );
    fputs( "P6\n2498 3510\n255\n", f );
    
    char b1[267*3],b2[323*3],b3[323*3],b4[323*3],b5[323*3],b6[324*3],b7[324*3],b8[291*3];
//    2552x3510
//    1-267 7 275-598 7 606-929 7 937-1260 7 1268-1591 7 1599-1923 6 1930-2254 5 2260-2551 
    int i = 0;
    
    do{
	fseek( file, BPL * i, 0 );
	fread( b1, 267 * 3 +  2, 1, file );
	fseek( file, BPL * i + 275 * 3, 0 );
	fread( b2, 323 * 3 + 2, 1, file );
	fseek( file, BPL * i + 606 * 3, 0 );
	fread( b3, 323 * 3 + 2, 1, file );
	fseek( file, BPL * i + 937 * 3, 0 );
	fread( b4, 323 * 3 + 2, 1, file );
	fseek( file, BPL * i + 1268 * 3, 0 );
	fread( b5, 323 * 3 + 2, 1, file );
	fseek( file, BPL * i + 1599 * 3, 0 );
	fread( b6, 324 * 3 + 2, 1, file );
	fseek( file, BPL * i + 1930 * 3, 0 );
	fread( b7, 324 * 3 + 2, 1, file );
	fseek( file, BPL * i + 2259 * 3, 0 );
	fread( b8, 291 * 3 + 2, 1, file );
	
	fwrite( b8, 291 * 3, 1, f );
	fwrite( b7, 324 * 3, 1, f );
	fwrite( b6, 324 * 3, 1, f );
	fwrite( b5, 323 * 3, 1, f );
	fwrite( b4, 323 * 3, 1, f );
	fwrite( b3, 323 * 3, 1, f );
	fwrite( b2, 323 * 3, 1, f );
	fwrite( b1, 267 * 3, 1, f );
	i++;
    }while( i < 3510 );
    fclose(f);fclose(file);
}

//rawtoppm 2498 3510 img.raw > 2.pnm
	
	ret = usb_release_interface(devh, 0);
	assert(ret == 0);
	ret = usb_close(devh);
	assert(ret == 0);
	return 0;
}
